<?php

/**
 * Custom template parts for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package crisop
*/


/*************************************************
##  LOGO
*************************************************/


if ( ! function_exists( 'ninetheme_logo' ) ) {
    function ninetheme_logo( $mobile=false )
    {
        $logo          = ninetheme_settings( 'logo_type', 'sitename' );
        $mainlogo      = '' != ninetheme_settings( 'img_logo' ) ? ninetheme_settings( 'img_logo' )[ 'url' ] : '';
        $stickylogo    = '' != ninetheme_settings( 'sticky_logo' ) ? ninetheme_settings( 'sticky_logo' )[ 'url' ] : '';
        $mobilelogo    = $mobile == true && '' != ninetheme_settings( 'minibar_logo' ) ? ninetheme_settings( 'minibar_logo' )[ 'url' ] : '';
        $hasstickylogo = '' != $stickylogo ? ' has-sticky-logo': '';
        $type          = true == $mobile ? 'nav-logo logo-type-'.$logo : 'logo logo-type-'.$logo;

        if ( is_page() ) {
            $page_logo  = ninetheme_page_settings( 'ninetheme_page_header_logo' );
            $mainlogo   = !empty( $page_logo['url'] ) ? $page_logo['url'] : $mainlogo;
            $logo       = !empty( $page_logo['url'] ) ? 'img' : $logo;
            $page_slogo = ninetheme_page_settings( 'ninetheme_page_header_sticky_logo' );
            $stickylogo = !empty( $page_slogo['url'] ) ? $page_slogo['url'] : $stickylogo;
            $hasstickylogo = !empty( $page_slogo['url'] ) ? ' has-sticky-logo': $hasstickylogo;
        }

        if ( '0' != ninetheme_settings( 'logo_visibility', '1' ) ) {
            ?>
            <div class="<?php echo esc_attr( $type ); ?>">
                <a href="<?php echo esc_url( home_url( '/' ) ); ?>" aria-label="logo image" class="nt-logo header-logo logo-type-<?php echo esc_attr( $logo.$hasstickylogo ); ?>">

                    <?php if ( 'img' == $logo && '' != $mainlogo ) { ?>

                        <?php if ( true == $mobile && $mobilelogo ) { ?>

                            <img class="mobile-menu-logo" src="<?php echo esc_url( $mobilelogo ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">

                        <?php } else { ?>

                            <?php if ( $mainlogo ) { ?>

                                <img class="main-logo" src="<?php echo esc_url( $mainlogo ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">

                                <?php if ( '' != $stickylogo ) { ?>

                                    <img class="main-logo sticky-logo" src="<?php echo esc_url( $stickylogo ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">

                                <?php } ?>

                            <?php } ?>

                        <?php } ?>

                    <?php } elseif ( 'sitename' == $logo ) { ?>

                        <span class="header-text-logo"><?php bloginfo( 'name' ); ?></span>

                    <?php } elseif ( 'customtext' == $logo ) { ?>

                        <span class="header-text-logo"><?php echo ninetheme_settings( 'text_logo' ); ?></span>

                    <?php } else { ?>

                        <span class="header-text-logo"> <?php bloginfo( 'name' ); ?> </span>

                    <?php } ?>
                </a>
            </div>
            <?php
        }
    }
}


if ( ! class_exists( 'Ninetheme_Header' ) ) {
    class Ninetheme_Header
    {
        private static $instance = null;
        public static $location  = 'header_menu';
        public static $menu      = '';

        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }

        function __construct()
        {
            add_action( 'ninetheme_theme_header_layouts', [ $this, 'header_all_layouts' ] );
            add_action( 'ninetheme_theme_mobile_header', [ $this, 'mobile_header' ] );
            add_action( 'ninetheme_theme_header_mobile_sidebar', [ $this, 'mobile_sidebar_menu' ] );
            add_action( 'ninetheme_theme_header_elementor', [ $this, 'header_elementor' ] );
            add_action( 'ninetheme_header_action', [ $this, 'main_header' ] );
            add_action( 'ninetheme_mobile_menu_bottom', [ $this, 'sidebar_menu_copyright' ] );
            add_action( 'ninetheme_before_wp_footer', [ $this, 'my_account_form_popup_template' ] );
        }

        public static function check_layout_manager( $layouts, $item )
        {
            if ( is_array( $layouts ) ) {
                unset( $layouts['show']['placebo'] );
                return isset( $layouts['show'][$item] ) ? true : false;
            }
            return false;
        }

        public static function get_nav_menu( $location, $menu )
        {
            self::$location = $location;
            self::$menu = $menu;
            return wp_nav_menu(
                array(
                    'menu' => self::$menu,
                    'theme_location' => self::$location,
                    'container' => '',
                    'container_class' => '',
                    'container_id' => '',
                    'menu_class' => '',
                    'menu_id' => '',
                    'items_wrap' => '%3$s',
                    'before' => '',
                    'after' => '',
                    'link_before' => '',
                    'link_after' => '',
                    'depth' => 4,
                    'echo' => true,
                    'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                    'walker' => new \Ninetheme_Wp_Bootstrap_Navwalker()
                )
            );
        }

        public static function get_sidebar_nav_menu( $location = '' )
        {
            $location = $location && has_nav_menu( $location ) ? $location : 'header_menu';
            return wp_nav_menu(
                array(
                    'menu' => '',
                    'theme_location' => $location,
                    'container' => '',
                    'container_class' => '',
                    'container_id' => '',
                    'menu_class' => '',
                    'menu_id' => '',
                    'items_wrap' => '%3$s',
                    'before' => '',
                    'after' => '',
                    'link_before' => '',
                    'link_after' => '',
                    'depth' => 4,
                    'echo' => true,
                    'fallback_cb' => 'Ninetheme_Sliding_Navwalker::fallback',
                    'walker' => new \Ninetheme_Sliding_Navwalker()
                )
            );
        }

        public static function header_menu()
        {
            ?>
            <div class="ninetheme-header-top-menu-area">
                <ul class="navigation primary-menu">
                    <?php echo self::get_nav_menu( self::$location, self::$menu ); ?>
                </ul>
            </div>
            <?php
        }

        public static function header_mini_menu( $location = '' )
        {
            $html = '';
            if ( has_nav_menu( $location ) ) {
                $mini_menu = wp_nav_menu(
                    array(
                        'menu' => '',
                        'theme_location' => $location,
                        'container' => '',
                        'container_class' => '',
                        'container_id' => '',
                        'menu_class' => '',
                        'menu_id' => '',
                        'items_wrap' => '%3$s',
                        'before' => '',
                        'after' => '',
                        'link_before' => '',
                        'link_after' => '',
                        'depth' => 1,
                        'echo' => false,
                        'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                        'walker' => new \Ninetheme_Wp_Bootstrap_Navwalker()
                    )
                );
                $html .= '<div class="ninetheme-header-top-mini-menu-inline">';
                    $html .= '<ul class="navigation-mini-inline">'.$mini_menu.'</ul>';
                $html .= '</div>';
            }
            echo apply_filters( 'ninetheme_header_topbar_mini_menu', $html );
        }

        public static function menu_center_logo()
        {
            $menu      = apply_filters('ninetheme_menu_left', '' );
            $menu2     = apply_filters('ninetheme_menu_right', '' );
            $location  = apply_filters('ninetheme_menu_left', 'left_menu' );
            $location2 = apply_filters('ninetheme_menu_right', 'rigt_menu' );
            ?>
            <div class="ninetheme-header-top-menu-area nav-logo-center ninetheme-flex ninetheme-align-center ninetheme-justify-center">
                <ul class="navigation primary-menu left-menu ninetheme-flex-right">
                    <?php echo self::get_nav_menu( $location, $menu )?>
                </ul>
                <div class="center-logo-wrapper flex-center-items">
                    <?php ninetheme_logo(false); ?>
                </div>
                <ul class="navigation primary-menu right-menu ninetheme-flex-left">
                    <?php echo self::get_nav_menu( $location2, $menu2 )?>
                </ul>
            </div>
            <?php
        }

        public static function header_buttons_layouts( $layout = array() )
        {
            $layouts = [
                'show' => [
                    'cart' => '',
                    'wishlist' => '',
                    'compare' => '',
                    'account' => ''
                ]
            ];
            $layouts = is_array( $layout ) && !empty( $layout ) ? $layout : ninetheme_settings( 'header_buttons_layouts', $layouts );

            $counter_attr  = 'counter-'.ninetheme_settings( 'header_buttons_counter_position', 'right' );
            $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_bgcolor_type', 'primary' );
            $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_radius_type', 'radius' );
            $layouts = apply_filters( 'header_buttons_layouts', $layouts );
            $html = $html_out = '';
            $cart      = esc_html__('Cart','crisop');
            $compare   = esc_html__('Compare','crisop');
            $wishlist  = esc_html__('Wishlist','crisop');
            $account   = esc_html__('Account','crisop');
            if ( $layouts ) {
                unset( $layouts['show']['placebo'] );
                foreach ( $layouts['show'] as $key => $value ) {

                    switch ( $key ) {
                        case 'search':
                        $html .= '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                        break;

                        case 'cart':
                        if ( ninetheme_is_woocommerce() ) {
                            $html .= '<div class="top-action-btn" data-name="cart">'.ninetheme_svg_lists( 'bag', 'ninetheme-svg-icon' ).'<span class="ninetheme-cart-count ninetheme-wc-count">'.WC()->cart->get_cart_contents_count().'</span><span class="top-action-btn-text">'.$cart.'</span></div>';
                        }
                        break;

                        case 'wishlist':
                        if ( ninetheme_is_woocommerce() && class_exists( 'WPCleverWoosw' ) ) {
                            $html .= '<div class="top-action-btn has-custom-action open-wishlist-btn"><div class="woosw-menu-item ninetheme-hidden"><span class="woosw-menu-item-inner"></span></div>'.ninetheme_svg_lists( 'love', 'ninetheme-svg-icon' ).'<span class="ninetheme-wishlist-count ninetheme-wc-count"></span><span class="top-action-btn-text">'.$wishlist.'</span></div>';
                        }
                        break;

                        case 'compare':
                        if ( ninetheme_is_woocommerce() && class_exists( 'WPCleverWoosc' ) ) {
                            $html .= '<div class="top-action-btn has-custom-action open-compare-btn">'.ninetheme_svg_lists( 'compare', 'ninetheme-svg-icon' ).'<span class="ninetheme-compare-count ninetheme-wc-count"></span><span class="top-action-btn-text">'.$compare.'</span></div>';
                        }
                        break;

                        case 'account':
                        if ( ninetheme_is_woocommerce() ) {
                            $account_url = apply_filters('ninetheme_myaccount_page_url', wc_get_page_permalink( 'myaccount' ) );
                            $action_type = !is_account_page() ? ninetheme_settings( 'header_myaccount_action_type', 'open-in-popup' ) : 'open-in-popup';
                            $account_url = 'open-in-popup' == $action_type && !is_account_page() ? '#ninetheme-account-popup' : esc_url( $account_url );
                            if ( 'open-in-popup' == $action_type ) {
                                $action_link = '<a class="account-page-link ninetheme-open-popup" href="'.$account_url.'">';
                            } elseif ( 'account-page' == $action_type ) {
                                $action_link = '<a class="account-page-link" href="'.$account_url.'">';
                            } else {
                                $action_link = '<a class="account-page-link" href="#0" data-account-action="account">';
                            }
                            $html .= '<div class="top-action-btn">'.$action_link.ninetheme_svg_lists( 'user-1', 'ninetheme-svg-icon' ).'<span class="top-action-btn-text">'.$account.'</span></a></div>';
                        }
                        break;
                    }
                }
                $html_out = '<div class="header-top-buttons '.$counter_attr.'">'.$html.'</div>';
            }
            echo apply_filters('ninetheme_header_buttons_html', $html_out );
        }

        public static function mobile_buttons_layouts()
        {
            $layouts = ninetheme_settings( 'mobile_header_buttons_layouts' );
            $layouts = apply_filters( 'ninetheme_mobile_header_buttons_layouts', $layouts );

            if ( $layouts ) {
                unset( $layouts['show']['placebo'] );

                foreach ( $layouts['show'] as $key => $value ) {

                    switch ( $key ) {
                        case 'search':
                        echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                        break;

                        case 'cart':
                        if ( ninetheme_is_woocommerce() ) {
                            echo '<div class="top-action-btn" data-name="cart">'.ninetheme_svg_lists( 'bag', 'ninetheme-svg-icon' ).'<span class="ninetheme-cart-count ninetheme-wc-count">'.WC()->cart->get_cart_contents_count().'</span></div>';
                        }
                        break;

                        case 'account':
                        if ( ninetheme_is_woocommerce() ) {
                            $account_url = apply_filters('ninetheme_myaccount_page_url', wc_get_page_permalink( 'myaccount' ) );
                            echo '<div class="top-action-btn"><a class="account-page-link" href="'.esc_url( $account_url ).'">'.ninetheme_svg_lists( 'user-1', 'ninetheme-svg-icon' ).'</a></div>';
                        }
                        break;
                    }
                }
            }
        }

        public static function sidebar_buttons_layouts()
        {
            $layouts   = ninetheme_settings( 'sidebar_menu_buttons_layouts' );
            $layouts   = apply_filters( 'ninetheme_sidebar_buttons_layouts', $layouts );
            $cat_count = self::get_categories_count();

            if ( $layouts ) {
                unset( $layouts['show']['placebo'] );

                foreach ( $layouts['show'] as $key => $value ) {

                    switch ( $key ) {
                        case 'search':
                        echo '<div class="top-action-btn" data-name="search-cats"><span class="ninetheme-category-count ninetheme-wc-count">'.$cat_count.'</span>'.ninetheme_svg_lists( 'paper-search', 'ninetheme-svg-icon' ).'</div>';
                        break;

                        case 'contact':
                        $cf7_form = ninetheme_settings('sidebar_menu_cf7') ? '[contact-form-7 id="'.ninetheme_settings('sidebar_menu_cf7').'"]' : '';
                        $form     = ninetheme_settings('sidebar_menu_custom_form') ? ninetheme_settings('sidebar_menu_custom_form') : $cf7_form;
                        if ( $form ) {
                            echo '<div class="top-action-btn" data-name="contact">'.ninetheme_svg_lists( 'contact-form', 'ninetheme-svg-icon' ).'</div>';
                        }
                        break;

                        case 'cart':
                        if ( ninetheme_is_woocommerce() ) {
                            echo '<div class="top-action-btn" data-name="cart"><span class="ninetheme-cart-count ninetheme-wc-count">'.WC()->cart->get_cart_contents_count().'</span>'.ninetheme_svg_lists( 'bag', 'ninetheme-svg-icon' ).'</div>';
                        }
                        break;

                        case 'wishlist':
                        if ( ninetheme_is_woocommerce() && class_exists( 'WPCleverWoosw' ) ) {
                            echo '<div class="top-action-btn has-custom-action open-wishlist-btn"><div class="woosw-menu-item ninetheme-hidden"><span class="woosw-menu-item-inner"></span></div><span class="ninetheme-wishlist-count ninetheme-wc-count"></span>'.ninetheme_svg_lists( 'love', 'ninetheme-svg-icon' ).'</div>';
                        }
                        break;

                        case 'compare':
                        if ( ninetheme_is_woocommerce()  && class_exists( 'WPCleverWoosc' ) ) {
                            echo '<div class="top-action-btn has-custom-action"><a class="open-compare-btn" href="#0"></a><span class="ninetheme-compare-count ninetheme-wc-count"></span>'.ninetheme_svg_lists( 'compare', 'ninetheme-svg-icon' ).'</div>';
                        }
                        break;

                        case 'account':
                        if ( ninetheme_is_woocommerce() ) {
                            $action_type = ninetheme_settings( 'header_myaccount_action_type', 'open-in-popup' );
                            if ( 'open-in-popup' == $action_type ) {
                                echo '<a class="top-action-btn popup" href="#ninetheme-account-popup">'.ninetheme_svg_lists( 'user-1', 'ninetheme-svg-icon' ).'</a>';
                            } else {
                                echo '<div class="top-action-btn" data-name="account">'.ninetheme_svg_lists( 'user-1', 'ninetheme-svg-icon' ).'</div>';
                            }
                        }
                        break;

                        case 'location':
                        echo '<div class="top-action-btn location" data-name="location">'.ninetheme_svg_lists( 'location', 'ninetheme-svg-icon' ).'</div>';
                        break;
                    }
                }
            }
        }

        public static function header_top_layouts()
        {
            $layouts     = ninetheme_settings( 'header_top_layouts' );
            $mobile      = '0' == ninetheme_settings( 'header_top_mobile_visibility', '0' ) ? ' hide-on-mobile' : '';
            $layouts     = apply_filters( 'ninetheme_header_top_layouts', $layouts );
            $custom_html = ninetheme_settings( 'header_top_custom_html', '' );

            if ( $layouts ) {

                unset( $layouts['left']['placebo'] );
                unset( $layouts['center']['placebo'] );
                unset( $layouts['right']['placebo'] );

                echo '<div class="ninetheme-header-default-topbar ninetheme-header-row'.$mobile.'">';
                    echo '<div class="container-xl ninetheme-container-xl">';
                        if ( !empty( $layouts['left'] ) ) {

                            echo '<div class="ninetheme-header-top-left">';
                                echo '<div class="ninetheme-header-default-inner">';
                                    foreach ( $layouts['left'] as $key => $value ) {

                                        switch( $key ) {
                                            case 'mini-menu1': self::header_mini_menu('header_topbar_menu1');
                                            break;

                                            case 'mini-menu2': self::header_mini_menu('header_topbar_menu2');
                                            break;

                                            case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                            break;

                                            case 'discount': self::wc_header_products();
                                            break;

                                            case 'lang-switcher': self::lang_switcher();
                                            break;

                                            case 'currency-switcher': shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                            break;

                                            case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_top_socials', '' ).'</div>';
                                            break;

                                            case 'custom-html': echo ninetheme_settings( 'header_top_custom_html', '' );
                                            break;
                                        }
                                    }
                                echo '</div>';
                            echo '</div>';
                        }
                        if ( !empty( $layouts['center'] ) ) {
                            echo '<div class="ninetheme-header-top-center">';
                                echo '<div class="ninetheme-header-default-inner">';
                                    foreach ( $layouts['center'] as $key => $value ) {

                                        switch( $key ) {
                                            case 'mini-menu1': self::header_mini_menu('header_topbar_menu1');
                                            break;

                                            case 'mini-menu2': self::header_mini_menu('header_topbar_menu2');
                                            break;

                                            case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                            break;

                                            case 'discount': self::wc_header_products();
                                            break;

                                            case 'lang-switcher': self::lang_switcher();
                                            break;

                                            case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                            break;

                                            case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_top_socials', '' ).'</div>';
                                            break;

                                            case 'custom-html': echo ninetheme_settings( 'header_top_custom_html', '' );
                                            break;
                                        }
                                    }
                                echo '</div>';
                            echo '</div>';
                        }
                        if ( !empty( $layouts['right'] ) ) {
                            echo '<div class="ninetheme-header-top-right">';
                                echo '<div class="ninetheme-header-default-inner">';
                                    foreach ( $layouts['right'] as $key => $value ) {

                                        switch( $key ) {
                                            case 'mini-menu1': self::header_mini_menu('header_topbar_menu1');
                                            break;

                                            case 'mini-menu2': self::header_mini_menu('header_topbar_menu2');
                                            break;

                                            case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                            break;

                                            case 'discount': self::wc_header_products();
                                            break;

                                            case 'lang-switcher': self::lang_switcher();
                                            break;

                                            case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                            break;

                                            case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_top_socials', '' ).'</div>';
                                            break;

                                            case 'custom-html': echo ninetheme_settings( 'header_top_custom_html', '' );
                                            break;
                                        }
                                    }
                                echo '</div>';
                            echo '</div>';
                        }
                    echo '</div>';
                echo '</div>';
            }
        }

        public static function header_center_layouts()
        {
            $layouts = [
                'left' => [
                    'logo' => '',
                    'sidemenu' => ''
                ],
                'right' => [
                    'search-form' => ''
                ]
            ];
            $layouts = ninetheme_settings( 'header_center_layouts', $layouts );
            $search_type = ninetheme_settings('ajax_search_type');
            $search_shortcode = ninetheme_settings('ajax_search_custom_shortcode');
            if ( $layouts ) {

                unset( $layouts['left']['placebo'] );
                unset( $layouts['center']['placebo'] );
                unset( $layouts['right']['placebo'] );

                echo '<div class="ninetheme-header-default-center ninetheme-header-content ninetheme-header-row">';
                    echo '<div class="container-xl ninetheme-container-xl">';
                        if ( !empty( $layouts['left'] ) ) {

                            echo '<div class="ninetheme-header-top-left header-top-side">';
                                echo '<div class="ninetheme-header-default-inner">';
                                    foreach ( $layouts['left'] as $key => $value ) {

                                        switch( $key ) {
                                            case 'logo': ninetheme_logo();
                                            break;

                                            case 'search-icon': echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                            break;

                                            case 'search-form':
                                                if ( 'plugin' == $search_type && $search_shortcode ) {
                                                    echo do_shortcode( $search_shortcode );
                                                } else {
                                                    if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                                                        echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                                                    } else {
                                                        ninetheme_ajax_search_form( 'inline' );
                                                    }
                                                }
                                            break;

                                            case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                            break;

                                            case 'discount': self::wc_header_products();
                                            break;

                                            case 'lang-switcher': self::lang_switcher();
                                            break;

                                            case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                            break;

                                            case 'sidemenu': echo '<div class="mobile-toggle">'.ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ).'</div>';
                                            break;

                                            case 'cats-menu': self::wc_cats_menu();
                                            break;

                                            case 'menu': self::header_menu();
                                            break;

                                            case 'custom-html': echo ninetheme_settings( 'header_center_custom_html', '' );
                                            break;

                                            case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_center_socials', '' ).'</div>';
                                            break;

                                            case 'buttons': self::header_buttons_layouts();
                                            break;
                                        }
                                    }
                                    do_action( 'ninetheme_theme_header_left' );
                                echo '</div>';
                            echo '</div>';
                        }
                        if ( !empty( $layouts['center'] ) ) {
                            echo '<div class="ninetheme-header-top-center">';
                                echo '<div class="ninetheme-header-default-inner">';
                                    foreach ( $layouts['center'] as $key => $value ) {

                                        switch( $key ) {
                                            case 'logo': ninetheme_logo();
                                            break;

                                            case 'search-icon': echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                            break;

                                            case 'search-form':
                                                if ( 'plugin' == $search_type && $search_shortcode ) {
                                                    echo do_shortcode( $search_shortcode );
                                                } else {
                                                    if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                                                        echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                                                    } else {
                                                        ninetheme_ajax_search_form( 'inline' );
                                                    }
                                                }
                                            break;

                                            case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                            break;

                                            case 'discount': self::wc_header_products();
                                            break;

                                            case 'lang-switcher': self::lang_switcher();
                                            break;

                                            case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                            break;

                                            case 'sidemenu': echo '<div class="mobile-toggle">'.ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ).'</div>';
                                            break;

                                            case 'menu': self::header_menu();
                                            break;

                                            case 'custom-html': echo ninetheme_settings( 'header_center_custom_html', '' );
                                            break;

                                            case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_center_socials', '' ).'</div>';
                                            break;

                                            case 'buttons': self::header_buttons_layouts();
                                            break;
                                        }
                                    }
                                    do_action( 'ninetheme_theme_header_center' );
                                echo '</div>';
                            echo '</div>';
                        }
                        if ( !empty( $layouts['right'] ) ) {
                            echo '<div class="ninetheme-header-top-right header-top-side">';
                                echo '<div class="ninetheme-header-default-inner">';
                                    foreach ( $layouts['right'] as $key => $value ) {

                                        switch( $key ) {
                                            case 'logo': ninetheme_logo();
                                            break;

                                            case 'search-icon': echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                            break;

                                            case 'search-form':
                                                if ( 'plugin' == $search_type && $search_shortcode ) {
                                                    echo do_shortcode( $search_shortcode );
                                                } else {
                                                    if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                                                        echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                                                    } else {
                                                        ninetheme_ajax_search_form( 'inline' );
                                                    }
                                                }
                                            break;

                                            case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                            break;

                                            case 'discount': self::wc_header_products();
                                            break;

                                            case 'sidemenu': echo '<div class="mobile-toggle">'.ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ).'</div>';
                                            break;

                                            case 'lang-switcher': self::lang_switcher();
                                            break;

                                            case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                            break;

                                            case 'menu': self::header_menu();
                                            break;

                                            case 'cats-menu': self::wc_cats_menu();
                                            break;

                                            case 'custom-html': echo ninetheme_settings( 'header_center_custom_html', '' );
                                            break;

                                            case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_center_socials', '' ).'</div>';
                                            break;

                                            case 'buttons': self::header_buttons_layouts();
                                            break;
                                        }
                                    }
                                    do_action( 'ninetheme_theme_header_right' );
                                echo '</div>';
                            echo '</div>';
                        }
                    echo '</div>';
                echo '</div>';
            }
        }

        public static function header_bottom_layouts()
        {
            $layouts = [
                'left' => [
                    'cats-menu' => '',
                    'menu' => ''
                ],
                'right' => [
                    'custom-html' => '',
                    'discount' => ''
                ]
            ];

            $layouts = ninetheme_settings( 'header_bottom_layouts', $layouts );
            $search_type = ninetheme_settings('ajax_search_type');
            $search_shortcode = ninetheme_settings('ajax_search_custom_shortcode');
            if ( $layouts ) {

                unset( $layouts['left']['placebo'] );
                unset( $layouts['center']['placebo'] );
                unset( $layouts['right']['placebo'] );
                $is_sticky = '1' == ninetheme_settings( 'header_sticky_visibility', '1' ) ? ' ninetheme-header-sticky' : '';
                $is_boxed  = apply_filters('ninetheme_header_bottom_boxed', ninetheme_settings( 'header_bottom_boxed', '1' ) );

                echo '<div class="ninetheme-header-default-bottom ninetheme-header-row">';
                    echo '<div class="ninetheme-header-default-bottom-sticky'.$is_sticky.'">';
                        echo '<div class="container-xl ninetheme-container-xl">';
                            if ( !empty( $layouts['left'] ) ) {

                                echo '<div class="ninetheme-header-top-left">';
                                    echo '<div class="ninetheme-header-default-inner">';
                                        foreach ( $layouts['left'] as $key => $value ) {

                                            switch( $key ) {
                                                case 'logo': ninetheme_logo();
                                                break;

                                                case 'search-icon': echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                                break;

                                                case 'search-form':
                                                    if ( 'plugin' == $search_type && $search_shortcode ) {
                                                        echo do_shortcode( $search_shortcode );
                                                    } else {
                                                        if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                                                            echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                                                        } else {
                                                            ninetheme_ajax_search_form( 'inline' );
                                                        }
                                                    }
                                                break;

                                                case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                                break;

                                                case 'discount': self::wc_header_products();
                                                break;

                                                case 'sidemenu': echo '<div class="mobile-toggle">'.ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ).'</div>';
                                                break;

                                                case 'menu': self::header_menu();
                                                break;

                                                case 'cats-menu': self::wc_cats_menu();
                                                break;

                                                case 'buttons': self::header_buttons_layouts();
                                                break;

                                                case 'mini-menu1': header_mini_menu('header_topbar_menu1');
                                                break;

                                                case 'mini-menu2': self::header_mini_menu('header_topbar_menu2');
                                                break;

                                                case 'lang-switcher': self::lang_switcher();
                                                break;

                                                case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                                break;

                                                case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_bottom_socials', '' ).'</div>';
                                                break;

                                                case 'custom-html':
                                                if ( ninetheme_settings( 'header_bottom_custom_html', '' ) ) {
                                                    echo ninetheme_settings( 'header_bottom_custom_html', '' );
                                                } else {
                                                    echo '<a class="header-phone-number" href="tel:2809003434"><i aria-hidden="true" class="ninetheme-icons flaticon-24-hours-support"></i><span><span class="phone-text">Call Anytime</span><span class="phone-number">280 900 3434</span></span></a>';
                                                }
                                                break;
                                            }
                                        }
                                    echo '</div>';
                                echo '</div>';
                            }
                            if ( !empty( $layouts['center'] ) ) {
                                echo '<div class="ninetheme-header-top-center">';
                                    echo '<div class="ninetheme-header-default-inner">';
                                        foreach ( $layouts['center'] as $key => $value ) {

                                            switch( $key ) {
                                                case 'logo': ninetheme_logo();
                                                break;

                                                case 'search-icon': echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                                break;

                                                case 'search-form':
                                                    if ( 'plugin' == $search_type && $search_shortcode ) {
                                                        echo do_shortcode( $search_shortcode );
                                                    } else {
                                                        if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                                                            echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                                                        } else {
                                                            ninetheme_ajax_search_form( 'inline' );
                                                        }
                                                    }
                                                break;

                                                case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                                break;

                                                case 'discount': self::wc_header_products();
                                                break;

                                                case 'sidemenu': echo '<div class="mobile-toggle">'.ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ).'</div>';
                                                break;

                                                case 'menu': self::header_menu();
                                                break;

                                                case 'cats-menu': self::wc_cats_menu();
                                                break;

                                                case 'buttons': self::header_buttons_layouts();
                                                break;

                                                case 'mini-menu1': header_mini_menu('header_topbar_menu1');
                                                break;

                                                case 'mini-menu2': self::header_mini_menu('header_topbar_menu2');
                                                break;

                                                case 'lang-switcher': self::lang_switcher();
                                                break;

                                                case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                                break;

                                                case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_bottom_socials', '' ).'</div>';
                                                break;

                                                case 'custom-html':
                                                if ( ninetheme_settings( 'header_bottom_custom_html', '' ) ) {
                                                    echo ninetheme_settings( 'header_bottom_custom_html', '' );
                                                } else {
                                                    echo '<a class="header-phone-number" href="tel:2809003434"><i aria-hidden="true" class="ninetheme-icons flaticon-24-hours-support"></i><span><span class="phone-text">Call Anytime</span><span class="phone-number">280 900 3434</span></span></a>';
                                                }
                                                break;
                                            }
                                        }
                                    echo '</div>';
                                echo '</div>';
                            }
                            if ( !empty( $layouts['right'] ) ) {
                                echo '<div class="ninetheme-header-top-right">';
                                    echo '<div class="ninetheme-header-default-inner">';
                                        foreach ( $layouts['right'] as $key => $value ) {

                                            switch( $key ) {
                                                case 'logo': ninetheme_logo();
                                                break;

                                                case 'search-icon': echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                                break;

                                                case 'search-form':
                                                    if ( 'plugin' == $search_type && $search_shortcode ) {
                                                        echo do_shortcode( $search_shortcode );
                                                    } else {
                                                        if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                                                            echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                                                        } else {
                                                            ninetheme_ajax_search_form( 'inline' );
                                                        }
                                                    }
                                                break;

                                                case 'location': echo shortcode_exists( 'ninetheme_location' ) ? do_shortcode( '[ninetheme_location]' ) : '';
                                                break;

                                                case 'discount': self::wc_header_products();
                                                break;

                                                case 'sidemenu': echo '<div class="mobile-toggle">'.ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ).'</div>';
                                                break;

                                                case 'menu': self::header_menu();
                                                break;

                                                case 'cats-menu': self::wc_cats_menu();
                                                break;

                                                case 'buttons': self::header_buttons_layouts();
                                                break;

                                                case 'mini-menu1': header_mini_menu('header_topbar_menu1');
                                                break;

                                                case 'mini-menu2': self::header_mini_menu('header_topbar_menu2');
                                                break;

                                                case 'lang-switcher': self::lang_switcher();
                                                break;

                                                case 'currency-switcher': echo shortcode_exists( 'woocs_price' ) ? do_shortcode( '[woocs_price]' ) : '';
                                                break;

                                                case 'socials': echo '<div class="ninetheme-header-socials">'.ninetheme_settings( 'header_bottom_socials', '' ).'</div>';
                                                break;

                                                case 'custom-html':
                                                if ( ninetheme_settings( 'header_bottom_custom_html', '' ) ) {
                                                    echo ninetheme_settings( 'header_bottom_custom_html', '' );
                                                } else {
                                                    echo '<a class="header-phone-number" href="tel:2809003434"><i aria-hidden="true" class="ninetheme-icons flaticon-24-hours-support"></i><span><span class="phone-text">Call Anytime</span><span class="phone-number">280 900 3434</span></span></a>';
                                                }
                                                break;
                                            }
                                        }
                                    echo '</div>';
                                echo '</div>';
                            }
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            }
        }

        public static function header_all_layouts()
        {
            if ( '1' == ninetheme_settings( 'header_visibility', '0' ) && 'default' == ninetheme_settings( 'header_template', 'default' ) ) {
                $header_w      = apply_filters( 'ninetheme_header_width', ninetheme_settings( 'header_width', 'default' ) );
                $page_header_w = ninetheme_page_settings( 'ninetheme_page_header_width' );
                $header_w      = $page_header_w ? $page_header_w : $header_w;
                $breakpoint    = ninetheme_settings( 'mobile_header_breakpoint', 1280 );
                $breakpoint    = ninetheme_settings( 'disable_desktop_header_on_mobile', 0 );

                if ( 'off' == ninetheme_settings( 'disable_desktop_header_on_mobile', 0 ) && wp_is_mobile() ) {
                    return;
                }
                echo '<header class="ninetheme-header-default header-width-'.$header_w.'" data-breakpoint="'.$breakpoint.'">';
                    self::header_top_layouts();
                    self::header_center_layouts();
                    self::header_bottom_layouts();
                echo '</header>';
            }
        }

        public static function header_bottom_bar()
        {
            if ( '1' == ninetheme_settings( 'header_bottom_area_visibility', '0' ) ) {
                $template_type  = ninetheme_settings( 'header_bottom_area_template_type', 'filters' );
                $header_filter  = ninetheme_settings( 'header_bottom_area_display_type', 'show-on-scroll' );
                $header_filter .= ' shop-layout-'.ninetheme_settings( 'shop_layout', 'left-sidebar' );
                $header_filter .= ' fixed-sidebar-'.ninetheme_settings( 'shop_hidden_sidebar_position', 'left' );

                if ( class_exists('WooCommerce') && ( is_shop() || is_product_category() || is_product_tag() ) && 'filters' == $template_type ) {
                    echo '<div class="ninetheme-header-bottom-bar '.$header_filter.'">';
                        shop_loop_filters_layouts();
                    echo '</div>';
                } else {
                    echo '<div class="ninetheme-header-bottom-bar ninetheme-elementor-template '.ninetheme_settings( 'header_bottom_area_display_type', 'show-on-scroll' ).'">';
                        echo ninetheme_print_elementor_templates( 'header_bottom_bar_template' );
                    echo '</div>';
                }
            }
        }

        public static function mobile_header()
        {
            $search        = ninetheme_settings( 'mobile_header_search', '1' );
            $layouts       = ninetheme_settings( 'mobile_header_layouts' );
            $layouts       = apply_filters( 'ninetheme_mobile_header_layouts', $layouts );
            $counter_attr  = 'counter-'.ninetheme_settings( 'header_buttons_counter_position', 'right' );
            $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_bgcolor_type', 'primary' );
            $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_radius_type', 'radius' );
            $breakpoint    = ninetheme_settings( 'mobile_header_breakpoint', 1280 );
            $search_type = ninetheme_settings('ajax_search_type');
            $search_shortcode = ninetheme_settings('ajax_search_custom_shortcode');
            if ( $layouts ) {
                unset( $layouts['show']['placebo'] );
                echo '<div class="ninetheme-header-mobile-top-wrapper" data-breakpoint="'.$breakpoint.'">';
                    self::header_top_layouts();
                    echo '<div class="ninetheme-header-mobile-top ninetheme-container-xl">';
                        foreach ( $layouts['show'] as $key => $value ) {

                            switch ( $key ) {
                                case 'toggle':
                                echo '<div class="mobile-toggle">'.ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ).'</div>';
                                break;

                                case 'logo':
                                echo '<div class="ninetheme-header-mobile-logo">';
                                    ninetheme_logo();
                                echo '</div>';
                                break;

                                case 'buttons':
                                echo '<div class="ninetheme-header-mobile-top-actions '.$counter_attr.'">';
                                    self::mobile_buttons_layouts();
                                echo '</div>';
                                break;
                            }
                        }
                    echo '</div>';
                echo '</div>';
            }
            if ( wp_is_mobile() && '1' == $search ) {
                echo '<div class="ninetheme-header-mobile-search-wrapper">';
                if ( 'plugin' == $search_type && $search_shortcode ) {
                    echo do_shortcode( $search_shortcode );
                } else {
                    if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                        echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                    } else {
                        ninetheme_ajax_search_form( 'inline' );
                    }
                }
                echo '</div>';
            }
        }

        public static function mobile_sidebar_menu()
        {
            $layouts = ninetheme_settings( 'sidebar_menu_layouts' );
            $layouts = apply_filters( 'ninetheme_mobile_header_sidebar_layouts', $layouts );

            $sidebar_layouts = ninetheme_settings( 'sidebar_menu_buttons_layouts' );
            $class           = !empty($layouts['show']) ? 'has-bar' : 'no-bar';
            $class          .= isset($layouts['show']['buttons']) ? ' has-buttons' : ' no-buttons';
            $class          .= isset($layouts['show']['socials']) ? ' has-socials' : ' no-socials';
            $class          .= isset($layouts['show']['logo']) ? ' has-logo' : ' no-logo';
            $cf7_form        = ninetheme_settings('sidebar_menu_cf7') ? '[contact-form-7 id="'.ninetheme_settings('sidebar_menu_cf7').'"]' : '';
            $form            = ninetheme_settings('sidebar_menu_custom_form') ? ninetheme_settings('sidebar_menu_custom_form') : $cf7_form;
            $counter_attr    = 'counter-'.ninetheme_settings( 'header_buttons_counter_position', 'right' );
            $counter_attr   .= ' counter-'.ninetheme_settings( 'header_buttons_counter_bgcolor_type', 'primary' );
            $counter_attr   .= ' counter-'.ninetheme_settings( 'header_buttons_counter_radius_type', 'radius' );
            $search_type = ninetheme_settings('ajax_search_type');
            $search_shortcode = ninetheme_settings('ajax_search_custom_shortcode');
            ?>
            <nav class="ninetheme-header-mobile <?php echo esc_attr( $class ); ?>">
                <div class="ninetheme-panel-close no-bar"></div>
                <?php
                if ( !empty( $layouts['show'] ) ) {
                    unset( $layouts['show']['placebo'] );
                    echo '<div class="ninetheme-header-mobile-sidebar">';
                        echo '<div class="ninetheme-panel-close ninetheme-panel-close-button"></div>';
                        echo '<div class="ninetheme-header-mobile-sidebar-inner">';
                            foreach ( $layouts['show'] as $key => $value ) {

                                switch ( $key ) {
                                    case 'socials':
                                    echo '<div class="ninetheme-header-mobile-sidebar-bottom" data-target-name="share">';
                                        echo '<div class="sidebar-bottom-socials">';
                                            echo ninetheme_settings('sidebar_menu_socials');
                                        echo '</div>';
                                    echo '</div>';
                                    break;

                                    case 'logo':
                                    echo '<div class="ninetheme-header-mobile-sidebar-logo">';
                                        ninetheme_logo(true);
                                    echo '</div>';
                                    break;

                                    case 'buttons':
                                    echo '<div class="sidebar-top-action '.$counter_attr.'">';
                                        self::sidebar_buttons_layouts();
                                    echo '</div>';
                                    break;
                                }
                            }
                        echo '</div>';
                    echo '</div>';
                }
                ?>

                <div class="ninetheme-header-mobile-content">

                    <div class="ninetheme-header-slide-menu menu-area">
                        <div class="ninetheme-header-slide-menu-inner">

                            <div class="search-area-top active">
                            <?php
                            if ( 'plugin' == $search_type && $search_shortcode ) {
                                echo do_shortcode( $search_shortcode );
                            } else {
                                if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
                                    echo do_shortcode( '[ninetheme_wc_ajax_product_search class="style-inline style-select-bars style-circle" cats="hide"]' );
                                } else {
                                    ninetheme_ajax_search_form( 'inline' );
                                }
                            }
                            ?>
                            </div>

                            <?php
                            $sidemenu = has_nav_menu( 'sidebar_menu' ) ? ' hidden-on-desktop' : '';
                            if ( has_nav_menu( 'sidebar_menu' ) ) { ?>
                                <div class="ninetheme-header-mobile-slide-menu hidden-on-mobile">
                                    <ul class="navigationn primary-menuu">
                                        <?php echo self::get_sidebar_nav_menu('sidebar_menu'); ?>
                                    </ul>
                                </div>
                            <?php } ?>

                            <div class="ninetheme-header-mobile-slide-menu<?php echo esc_attr( $sidemenu ); ?>">
                                <ul class="navigationn primary-menuu">
                                    <?php echo self::get_sidebar_nav_menu('header_menu'); ?>
                                </ul>
                            </div>
                        </div>

                        <?php do_action( 'ninetheme_after_mobile_menu' ); ?>

                        <?php do_action( 'ninetheme_mobile_menu_bottom' ); ?>
                    </div>

                    <?php if ( self::check_layout_manager( $sidebar_layouts, 'search' ) ) { ?>
                        <div class="category-area action-content ninetheme-scrollbar" data-target-name="search-cats">
                            <?php if ( '' != ninetheme_settings('sidebar_panel_categories_custom_title') ) { ?>
                                <span class="panel-top-title"><?php echo esc_html( ninetheme_settings('sidebar_panel_categories_custom_title') ); ?></span>
                            <?php } else {
                                $title = ninetheme_is_woocommerce() ? esc_html__( 'All Products Categories', 'crisop' ) : esc_html__( 'All Categories', 'crisop' );
                                ?>
                                <span class="panel-top-title"><?php echo esc_html( $title ); ?></span>
                            <?php } ?>
                            <div class="category-area-inner">
                                <?php self::get_all_categories(); ?>
                            </div>
                        </div>
                    <?php } ?>

                    <?php if ( self::check_layout_manager( $sidebar_layouts, 'cart' ) ) { ?>
                        <div class="cart-area action-content" data-target-name="cart">
                            <?php if ( '' != ninetheme_settings('sidebar_panel_cart_custom_title') ) { ?>
                                <span class="panel-top-title"><?php echo esc_html( ninetheme_settings('sidebar_panel_cart_custom_title') ); ?></span>
                            <?php } else { ?>
                                <span class="panel-top-title"><?php esc_html_e( 'Your Cart', 'crisop' ); ?></span>
                            <?php } ?>
                            <?php get_template_part( 'woocommerce/minicart/minicart' ); ?>
                        </div>
                    <?php } ?>

                    <?php if ( self::check_layout_manager( $sidebar_layouts, 'contact' ) && $form ) { ?>
                        <div class="contact-area action-content" data-target-name="contact">
                            <?php if ( '' != ninetheme_settings('sidebar_panel_contact_custom_title') ) { ?>
                                <span class="panel-top-title"><?php echo esc_html( ninetheme_settings('sidebar_panel_contact_custom_title') ); ?></span>
                            <?php } else { ?>
                                <span class="panel-top-title"><?php esc_html_e( 'Contact Us', 'crisop' ); ?></span>
                            <?php } ?>
                            <?php echo do_shortcode( $form ); ?>
                        </div>
                    <?php } ?>

                    <?php
                    if ( self::check_layout_manager( $sidebar_layouts, 'location' ) ) { ?>
                        <div class="location-area ninetheme-header-location action-content" data-target-name="location"></div>
                    <?php } ?>

                    <?php
                    if ( 'open-in-sidebar' == ninetheme_settings( 'header_myaccount_action_type', 'open-in-popup' ) ) {
                        self::my_account_form_template();
                    }
                    ?>
                </div>
            </nav>
            <?php
        }

        public static function lang_switcher()
        {
            if ( has_nav_menu( 'header_lang_menu' ) ) {
                $lang_menu = wp_nav_menu(
                    array(
                        'menu' => '',
                        'theme_location' => 'header_lang_menu',
                        'container' => '',
                        'container_class' => '',
                        'container_id' => '',
                        'menu_class' => '',
                        'menu_id' => '',
                        'items_wrap' => '%3$s',
                        'before' => '',
                        'after' => '',
                        'link_before' => '',
                        'link_after' => '',
                        'depth' => 2,
                        'echo' => false,
                        'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                        'walker' => new \Ninetheme_Wp_Bootstrap_Navwalker()
                    )
                );
                echo '<div class="ninetheme-lang-switcher ninetheme-header-mini-dropdown">
                    <ul class="ninetheme-lang-menu">'.$lang_menu.'</ul>
                </div>';

            } elseif ( has_action( 'wpml_add_language_selector' ) ) {

                echo '<div class="ninetheme-lang-switcher ninetheme-header-mini-dropdown">';
                    do_action('wpml_add_language_selector');
                echo '</div>';

            } elseif ( function_exists( 'pll_the_languages' ) ) {

                echo '<div class="ninetheme-lang-switcher ninetheme-header-mini-dropdown">';
                    pll_the_languages(
                        array(
                            'show_flags'       => 1,
                            'show_names'       => 1,
                            'dropdown'         => 1,
                            'raw'              => 0,
                            'hide_current'     => 0,
                            'display_names_as' => 'name'
                        )
                    );
                echo '</div>';
            }
        }

        public static function sidebar_menu_copyright()
        {
            if ( ninetheme_settings( 'sidebar_menu_copyright', '' ) ) {
                echo '<div class="ninetheme-sidemenu-copyright">'.ninetheme_settings( 'sidebar_menu_copyright', '' ).'</div>';
            }
        }

        public static function header_elementor()
        {
            $header_id = apply_filters('ninetheme_elementor_header_template', '');

            if ( class_exists( '\Elementor\Core\Settings\Manager' ) ) {

                $page_settings = \Elementor\Core\Settings\Manager::get_settings_managers( 'page' )->get_model( get_the_ID() );
                $pageheader_id = $page_settings->get_settings( 'ninetheme_page_header_template' );
                $header_id     = $pageheader_id != '' ? $pageheader_id : $header_id;
            }

            if ( $header_id ) {

                $frontend = new \Elementor\Frontend;
                printf( '<div class="ninetheme-elementor-header header-'.$header_id.'">%1$s</div>', $frontend->get_builder_content_for_display( $header_id, false ) );

            } else {
                $header_id = ninetheme_settings( 'header_elementor_templates', '' );
                echo ninetheme_print_elementor_templates( 'header_elementor_templates', 'ninetheme-elementor-header header-'.$header_id );

            }
        }

        public static function main_header()
        {
            if ( '0' == ninetheme_settings( 'header_visibility', '1' ) ) {
                return;
            }

            if ( ! class_exists( 'Redux' ) ) {
                self::header_default();
                return;
            }

            $header_template = apply_filters('ninetheme_header_template_type', ninetheme_settings( 'header_template', 'default' ) );

            if ( 'elementor' == $header_template ) {

                /**
                * HEADER ELEMENTOR TEMPLATES.
                * Hook: ninetheme_theme_header_elementor.
                *
                * @hooked header_elementor
                */
                do_action( 'ninetheme_theme_header_elementor' );

            } else {

                do_action( 'ninetheme_theme_header_before' );

                /**
                * HEADER TOP
                * Hook: ninetheme_theme_header_layouts.
                *
                * @hooked header_layouts
                */
                do_action( 'ninetheme_theme_header_layouts' );

                do_action( 'ninetheme_theme_header_after' );

                /**
                * HEADER MOBILE
                * Hook: ninetheme_theme_mobile_header.
                *
                * @hooked mobile_header
                */
                do_action( 'ninetheme_theme_mobile_header' );

                /**
                * HEADER SIDEBAR MENU
                * Hook: ninetheme_theme_header_mobile_sidebar.
                *
                * @hooked mobile_sidebar_menu
                */
                do_action( 'ninetheme_theme_header_mobile_sidebar' );

            }
        }

        public static function wc_cats_menu()
        {
            $taxonomy = ninetheme_is_woocommerce() ? 'product_cat' : 'category';

            $categories = get_terms( $taxonomy, array(
                'orderby'    => 'name',
                'order'      => 'asc',
                'hide_empty' => true
            ));

            $hide_empty = ninetheme_settings( 'header_woo_categories_hide_empty_cats', 1 );
            $exclude    = ninetheme_settings( 'header_woo_categories_exclude', null ) ? ninetheme_settings( 'header_woo_categories_exclude' ) : '';

            if ( !empty( $categories ) ) {
                ?>
                <div class="ninetheme-header-wc-categories ninetheme-wc-vertical-menu taxonomy-<?php echo esc_attr( $taxonomy ); ?>">

                    <?php
                    if ( has_nav_menu( 'department_menu' ) ) {
                        echo '<ul class="ninetheme-vertical-catmenu-primary submenu">';
                            echo wp_nav_menu(
                                array(
                                    'menu' => '',
                                    'theme_location' => 'department_menu',
                                    'container' => '',
                                    'container_class' => '',
                                    'container_id' => '',
                                    'menu_class' => '',
                                    'menu_id' => '',
                                    'items_wrap' => '%3$s',
                                    'before' => '',
                                    'after' => '',
                                    'link_before' => '',
                                    'link_after' => '',
                                    'depth' => 4,
                                    'echo' => true,
                                    'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                                    'walker' => new \Ninetheme_Wp_Bootstrap_Navwalker()
                                )
                            );
                        echo '</ul>';
                    } else {
                        ?>
                        <span class="ninetheme-vertical-catmenu-title"><?php esc_html_e( 'Categories', 'crisop' ); ?><span class="dropdown-btn fas fa-angle-down"></span></span>
                        <ul class="ninetheme-vertical-catmenu-primary submenu">
                            <?php
                            echo wp_list_categories(array(
                                'echo'       => true,
                                'taxonomy'   => $taxonomy,
                                'depth'      => 5,
                                'hide_empty' => $hide_empty,
                                'title_li'   => '',
                                'exclude'    => $exclude,
                                'walker'     => new Ninetheme_WooCommerce_Categories_Walker()
                            ));
                            ?>
                        </ul>
                        <?php
                    }
                    ?>
                </div>
                <?php
            }
        }

        public static function wc_header_products()
        {
            if ( !ninetheme_is_woocommerce() ) {
                return;
            }
            $img = get_template_directory_uri().'/images/discount.png';
            ?>
            <div class="ninetheme-discount-products-wrapper">
                <div class="ninetheme-header-discount-trigger">
                    <img src="<?php echo esc_url( $img ); ?>" alt="<?php echo esc_html_e( 'Super Discount', 'crisop' ); ?>">
                    <div class="ninetheme-header-discount-trigger-text">
                        <div class="ninetheme-header-discount-subtitle"><?php echo esc_html_e( 'Only this weekend', 'crisop' ); ?></div>
                        <div class="ninetheme-header-discount-title"><?php echo esc_html_e( 'Super Discount', 'crisop' ); ?></div>
                    </div>
                </div>

                <div class="ninetheme-discount-items ninetheme-scrollbar">

                    <?php

                    if ( ninetheme_settings('header_discount_products_elementor_templates', null ) ) {

                        echo ninetheme_print_elementor_templates( 'header_elementor_templates', '' );

                    } else {

                        ?>
                        <div class="ninetheme-discount-products-header">
                            <h5 class="ninetheme-header-products-discount-title"><?php echo esc_html_e( 'Items on sale this week', 'crisop' ); ?></h5>
                            <p class="ninetheme-header-discount-text"><?php echo esc_html_e( 'Top picks this week. Up to 50% off the best selling products.', 'crisop' ); ?></p>
                        </div>
                        <div class="products shop-products style-1 row row-cols-lg-6">
                            <?php
                            $scenario     = ninetheme_settings('header_products_scenario', 'featured' );
                            $per_page     = ninetheme_settings('header_products_count', 6 );
                            $cat_include  = ninetheme_settings('header_products_category_include');
                            $cat_exclude  = ninetheme_settings('header_products_category_exclude');
                            $order        = ninetheme_settings('header_products_order');
                            $orderby      = ninetheme_settings('header_products_orderby');

                            $args = array(
                                'post_type'      => 'product',
                                'posts_per_page' => $per_page,
                                'order'          => $order
                            );

                            if ( 'featured' == $scenario ) {
                               $args['tax_query'] = array(
                                    array(
                                        'taxonomy' => 'product_visibility',
                                        'field' => 'name',
                                        'terms' => 'featured'
                                    )
                                );

                            } elseif ( 'on-sale' == $scenario ) {

                                $args['meta_query'] = array(
                                    'relation' => 'OR',
                                    array( // Simple products type
                                        'key' => '_sale_price',
                                        'value' => 0,
                                        'compare' => '>',
                                        'type' => 'numeric'
                                    ),
                                    array( // Variable products type
                                        'key' => '_min_variation_sale_price',
                                        'value' => 0,
                                        'compare' => '>',
                                        'type' => 'numeric'
                                    )
                                );

                            } elseif ( 'best' == $scenario ) {

                                $args['orderby'] = 'meta_value_num';
                                $args['meta_key'] = 'total_sales';

                            } else {

                                $args['orderby'] = $orderby;

                            }

                            if ( $cat_include ) {
                                $args['tax_query'] = array(
                                    array(
                                        'taxonomy' => 'product_cat',
                                        'field' => 'id',
                                        'terms' => $cat_include,
                                        'operator' => 'IN'
                                    )
                                );
                            }
                            if ( $cat_exclude ) {
                                $args['tax_query'] = array(
                                    array(
                                        'taxonomy' => 'product_cat',
                                        'field' => 'id',
                                        'terms' => $cat_exclude,
                                        'operator' => 'NOT IN'
                                    )
                                );
                            }

                            $the_query = new WP_Query( $args );
                            if ( $the_query->have_posts() ) {

                                while ( $the_query->have_posts() ) {
                                    $the_query->the_post();
                                    wc_get_template_part( 'content', 'product' );
                                }
                            }
                            wp_reset_postdata();
                            ?>
                        </div>
                    <?php } ?>
                </div>
            </div>
            <?php
        }

        public static function get_all_categories()
        {
            $taxonomy   = ninetheme_is_woocommerce() ? 'product_cat' : 'category';
            $hide_empty = ninetheme_settings( 'sidemenu_hide_empty_cats', 1 );
            $subcats    = ninetheme_settings( 'sidemenu_subcategories', 0 );
            $exclude    = ninetheme_settings( 'sidemenu_categories_exclude', null );
            $thumb      = ninetheme_settings( 'sidemenu_cats_thumb_visibility', 1 );
            $thumb_size = ninetheme_settings( 'sidemenu_cats_thumb_imgsize', 'thumbnail' );

            if ( '1' == $subcats ) {
                $categories = get_terms( $taxonomy, array(
                    'orderby'    => 'name',
                    'order'      => 'asc',
                    'hide_empty' => '1' == $hide_empty ? true : false,
                    'exclude'    => !empty( $exclude ) ? $exclude : null,
                ));
            } else {
                $categories = get_terms( $taxonomy, array(
                    'orderby'    => 'name',
                    'order'      => 'asc',
                    'hide_empty' => '1' == $hide_empty ? true : false,
                    'exclude'    => !empty( $exclude ) ? $exclude : null,
                    'parent'     => 0
                ));
            }

            if ( !empty( $categories ) ) {
                if ( $taxonomy == 'product_cat' ) {
                    ?>
                    <div class="row row-cols-3">
                        <?php
                        foreach ( $categories as $key => $category ) {

                            $thumb_id = get_term_meta( $category->term_id, 'thumbnail_id', true );
                            ?>
                            <div class="col">
                                <div class="product-category">
                                    <a href="<?php echo esc_url( get_term_link( $category ) ); ?>">
                                        <?php
                                        if ( '1' == $thumb ) {
                                            if ( $thumb_id ) {
                                                echo wp_get_attachment_image($thumb_id,$thumb_size);
                                            } else {
                                                echo wc_placeholder_img( $thumb_size );
                                            }
                                        }
                                        ?>
                                        <span class="cat-count"><?php echo esc_html( $category->count ); ?></span>
                                        <span class="category-title"><?php echo esc_html( $category->name ); ?></span>
                                    </a>
                                </div>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                    <?php
                } else {
                    ?>
                    <ul class="category-list post-categories">
                        <?php
                        echo wp_list_categories(array(
                            'echo'       => true,
                            'taxonomy'   => 'category',
                            'depth'      => 5,
                            'hide_empty' => 1,
                            'title_li'   => '',
                            'cat_count'  => true,
                            'walker'     => new Ninetheme_WooCommerce_Categories_Walker()
                        ));
                        ?>
                    </ul>
                    <?php
                }
            }
        }

        public static function get_categories_count()
        {
            $taxonomy = ninetheme_is_woocommerce() ? 'product_cat' : 'category';

            if ( '1' == ninetheme_settings( 'sidemenu_subcategories', '0' ) ) {
                $categories = get_terms( $taxonomy, array(
                    'orderby'    => 'name',
                    'order'      => 'asc',
                    'hide_empty' => '1' == ninetheme_settings( 'sidemenu_hide_empty_cats', '0' ) ? true : false
                ));
            } else {
                $categories = get_terms( $taxonomy, array(
                    'orderby'    => 'name',
                    'order'      => 'asc',
                    'hide_empty' => '1' == ninetheme_settings( 'sidemenu_hide_empty_cats', '0' ) ? true : false,
                    'parent'     => 0
                ));
            }

            if ( !empty( $categories ) ) {
                return count( $categories );
            }
        }

        public static function print_account_register_form()
        {
            if ( !class_exists( 'WooCommerce' ) ) {
                return;
            }
            if ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) {
                ?>
                <form method="post" class="woocommerce-form woocommerce-form-register register" <?php do_action( 'woocommerce_register_form_tag' ); ?> >

                    <?php do_action( 'woocommerce_register_form_start' ); ?>

                    <?php if ( 'no' === get_option( 'woocommerce_registration_generate_username' ) ) : ?>

                        <p class="form-row ninetheme-is-required">
                            <label for="reg_username"><?php esc_html_e( 'Username', 'crisop' ); ?>&nbsp;<span class="required">*</span></label>
                            <input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="reg_username" autocomplete="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
                            <span class="ninetheme-form-message"></span>
                        </p>

                    <?php endif; ?>

                    <p class="form-row ninetheme-is-required">
                        <label for="reg_email"><?php esc_html_e( 'Email address', 'crisop' ); ?>&nbsp;<span class="required">*</span></label>
                        <input type="email" class="woocommerce-Input woocommerce-Input--text input-text" name="email" id="reg_email" autocomplete="email" value="<?php echo ( ! empty( $_POST['email'] ) ) ? esc_attr( wp_unslash( $_POST['email'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
                        <span class="ninetheme-form-message"></span>
                    </p>

                    <?php if ( 'no' === get_option( 'woocommerce_registration_generate_password' ) ) : ?>

                        <p class="form-row ninetheme-is-required">
                            <label for="reg_password"><?php esc_html_e( 'Password', 'crisop' ); ?>&nbsp;<span class="required">*</span></label>
                            <input type="password" class="woocommerce-Input woocommerce-Input--text input-text" name="password" id="reg_password" autocomplete="new-password" />
                            <span class="ninetheme-form-message"></span>
                        </p>

                    <?php else : ?>

                        <p><?php esc_html_e( 'A password will be sent to your email address.', 'crisop' ); ?></p>

                    <?php endif; ?>

                    <?php do_action( 'woocommerce_register_form' ); ?>

                    <p class="form-row">
                        <?php wp_nonce_field( 'woocommerce-register', 'woocommerce-register-nonce' ); ?>
                        <button type="submit" class="woocommerce-Button woocommerce-button button woocommerce-form-register__submit ninetheme-btn-medium ninetheme-btn ninetheme-btn-dark" name="register" value="<?php esc_attr_e( 'Register', 'crisop' ); ?>"><?php esc_html_e( 'Register', 'crisop' ); ?></button>
                    </p>

                    <?php do_action( 'woocommerce_register_form_end' ); ?>

                </form>
                <?php
            }
        }

        public static function my_account_form_popup_template()
        {
            if ( !class_exists( 'WooCommerce' ) || is_account_page() ) {
                return;
            }
            if ( 'open-in-popup' == ninetheme_settings( 'header_myaccount_action_type', 'open-in-popup' ) ) {
                ?>
                <div class="account-popup-content ninetheme-popup-item zoom-anim-dialog mfp-hide" id="ninetheme-account-popup">
                    <?php self::my_account_form_template(); ?>
                </div>
                <?php
            }
        }

        public static function my_account_form_template()
        {
            if ( !class_exists( 'WooCommerce' )  ) {
                return;
            }

            if ( is_user_logged_in() ) {
                $current_user = wp_get_current_user();
                ?>
                <?php if ( 'open-in-popup' == ninetheme_settings( 'header_myaccount_action_type', 'open-in-popup' ) ) { ?>
                    <div class="account-area account-logged-in">
                <?php } else { ?>
                    <div class="account-area action-content account-logged-in" data-target-name="account">
                <?php } ?>
                    <span class="panel-top-title"><?php echo esc_html__( 'Hello', 'crisop' ); ?><strong class="nt-strong-sfot"> <?php echo esc_html( $current_user->display_name );?></strong></span>
                    <ul class="navigation">
                    <?php foreach ( wc_get_account_menu_items() as $endpoint => $label ) { ?>
                        <li class="menu-item <?php echo esc_attr( wc_get_account_menu_item_classes( $endpoint ) ); ?>">
                            <a href="<?php echo esc_url( wc_get_account_endpoint_url( $endpoint ) ); ?>"><?php echo esc_html( $label ); ?></a>
                        </li>
                    <?php } ?>

                    </ul>
                </div>
                <?php

            } else {

                $url         = wc_get_page_permalink( 'myaccount' );
                $actionturl  = ninetheme_settings( 'header_myaccount_after_login_url', '' );
                $redirecturl = '' != $actionturl ? array( 'redirect' => $url ) : '';
                $redirecturl = class_exists('NextendSocialLogin', false) ? ' has-social-login' : '';
                ?>
                <?php if ( 'open-in-popup' == ninetheme_settings( 'header_myaccount_action_type', 'open-in-popup' ) ) { ?>
                    <div class="account-area">
                <?php } else { ?>
                    <div class="account-area action-content" data-target-name="account">
                <?php } ?>
                    <div class="panel-top-title">
                        <span class="form-action-btn signin-title active" data-target-form="login">
                            <span><?php esc_html_e( 'Sign in', 'crisop' ); ?>&nbsp;</span>
                            <?php echo ninetheme_svg_lists( 'arrow-right' ); ?>
                        </span>
                        <?php if ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) { ?>
                            <span class="form-action-btn register-title" data-target-form="register">
                                <?php echo ninetheme_svg_lists( 'user-2' ); ?>
                                <span>&nbsp;<?php esc_html_e( 'Register', 'crisop' ); ?></span>
                            </span>
                        <?php } ?>
                    </div>

                    <div class="account-area-form-wrapper">
                        <div class="login-form-content active">
                            <?php woocommerce_login_form( $redirecturl ); ?>
                        </div>
                        <?php if ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) { ?>
                            <div class="register-form-content">
                                <?php self::print_account_register_form(); ?>
                            </div>
                        <?php } ?>
                    </div>

                    <?php
                    if ( class_exists('NextendSocialLogin', false ) ) {
                        echo '<div class="account-area-social-form-wrapper">';
                        echo NextendSocialLogin::renderButtonsWithContainer();
                        echo '</div>';
                    }
                    ?>
                </div>
                <?php
            }
        }

        public static function header_before()
        {
            if ( isset( $_GET['header_topbar'] ) && '' != esc_html( $_GET['header_topbar'] ) ) {
                return;
            }
            echo ninetheme_print_elementor_templates( 'before_header_template', 'header-top-area ninetheme-elementor-before-header' );
        }

        public static function header_after()
        {
            echo ninetheme_print_elementor_templates( 'after_header_template', 'header-search-area ninetheme-elementor-after-header' );
        }

        public static function header_default()
        {
            $breakpoint = ninetheme_settings( 'mobile_header_breakpoint', 1280 );
            ?>
            <header class="ninetheme-header-default header-width-default ttttt" data-breakpoint="<?php echo esc_attr( $breakpoint ); ?>">
                <?php
                self::header_top_layouts();
                self::header_center_layouts();
                self::header_bottom_layouts();
                ?>
            </header>

            <div class="ninetheme-header-mobile-top-wrapper" data-breakpoint="<?php echo esc_attr( $breakpoint ); ?>">
                <div class="ninetheme-header-mobile-top ninetheme-container-xl">
                    <div class="ninetheme-header-mobile-logo">
                        <?php ninetheme_logo(); ?>
                    </div>
                    <div class="mobile-toggle"><?php echo ninetheme_svg_lists( 'bars', 'ninetheme-svg-icon' ); ?></div>
                </div>
            </div>

            <nav class="ninetheme-header-mobile">
                <div class="ninetheme-panel-close no-bar"></div>
                <div class="ninetheme-header-mobile-content">
                    <div class="ninetheme-header-slide-menu menu-area">
                        <div class="ninetheme-header-slide-menu-inner">
                            <div class="ninetheme-header-mobile-slide-menu">
                                <ul class="navigationn primary-menuu">
                                    <?php echo self::get_sidebar_nav_menu('header_menu'); ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </nav>
            <?php
        }

    }
    Ninetheme_Header::get_instance();
}


if ( !function_exists( 'ninetheme_bottom_mobile_menu' ) ) {
    add_action( 'ninetheme_before_wp_footer', 'ninetheme_bottom_mobile_menu' );
    function ninetheme_bottom_mobile_menu() {
        if ( '0' == ninetheme_settings( 'bottom_mobile_nav_visibility', '1' ) ) {
            return;
        }
        $menu_type    = ninetheme_settings( 'bottom_mobile_menu_type' );
        $display_type = ninetheme_settings( 'bottom_mobile_menu_display_type' );
        ?>
        <nav class="ninetheme-bottom-mobile-nav <?php echo esc_attr( $display_type ); ?>">
            <?php
            if ( 'elementor' == $menu_type ) {

                echo ninetheme_print_elementor_templates( 'mobile_bottom_menu_elementor_templates' );

            } elseif ( 'wp-menu' == $menu_type ) {

                if ( has_nav_menu( 'mobile_bottom_menu' ) ) {

                    echo '<div class="ninetheme-mobile-nav-wrapper">';
                        echo '<ul>';
                            echo wp_nav_menu(
                                array(
                                    'menu' => '',
                                    'theme_location' => 'mobile_bottom_menu',
                                    'container' => '',
                                    'container_class' => '',
                                    'container_id' => '',
                                    'menu_class' => '',
                                    'menu_id' => '',
                                    'items_wrap' => '%3$s',
                                    'before' => '',
                                    'after' => '',
                                    'link_before' => '',
                                    'link_after' => '',
                                    'depth' => 1,
                                    'echo' => true,
                                    'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                                    'walker' => new Ninetheme_Wp_Bootstrap_Navwalker()
                                )
                            );
                        echo '</ul>';
                    echo '</div>';
                }

            } else {

                $layouts = ninetheme_settings( 'mobile_bottom_menu_layouts' );
                $layouts = apply_filters( 'ninetheme_mobile_bottom_menu_layouts', $layouts );
                $arrow   = is_rtl() ? 'arrow-right' : 'arrow-left';
                $counter_attr  = 'counter-'.ninetheme_settings( 'header_buttons_counter_position', 'right' );
                $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_bgcolor_type', 'primary' );
                $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_radius_type', 'radius' );
                if ( !empty( $layouts['show'] ) ) {
                    unset( $layouts['show']['placebo'] );
                    echo '<div class="ninetheme-mobile-nav-wrapper">';
                        echo '<ul>';
                        foreach ( $layouts['show'] as $key => $value ) {

                            switch ( $key ) {
                                case 'home':
                                    if ( '1' == ninetheme_settings( 'bottom_mobile_nav_item_customize' ) && '' != ninetheme_settings( 'mobile_bottom_menu_custom_home_html' ) ) {
                                        echo ninetheme_settings( 'mobile_bottom_menu_custom_home_html' );
                                    } else {
                                        echo '<li class="menu-item">';
                                            echo '<a href="'.esc_url( home_url( '/' ) ).'" class="home-page-link">';
                                                echo ninetheme_svg_lists( $arrow, 'ninetheme-svg-icon' );
                                                echo '<span>'.esc_html__( 'Home', 'crisop' ).'</span>';
                                            echo '</a>';
                                        echo '</li>';
                                    }
                                break;

                                case 'shop':
                                    if ( '1' == ninetheme_settings( 'bottom_mobile_nav_item_customize' ) && '' != ninetheme_settings( 'mobile_bottom_menu_custom_shop_html' ) ) {
                                        echo ninetheme_settings( 'mobile_bottom_menu_custom_shop_html' );
                                    } else {
                                        if ( ninetheme_is_woocommerce() ) {
                                            echo '<li class="menu-item">';
                                                echo '<a href="'.esc_url( wc_get_page_permalink( 'shop' ) ).'" class="shop-page-link">';
                                                    echo ninetheme_svg_lists( 'store', 'ninetheme-svg-icon' );
                                                    echo '<span>'.esc_html__( 'Store', 'crisop' ).'</span>';
                                                echo '</a>';
                                            echo '</li>';
                                        }
                                    }
                                break;

                                case 'cart':
                                    if ( '1' == ninetheme_settings( 'bottom_mobile_nav_item_customize' ) && '' != ninetheme_settings( 'mobile_bottom_menu_custom_cart_html' ) ) {
                                        echo ninetheme_settings( 'mobile_bottom_menu_custom_cart_html' );
                                    } else {
                                        if ( ninetheme_is_woocommerce() ) {
                                            $cart_link  = esc_url( wc_get_page_permalink( 'cart' ) );
                                            echo '<li class="menu-item '.$counter_attr.'">';
                                                echo '<a href="#0" class="cart-page-link" data-name="cart">';
                                                    echo ninetheme_svg_lists( 'bag', 'ninetheme-svg-icon' );
                                                    echo '<span class="ninetheme-cart-count ninetheme-wc-count">'.WC()->cart->get_cart_contents_count().'</span>';
                                                    echo '<span>'.esc_html__( 'Cart', 'crisop' ).'</span>';
                                                echo '</a>';
                                            echo '</li>';
                                        }
                                    }
                                break;

                                case 'account':
                                    if ( '1' == ninetheme_settings( 'bottom_mobile_nav_item_customize' ) && '' != ninetheme_settings( 'mobile_bottom_menu_custom_account_html' ) ) {
                                        echo ninetheme_settings( 'mobile_bottom_menu_custom_account_html' );
                                    } else {
                                        if ( ninetheme_is_woocommerce() ) {
                                            echo '<li class="menu-item">';
                                                echo '<a href="'.esc_url( wc_get_page_permalink( 'myaccount' ) ).'" class="acoount-page-link">';
                                                    echo ninetheme_svg_lists( 'user-1', 'ninetheme-svg-icon' );
                                                    echo '<span>'.esc_html__( 'Account', 'crisop' ).'</span>';
                                                echo '</a>';
                                            echo '</li>';
                                        }
                                    }
                                break;

                                case 'search':
                                    if ( '1' == ninetheme_settings( 'bottom_mobile_nav_item_customize' ) && '' != ninetheme_settings( 'mobile_bottom_menu_custom_search_html' ) ) {
                                        echo ninetheme_settings( 'mobile_bottom_menu_custom_search_html' );
                                    } else {
                                        echo '<li class="menu-item">';
                                            echo '<a href="#0" data-name="search-popup" class="search-link popup">';
                                                echo ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' );
                                                echo '<span>'.esc_html__( 'Search', 'crisop' ).'</span>';
                                            echo '</a>';
                                        echo '</li>';
                                    }
                                break;

                                case 'cats':
                                    if ( '1' == ninetheme_settings( 'bottom_mobile_nav_item_customize' ) && '' != ninetheme_settings( 'mobile_bottom_menu_custom_cats_html' ) ) {
                                        echo ninetheme_settings( 'mobile_bottom_menu_custom_cats_html' );
                                    } else {
                                        echo '<li class="menu-item">';
                                            echo '<a href="#0" class="search-cats-trigger">';
                                                echo ninetheme_svg_lists( 'paper-search', 'ninetheme-svg-icon' );
                                                echo '<span>'.esc_html__( 'Categories', 'crisop' ).'</span>';
                                            echo '</a>';
                                        echo '</li>';
                                    }
                                break;

                                case 'location':
                                    if ( '1' == ninetheme_settings( 'bottom_mobile_nav_item_customize' ) && '' != ninetheme_settings( 'mobile_bottom_menu_custom_location_html' ) ) {
                                        echo ninetheme_settings( 'mobile_bottom_menu_custom_location_html' );
                                    } else {
                                        echo '<li class="menu-item">';
                                            echo '<a href="#0" data-name="location" class="location-trigger popup">';
                                                echo ninetheme_svg_lists( 'location', 'ninetheme-svg-icon' );
                                                echo '<span>'.esc_html__( 'Location', 'crisop' ).'</span>';
                                            echo '</a>';
                                        echo '</li>';
                                    }
                                break;
                            }
                        }
                        echo '</ul>';
                    echo '</div>';
                }
            }
            ?>
        </nav>
        <?php
    }
}
