/*-----------------------------------------------------------------------------------

    Theme Name: Crisop
    Description: WordPress Theme
    Author: Ninetheme
    Author URI: https://ninetheme.com/
    Version: 1.0

-----------------------------------------------------------------------------------*/

(function(window, document, $) {

    "use strict";

    var instance;
    var update_lazyload;

    var init_lazyload = function(){
        if ($('body').hasClass('ninetheme-lazyload-disabled') ) {
            return;
        }
        instance = new LazyLoad( {
            elements_selector: '[data-src],[data-bg],.lazy',
            callback_loading: (el)=>{
                $(el).closest('.ninetheme-thumb-wrapper').addClass('loading');
                $(el).closest('.ninetheme-swiper-slide-first').addClass('img-loading');

                if ( typeof elementorFrontend != 'undefined' ) {
                    var deviceMode = elementorFrontend.getCurrentDeviceMode();
                    var elBg = $(el).data('bg-responsive');

                    if ( typeof elBg != 'undefined' ) {
                        var desktop = $(el).data('bg');

                        var widescreen   = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : desktop;
                        var laptop       = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : desktop;
                        var tablet_extra = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : laptop;
                        var tablet       = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : tablet_extra;
                        var mobile_extra = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : tablet;
                        var mobile       = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : mobile_extra;
                        var bgUrl        = mobile;

                        if ( bgUrl ) {
                            $(el).css('background-image', 'url(' + bgUrl + ')' );
                        }
                    }
                }
            },
            callback_loaded: (el)=>{
                $(el).closest('.ninetheme-thumb-wrapper').removeClass('loading');

                var iframeWrapper = $(el).closest('.ninetheme-loop-product-iframe-wrapper');
                var iframeWrapper2 = $(el).closest('.ninetheme-woo-banner-iframe-wrapper');

                var videoid = $(el).data('ninetheme-bg-video'),
                    aspectRatioSetting = $(el).data('bg-aspect-ratio');

                if ( iframeWrapper2.hasClass('ninetheme-video-calculate') ) {
                    var containerWidth = iframeWrapper2.outerWidth(),
                        containerHeight = iframeWrapper2.outerHeight(),
                        aspectRatioArray = aspectRatioSetting.split(':'),
                        aspectRatio = aspectRatioArray[0] / aspectRatioArray[1],
                        ratioWidth = containerWidth / aspectRatio,
                        ratioHeight = containerHeight * aspectRatio,
                        isWidthFixed = containerWidth / containerHeight > aspectRatio,
                        size = {
                            w: isWidthFixed ? containerWidth : ratioHeight,
                            h: isWidthFixed ? ratioWidth : containerHeight
                        };

                    $(el).css({
                        width: size.w + 100,
                        height: size.h + 100
                    });
                }
                if ( winw <= 1024 && ( iframeWrapper.length || iframeWrapper2.length ) ) {
                    var iframe = $(el);
                    if ( iframeWrapper.length ) {
                        iframe[0].contentWindow.postMessage('{"event":"command","func":"' + 'playVideo' + '","args":""}', '*');
                    }

                    if ( iframeWrapper2.hasClass('ninetheme-video-youtube') ) {
                        iframe[0].contentWindow.postMessage('{"event":"command","func":"' + 'playVideo' + '","args":""}', '*');
                    }
                    if ( iframeWrapper2.hasClass('ninetheme-video-vimeo') ) {
                        iframe[0].contentWindow.postMessage('{"method":"play"}', '*');
                    }
                    if ( $(el).hasClass('ninetheme-video-local') ) {
                        iframe.get(0).play();
                    }
                }
                if ( $('.ninetheme-masonry-container').length ) {
                    var container = document.querySelector('.ninetheme-masonry-container');
                    //create empty var msnry
                    var msnry;
                    // initialize Masonry after all images have loaded
                    msnry = new Masonry( container, {
                        itemSelector: '.ninetheme-masonry-container>div'
                    });
                }
            },
            callback_finish: (el)=>{
                document.body.classList.add( 'ninetheme_lazyloaded' );
            },
            threshold: 1000,
        });

        update_lazyload = function(){
            instance.update();
        };

        if ( window.MutationObserver ) {
            new MutationObserver( update_lazyload ).observe( document.documentElement, { childList: true, subtree: true, attributes: true } ) ;
        }
    };
    window.addEventListener ? window.addEventListener( "load", init_lazyload, false ) : window.attachEvent( "onload", init_lazyload );

    $(document).ready(function(){
        var init_beforelazyload = function(){
            $('.ninetheme-gallery-wrapper img[data-src]:not(.loaded),.ninetheme-product-gallery-main-slider-carousel img[data-src]:not(.loaded),.ninetheme-product-thumbnails img[data-src]:not(.loaded),.ninetheme-product-gallery-main-slider img[data-src]:not(.loaded),.ninetheme-checkout-review-order-table img[data-src]:not(.loaded), .ninetheme-thumb-wrapper .ninetheme-loop-slider img[data-src]:not(.loaded)').each(function(){
                var $this  = $(this);
                var src    = $this.data('src');
                var srcset = $this.data('srcset');
                var sizes  = $this.data('sizes');
                $this.attr('src', src);
                $this.attr('srcset', srcset);
            });
            $('.ninetheme-product-gallery-main-slider').addClass('loading');
        };
        init_beforelazyload();

    });

    $.fn.isInViewport = function() {
        var elementTop = $(this).offset().top;
        var elementBottom = elementTop + $(this).outerHeight();

        var viewportTop = $(window).scrollTop();
        var viewportBottom = viewportTop + $(window).height();

        return elementBottom > viewportTop && elementTop < viewportBottom;
    };

    /*
    * same height
    * $('selector').sameSize();
    * ------------------------
    * same width
    * $('selector').sameSize(true);
    * ------------------------
    * same width, and max constraint
    * $('selector').sameSize(true, 20);
    */
    $.fn.sameSize = function( width, max ) {
        var prop = width ? 'width' : 'height',
        size = Math.max.apply( null, $.map( this, function( elem ) {
            return $( elem )[ prop ]();
        })),
        max = size < max ? size : max;
        return this[ prop ]( max || size );
    };


    function ninethemeSlider(el) {

        var self         = $( el ),
            myPSlider    = self,
            myData       = self.data( 'slider-settings' ),
            myInvisible  = self.find( '.elementor-invisible' ),
            mySlide      = self.find( '.elementor-top-section' ),
            myWrapper    = self.find( '.swiper-wrapper.ninetheme-template-slider-wrapper' ),
            myPage       = self.find( '[data-elementor-type="section"]' ),
            myElSecId    = myPage.data('data-elementor-id'),
            myPageClass  = myPage.attr( 'class' ),
            myParallaxSlider,
            myVideoMuteYoutube,
            myVideoMuteVimeo,
            myVideoHtml,
            windowWidth  = window.innerWidth;

        var checkVideo = function() {
            if ( self.hasClass('video-unmute') ) {
                myVideoMuteYoutube = 'mute=0';
                myVideoMuteVimeo   = 'muted=0';
                myVideoHtml        = 'muted';
            } else {
                myVideoMuteYoutube = 'mute=1';
                myVideoMuteVimeo   = 'muted=1';
            }

            mySlide.each( function () {
                var $this = $( this );
                $this.addClass( 'swiper-slide onepage-slide-item' ).prependTo( myWrapper );

                $this.find( 'div[data-settings]').each(function () {
                    var $thiss = $( this );
                    var $anim = $thiss.data('settings');

                    if ( typeof $anim._animation != 'undefined' ) {
                        $thiss.removeClass( 'elementor-invisible' );
                    }
                });

                var htmlVideo,
                video          = $this.data('ninetheme-bg-video'),
                provider       = video ? video.provider : '',
                videoId        = video ? video.video_id : '',
                videoContainer = $this.find('.elementor-background-video-container'),
                videoEl        = $this.find('.elementor-widget-video'),
                videoElCont    = videoEl.find('.elementor-video'),
                vSettings      = videoEl.data('settings'),
                videoType      = vSettings ? vSettings.video_type : '',
                videoUrl       = vSettings ? vSettings.youtube_url : '';

                if ( typeof videoEl != 'undefined' ) {
                    if ( 'vimeo' == videoType ) {
                        var videoIDParts = videoUrl.match(/^(?:https?:\/\/)?(?:www|player\.)?(?:vimeo\.com\/)?(?:video\/|external\/)?(\d+)([^.?&#"'>]?)/);
                        htmlVideo = '<iframe class="elementor-background-embed-video vimeo-video" title="vimeo Video Player" src="https://player.vimeo.com/video/'+videoIDParts[1]+'?autoplay=1&loop=1&autopause=0&'+self.myVideoMuteVimeo+'" allow="autoplay; fullscreen" webkitallowfullscreen mozallowfullscreen allowfullscreen frameborder="0" data-ready="true" width="640" height="360"></iframe>';
                    }
                    if ( 'youtube' == videoType ) {
                        var videoIDParts = videoUrl.match(/^(?:https?:\/\/)?(?:www\.)?(?:m\.)?(?:youtu\.be\/|youtube\.com\/(?:(?:watch)?\?(?:.*&)?vi?=|(?:embed|v|vi|user)\/))([^?&"'>]+)/);
                        htmlVideo    = '<iframe class="elementor-background-embed-video youtube-video" title="youtube Video Player" src="https://www.youtube.com/embed/'+videoIDParts[1]+'?controls=0&rel=0&autoplay=1&playsinline=1&enablejsapi=1&version=3&playerapiid=ytplayer&'+self.myVideoMuteYoutube+'" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" webkitallowfullscreen mozallowfullscreen allowfullscreen frameborder="0" width="640" height="360"></iframe>';
                    }
                    if ( 'hosted' == videoType ) {
                        videoEl.find('video:first-child').remove();
                        htmlVideo = '<video class="elementor-background-video-hosted elementor-html5-video video-hosted" autoplay '+self.myVideoHtml+' playsinline loop src="'+video.video_id+'"></video>';
                    }
                    videoElCont.prepend( htmlVideo );
                }

                if ( typeof videoId != 'undefined') {
                    videoContainer.find('div.elementor-background-video-embed').remove();
                    if ( 'vimeo' == provider ) {
                        htmlVideo = '<iframe class="elementor-background-embed-video vimeo-video" title="vimeo Video Player" src="https://player.vimeo.com/video/'+video.video_id+'?autoplay=1&loop=1&autopause=0&'+self.myVideoMuteVimeo+'" allow="autoplay; fullscreen" webkitallowfullscreen mozallowfullscreen allowfullscreen frameborder="0" data-ready="true" width="640" height="360"></iframe>';
                    }
                    if ( 'youtube' == provider ) {
                        htmlVideo = '<iframe class="elementor-background-embed-video youtube-video" title="youtube Video Player" src="https://www.youtube.com/embed/'+video.video_id+'?controls=0&rel=0&autoplay=1&playsinline=1&enablejsapi=1&version=3&playerapiid=ytplayer&'+self.myVideoMuteYoutube+'" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" webkitallowfullscreen mozallowfullscreen allowfullscreen frameborder="0" width="640" height="360"></iframe>';
                    }
                    if ( 'hosted' == provider ) {
                        videoContainer.find('video:first-child').remove();
                        htmlVideo = '<video class="elementor-background-video-hosted elementor-html5-video video-hosted" autoplay '+self.myVideoHtml+' playsinline loop src="'+video.video_id+'"></video>';
                    }
                    videoContainer.prepend( htmlVideo );
                }
            });
        };

        var createSlider = function() {
            var myData  = self.data( 'slider-settings' );
            self.addClass( myPageClass );

            checkVideo();

            myPage.remove();

            myParallaxSlider = new NTSwiper( el, myData );

            myParallaxSlider.on('init',function (swiper) {
                setTimeout(function(){
                    self.find( '.swiper-slide:not(:first-child)' ).each(function () {

                        var iframe = $( this ).find('iframe');
                        var vid = $( this ).find('.video-hosted');
                        if ( iframe.size() && iframe.hasClass('youtube-video') ) {
                            iframe[0].contentWindow.postMessage('{"event":"command","func":"' + 'pauseVideo' + '","args":""}', '*');
                        }
                        if ( iframe.size() && iframe.hasClass('vimeo-video') ) {
                            iframe[0].contentWindow.postMessage('{"method":"pause"}', '*');
                        }
                        if ( vid.size() ) {
                            vid.get(0).pause();
                        }
                    });
                }, 2000);
            });

            myParallaxSlider.on('transitionEnd', function ( swiper ) {
                var  active = swiper.realIndex;
                $( '.swiper-slide:not([data-swiper-slide-index="'+active+'"])' ).find( 'div[data-settings]' ).each(function () {
                    var $this    = $( this ),
                    animData = $this.data('settings'),
                    anim     = animData._animation;
                    if ( 'undefined' === typeof animData._animation ) {
                        anim = animData.animation;
                    }

                    $this.addClass( 'elementor-invisible' ).removeClass( 'animated ' + anim );

                });
            });

            myParallaxSlider.on('slideChange', function ( swiper ) {
                var  active = swiper.realIndex;

                $( '.swiper-slide[data-swiper-slide-index="'+active+'"]' ).find( 'div[data-settings]' ).each(function () {
                    var $this    = $( this ),
                    animData = $this.data( 'settings' ),
                    anim     = animData._animation,
                    delay    = animData._animation_delay;
                    if ( 'undefined' === typeof animData._animation ) {
                        anim = animData.animation;
                    }
                    setTimeout(function() {
                        $this.addClass( 'animated ' + anim ).removeClass( 'elementor-invisible' );
                    }, delay, $this);

                });

                $( '.swiper-slide:not(.swiper-slide-active)' ).each(function () {

                    var iframe = $( this ).find('iframe');
                    var vid    = $( this ).find('.video-hosted');
                    if ( iframe.size() && iframe.hasClass('youtube-video') ) {
                        iframe[0].contentWindow.postMessage('{"event":"command","func":"' + 'pauseVideo' + '","args":""}', '*');
                    }
                    if ( iframe.size() && iframe.hasClass('vimeo-video') ) {
                        iframe[0].contentWindow.postMessage('{"method":"pause"}', '*');
                    }
                    if ( vid.size() ) {
                        vid.get(0).pause();
                    }

                });

                $( '.swiper-slide-active' ).each(function () {

                    var iframe2 = $( this ).find('iframe');
                    var vid     = $( this ).find('.video-hosted');
                    if ( iframe2.size() && iframe2.hasClass('youtube-video') ) {
                        iframe2[0].contentWindow.postMessage('{"event":"command","func":"' + 'playVideo' + '","args":""}', '*');
                    }
                    if ( iframe2.size() && iframe2.hasClass('vimeo-video') ) {
                        iframe2[0].contentWindow.postMessage('{"method":"play"}', '*');
                    }
                    if ( vid.size() ) {
                        vid.get(0).play();
                    }
                });
            });

            myParallaxSlider.on('resize', function (swiper) {
                swiper.update();
            });
        };

        createSlider();
    }

    var doc         = $(document),
        win         = $(window),
        body        = $('body'),
        winw        = $(window).outerWidth(),
        megasubmenu = $('.elementor-top-section .ninetheme-header-top-menu-area li.menu-item-mega-parent > ul.submenu');

    function bodyResize(winw) {
        if ( winw <= 1024 ) {
            body.removeClass('nt-desktop').addClass('nt-mobile');
        } else {
            body.removeClass('nt-mobile').addClass('nt-desktop');
        }
    }

    function topMainHeader() {
        megasubmenu.each( function() {
            var cont     = $( this ),
                wrap     = cont.closest( '.navigation' ),
                wrapoff  = wrap.offset(),
                wrapleft = wrapoff.left,
                parentw  = cont.closest( '.elementor-top-section' ).outerWidth();

            if ( winw > 1024 ) {
                cont.css({
                    'left':'-'+ ( wrapleft ) +'px',
                    'width': parentw+'px',
                });
            } else {
                cont.removeAttr('style');
            }
        });
    }

    function topMainHeaderResize(winw) {
        if ( winw <= 1024 ) {
            megasubmenu.each( function() {
                var cont = $( this );
                cont.removeAttr('style');
            });
        } else {
            megasubmenu.each( function() {
                var cont     = $( this ),
                    wrap     = cont.closest( '.navigation' ),
                    wrapoff  = wrap.offset(),
                    wrapleft = wrapoff.left,
                    parentw  = cont.closest('.elementor-top-section').outerWidth();
                cont.css({
                    'left':'-'+ ( wrapleft ) +'px',
                    'width': parentw+'px',
                });
            });
        }
    }

    function mobileSlidingMenu() {

        $('.ninetheme-header-mobile-slide-menu').slidingMenu({
            className : "ninetheme-header-mobile-slide-menu",
            transitionDuration : 250,
            dataJSON : false,
            initHref : false,
            backLabel: 'Back'
        });

        $('.ninetheme-slide-menu').slidingMenu({
            className : "ninetheme-slide-menu",
            transitionDuration : 250,
            dataJSON : false,
            initHref : false,
            backLabel: 'Back'
        });

        $('.ninetheme-header-lang-slide-menu').slidingMenu({
            className : "ninetheme-header-lang-slide-menu",
            transitionDuration : 250,
            dataJSON : false,
            initHref : false,
            backLabel: 'Back'
        });

        $('.sliding-menu .menu-item-has-children>.sliding-menu__nav').each( function() {
            var $this = $( this ),
                id = $this.data( 'id' ),
                parentTitle = $this.text(),
                parents = $this.parents( '.sliding-menu' ),
                subBack = parents.find( '.sliding-menu__panel[data-id="'+id+'"] .sliding-menu__back' );
            subBack.text(parentTitle);
        });

        $('.elementor-section[data-header-mobile-breakpoint]').each( function() {
            var $breakpoint = $( this ).data('header-mobile-breakpoint');
            if ( $(window).width() <= $breakpoint ) {
                $('body').addClass('mobile-active');
            } else {
                $('body').removeClass('mobile-active');
            }
        });

        $('.elementor-section.ninetheme-elementor-header-mobile').each( function() {
            var $this  = $( this ),
                paddt  = parseFloat( $('.elementor-section.ninetheme-elementor-header-mobile-menu').css('padding-top') ),
                paddb  = parseFloat( $('.elementor-section.ninetheme-elementor-header-mobile-menu').css('padding-top') ),
                padd   = paddt + paddb,
                height = $('body.admin-bar') ? parseFloat($this.outerHeight()) + 32 + padd : $this.outerHeight() + padd,
                pos    = $this.position(),
                postop = $('body.admin-bar') ? parseFloat(pos.top + $this.height() ) + 32 : pos.top + height;


            $('.elementor-section.ninetheme-elementor-header-mobile-menu>.elementor-container').css(
                {
                    'max-height'    : 'calc(100vh - '+ height +'px)',
                    'height'        : 'calc(100vh - '+ height +'px)',
                    'min-height'    : 'auto',
                    'padding-right' : '15px',
                }
            );
            $('.elementor-section.ninetheme-elementor-header-mobile-menu').css(
                {
                    'top'           : postop+'px'
                }
            );
        });

        $('.elementor-section.ninetheme-elementor-header-mobile .mobile-menu-open, .elementor-section .mobile-menu-close').on('click', function(e) {
            e.preventDefault();
            var $this = $( this );
            $this.parent().toggleClass('active');
            $('.ninetheme-elementor-header-mobile-menu').toggleClass('active');
            $('html,body').toggleClass('ninetheme-overlay-open');
            $('body').toggleClass('mobile-menu-active');
        });

        $('.ninetheme-lang-menu>li>a').on('click', function(e) {
            var $this = $( this );
            var parents = $this.parents('.ninetheme-lang-menu');
            if ( parents.hasClass('active') ) {
                parents.removeClass('active');
            } else {
                parents.addClass('active');
            }
        });
        $('.ninetheme-lang-menu .submenu>li>a').on('click', function(e) {
            var $this = $( this );
            var lang = $this.text();
            var parents = $this.parents('.ninetheme-lang-menu');
            var activeLang = parents.find('>li>a');

            activeLang.html(lang+'<div class="dropdown-btn"><span class="fas fa-angle-down"></span></div>');
            parents.find('.submenu>li>a').removeClass('active');
            if ( $this.hasClass('active') ) {
                $this.removeClass('active');
            } else {
                $this.addClass('active');
            }
        });

        $('.sliding-menu__panel:not(.shortcode_panel)').each( function() {
            $( '<li class="sliding-menu-inner ninetheme-scrollbar"><ul></ul></li>' ).appendTo($(this ));
        });
        $('.sliding-menu__panel .menu-item').each( function() {
            $( this ).appendTo($( this ).parents('.sliding-menu__panel').find('.sliding-menu-inner>ul'));
        });
        $('.sliding-menu').each( function() {
            var height = $( this ).find('.sliding-menu__panel-root').outerHeight();
            $( this ).css('height',height);
        });
    }

    $('.header-top-buttons .top-action-btn[data-name]:not(.popup), .ninetheme-header-mobile-top-actions .top-action-btn[data-name]:not(.popup)').on('click',function(e){
        var $this = $(this),
            $name = $this.data('name');

        $('html,body').addClass('ninetheme-overlay-open');
        $('.top-action-btn:not([data-name="'+$name+'"],.panel-header-btn').removeClass('active');
        $('.ninetheme-side-panel .panel-content-item:not([data-name="'+$name+'"])').removeClass('active');
        $('.ninetheme-side-panel,.ninetheme-side-panel [data-name="'+$name+'"],.panel-header-btn[data-name="'+$name+'"]').addClass('active');
        setTimeout(function() {
            $('.ninetheme-header-overlay').addClass('close-cursor');
        }, 1000);
    });

    $('.ninetheme-bottom-mobile-nav a[data-name]:not(.popup)').on('click',function(e){
        var $this = $(this),
            $name = $this.data('name');

        $('html,body').addClass('ninetheme-overlay-open');
        $('.top-action-btn:not([data-name="'+$name+'"],.panel-header-btn').removeClass('active');
        $('.ninetheme-side-panel .panel-content-item:not([data-name="'+$name+'"]),.panel-header-btn:not([data-name="'+$name+'"])').removeClass('active');
        $('.ninetheme-side-panel,.ninetheme-side-panel [data-name="'+$name+'"],.panel-header-btn[data-name="'+$name+'"]').addClass('active');
        setTimeout(function() {
            $('.ninetheme-header-overlay').addClass('close-cursor');
        }, 1000);
    });

    $('[data-name="search-popup"], .popup-search, a[href="#ninetheme-popup-search"]').on('click',function(e){
        $('html,body').addClass('ninetheme-overlay-open');
        $('.ninetheme-popup-search-panel').addClass('active');
        $('.top-action-btn:not([data-name="search"]),.panel-header-btn').removeClass('active');
        $('.ninetheme-side-panel .panel-content-item,.panel-header-btn').removeClass('active');
        setTimeout(function() {
            $('.ninetheme-header-overlay').addClass('close-cursor');
        }, 1000);
    });

    $('[data-account-action="account"]').on('click',function(e){
        $('html,body').addClass('ninetheme-overlay-open');
        $('.account-area-form-wrapper .active').removeClass('active');
        $('.ninetheme-header-mobile, .ninetheme-header-mobile .account-area, .ninetheme-header-mobile-content .login-form-content').addClass('active');
        $('.top-action-btn[data-name="account"]').trigger('click');
        setTimeout(function() {
            $('.ninetheme-header-overlay').addClass('close-cursor');
        }, 1000);
    });

    $('.ninetheme-bottom-mobile-nav a[data-name="location"]').on('click',function(e){
        $('.ninetheme-header-mobile').addClass('active');
        $('.top-action-btn[data-name="location"]').trigger('click');
        e.preventDefault();
    });
    $('.ninetheme-bottom-mobile-nav .search-cats-trigger').on('click',function(e){
        if ( $('.ninetheme-header-mobile').length>0 ) {
            $('html,body').addClass('ninetheme-overlay-open');
            $('.ninetheme-header-mobile').addClass('active');
            $('.top-action-btn[data-name="search-cats"]').trigger('click');
            e.preventDefault();
        }
    });

    $('.has-default-header-type-trans .ninetheme-header-default').hover(
        function(){
            $('.ninetheme-header-default').addClass('trans-hover');
        },
        function(){
            $('.ninetheme-header-default').removeClass('trans-hover');
        }
    );

    function mobileHeaderActions() {
        $('.top-action-btn[data-name]:not(.popup)').each( function(){
            var $this = $(this),
                $name = $this.data('name');

            $this.on('click',function(e){
                var $thiss = $(this);
                $('.top-action-btn:not([data-name="'+$name+'"]').removeClass('active');

                $('[data-target-name]').removeClass('active');
                if ( $thiss.hasClass('active') ) {
                    $thiss.removeClass('active');
                    $('.ninetheme-header-slide-menu,.search-area-top').addClass('active');
                    $('[data-target-name="'+$name+'"]').removeClass('active');
                } else {
                    $thiss.addClass('active');
                    $('.ninetheme-header-slide-menu,.search-area-top').removeClass('active');
                    $('[data-target-name="'+$name+'"]').addClass('active');
                }
                if ( !($('[data-target-name="'+$name+'"]').length) ) {
                    $('.search-area-top,.ninetheme-header-slide-menu').addClass('active');
                }
                if ( $('.ninetheme-header-mobile-content div[data-name="checkout"]').hasClass('active') ) {
                    $('.ninetheme-header-mobile-content div[data-name="checkout"]').removeClass('active');
                }
                e.preventDefault();
            });
        });

        $('.mobile-toggle').on('click',function(e){

            $('.ninetheme-header-mobile-content .active, .sidebar-top-action .active, .ninetheme-side-panel').removeClass('active');
            $('.search-area-top').addClass('active');
            $('.account-area .login-form-content').addClass('active');
            if ( $('.ninetheme-header-mobile').hasClass('active') ) {
                $('html,body').removeClass('ninetheme-overlay-open');
                $('.ninetheme-header-mobile').removeClass('active');
                $('.ninetheme-header-overlay').removeClass('close-cursor');
            } else {
                $('html,body').addClass('ninetheme-overlay-open');
                $('.ninetheme-header-mobile,.menu-area').addClass('active');
                setTimeout(function() {
                    $('.ninetheme-header-overlay').addClass('close-cursor');
                }, 1000);
            }
            e.preventDefault();
        });

        $('.account-area .signin-title').on('click',function(){
            $('.form-action-btn').removeClass('active');
            $(this).addClass('active');
            $('.account-area .register-form-content').removeClass('active');
            $('.account-area .login-form-content').addClass('active');
        });
        $('.account-area .register-title').on('click',function(){
            $('.form-action-btn').removeClass('active');
            $(this).addClass('active');
            $('.account-area .login-form-content').removeClass('active');
            $('.account-area .register-form-content').addClass('active');
        });
        if ( $('.account-area.action-content .account-area-social-form-wrapper').length ) {
            $('.account-area-form-wrapper').css('min-height', $('.account-area-form-wrapper .woocommerce-form-login').height()+50);
        }
    }

    $('.ninetheme-panel-close,.ninetheme-header-overlay').on('click',function(){
        $('html,body').removeClass('ninetheme-overlay-open');
        $('.ninetheme-header-overlay').removeClass('close-cursor');
        $('.ninetheme-header-mobile, .ninetheme-side-panel, .ninetheme-popup-search-panel, .nt-sidebar').removeClass('active');
        $('.ninetheme-header-mobile-content .active, .ninetheme-header-mobile-sidebar-bottom, .sidebar-top-action .active').removeClass('active');
        $('.ninetheme-header-slide-menu').addClass('active');
        $('.ninetheme-shop-popup-notices').removeClass('active');
        $('.ninetheme-shop-popup-notices').removeClass('ninetheme-notices-has-error');
    });


    $('.panel-header-wishlist,.panel-header-compare').on('click',function(){
        $('.ninetheme-side-panel').removeClass('active');
        $('html,body').removeClass('ninetheme-overlay-open');
    });

    $(".ninetheme-header-top-menu-area .menu-item-has-children").hover(
        function(){
            $(this).addClass('on-hover');
        },
        function(){
            $(this).removeClass('on-hover');
        }
    );

    $(".ninetheme-header-menu-widget.display-type-dropdown.open-submenu-on-click .ninetheme-dropdown-menu-trigger").on('click',function(){
        $(this).toggleClass('active').parent().toggleClass('active');
        $(this).next().find('.active').removeClass('active');
    });
    $(".ninetheme-header-menu-widget.display-type-dropdown.open-submenu-on-click .dropdown-btn").on('click',function(){
        $(this).toggleClass('active').parent().toggleClass('active');
        $(this).parent().siblings().removeClass('active');
    });


    function mobileHeaderResize(winw) {
        if ( winw >= 490 ) {
            if ( $('.top-action-btn.share').hasClass('active') ) {
                $('.top-action-btn.share,.ninetheme-header-mobile-content').removeClass('active');
            }
        }
        if ( winw > 992 ) {
            $('html,body').removeClass('ninetheme-overlay-open');
            $('.ninetheme-header-mobile').removeClass('active');
            $('.ninetheme-popup-search-panel').removeClass('active');
            $('.ninetheme-shop-sidebar.ninetheme-shop-fixed-sidebar').removeClass('active');
            $('.ninetheme-header-overlay').removeClass('close-cursor');
        }
    }

    /*=============================================
    Mobile Menu
    =============================================*/
    //SubMenu Dropdown Toggle
    if ( $('.header-widget').length ) {
        $('.header-widget.header-style-two').parents('.elementor-top-section').addClass('big-index has-header-style-two');
    }

    function ninethemeHeaderCatMenu() {
        $('.ninetheme-vertical-menu-wrapper').each(function () {
            const $this    = $(this);
            const menu     = $this.find('.ninetheme-vertical-menu');
            const toggle   = $this.find('.ninetheme-vertical-menu-toggle');
            const speed    = toggle.data('speed');
            const more     = $this.find('.ninetheme-more-item-open');
            const morecats = $this.find('.ninetheme-more-categories');
            /*=============================================
            Toggle Active
            =============================================*/
            $(toggle).on('click', function () {
                $(menu).slideToggle(speed);
                return false;
            });
            $(more).slideUp();
            $(morecats).on('click', function () {
                $(this).toggleClass('show');
                $(more).slideToggle();
            });
        });
    }

    function ninethemeHeaderVerticalMenu2() {
        $('.ninetheme-vertical-menu-wrapper-two').each(function () {
            const $this     = $(this);
            const menu      = $this.find('.ninetheme-vertical-menu-two .navigation');
            const togglebtn = $this.find('.ninetheme-vertical-menu-mobile-trigger');
            const speed     = togglebtn.data('speed');

            $(togglebtn).on('click', function () {
                if ( $(this).hasClass('active') ) {
                    $(this).removeClass('active');
                } else {
                    $(this).addClass('active');
                }
                $(menu).slideToggle(speed);
                return false;
            });
        });
    }

    /*=============================================
    Menu sticky & Scroll to top
    =============================================*/
    function scrollToTopBtnClick() {
        if ( $(".scroll-to-target").length ) {
            $( ".scroll-to-target" ).on("click", function () {
                var target = $(this).attr("data-target");
                // animate
                $("html, body").animate({scrollTop: $(target).offset().top},1000);
                return false;
            });
        }
    }
    if ( $(".scroll-to-target").length ) {
        $( ".scroll-to-target" ).on("click", function () {
            var target = $(this).attr("data-target");
            // animate
            $("html, body").animate({scrollTop: $(target).offset().top},1000);
            return false;
        });
    }
    /*=============================================
    Menu sticky & Scroll to top
    =============================================*/
    function scrollToTopBtnHide() {
        var offset = 100;
        if ( $(".scroll-to-target").length ) {
            if ( $(window).scrollTop() > offset ) {
                $(".scroll-to-top").fadeIn(500);
            } else if ( $(".scroll-to-top").scrollTop() <= offset ) {
                $(".scroll-to-top").fadeOut(500);
            }
        }
    }

    /*=============================================
    Data Background
    =============================================*/
    $("[data-background]").each(function () {
        $(this).css("background-image", "url(" + $(this).attr("data-background") + ")")
    });

    /* ninethemeSwiperSlider */
    function ninethemeSwiperSlider() {
        $('.ninetheme-swiper-slider').each(function () {
            const options  = $(this).data('swiper-options');
            const mySlider = new NTSwiper(this, options );
        });
    }

    /* ninethemeSlickSlider */
    function ninethemeSlickSlider() {
        $('.ninetheme-slick-slider').each(function () {
            $(this).not('.slick-initialized').slick();
        });
    }

    /* ninethemeSimpleParallax */
    function ninethemeSimpleParallax() {
        $('.thumparallax').each(function () {
            // html attr output =====> data-parallax-options='{"orientation": "down","delay": 1..... }'
            const options = JSON.parse(this.dataset.parallaxOptions);
            let mySlider = new simpleParallax($(this), options);
        });
    }

    function ninethemeTooltip() {
        var myTooltips = $('[data-ninetheme-tooltip]');
        myTooltips.each(function(i, el) {
            var myTooltip = $(el).data('ninetheme-tooltip');
            $(el).tooltipster({
                position      : myTooltip.position,
                content       : myTooltip.content,
                animation     : myTooltip.animation,
                theme         : myTooltip.theme,
                trigger       : myTooltip.trigger,
                distance      : [ myTooltip.offsetx,myTooltip.offsety ],
                arrow         : myTooltip.arrow,
                maxWidth      : myTooltip.maxwidth,
                contentAsHTML : true,
                hideOnClick   : true,
                interactive   : true,
                touchDevices  : true,
                functionReady : function(){
                    var id  = this.__namespace,
                        bg  = myTooltip.bgcolor != '' ? myTooltip.bgcolor : '',
                        brd = myTooltip.brdcolor != '' ? myTooltip.brdcolor : '',
                        pos = myTooltip.position;

                    $('#'+id+' .tooltipster-box').css({
                        'background-color' : bg,
                        'border-color' : brd
                    });

                    if ( myTooltip.arrow ) {
                        $('#'+id+' .tooltipster-arrow-background').css('border-'+pos+'-color', bg);
                        $('#'+id+' .tooltipster-arrow-border').css('border-'+pos+'-color', brd);
                    }
                }
            });
        });
    }

    function ninethemeLightbox() {
        var myLightboxes = $('[data-ninetheme-lightbox]');
        if (myLightboxes.length) {
            myLightboxes.each(function(i, el) {
                var myLightbox = $(el);
                var myData = myLightbox.data('ninetheme-lightbox');
                var myDataGallery = myLightbox.data('ninetheme-lightbox-gallery');

                var myOptions = {};
                if (!myData || !myData.type) {
                    return true; // next iteration
                }
                if (myData.type === 'gallery') {
                    myOptions = {
                        //delegate: myData.selector,
                        type    : 'image',
                        gallery : {
                            enabled : true
                        },
                        items : myDataGallery
                    };
                }
                if (myData.type === 'image') {
                    myOptions = {
                        type : 'image'
                    };
                }
                if (myData.type === 'iframe') {
                    myOptions = {
                        type            : 'iframe',
                        fixedContentPos : false,
                        fixedBgPos      : true,
                        overflowY       : 'auto',
                        closeBtnInside  : false,
                        preloader       : false,
                        midClick        : true,
                        removalDelay    : 0,
                        mainClass       : 'ninetheme-mfp-slide-bottom',
                        tClose          : '',
                        closeMarkup     : '<div title="%title%" class="ninetheme-mfp-close"></div>',
                        callbacks       : {
                            open: function() {
                                $('body').addClass('magnificpopupnoscroll');
                            },
                            close: function() {
                                $('body').removeClass('magnificpopupnoscroll');
                            }
                        }
                    };
                }
                if (myData.type === 'inline') {
                    myOptions = {
                        type : 'inline',
                    };
                }
                if (myData.type === 'modal') {
                    myOptions = {
                        type  : 'inline',
                        modal : false
                    };
                }
                if (myData.type === 'ajax') {
                    myOptions = {
                        type      : 'ajax',
                        overflowY : 'auto'
                    };
                }
                myLightbox.magnificPopup(myOptions);
            });
        }
    }




    // agrikonVegasSlider Preview function
    function ninethemeVegasSlider() {

        $(".home-slider-vegas-wrapper").each(function (i, el) {
            var myEl       = jQuery(el),
                myVegasId  = myEl.find('.nt-home-slider-vegas').attr('id'),
                myVegas    = $( '#' + myVegasId ),
                myPrev     = myEl.find('.vegas-control-prev'),
                myNext     = myEl.find('.vegas-control-next'),
                mySettings = myEl.find('.nt-home-slider-vegas').data('slider-settings'),
                myContent  = myEl.find('.nt-vegas-slide-content'),
                myCounter  = myEl.find('.nt-vegas-slide-counter'),
                myTitle    = myEl.find('.slider_title'),
                myDesc     = myEl.find('.slider_desc'),
                myBtn      = myEl.find('.btn'),
                myCounter  = myEl.find('.nt-vegas-slide-counter');

            myEl.parents('.elementor-widget-agrikon-vegas-slider').removeClass('elementor-invisible');

            if( mySettings.slides.length ) {
                var slides = mySettings.slides,
                    anim   = mySettings.animation ? mySettings.animation : 'kenburns',
                    trans  = mySettings.transition ? mySettings.transition : 'slideLeft',
                    delay  = mySettings.delay ? mySettings.delay : 7000,
                    dur    = mySettings.duration ? mySettings.duration : 2000,
                    autoply= mySettings.autoplay,
                    shuf   = 'yes' == mySettings.shuffle ? true : false,
                    timer  = 'yes' == mySettings.timer ? true : false,
                    over   = 'none' != mySettings.overlay ? true : false;

                myVegas.vegas({
                    autoplay: autoply,
                    delay: delay,
                    timer: timer,
                    shuffle: shuf,
                    animation: anim,
                    transition: trans,
                    transitionDuration: dur,
                    overlay: over,
                    slides: mySettings.slides,
                    init: function (globalSettings) {
                        myContent.eq(0).addClass('active');
                        myTitle.eq(0).addClass('fadeInLeft');
                        myDesc.eq(0).addClass('fadeInLeft');
                        myBtn.eq(0).addClass('fadeInLeft');
                        var total = myContent.size();
                        myCounter.find('.total').html(total);
                    },
                    walk: function (index, slideSettings) {
                        myContent.removeClass('active').eq(index).addClass('active');
                        myTitle.removeClass('fadeInLeft').addClass('fadeOutLeft').eq(index).addClass('fadeInLeft').removeClass('fadeOutLeft');
                        myDesc.removeClass('fadeInLeft').addClass('fadeOutLeft').eq(index).addClass('fadeInLeft').removeClass('fadeOutLeft');
                        myBtn.removeClass('fadeInLeft').addClass('fadeOutLeft').eq(index).addClass('fadeInLeft').removeClass('fadeOutLeft');
                        var current = index +1;
                        myCounter.find('.current').html(current);
                    },
                    end: function (index, slideSettings) {
                    }
                });

                myPrev.on('click', function () {
                    myVegas.vegas('previous');
                });

                myNext.on('click', function () {
                    myVegas.vegas('next');
                });
            }
        });
        // add video support on mobile device for vegas slider
        if( $(".home-slider-vegas-wrapper").length ) {
            $.vegas.isVideoCompatible = function () {
                return true;
            }
        }
    }

    // ninethemeVegasTemplate Preview function
    function ninethemeVegasTemplateSlider() {
        $(".vegas-template-slider").each(function () {
            var myEl        = $(this),
                myContent   = myEl.find('.vegas-content-wrapper .elementor-top-section'),
                myBgContent = myEl.find('.vegas-bg-content'),
                mySettings  = myBgContent.data('slider-settings'),
                myVegasId   = myBgContent.attr('id'),
                myVegas     = $( '#' + myVegasId ),
                myPrev      = myEl.find('.vegas-control-prev'),
                myNext      = myEl.find('.vegas-control-next'),
                myCounter   = myEl.find('.nt-vegas-slide-counter');

            myEl.parents('.elementor-widget-ninetheme-vegas-template').removeClass('elementor-invisible');

            var mySlides = [];
            myContent.each( function(){
                var mySlide = $(this),
                    bgImage = mySlide.css('background-image');
                    bgImage = bgImage.replace(/.*\s?url\([\'\"]?/, '').replace(/[\'\"]?\).*/, ''),
                    bgImage = {"src": bgImage};

                mySlides.push( bgImage );
                mySlide.addClass('vegas-slide-template-section').css({
                    'background-image' : 'none',
                    'background-color' : 'transparent',
                });
            });

            if( mySlides.length ) {
                var anim  = mySettings.animation ? mySettings.animation : 'kenburns',
                    trans = mySettings.transition ? mySettings.transition : 'slideLeft',
                    delay = mySettings.delay ? mySettings.delay : 7000,
                    dur   = mySettings.duration ? mySettings.duration : 2000,
                    aply  = mySettings.autoplay,
                    shuf  = 'yes' == mySettings.shuffle ? true : false,
                    timer = 'yes' == mySettings.timer ? true : false,
                    over  = 'none' != mySettings.overlay ? true : false;

                myVegas.vegas({
                    autoplay: aply,
                    delay: delay,
                    timer: timer,
                    shuffle: shuf,
                    animation: anim,
                    transition: trans,
                    transitionDuration: dur,
                    overlay: over,
                    slides: mySlides,
                    init: function (globalSettings) {
                        myContent.eq(0).addClass('active');
                        var total = myContent.size();
                        myCounter.find('.total').html(total);
                        myContent.each( function(){
                            var myElAnim = $(this).find( '.elementor-element[data-settings]' ),
                                myData = myElAnim.data('settings'),
                                myAnim = myData && myData._animation ? myData._animation : '',
                                myDelay = myData && myData._animation_delay ? myData._animation_delay / 1000 : '';

                            if (myData && myAnim ) {
                                myElAnim.removeClass( 'animated' );
                                $(this).find(myElAnim).css({
                                    'animation-delay' : myDelay+'s',
                                });
                            }
                        });
                    },
                    walk: function (index, slideSettings) {

                        myContent.removeClass('active').eq(index).addClass('active');

                        myContent.each( function(){
                            var myElAnim = $(this).find( '.elementor-element[data-settings]' ),
                                myData = myElAnim.data('settings'),
                                myAnim = myData && myData._animation ? myData._animation : '',
                                myDelay = myData && myData._animation_delay ? myData._animation_delay / 1000 : '';

                            if (myData && myAnim ) {
                                myElAnim.removeClass( 'animated ' + myAnim );
                                myContent.eq(index).find(myElAnim).addClass('animated ' + myAnim);
                            }
                        });
                        var current = index +1;
                        myCounter.find('.current').html(current);
                    },
                    end: function (index, slideSettings) {
                    }
                });

                myPrev.on('click', function () {
                    myVegas.vegas('previous');
                });

                myNext.on('click', function () {
                    myVegas.vegas('next');
                });
            }
        });
    }

   // ninethemeFixedSection
    function ninethemeFixedSection() {
        var myFixedSection = $( '.ninetheme-section-fixed-yes' );
        if ( myFixedSection.length ) {
            myFixedSection.parents( '[data-elementor-type="section"]' ).addClass( 'ninetheme-section-fixed ninetheme-custom-header' );
            win.on( "scroll", function () {
                var bodyScroll = win.scrollTop();
                if ( bodyScroll > 100 ) {
                    myFixedSection.parents( '[data-elementor-type="section"]' ).addClass( 'section-fixed-active' );
                } else {
                   myFixedSection.parents( '[data-elementor-type="section"]' ).removeClass( 'section-fixed-active' );
                }
            });
        }
    }
    // ninethemePopup
    function ninethemePopupTemplate() {
        var myPopups = $('.ninetheme-popup-item');
        myPopups.each(function (i, el) {
            var myPopup = $(el),
                myId    = myPopup.attr('id'),
                myEl    = $('body a[href="#'+myId+'"]' );

            if ( myEl.length ) {
                myEl.addClass('ninetheme-open-popup');
            }
        });
        $(".ninetheme-open-popup").magnificPopup({
            type            : 'inline',
            fixedContentPos : false,
            fixedBgPos      : true,
            overflowY       : 'scroll',
            closeBtnInside  : true,
            preloader       : false,
            midClick        : true,
            removalDelay    : 0,
            mainClass       : 'ninetheme-mfp-slide-bottom',
            tClose          : '',
            tLoading        : '<span class="loading-wrapper"><span class="ajax-loading"></span></span>',
            closeMarkup     : '<div title="%title%" class="mfp-close ninetheme-mfp-close"></div>',
            callbacks: {
                open: function() {
                    $("body").addClass('ninetheme-popup-open');
                    $('body').addClass('magnificpopupnoscroll');
                    if ( $('.ninetheme-popup-item .ninetheme-slick-slider').length ) {
                        $('.ninetheme-popup-item .ninetheme-slick-slider').each(function () {
                            $(this).slick('refresh');
                        });
                    }
                },
                close: function() {
                    $("body").removeClass('ninetheme-popup-open');
                    $('body').removeClass('magnificpopupnoscroll');
                }
            }
        });
    }

    function ninethemeCountDown() {
        $('[data-countdown]').each(function () {
            var self      = $(this),
                data      = self.data('countdown'),
                countDate = data.date,
                expired   = data.expired;

            if (!countDate) {
               return;
            }

            let countDownDate = new Date( countDate ).getTime();

            const d = self.find( '.days' );
            const h = self.find( '.hours' );
            const m = self.find( '.minutes' );
            const s = self.find( '.second' );

            var x = setInterval(function() {

                var now = new Date().getTime();

                var distance = countDownDate - now;

                var days    = ('0' + Math.floor(distance / (1000 * 60 * 60 * 24))).slice(-2);
                var hours   = ('0' + Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60))).slice(-2);
                var minutes = ('0' + Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60))).slice(-2);
                var seconds = ('0' + Math.floor((distance % (1000 * 60)) / 1000)).slice(-2);

                d.text( days );
                h.text( hours );
                m.text( minutes );
                s.text( seconds );

                if (distance < 0) {
                    clearInterval(x);
                    self.html('<div class="expired">' + expired + '</div>');
                }
            }, 1000);
        });
    }


    /*=============================================
    Theme WooCommerce
    =============================================*/
    /* added_to_cart
    *  updated_cart_totals
    */

    // single product sticky section
    function producStickySummary() {

        $('.ninetheme-is-sticky').each( function() {
            var $sticky = $(this);
            if (!!$sticky.offset()) {

                var stickyHeight = $sticky.height(),
                    stickyTop    = $sticky.offset().top,
                    stickyOffset = 160,
                    stickyWidth  = $sticky.innerWidth(),
                    stickyStop   = $sticky.parent().height() + stickyOffset,
                    stopPoint    = stickyStop - stickyHeight - ( stickyOffset * 2 ),
                    diff         = stopPoint + stickyOffset;

                win.on('resize', function() {
                    stickyHeight = $sticky.height();
                    stickyTop    = $sticky.offset().top;
                    stickyOffset = 120;
                    stickyWidth  = $sticky.innerWidth();
                    stickyStop   = $sticky.parent().height() + stickyOffset;
                    stopPoint    = stickyStop - stickyHeight - ( stickyOffset * 2 );
                    diff         = stopPoint + stickyOffset;
                });

                win.on('scroll', function() {
                    var width = win.width();
                    if ( width > 1024 ) {
                        var windowTop = win.scrollTop();
                        if (stopPoint < windowTop) {
                            $sticky.css({ position: 'relative', top: diff });
                        } else if (stickyTop < windowTop+stickyOffset) {
                            $sticky.addClass('ninetheme-sticky-start').css({ position: 'fixed', top: stickyOffset, 'max-width': stickyWidth });
                        } else {
                            $sticky.removeClass('ninetheme-sticky-start').removeAttr('style');
                        }

                    } else {
                        $sticky.removeAttr('style');
                    }
                });
            }
        });
    }


    // none elementor page fix some js
    function noneElementorPageFix() {
        if ( !$('body').hasClass('archive') ) {
            return;
        }
        $('[data-widget_type="accordion.default"] .elementor-accordion-item .elementor-tab-title').each(function(e){
            $( this ).on('click',function(e){
                var $this = $( this );
                var $parent = $this.parent();

                $this.toggleClass('elementor-active');
                $parent.find('.elementor-tab-content').slideToggle();
                $parent.siblings().find('.elementor-tab-title').removeClass('elementor-active');
                $parent.siblings().find('.elementor-tab-content').slideUp();
            });
        });
    }

    // ninethemeCf7Form
    function ninethemeCf7Form() {
        $('.ninetheme-cf7-form-wrapper.form_front').each( function(){
            $(this).find('form>*').each( function(index,el){
                $(this).addClass('child-'+index);
            });
        });
    }

    // popupNewsletter
    function popupNewsletter() {
        if ( !$('body').hasClass('newsletter-popup-visible') ) {
            return;
        }

        var expires = $( '.ninetheme-newsletter' ).data( 'expires' );

        if (!( Cookies.get( 'newsletter-popup-visible' ) ) ) {
            $( window ).on( 'load', function() {
                $('.ninetheme-newsletter').trigger( 'click' );
            });
        }

        $(".ninetheme-newsletter .dontshow").click(function() {
            if ($(this).is(":checked")) {
                Cookies.set( 'newsletter-popup-visible', 'disable', { expires: expires, path: '/' });
            } else {
                Cookies.remove('newsletter-popup-visible')
            }
        });
    }

    // popupGdpr
    function popupGdpr() {
        if ( !$('body').hasClass('gdpr-popup-visible') ) {
            return;
        }

        var body        = $('body'),
            popup       = $('.site-gdpr'),
            popupClose  = $('.site-gdpr .gdpr-button a'),
            expiresDate = popup.data('expires');

        if ( !( Cookies.get( 'gdpr-popup-visible' ) ) ) {
            setTimeout(function(){
                popup.addClass( 'active' );
            },1000);
        }

        popupClose.on( 'click', function(e) {
            e.preventDefault();
            Cookies.set( 'gdpr-popup-visible', 'disable', { expires: expiresDate, path: '/' });
            popup.removeClass( 'active' );
            $.cookie("ninetheme_gdpr", 'accepted');
        });
    }

    // product list type masonry for mobile
    function masonryInit(winw) {
        var masonry = $('.ninetheme-product-list');
        if ( masonry.length && winw <= 1200 ) {
            var container = document.querySelector('.ninetheme-products.ninetheme-product-list');
            var msnry;
            imagesLoaded( container, function() {
               msnry = new Masonry( container, {
                   itemSelector: '.ninetheme-product-list>div.product'
               });
            });
        }
    }

    function ninethemeWcInit() {

        $('[data-label-color]').each( function() {
            var $this = $(this);
            var $color = $this.data('label-color');
            $this.css( {'background-color': $color,'border-color': $color } );
        });

        // product tabs
        $(document.body).on('click','.ninetheme-product-tab-title-item', function(e) {
            e.preventDefault();
            var id = $(this).data('id');
            $('.ninetheme-product-tabs-wrapper div[data-id="'+id+'"]').addClass('active');
            $('.ninetheme-product-tabs-wrapper div:not([data-id="'+id+'"])').removeClass('active');
        });

        // product summary accordion tabs
        $(document.body).on('click','.cr-qna-link', function(e) {
            e.preventDefault();
            var name  = 'accordion';
            var offset  = 32;
            if ($('.ninetheme-product-tabs-wrapper').length) {
                name  = 'tabs';
                offset = 0;
            }
            var target = $('.ninetheme-product-'+name+'-wrapper').position();

            $('html,body').stop().animate({
                scrollTop: target.top + offset
            }, 1500);
            if ( $('[data-id="accordion-cr_qna"]').parent().hasClass('active') ) {
                return;
            } else {
                setTimeout(function(){
                    $('[data-id="accordion-cr_qna"]').trigger('click');
                }, 700);
            }
            if ( $('[data-id="tab-cr_qna"]').hasClass('active') ) {
                return;
            } else {
                setTimeout(function(){
                    $('[data-id="tab-cr_qna"]').trigger('click');
                }, 700);
            }
        });

        $(document.body).on('click','.ninetheme-product-summary .woocommerce-review-link', function(e) {
            e.preventDefault();
            var target = $('.nt-woo-single #reviews').position();
            if ($('.ninetheme-product-tabs-wrapper').length) {
                target = $('.nt-woo-single .ninetheme-product-tabs-wrapper').position();
            }
            $('html,body').stop().animate({
                scrollTop: target.top
            }, 1500);

            if ( $('[data-id="tab-reviews"]').hasClass('active') ) {
                return;
            } else {
                setTimeout(function(){
                    $('[data-id="tab-reviews"]').trigger('click');
                }, 700);
            }
        });

        // product summary accordion tabs
        $(document.body).on('click','.ninetheme-accordion-header', function(e) {
            e.preventDefault();
            var accordionItem   = $(this),
                accordionParent = accordionItem.parent(),
                accordionHeight = accordionItem.outerHeight(),
                headerHeight    = $('body').hasClass('admin-bar') ? 32 : 0,
                totalHeight     = accordionHeight + headerHeight;

            accordionParent.toggleClass('active');
            accordionItem.next('.ninetheme-accordion-body').slideToggle();
            accordionParent.siblings().removeClass('active').find('.ninetheme-accordion-body').slideUp();
        });

        $(document.body).on('click','.nt-sidebar-inner-widget-title', function(e) {
            e.preventDefault();
            var $this = $(this);
            $this.parents('.nt-sidebar-inner-widget').toggleClass('active');
            $this.next().slideToggle();
            $this.toggleClass('no-margin');
        });

        $(document.body).on('click','.nt-sidebar-widget-body a', function (e) {
            e.preventDefault();
            $(this).parents('.nt-sidebar-widget-body').prev().toggleClass('active');
        });

        $(document.body).on('click','.ninetheme-loop-product-more-details-trigger', function (e) {
            e.preventDefault();
            $(this).parents('.ninetheme-type-product').toggleClass('details-open');
        });

        $(document.body).on('click','.ninetheme-header-discount-trigger', function (e) {
            e.preventDefault();
            $(this).parents('.ninetheme-discount-products-wrapper').toggleClass('active');
        });

        producStickySummary();
        masonryInit(winw);
    }

    $(document.body).on('ninetheme_masonry_init', function() {
        masonryInit(winw);
    });

    function timer() {
        $('[data-timer]').each(function () {
            var self      = $(this),
                data      = self.data('timer'),
                countDate = data.date,
                expired   = data.expired;

            let countDownDate = new Date( countDate ).getTime();

            const d = self.find( '.days' );
            const h = self.find( '.hours' );
            const m = self.find( '.minutes' );
            const s = self.find( '.second' );

            var x = setInterval(function() {

                var now = new Date().getTime();

                var distance = countDownDate - now;

                var days    = ('0' + Math.floor(distance / (1000 * 60 * 60 * 24))).slice(-2);
                var hours   = ('0' + Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60))).slice(-2);
                var minutes = ('0' + Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60))).slice(-2);
                var seconds = ('0' + Math.floor((distance % (1000 * 60)) / 1000)).slice(-2);

                d.text( days );
                h.text( hours );
                m.text( minutes );
                s.text( seconds );

                if (distance < 0) {
                    clearInterval(x);
                    console.log( 'expired' );
                    self.html('<div class="expired">' + expired + '</div>');
                }
            }, 1000);
        });
    }


    doc.ready( function() {
        $('.slider-home-onepage .swiper-container').each( function() {
            var $this = $(this).attr('id');
            ninethemeSlider('#'+$this);
        });
        var stickyHeaderHeight = $('.has-sticky-header .ninetheme-header-sticky').height();
        $('.has-sticky-header .ninetheme-header-sticky').parent().css("min-height",stickyHeaderHeight);
        winw = $(window).outerWidth();
        bodyResize();
        topMainHeader();
        mobileSlidingMenu();
        mobileHeaderActions();
        ninethemeHeaderCatMenu();
        ninethemeHeaderVerticalMenu2();
        ninethemeSwiperSlider();
        ninethemeSlickSlider();
        ninethemeVegasSlider();
        ninethemeVegasTemplateSlider();
        ninethemeFixedSection();
        ninethemePopupTemplate();
        ninethemeCountDown()
        scrollToTopBtnClick();
        noneElementorPageFix();
        ninethemeLightbox();
        ninethemeTooltip();
        popupNewsletter();
        popupGdpr();
        ninethemeCf7Form();
        // WooCommerce
        ninethemeWcInit();

        if ( $('.ninetheme-related-post-area .ninetheme-related-slider').length ) {
            var optionsRelated = $('.ninetheme-related-post-area .ninetheme-related-slider').data('swiper-options');
            var relatedSlider  = new NTSwiper('.ninetheme-related-post-area .ninetheme-related-slider', optionsRelated );
        }


        $('.ninetheme-header-bottom-bar .ninetheme-shop-filter-top-area').removeClass('ninetheme-shop-filter-top-area');

        if ( $('.ninetheme-header-content>div').length == 3 ) {
            $('div.header-top-side').sameSize(true);
        }

        $('div[data-bg]:not(.loaded)').each( function(i, el) {
            var $this = $(el);
            var bgUrl = $this.data('bg');
            $this.css('background-image', 'url(' + bgUrl + ')' );
        });

        $('.ninetheme-product-category-slider.style-3 .ninetheme-category-inner').each( function(i, el) {
            var $this = $(el);
            var height = $this.parent().css('width');
            console.log(height);
            $this.css('min-height', height );
        });

    });

    body.attr("data-ninetheme-resize", $(window).outerWidth());

    function getHeaderPositionTop() {
        var header  = $('.has-sticky-header .ninetheme-header-top-menu-area').parents('.ninetheme-header-row'),
            headerH = header.height(),
            headerP = header.position(),
            headerP = typeof headerP != 'undefined' ? headerP.top : 0,
            offSetH = headerH + headerP + 20;

        return offSetH;
    }
    function getHeaderPosition() {
        var header  = $('.has-sticky-header .ninetheme-header-top-menu-area').parents('.ninetheme-header-row'),
            headerH = header.height(),
            headerP = header.position(),
            headerP = typeof headerP != 'undefined' ? headerP.top : 0,
            offSetH = ( headerH * 2 ) + headerP+100;

        return offSetH;
    }

    // === window When resize === //
    win.resize( function() {
        winw = $(window).outerWidth();
        bodyResize(winw);
        topMainHeaderResize(winw);
        mobileHeaderResize(winw);
        masonryInit(winw);
        if ( $('.ninetheme-header-content>div').length == 3 ) {
            $('div.header-top-side').sameSize(true);
        }
        body.addClass("ninetheme-on-resize");
        body.attr("data-ninetheme-resize", winw);

        var bodyScroll = $(window).scrollTop();

        if ( winw == 1280 ) {
            $(".ninetheme-header-default-bottom-sticky").removeClass('sticky-start');
        }

        if ( bodyScroll > getHeaderPosition()  ) {
            $('.has-sticky-header .ninetheme-header-sticky').addClass("sticky-start");
        } else {
            $('.has-sticky-header .ninetheme-header-sticky').removeClass("sticky-start");
        }

        if ( typeof elementorFrontend != 'undefined' ) {
            var deviceMode = elementorFrontend.getCurrentDeviceMode();

            $('[data-bg-responsive]').each( function(index, el) {
                var $this = $(el);
                var elBg  = $this.data('bg-responsive');

                if ( typeof elBg != 'undefined' ) {
                    var desktop = $(el).data('bg');

                    var widescreen   = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : desktop;
                    var laptop       = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : desktop;
                    var tablet_extra = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : laptop;
                    var tablet       = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : tablet_extra;
                    var mobile_extra = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : tablet;
                    var mobile       = typeof elBg[deviceMode] != 'undefined' ? elBg[deviceMode] : mobile_extra;
                    var bgUrl        = mobile;

                    if ( bgUrl ) {
                        $this.css('background-image', 'url(' + bgUrl + ')' );
                    }
                }
            });

            var deviceMode = elementorFrontend.getCurrentDeviceMode();
            var dataDeviceMode = $('body');
            $('body').addClass(deviceMode);
        }

        $('.elementor-section[data-header-mobile-breakpoint]').each( function() {
            var $breakpoint = $( this ).data('header-mobile-breakpoint');
            if ( winw <= $breakpoint ) {
                $('body').addClass('mobile-active');
            } else {
                $('body').removeClass('mobile-active');
            }
        });

    });

    // === window When scroll === //
    var lastScrollTop = 0;
    win.on("scroll", function () {
        var bodyScroll = win.scrollTop();
        var st = $(this).scrollTop();

        var sheader = $('.has-sticky-header .ninetheme-header-sticky'),
            header  = $('.has-sticky-header .ninetheme-header-top-menu-area').parents('.ninetheme-header-row'),
            headerH = header.height(),
            headerP = header.position(),
            headerP = typeof headerP != 'undefined' ? headerP.top : 0,
            offSetH = headerH + headerP+20,
            offSetH2 = offSetH+10;

        if ( bodyScroll > 0 ) {
            body.addClass("scroll-start");
        } else {
            body.removeClass("scroll-start");
        }

        if ( bodyScroll > offSetH ) {
            sheader.addClass("sticky-ready");
        } else {
            sheader.removeClass("sticky-ready");
        }

        if ( bodyScroll > offSetH2 ) {
            sheader.addClass("sticky-start");
            //$('.has-sticky-header').addClass("sticky-header-start");
        } else {
            sheader.removeClass("sticky-start");
            //$('.has-sticky-header').removeClass("sticky-header-start");
        }

        if ( $('.ninetheme-header-mobile-top').length>0 ) {
            var mobHeaderPos = $('.ninetheme-header-mobile-top').position();
            var mobHeaderHeight = $('.ninetheme-header-mobile-top').outerHeight();
            var mobHeaderPosition = mobHeaderPos.top + mobHeaderHeight;

            if ( bodyScroll > mobHeaderPosition ) {
                $('.ninetheme-header-mobile-top-wrapper').css("padding-bottom",mobHeaderHeight);
                $('.ninetheme-header-mobile-top').addClass("sticky-start");
            } else {
                $('.ninetheme-header-mobile-top-wrapper').css("padding-bottom",0);
                $('.ninetheme-header-mobile-top').removeClass("sticky-start");
            }
        }

        var filterArea = $('.ninetheme-products-column .ninetheme-before-loop.ninetheme-shop-filter-top-area');

        if ( filterArea.length ) {
            var filterAreaPos = filterArea.offset(),
                topoffset = $('.ninetheme-header-bottom-bar').hasClass('ninetheme-elementor-template') ? 10 : filterAreaPos.top-62;
            if ( bodyScroll > topoffset ) {
                $('.ninetheme-header-bottom-bar').addClass('sticky-filter-active');
            } else {
                $('.ninetheme-header-bottom-bar').removeClass('sticky-filter-active');
            }
        }

        scrollToTopBtnHide();

    });

    // === window When Loading === //
    win.on("load", function () {
        var bodyScroll = win.scrollTop();

        if ( bodyScroll > getHeaderPosition()  ) {
            $('.has-sticky-header .ninetheme-header-sticky').addClass("sticky-start");
        } else {
            $('.has-sticky-header .ninetheme-header-sticky').removeClass("sticky-start");
        }

        if ( $(".preloader").length ) {
          $( ".preloader" ).fadeOut();
        }
        body.addClass("page-loaded");

        //$('body').trigger('ninetheme_lazy_load');

        ninethemeSimpleParallax();

    });

    if ( window.orientation == 0 || window.orientation == 180) {
        body.removeClass("ninetheme-landscape").addClass("ninetheme-portrait");
    } else {
        body.removeClass("ninetheme-portrait").addClass("ninetheme-landscape");
    }

    win.on('orientationchange', function(event) {

        body.addClass("ninetheme-orientation-changed");
        if ( window.orientation == 0 || window.orientation == 180) {
            body.removeClass("ninetheme-landscape").addClass("ninetheme-portrait");
        } else {
            body.removeClass("ninetheme-portrait").addClass("ninetheme-landscape");
        }
        console.log('Width: '+$(window).outerWidth());
        console.log('Height: '+$(window).outerHeight());
    });

})(window, document, jQuery);
