<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 8.6.0
 */

// Elementor `archive` location
if ( function_exists( 'elementor_theme_do_location' ) && elementor_theme_do_location( 'archive' ) ) {
    get_header();
}

// Elementor `archive` location
if ( ! function_exists( 'elementor_theme_do_location' ) || ! elementor_theme_do_location( 'archive' ) ) {

    if ( 'elementor' == ninetheme_settings( 'shop_template_type' ) || '' != apply_filters('ninetheme_elementor_shop', null ) ) {

        get_template_part('woocommerce/archive-product-elementor' );

    } else {

        $mode      = woocommerce_get_loop_display_mode();
        $is_tax    = isset( get_queried_object()->term_id ) ? get_queried_object()->term_id : '';
        $layout    = apply_filters('ninetheme_shop_layout', ninetheme_settings( 'shop_layout', 'left-sidebar' ) );
        $column    = ( $layout == 'left-sidebar' || $layout == 'right-sidebar' ) && is_active_sidebar( 'shop-page-sidebar' ) ? 'col-lg-9' : 'col-lg-12';
        $container = ninetheme_settings( 'shop_container_width', 'default' );
        $container = 'default' == $container ? 'container-xl ninetheme-container-xl' : 'container-fluid';
        $masonry   = 'masonry' == ninetheme_settings( 'shop_grid_type', 'grid' ) || ( isset( $_GET['shop_grid'] ) && $_GET['shop_grid'] == 'masonry' ) ? ' shop-masonry-grid masonry-column-'.ninetheme_settings( 'shop_masonry_column', '4' ) : '';

        $class      = ' '.$layout;
        $class     .= '1' == ninetheme_settings( 'woo_catalog_mode', '0' ) ? ' shop-catalog-mode' : '';
        $class     .= $mode == 'subcategories' || $mode == 'both' ? ' shop-mode-cats display_mode-'.$mode : '';
        $class     .= $is_tax ? ' is_tax-archive' : '';

        if ( $mode == 'subcategories' && !$is_tax ) {
            remove_action( 'ninetheme_shop_before_loop', 'shop_loop_filters_layouts', 15 );
            remove_action( 'ninetheme_shop_main_loop', 'ninetheme_shop_main_loop', 10 );
        }
        if ( $mode == 'subcategories' && $is_tax ) {
            remove_action( 'ninetheme_shop_before_loop', 'shop_loop_filters_layouts', 15 );
            remove_action( 'ninetheme_shop_main_loop', 'ninetheme_shop_main_loop', 10 );
        }

        wp_enqueue_script( 'jquery-nice-select');

        if ( ninetheme_is_pjax() ) {

            do_action( 'ninetheme_shop_main_loop' );
            do_action( 'ninetheme_shop_after_ajax' );

        } else {

            get_header();

        ?>
        <div id="nt-shop-page" class="nt-shop-page<?php echo esc_attr( $masonry ); ?>">
            <?php
            /**
            * Hook: ninetheme_before_shop_content.
            *
            * @hooked ninetheme_wc_hero_section - 10
            * @hooked ninetheme_before_shop_elementor_templates - 15
            */
            do_action( 'ninetheme_before_shop_content' );
            ?>

            <div class="ninetheme-inner-container shop-area section-padding<?php echo esc_attr( $class ); ?>">
                <div class="<?php echo esc_attr( $container ); ?>">

                    <?php if ( $mode == 'subcategories' && !$is_tax ) { ?>
                        <div class="row ninetheme-choosen-filters-row"><?php do_action( 'ninetheme_choosen_filters' );?></div>
                    <?php } ?>
                    <div class="row">

                        <?php
                        /**
                        * Hook: ninetheme_shop_sidebar.
                        *
                        * @hooked ninetheme_shop_sidebar - 10
                        */
                        do_action( 'ninetheme_shop_sidebar' );
                        ?>

                        <div class="<?php echo esc_attr( $column ); ?> ninetheme-products-column">
                            <?php
                            /**
                            * Hook: ninetheme_shop_before_loop.
                            *
                            * @hooked ninetheme_print_category_banner - 10
                            * @hooked shop_loop_filters_layouts - 15
                            * @hooked ninetheme_shop_top_hidden_sidebar - 20
                            */
                            do_action( 'ninetheme_shop_before_loop' );

                            /**
                            * Hook: ninetheme_shop_main_loop.
                            *
                            * @hooked ninetheme_shop_main_loop - 10
                            */
                            do_action( 'ninetheme_shop_main_loop' );

                            /**
                            * Hook: ninetheme_after_shop_loop.
                            *
                            * @hooked ninetheme_after_shop_loop_elementor_templates - 10
                            */
                            do_action( 'ninetheme_after_shop_loop' );
                            ?>
                        </div>

                    </div>
                </div>
            </div>
        </div>
        <?php

        /**
        * Hook: ninetheme_after_shop_page.
        *
        * @hooked ninetheme_after_shop_page_elementor_templates - 10
        * @hooked ninetheme_shop_sidebar_fixed - 20
        */
        do_action('ninetheme_after_shop_page');
        }

        if ( !ninetheme_is_pjax() ) {
            get_footer();
        }
    }
}
// Elementor `archive` location
if ( function_exists( 'elementor_theme_do_location' ) && elementor_theme_do_location( 'archive' ) ) {
    get_footer();
}

?>
