<?php
/**
* Mini-cart
*
* Contains the markup for the mini-cart, used by the cart widget.
*
* This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
*
* HOWEVER, on occasion WooCommerce will need to update template files and you
* (the theme developer) will need to copy the new files to your theme to
* maintain compatibility. We try to do this as little as possible, but it does
* happen. When this occurs the version of the template file will be bumped and
* the readme will list any important changes.
*
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
if ( ! class_exists('WooCommerce') ) {
    return;
}

global $woocommerce;

do_action( 'woocommerce_before_mini_cart' );

$checkout_url  = apply_filters( 'woocommerce_get_checkout_url', wc_get_checkout_url() );
$has_clear_btn = ! WC()->cart->is_empty() && count( WC()->cart->get_cart() ) >= 2 ? ' has-clear-btn' : '';
$show_quantity = ninetheme_settings('cart_quantity_visibility', '0');
?>
<div class="minicart-panel">
    <?php if ( ! WC()->cart->is_empty() ) : ?>
        <div class="ninetheme-header-cart-details ninetheme-minicart">
            <div class="woocommerce-mini-cart has-product<?php echo esc_attr( $has_clear_btn ); ?>">
                <div class="ninetheme-scrollbar">
                    <?php
                    do_action( 'woocommerce_before_mini_cart_contents' );
                    foreach ( WC()->cart->get_cart() as $key => $item ) {
                        $p   = apply_filters( 'woocommerce_cart_item_product', $item['data'], $item, $key );
                        $pid = apply_filters( 'woocommerce_cart_item_product_id', $item['product_id'], $item, $key );
                        $is_visible = apply_filters( 'woocommerce_widget_cart_item_visible', true, $item, $key );
                        if ( $p && $p->exists() && $item['quantity'] > 0 && $is_visible ) {
                            $name   = apply_filters( 'woocommerce_cart_item_name', $p->get_name(), $item, $key );
                            $price  = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $p ), $item, $key );
                            $imgurl = get_the_post_thumbnail_url($item['product_id'],'ninetheme-panel');
                            $imgsrc = $imgurl ? $imgurl : wc_placeholder_img_src();
                            $img    = '<img width="80" height="80" src="'.$imgsrc.'" alt="'.esc_attr( $name ).'"/>';
                            $qty    = $item['quantity'];
                            $max    = $p->backorders_allowed() ? '' : $p->get_stock_quantity();
                            //$class  = $max && ( $qty >= $max ) ? ' cart-disabled' : '';
                            ?>
                            <div class="woocommerce-mini-cart-item mini-cart-item ninetheme-cart-item">
                                <div class="cart-item-details">
                                    <a class="product-link" href="<?php echo esc_url( get_permalink( $item['product_id'] ) ) ?>"><?php printf( '%s', $img ); ?></a>
                                    <div class="cart-item-title ninetheme-small-title">
                                        <a class="product-link" href="<?php echo esc_url( get_permalink( $item['product_id'] ) ) ?>"><?php printf( '<span class="cart-name">%s %s</span>', $name, wc_get_formatted_cart_item_data( $item ) ); ?></a>

                                        <div class="cart-quantity-wrapper ajax-quantity" data-product_id="<?php echo esc_attr( $item['product_id'] ); ?>" data-key="<?php echo esc_attr( $key ); ?>">
                                            <?php
                                            if ( $p->is_sold_individually() ) {
                                                $min = 1;
                                                $max = 1;
                                            } else {
                                                $min = 0;
                                                $max = $p->get_max_purchase_quantity();
                                            }
                                            $quantity = woocommerce_quantity_input(
                                                array(
                                                    'input_name'   => "cart[{$key}][qty]",
                                                    'input_value'  => $qty,
                                                    'max_value'    => $max,
                                                    'min_value'    => $min,
                                                    'product_name' => $name
                                                ),
                                                $p,
                                                false
                                            );
                                            echo apply_filters( 'woocommerce_cart_item_quantity', $quantity, $key, $item );
                                            ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="del-icon" data-id="<?php echo esc_attr( $pid ); ?>">
                                    <?php echo apply_filters(
                                        'woocommerce_cart_item_remove_link',
                                        sprintf(
                                            '<a href="%s" class="ninetheme_remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_name="%s" data-qty="%s">'.ninetheme_svg_lists( 'trash', 'ninetheme-svg-icon mini-icon' ).'</a>',
                                            esc_url( wc_get_cart_remove_url( $key ) ),
                                            esc_attr( sprintf( __( 'Remove %s from cart', 'crisop' ), wp_strip_all_tags( $name ) ) ),
                                            esc_attr( $pid ),
                                            esc_attr( $key ),
                                            esc_attr( $name ),
                                            $qty
                                        ),
                                        $key
                                    );
                                    ?>
                                </div>
                            </div>
                            <?php
                        }
                    }
                    do_action( 'woocommerce_mini_cart_contents' );
                    ?>
                </div>
                <?php if ( count( WC()->cart->get_cart() ) >= 2 ) : ?><div class="ninetheme_clear_cart_button"><?php esc_html_e( 'Clear All', 'crisop' ); ?></div><?php endif; ?>
            </div>
            <div class="header-cart-footer">
                <div class="cart-total">
                    <div class="cart-total-price">
                        <div class="cart-total-price-left"><?php echo esc_html_e( 'Subtotal: ', 'crisop' ); ?></div>
                        <div class="cart-total-price-right"><?php printf( '%s', $woocommerce->cart->get_cart_subtotal() ); ?></div>
                    </div>
                </div>
                <?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>
                <div class="cart-bottom-btn">
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-yellow ninetheme-view-shop-link" href="<?php echo esc_url( apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) ); ?>"><?php esc_html_e( 'Continue Shopping', 'crisop' ); ?></a>
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-primary ninetheme-view-cart-link" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><?php echo esc_html_e( 'View Cart', 'crisop' ); ?></a>
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-primary ninetheme-view-checkout-link" href="<?php echo esc_url( $checkout_url ); ?>"><?php echo esc_html_e( 'Checkout', 'crisop' ); ?></a>
                </div>
                <?php do_action( 'woocommerce_widget_shopping_cart_after_buttons' ); ?>
            </div>
        </div>
    <?php else : ?>
        <div class="ninetheme-header-cart-details ninetheme-minicart">
            <div class="cart-empty-content">
                <?php echo ninetheme_svg_lists( 'bag' ); ?>
                <?php if ( '' != ninetheme_settings('sidebar_panel_cart_custom_title') ) { ?>
                    <span class="minicart-title"><?php echo esc_html( ninetheme_settings('sidebar_panel_cart_custom_title') ); ?></span>
                <?php } else { ?>
                    <span class="minicart-title"><?php esc_html_e( 'Your Cart', 'crisop' ); ?></span>
                <?php } ?>
                <p class="empty-title ninetheme-small-title"><?php esc_html_e( 'No products in the cart.', 'crisop' ); ?></p>
                <?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>
                <div class="cart-empty-actions cart-bottom-btn">
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-yellow" href="<?php echo esc_url( apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) ); ?>"><?php esc_html_e( 'Start Shopping', 'crisop' ); ?></a>
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-primary" href="<?php echo esc_url( get_permalink( get_option( 'wp_page_for_privacy_policy' ) ) ); ?>"><?php esc_html_e( 'Return Policy', 'crisop' ); ?></a>
                </div>
                <?php do_action( 'woocommerce_widget_shopping_cart_after_buttons' ); ?>
            </div>
        </div>
    <?php endif; ?>
</div>
<?php do_action( 'woocommerce_after_mini_cart' ); ?>
