<?php
/**
* Related Products
*
* This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
*
* HOWEVER, on occasion WooCommerce will need to update template files and you
* (the theme developer) will need to copy the new files to your theme to
* maintain compatibility. We try to do this as little as possible, but it does
* happen. When this occurs the version of the template file will be bumped and
* the readme will list any important changes.
*
* @see         https://docs.woocommerce.com/document/template-structure/
* @package     WooCommerce\Templates
* @version     3.9.0
*/

global $product, $woocommerce_loop;

if ( empty( $product ) || ! $product->exists() ) {
    return;
}

$posts_per_page = ninetheme_settings('single_shop_related_count', 10 );

if ( ! $related = wc_get_related_products( $product->get_id(), $posts_per_page ) ) {
    return;
}

// Get ID of current product, to exclude it from the related products query
$current_product_id = $product->get_id();

$cats_array = array(0);

// get categories
$terms = wp_get_post_terms( $product->get_id(), 'product_cat' );

// select only the category which doesn't have any children
foreach ( $terms as $term ) {
    $children = get_term_children( $term->term_id, 'product_cat' );
    if ( !sizeof( $children ) )
    $cats_array[] = $term->term_id;
}

$args = apply_filters( 'woocommerce_related_products_args', array(
    'post_type'           => 'product',
    'post__not_in'        => array( $current_product_id ),
    'posts_status'        => 'publish',
    'ignore_sticky_posts' => 1,
    'no_found_rows'       => 1,
    'posts_per_page'      => $posts_per_page,
    'tax_query'           => array(
        array(
            'taxonomy' => 'product_cat',
            'field'    => 'id',
            'terms'    => $cats_array
        )
    )
));
$hideoutstock = get_option('woocommerce_hide_out_of_stock_items');
if ($hideoutstock == 'yes' ) {
        $args['meta_query'][] = array(
            'key'       => '_stock_status',
            'compare'   => '=',
            'value'     => 'instock'
        );
}

$heading = ninetheme_settings('single_shop_related_title', '');
$heading = $heading ? esc_html( $heading ) : apply_filters('woocommerce_product_related_products_heading', esc_html__('Viewers Also Liked', 'crisop' ));

$slider_options = json_encode(array(
    "loop"          => '1' == ninetheme_settings( 'shop_related_loop', '0' ) ? true : false,
    "speed"         => intval(ninetheme_settings( 'shop_related_speed', 800 )),
    "spaceBetween"  => intval(ninetheme_settings( 'shop_related_gap', 20 )),
    "slidesPerView" => 1,
    "grabCursor"    => true,
    "autoHeight"    => true,
    "watchSlidesProgress" => true,
    "autoplay"      => '1' == ninetheme_settings( 'shop_related_autoplay', 1 ) ? ["pauseOnMouseEnter" => true,"disableOnInteraction" => false] : false,
    "navigation"    => [
        "nextEl" => ".related-slider-nav .ninetheme-slide-next",
        "prevEl" => ".related-slider-nav .ninetheme-slide-prev"
    ],
    "breakpoints"   => [
        "0" => [
            "slidesPerView" => intval(ninetheme_settings( 'shop_related_smperview', 2 ))
        ],
        "768" => [
            "slidesPerView" => intval(ninetheme_settings( 'shop_related_mdperview', 3 ))
        ],
        "1024" => [
            "slidesPerView" => intval(ninetheme_settings( 'shop_related_perview', 4 ))
        ]
    ]
));

$products = new WP_Query( $args );

if ( $products->have_posts() ) {
    wp_enqueue_script( 'swiper' );
    ?>
    <div class="ninetheme-product-related ninetheme-section">
        <div class="section-title-wrapper">
            <?php if ( $heading ) : ?>
                <h6 class="section-title"><?php echo esc_html( $heading ); ?></h6>
            <?php endif; ?>
            <div class="related-slider-nav slider-nav-top">
                <div class="ninetheme-slide-prev swiper-button-prev"></div>
                <div class="ninetheme-slide-next swiper-button-next"></div>
            </div>
        </div>
        <div class="ninetheme-wc-swipper-wrapper woocommerce style-1">
            <div class="ninetheme-related-slider swiper-container" data-swiper-options="<?php echo esc_attr( $slider_options ); ?>">
                <div class="swiper-wrapper">
                    <?php
                    while ( $products->have_posts() ) : $products->the_post();
                        global $product;
                        if ( !empty( $product ) && $product->is_visible() ) {
                            ?>
                            <div class="swiper-slide">
                                <?php wc_get_template_part( 'content', 'product' ); ?>
                            </div>
                            <?php
                        }
                    endwhile;
                    ?>
                </div>
            </div>
        </div>
    </div>
    <?php
}
wp_reset_postdata();
