<?php

/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (! class_exists('Redux' )) {
    return;
}


// This is your option name where all the Redux data is stored.
$ninetheme_pre = "crisop";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$ninetheme_theme = wp_get_theme(); // For use with some settings. Not necessary.

$ninetheme_options_args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $ninetheme_pre,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $ninetheme_theme->get('Name' ),
    // Name that appears at the top of your panel
    'display_version' => $ninetheme_theme->get('Version' ),
    // Version that appears at the top of your panel
    'menu_type' => 'submenu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => false,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__( 'Theme Options', 'crisop' ),
    'page_title' => esc_html__( 'Theme Options', 'crisop' ),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => false,
    // Use a asynchronous font on the front end or font string
    'admin_bar' => false,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-admin-generic',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => 'crisop',
    // Set a different name for your global variable other than the ninetheme_pre
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support

    // OPTIONAL -> Give you extra features
    'page_priority' => 99,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => apply_filters( 'ninetheme_parent_slug', 'themes.php' ),
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '',
    // Page slug used to denote the panel, will be based off page title then menu title then ninetheme_pre if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'dark',
            'shadow' => true,
            'rounded' => false,
            'style' => '',
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover',
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave',
            ),
        ),
    )
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$ninetheme_options_args['admin_bar_links'][] = array(
    'id' => 'ninetheme-ninetheme-docs',
    'href' => 'http://ninetheme.com/support/',
    'title' => esc_html__( 'Crisop Documentation', 'crisop' ),
);
$ninetheme_options_args['admin_bar_links'][] = array(
    'id' => 'ninetheme-support',
    'href' => 'https://9theme.ticksy.com/',
    'title' => esc_html__( 'Support', 'crisop' ),
);
$ninetheme_options_args['admin_bar_links'][] = array(
    'id' => 'ninetheme-portfolio',
    'href' => 'https://themeforest.net/user/ninetheme/portfolio',
    'title' => esc_html__( 'NineTheme Portfolio', 'crisop' ),
);

// Add content after the form.
$ninetheme_options_args['footer_text'] = esc_html__( 'If you need help please read docs and open a ticket on our support center.', 'crisop' );

Redux::setArgs($ninetheme_pre, $ninetheme_options_args);

/* END ARGUMENTS */

/* START SECTIONS */

$el_args = array(
	'post_type'      => 'elementor_library',
	'posts_per_page' => -1,
	'orderby'        => 'title',
	'order'          => 'ASC',
	'meta_query'     => array(
		'relation' => 'OR',
		array(
			'key'     => '_elementor_template_type',
			'value'   => 'section',
			'compare' => '='
		),
		array(
			'key'     => '_elementor_template_type',
			'value'   => 'container',
			'compare' => '='
		)
	)
);

$activekit = get_option( 'elementor_active_kit' );

$wpcf7_args = array(
    'post_type'      => 'wpcf7_contact_form',
    'posts_per_page' => -1,
    'orderby'        => 'title',
    'order'          => 'ASC'
);

function crisop_wc_attributes()
{
    $options = array();

    $terms = wc_get_attribute_taxonomies();
    if ( !empty( $terms ) && !is_wp_error( $terms ) ) {
        foreach ( $terms as $term ) {
            $options[ $term->attribute_name ] = $term->attribute_label;
        }
    }

    return $options;
}

/*************************************************
## MAIN SETTING SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Main Setting', 'crisop' ),
    'id' => 'theme_main_settings_section',
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'icon' => 'el el-cog',
));
//BREADCRUMBS SETTINGS SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Typograhy and Color', 'crisop' ),
    'id' => 'theme_colors_subsection',
    'icon' => 'el el-brush',
    'subsection' => true,
    'fields' => array(
        array(
            'id' =>'edit_typograhy_settings',
            'type' => 'info',
            'desc' => sprintf( '<b>%s</b> <a class="thm-btn" href="%s" target="_blank">%s</a>',
                esc_html__( 'This theme uses Elementor Site Settings', 'crisop' ),
                admin_url('post.php?post='.$activekit.'&action=elementor'),
                esc_html__( 'Site Settings', 'crisop' )
            )
        ),
        array(
            'id' =>'theme_layout_mode',
            'type' => 'button_set',
            'title' => esc_html__( 'Theme Layout', 'crisop' ),
            'customizer' => true,
            'options' => array(
                'theme-layout-default' => esc_html__( 'Default', 'crisop' ),
                'theme-layout-boxed' => esc_html__( 'Boxed', 'crisop' ),
                'theme-layout-fullwidth' => esc_html__( 'Fullwidth', 'crisop' ),
                'theme-layout-stretch' => esc_html__( 'Stretch', 'crisop' ),
            ),
            'default' => 'default'
        ),
        array(
            'title' => esc_html__( 'Boxed Layout Wrapper Width', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to control the theme boxed mode wraper width.', 'crisop' ),
            'customizer' => true,
            'id' => 'theme_boxed_mode_wrapper_width',
            'type' => 'slider',
            'default' => 1260,
            'min' => 0,
            'step' => 1,
            'max' => 4000,
            'display_value' => 'text',
            'required' => array( 'theme_layout_mode', '=', 'theme-layout-boxed' )
        ),
        array(
            'title' => esc_html__( 'Body Background Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#f7f7f8"></div> %s',esc_html__( 'Default: #f7f7f8', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_boxed_body_bgclr',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => 'body.boxed-mode-enabled',
            'default' => '',
            'required' => array( 'theme_layout_mode', '=', 'theme-layout-boxed' )
        ),
        array(
            'title' => esc_html__( 'Wrapper Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'theme_boxed_wrapper_bgclr',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => 'body.boxed-mode-enabled #wrapper',
            'default' => '',
            'required' => array( 'theme_layout_mode', '=', 'theme-layout-boxed' )
        ),
        array(
            'title' => esc_html__( 'Theme Content Width', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to control the theme content width.', 'crisop' ),
            'customizer' => true,
            'id' => 'content_width',
            'type' => 'slider',
            'default' => 1240,
            'min' => 0,
            'step' => 1,
            'max' => 4000,
            'display_value' => 'text'
        ),
        array(
            'title' => esc_html__( 'Primary Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#6C5EBC"></div> %s',esc_html__( 'Default: #6C5EBC', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr1',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Secondary Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#96BB7C"></div> %s',esc_html__( 'Default: #96BB7C', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr2',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Text Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#2d2d2d"></div> %s',esc_html__( 'Default: #2d2d2d', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr3',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Text Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#6a6a6a"></div> %s',esc_html__( 'Default: #6a6a6a', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr4',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Dark Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#161616"></div> %s',esc_html__( 'Default: #161616', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr5',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Dark Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#343131"></div> %s',esc_html__( 'Default: #343131', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr6',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Light Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#ffffff"></div> %s',esc_html__( 'Default: #ffffff', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr7',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Light Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#bdbdbd"></div> %s',esc_html__( 'Default: #bdbdbd', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr8',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Gray Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#E1E2E3"></div> %s',esc_html__( 'Default: #E1E2E3', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr9',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Gray Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#F7F7F8"></div> %s',esc_html__( 'Default: #F7F7F8', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr10',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Border Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#f0f0f1"></div> %s',esc_html__( 'Default: #f0f0f1', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr11',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Border Dark Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#363636"></div> %s',esc_html__( 'Default: #363636', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr12',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Border Trans Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#f7f7f833"></div> %s',esc_html__( 'Default: #f7f7f833', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr13',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Success Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#5aab19"></div> %s',esc_html__( 'Default: #5aab19', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr14',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Red Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#DD2623"></div> %s',esc_html__( 'Default: #DD2623', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr15',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Red Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#FFC4C3"></div> %s',esc_html__( 'Default: #FFC4C3', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr16',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Green Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#599078"></div> %s',esc_html__( 'Default: #599078', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr17',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Green Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#C0F0DC"></div> %s',esc_html__( 'Default: #C0F0DC', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr18',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Purple Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#6C5EBC"></div> %s',esc_html__( 'Default: #6C5EBC', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr19',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Purple Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#D8D2FF"></div> %s',esc_html__( 'Default: #D8D2FF', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr20',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Yellow Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#EFDE35"></div> %s',esc_html__( 'Default: #EFDE35', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr21',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Yellow Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#FFFDA5"></div> %s',esc_html__( 'Default: #FFFDA5', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr22',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Brown Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#ECDBBA"></div> %s',esc_html__( 'Default: #ECDBBA', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr23',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Blue Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#002597"></div> %s',esc_html__( 'Default: #002597', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr24',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Blue Soft Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#B5C7FF"></div> %s',esc_html__( 'Default: #B5C7FF', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr25',
            'type' => 'color',
            'default' => ''
        ),
        array(
            'title' => esc_html__( 'Blue Dark Color', 'crisop' ),
            'subtitle' => sprintf( '<div style="width:15px;height:15px;background:#011962"></div> %s',esc_html__( 'Default: #011962', 'crisop' )),
            'customizer' => true,
            'id' => 'theme_clr26',
            'type' => 'color',
            'default' => ''
        )
    )
));
//BREADCRUMBS SETTINGS SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Breadcrumbs', 'crisop' ),
    'id' => 'theme_breadcrumbs_subsection',
    'icon' => 'el el-cog',
    'subsection' => true,
    'fields' => array(
        array(
            'title' => esc_html__( 'Breadcrumbs', 'crisop' ),
            'subtitle' => esc_html__( 'If enabled, adds breadcrumbs navigation to bottom of page title.', 'crisop' ),
            'customizer' => true,
            'id' => 'breadcrumbs_visibility',
            'type' => 'switch',
            'default' => true
        ),
        array(
            'id' =>'shop_breadcrumbs_type',
            'type' => 'button_set',
            'title' => esc_html__( 'Shop Pages Breadcrumbs Template', 'crisop' ),
            'customizer' => true,
            'options' => array(
                'theme' => esc_html__( 'Theme Breadcrumbs', 'crisop' ),
                'woo' => esc_html__( 'WooCommerce Breadcrumbs', 'crisop' ),
            ),
            'default' => 'theme',
            'required' => array( 'breadcrumbs_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Typography', 'crisop' ),
            'id' => 'breadcrumbs_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.ninetheme-breadcrumb li a,.woocommerce-breadcrumb a' ),
            'required' => array(
                array( 'shop_hero_visibility', '=', '1' ),
                array( 'shop_hero_type', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Breadcrumbs Link Color', 'crisop' ),
            'customizer' => true,
            'id' => 'breadcrumbs_link_clr',
            'type' => 'color',
            'default' => '',
            'output' => array( '.ninetheme-breadcrumb li a,.woocommerce-breadcrumb a' ),
            'required' => array( 'breadcrumbs_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Breadcrumbs Link Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'breadcrumbs_link_hvrclr',
            'type' => 'color',
            'default' => '',
            'output' => array( '.ninetheme-breadcrumb li a:hover,.woocommerce-breadcrumb a:hover' ),
            'required' => array( 'breadcrumbs_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Breadcrumbs Current Color', 'crisop' ),
            'customizer' => true,
            'id' => 'breadcrumbs_current',
            'type' => 'color',
            'default' => '',
            'output' => array( '.ninetheme-breadcrumb li.breadcrumb_active, .ninetheme-breadcrumb .breadcrumb-item.active, .woocommerce-breadcrumb' ),
            'required' => array( 'breadcrumbs_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Breadcrumbs Separator Color', 'crisop' ),
            'customizer' => true,
            'id' => 'breadcrumbs_icon',
            'type' => 'color',
            'default' => '',
            'output' => array( '.ninetheme-breadcrumb .breadcrumb_link_seperator, .ninetheme-breadcrumb .breadcrumb-item+.breadcrumb-item::before,.woocommerce-breadcrumb a:after' ),
            'required' => array( 'breadcrumbs_visibility', '=', '1' )
        )
    )
));
//PRELOADER SETTINGS SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Preloader', 'crisop' ),
    'id' => 'theme_preloader_subsection',
    'icon' => 'el el-cog',
    'subsection' => true,
    'fields' => array(
        array(
            'title' => esc_html__( 'Preloader', 'crisop' ),
            'subtitle' => esc_html__( 'If enabled, adds preloader.', 'crisop' ),
            'customizer' => true,
            'id' => 'preloader_visibility',
            'type' => 'switch',
            'default' => true
        ),
        array(
            'title' => esc_html__( 'Preloader Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your preloader type.', 'crisop' ),
            'customizer' => true,
            'id' => 'pre_type',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'default' => esc_html__( 'Default', 'crisop' ),
                '01' => esc_html__( 'Type 1', 'crisop' ),
                '02' => esc_html__( 'Type 2', 'crisop' ),
                '03' => esc_html__( 'Type 3', 'crisop' ),
                '04' => esc_html__( 'Type 4', 'crisop' ),
                '05' => esc_html__( 'Type 5', 'crisop' ),
                '06' => esc_html__( 'Type 6', 'crisop' ),
                '07' => esc_html__( 'Type 7', 'crisop' ),
                '08' => esc_html__( 'Type 8', 'crisop' ),
                '09' => esc_html__( 'Type 9', 'crisop' ),
                '10' => esc_html__( 'Type 10', 'crisop' ),
                '11' => esc_html__( 'Type 11', 'crisop' ),
                '12' => esc_html__( 'Type 12', 'crisop' )
            ),
            'default' => '12'
        ),
        array(
            'title' => esc_html__( 'Preloader Image', 'crisop' ),
            'subtitle' => esc_html__( 'Upload your Logo. If left blank theme will use site default preloader.', 'crisop' ),
            'customizer' => true,
            'id' => 'pre_img',
            'type' => 'media',
            'url' => true,
            'customizer' => true,
            'required' => array(
                array( 'preloader_visibility', '=', '1' ),
                array( 'pre_type', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Background Color', 'crisop' ),
            'subtitle' => esc_html__( 'Add preloader background color.', 'crisop' ),
            'customizer' => true,
            'id' => 'pre_bg',
            'type' => 'color',
            'default' => '',
            'required' => array( 'preloader_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Spin Color', 'crisop' ),
            'subtitle' => esc_html__( 'Add preloader spin color.', 'crisop' ),
            'customizer' => true,
            'id' => 'pre_spin',
            'type' => 'color',
            'default' => '',
            'required' => array( 'preloader_visibility', '=', '1' )
        )
    )
));
//NEWSLETTER SETTINGS SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Popup Newsletter', 'crisop' ),
    'id' => 'theme_newsletter_subsection',
    'icon' => 'el el-cog',
    'subsection' => true,
    'fields' => array(
        array(
            'title' => esc_html__( 'Newsletter Popup', 'crisop' ),
            'subtitle' => esc_html__( 'If enabled, adds preloader.', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_newsletter_visibility',
            'type' => 'switch',
            'default' => false
        ),
        array(
            'title' => esc_html__( 'Template Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your preloader type.', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_newsletter_type',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'elementor' => esc_html__( 'Elementor', 'crisop' ),
                'shortcode' => esc_html__( 'Shortcode', 'crisop' )
            ),
            'default' => 'elementor',
            'required' => array( 'popup_newsletter_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates.', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_newsletter_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array(
                array( 'popup_newsletter_visibility', '=', '1' ),
                array( 'popup_newsletter_type', '=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'Shortcode', 'crisop' ),
            'subtitle' => esc_html__( 'Add your shortcode here', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_newsletter_shortcode',
            'type' => 'text',
            'customizer' => true,
            'required' => array(
                array( 'popup_newsletter_visibility', '=', '1' ),
                array( 'popup_newsletter_type', '=', 'shortcode' )
            )
        ),
        array(
            'title' => esc_html__( 'Expire Date', 'crisop' ),
            'subtitle' => esc_html__( 'Add your expire date here', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_newsletter_expire_date',
            'type' => 'text',
            'validate' => 'number',
            'default' => 15,
            'customizer' => true,
            'required' => array( 'popup_newsletter_visibility', '=', '1' )
        )
    )
));
//NEWSLETTER SETTINGS SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Popup GDPR', 'crisop' ),
    'id' => 'theme_gdpr_subsection',
    'icon' => 'el el-cog',
    'subsection' => true,
    'fields' => array(
        array(
            'title' => esc_html__( 'Popup GDPR', 'crisop' ),
            'subtitle' => esc_html__( 'You can choose status of GDPR', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_gdpr_visibility',
            'type' => 'switch',
            'default' => false
        ),
        array(
            'title' => esc_html__( 'Template Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your preloader type.', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_gdpr_type',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'elementor' => esc_html__( 'Elementor', 'crisop' ),
                'shortcode' => esc_html__( 'Shortcode', 'crisop' ),
                'deafult' => esc_html__( 'Default', 'crisop' ),
            ),
            'default' => 'deafult',
            'required' => array( 'popup_gdpr_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates.', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_gdpr_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array(
                array( 'popup_newsletter_visibility', '=', '1' ),
                array( 'popup_gdpr_type', '=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'Shortcode', 'crisop' ),
            'subtitle' => esc_html__( 'Add your shortcode here', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_gdpr_shortcode',
            'type' => 'text',
            'customizer' => true,
            'required' => array(
                array( 'popup_gdpr_visibility', '=', '1' ),
                array( 'popup_gdpr_type', '=', 'shortcode' )
            )
        ),
        array(
            'title' => esc_html__( 'Expire Date', 'crisop' ),
            'subtitle' => esc_html__( 'Add your expire date here', 'crisop' ),
            'customizer' => true,
            'id' => 'popup_gdpr_expire_date',
            'type' => 'text',
            'validate' => 'number',
            'default' => 15,
            'customizer' => true,
            'required' => array( 'popup_gdpr_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'GDPR Image', 'crisop' ),
            'subtitle' => esc_html__( 'Upload your Logo. If left blank theme will use site default preloader.', 'crisop' ),
            'customizer' => true,
            'id' => 'gdpr_image',
            'type' => 'media',
            'url' => true,
            'customizer' => true,
            'required' => array(
                array( 'popup_gdpr_visibility', '=', '1' ),
                array( 'popup_gdpr_type', '=', 'deafult' )
            )
        ),
        array(
            'title' => esc_html__( 'GDPR Text', 'crisop' ),
            'subtitle' => esc_html__( 'Add your gdpr text here', 'crisop' ),
            'customizer' => true,
            'id' => 'gdpr_text',
            'type' => 'textarea',
            'default' => 'In order to provide you a personalized shopping experience, our site uses cookies. <br><a href="#">cookie policy</a>.',
            'customizer' => true,
            'required' => array(
                array( 'popup_gdpr_visibility', '=', '1' ),
                array( 'popup_gdpr_type', '=', 'deafult' )
            )
        ),
        array(
            'title' => esc_html__( 'GDPR Button Text', 'crisop' ),
            'subtitle' => esc_html__( 'Add your gdpr button text here', 'crisop' ),
            'customizer' => true,
            'id' => 'gdpr_button_text',
            'type' => 'text',
            'default' => 'Accept Cookies',
            'customizer' => true,
            'required' => array( 'popup_gdpr_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'gdpr_bg',
            'type' => 'color',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.site-gdpr'),
            'required' => array( 'popup_gdpr_visibility', '=', '1' )
        )
    )
));

//BACKTOTOP BUTTON SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Back-to-top Button', 'crisop' ),
    'id' => 'theme_backtotop_subsection',
    'icon' => 'el el-cog',
    'subsection' => true,
    'fields' => array(
        array(
            'title' => esc_html__( 'Back-to-top', 'crisop' ),
            'subtitle' => esc_html__( 'Switch On-off', 'crisop' ),
            'desc' => esc_html__( 'If enabled, adds back to top.', 'crisop' ),
            'customizer' => true,
            'id' => 'backtotop_visibility',
            'type' => 'switch',
            'default' => true
        ),
        array(
            'title' => esc_html__( 'Bottom Offset', 'crisop' ),
            'subtitle' => esc_html__( 'Set custom bottom offset for the back-to-top button', 'crisop' ),
            'customizer' => true,
            'id' => 'backtotop_top_offset',
            'type' => 'spacing',
            'output' => array('.scroll-to-top'),
            'mode' => 'absolute',
            'units' => array('px'),
            'all' => false,
            'top' => false,
            'right' => true,
            'bottom' => true,
            'left' => false,
            'default' => array(
                'right' => '30',
                'bottom' => '30',
                'units' => 'px'
            ),
            'required' => array( 'backtotop_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'backtotop_bg',
            'type' => 'color',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.scroll-to-top'),
            'required' => array( 'backtotop_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Hover Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'backtotop_hvrbg',
            'type' => 'color',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.scroll-to-top:hover'),
            'required' => array( 'backtotop_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Arrow Color', 'crisop' ),
            'customizer' => true,
            'id' => 'backtotop_icon',
            'type' => 'color',
            'default' =>  '',
            'validate' => 'color',
            'output' => array('.scroll-to-top'),
            'required' => array( 'backtotop_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Hover Arrow Color', 'crisop' ),
            'customizer' => true,
            'id' => 'backtotop_hvricon',
            'type' => 'color',
            'default' =>  '',
            'validate' => 'color',
            'output' => array('.scroll-to-top:hover'),
            'required' => array( 'backtotop_visibility', '=', '1' )
        )
    )
));

// THEME PAGINATION SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Pagination', 'crisop' ),
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'id' => 'theme_pagination_subsection',
    'subsection' => true,
    'icon' => 'el el-link',
    'fields' => array(
        array(
            'title' => esc_html__( 'Pagination', 'crisop' ),
            'subtitle' => esc_html__( 'Switch On-off', 'crisop' ),
            'desc' => esc_html__( 'If enabled, adds pagination.', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_visibility',
            'type' => 'switch',
            'default' => true
        ),
        array(
            'title' => esc_html__( 'Alignment', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_alignment',
            'type' => 'button_set',
            'customizer' => true,
            'options' => array(
                'flex-start' => esc_html__( 'Left', 'crisop' ),
                'center' => esc_html__( 'Center', 'crisop' ),
                'flex-end' => esc_html__( 'Right', 'crisop' )
            ),
            'default' => 'center',
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Size', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo width and height of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_size',
            'type' => 'dimensions',
            'output' => array('.nt-pagination .nt-pagination-item .nt-pagination-link,.ninetheme-woocommerce-pagination ul li a, .ninetheme-woocommerce-pagination ul li span' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Border', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo width and height of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_border',
            'type' => 'border',
            'output' => array('.nt-pagination .nt-pagination-item .nt-pagination-link,.ninetheme-woocommerce-pagination ul li a, .ninetheme-woocommerce-pagination ul li span' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Border ( Hover/Active )', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_hvrborder',
            'type' => 'border',
            'output' => array('.nt-pagination .nt-pagination-item.active .nt-pagination-link,.nt-pagination .nt-pagination-item .nt-pagination-link:hover,.ninetheme-woocommerce-pagination ul li a:focus, .ninetheme-woocommerce-pagination ul li a:hover, .ninetheme-woocommerce-pagination ul li span.current' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Border Radius ( px )', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_border_radius',
            'type' => 'slider',
            'max' => 300,
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_bgclr',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.nt-pagination .nt-pagination-item .nt-pagination-link,.ninetheme-woocommerce-pagination ul li a, .ninetheme-woocommerce-pagination ul li span' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Background Color ( Hover/Active )', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_hvrbgclr',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array('.nt-pagination .nt-pagination-item.active .nt-pagination-link,.nt-pagination .nt-pagination-item .nt-pagination-link:hover,.ninetheme-woocommerce-pagination ul li a:focus, .ninetheme-woocommerce-pagination ul li a:hover, .ninetheme-woocommerce-pagination ul li span.current' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Number Color', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_clr',
            'type' => 'color',
            'validate' => 'color',
            'output' => array('.nt-pagination .nt-pagination-item .nt-pagination-link,.ninetheme-woocommerce-pagination ul li a, .ninetheme-woocommerce-pagination ul li span' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Number Color ( Hover/Active )', 'crisop' ),
            'customizer' => true,
            'id' => 'pagination_hvrclr',
            'type' => 'color',
            'validate' => 'color',
            'output' => array('.nt-pagination .nt-pagination-item.active .nt-pagination-link,.nt-pagination .nt-pagination-item .nt-pagination-link:hover,.ninetheme-woocommerce-pagination ul li a:focus, .ninetheme-woocommerce-pagination ul li a:hover, .ninetheme-woocommerce-pagination ul li span.current' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        )
    )
));

// THEME LIGHTBOX POPUP SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Lightbox', 'crisop' ),
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'id' => 'theme_lightbox_subsection',
    'subsection' => true,
    'icon' => 'el el-brush',
    'fields' => array(
        array(
            'title' => esc_html__( 'Overlay Color', 'crisop' ),
            'customizer' => true,
            'id' => 'lightbox_overlay_bgclr',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.mfp-bg' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Content Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'lightbox_content_bgclr',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.ninetheme-product360-wrapper, .ninetheme-single-product-delivery, .ninetheme-single-product-question, .ninetheme-quickview-wrapper' )
        ),
        array(
            'title' => esc_html__( 'Content Max-width', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo width and height of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'lightbox_maxwidth',
            'type' => 'dimensions',
            'output' => array('.nt-pagination .nt-pagination-item .nt-pagination-link,.ninetheme-woocommerce-pagination ul li a, .ninetheme-woocommerce-pagination ul li span' ),
            'required' => array( 'pagination_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Close Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'lightbox_close_bgclr',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.ninetheme-mfp-close' )
        ),
        array(
            'title' => esc_html__( 'Close Color', 'crisop' ),
            'customizer' => true,
            'id' => 'lightbox_close_clr',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array('.mfp-close-btn-in .mfp-close' )
        )
    )
));

// THEME OPTIMIZATION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Optimization', 'crisop' ),
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'id' => 'theme_optimization_subsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'LazyLoad', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to disable or enable lazy loading of image files.', 'crisop' ),
            'customizer' => true,
            'id' => 'theme_lazyload_images',
            'type' => 'switch',
            'default' => true
        ),
        array(
            'title' => esc_html__( 'Theme Gutenberg CSS Files', 'crisop' ),
            'subtitle' => esc_html__( 'This theme does not support gutenberg so some css files are filtered, if you want to use gutenberg you can use this option', 'crisop' ),
            'customizer' => true,
            'id' => 'theme_blocks_styles',
            'type' => 'switch',
            'default' => false
        )
    )
));

/*************************************************
## LOGO SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Logo', 'crisop' ),
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'id' => 'logo_section',
    'icon' => 'el el-star-empty',
    'fields' => array(
        array(
            'title' => esc_html__( 'Logo Switch', 'crisop' ),
            'subtitle' => esc_html__( 'You can select logo on or off.', 'crisop' ),
            'customizer' => true,
            'id' => 'logo_visibility',
            'type' => 'switch',
            'default' => true
        ),
        array(
            'title' => esc_html__( 'Logo Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your logo type.', 'crisop' ),
            'customizer' => true,
            'id' => 'logo_type',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'img' => esc_html__( 'Image Logo', 'crisop' ),
                'sitename' => esc_html__( 'Site Name', 'crisop' ),
                'customtext' => esc_html__( 'Custom HTML', 'crisop' )
            ),
            'default' => 'sitename',
            'required' => array( 'logo_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Custom text for logo', 'crisop' ),
            'desc' => esc_html__( 'Text entered here will be used as logo', 'crisop' ),
            'customizer' => true,
            'id' => 'text_logo',
            'type' => 'editor',
            'args' => array(
                'teeny' => false,
                'textarea_rows' => 10
            ),
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'customtext' )
            ),
        ),
        array(
            'title' => esc_html__( 'Hover Logo Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the text logo.', 'crisop' ),
            'customizer' => true,
            'id' => 'text_logo_hvr',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.nt-logo .header-text-logo:hover' ),
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '!=', 'img' )
            )
        ),
        array(
            'title' => esc_html__( 'Logo Image', 'crisop' ),
            'subtitle' => esc_html__( 'Upload your Logo. If left blank theme will use site default logo.', 'crisop' ),
            'customizer' => true,
            'id' => 'img_logo',
            'type' => 'media',
            'url' => true,
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' )
            )
        ),
        array(
            'title' => esc_html__( 'Logo Size', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo max-width of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'logo_size',
            'type' => 'slider',
            'default' => '',
            'min' => 0,
            'step' => 1,
            'max' => 400,
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' ),
                array( 'logo_type', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Sticky Logo', 'crisop' ),
            'subtitle' => esc_html__( 'Upload your Logo. If left blank theme will use site default logo.', 'crisop' ),
            'customizer' => true,
            'id' => 'sticky_logo',
            'type' => 'media',
            'url' => true,
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' )
            )
        ),
        array(
            'title' => esc_html__( 'Sticky Logo Size', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo max-width of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'sticky_logo_size',
            'type' => 'slider',
            'default' => '',
            'min' => 0,
            'step' => 1,
            'max' => 400,
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' )
            )
        ),
        array(
            'title' => esc_html__( 'Mobile Logo Size', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo max-width of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_logo_size',
            'default' => '',
            'min' => 0,
            'step' => 1,
            'max' => 400,
            'type' => 'slider',
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' ),
                array( 'logo_type', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Logo', 'crisop' ),
            'subtitle' => esc_html__( 'Upload your Logo. If left blank theme will use site default logo.', 'crisop' ),
            'customizer' => true,
            'id' => 'minibar_logo',
            'type' => 'media',
            'url' => true,
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Logo Size', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo max-width of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'minibar_logo_size',
            'default' => 80,
            'min' => 0,
            'step' => 1,
            'max' => 400,
            'type' => 'slider',
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' ),
                array( 'logo_type', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Logo Left Offset', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo max-width of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_logo_left_offset',
            'default' => '',
            'min' => -200,
            'step' => 1,
            'max' => 400,
            'type' => 'slider',
            'required' => array(
                array( 'logo_visibility', '=', '1' ),
                array( 'logo_type', '=', 'img' ),
                array( 'logo_type', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Logo Padding', 'crisop' ),
            'customizer' => true,
            'id' => 'text_logo_pad',
            'type' => 'spacing',
            'mode' => 'padding',
            'all' => false,
            'units' => array( 'em', 'px', '%' ),
            'units_extended' => 'true',
            'output' => array( '.nt-logo' ),
            'required' => array( 'logo_visibility', '=', '1' )
        )
    )
));

/*************************************************
## HEADER & NAV SECTION
*************************************************/
Redux::setSection($ninetheme_pre,array(
    'title' => esc_html__( 'Header', 'crisop' ),
    'id' => 'header_section',
    'icon' => 'el el-lines',
));
//HEADER MENU
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'General', 'crisop' ),
    'id' => 'header_general_section',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Header Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site navigation.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'id' =>'header_template',
            'type' => 'button_set',
            'title' => esc_html__( 'Header Template', 'crisop' ),
            'subtitle' => esc_html__( 'Select your header template.', 'crisop' ),
            'customizer' => true,
            'options' => array(
                'default' => esc_html__( 'Deafult Site Header', 'crisop' ),
                'elementor' => esc_html__( 'Elementor Templates', 'crisop' )
            ),
            'default' => 'default',
            'required' => array( 'header_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Sticky Header Display', 'crisop' ),
            'customizer' => true,
            'id' => 'header_sticky_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'header_width',
            'type' => 'button_set',
            'title' => esc_html__( 'Header Container Width', 'crisop' ),
            'subtitle' => esc_html__( 'Select your header container type.', 'crisop' ),
            'customizer' => true,
            'options' => array(
                'default' => esc_html__( 'Deafult', 'crisop' ),
                'stretch' => esc_html__( 'Stretch', 'crisop' )
            ),
            'default' => 'default',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Mobile Header Breakpoint', 'crisop' ),
            'subtitle' => esc_html__( 'Here you can set the screen width where the mobile header will be active.Please use number.ex: 1280', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_header_breakpoint',
            'type' => 'text',
            'validate' => array('numeric'),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'disable_desktop_header_on_mobile',
            'type' => 'button_set',
            'title' => esc_html__( 'Desktop Header On Mobile Device Display', 'crisop' ),
            'subtitle' => esc_html__( 'This option prevents the desktop header from loading on the page on mobile devices.( all iPhone, iPad, Android etc. )', 'crisop' ),
            'customizer' => true,
            'options' => array(
                'off' => esc_html__( 'Disable', 'crisop' ),
                'on' => esc_html__( 'Enable', 'crisop' )
            ),
            'default' => 'on',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'elementor' )
            )
        ),
        array(
            'id' =>'edit_header_elementor_template',
            'type' => 'info',
            'desc' => 'Select template',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'elementor' ),
                array( 'header_elementor_templates', '!=', '' )
            )
        )
    )
));
//HEADER MENU
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Header Top', 'crisop' ),
    'id' => 'headertopbarsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'id' => 'header_top_start',
            'type' => 'section',
            'title' => esc_html__('Header Top Main Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'header_top_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Header Top Layout Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme header top', 'crisop' ),
            'options' => array(
                'left' => array(
                    'custom-html' => esc_html__( 'Custom Text', 'crisop' )
                ),
                'center'=> array(
                ),
                'right'=> array(
                    'socials' => esc_html__( 'Socials', 'crisop' )
                ),
                'hide'  => array(
                    'lang-switcher' => esc_html__( 'Lang Switcher', 'crisop' ),
                    'currency-switcher' => esc_html__( 'Currency Switcher', 'crisop' ),
                    'mini-menu1' => esc_html__( 'Mini Menu 1', 'crisop' ),
                    'mini-menu2' => esc_html__( 'Mini Menu 2', 'crisop' ),
                    'location' => esc_html__( 'Location', 'crisop' ),
                    'discount' => esc_html__( 'Discount Products', 'crisop' )
                )
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Top Custom Text', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom html here.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_custom_html',
            'type' => 'textarea',
            'default' => 'Welcome to our online store!',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Top Socials Icons', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom html here.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_socials',
            'type' => 'textarea',
            'default' => '<a href="#0" title="facebook"><i class="fab fa-facebook"></i></a>
<a href="#0" title="twitter"><i class="fab fa-twitter"></i></a>
<a href="#0" title="instagram"><i class="fab fa-instagram"></i></a>
<a href="#0" title="youtube"><i class="fab fa-youtube"></i></a>',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Top Left Items Spacing', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to adjust the spacing between header top left items.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_left_item_spacing',
            'type' => 'slider',
            'default' => 20,
            'min' => 0,
            'step' => 1,
            'max' => 50,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Top Right Items Spacing', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to adjust the spacing between header top right items.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_right_item_spacing',
            'type' => 'slider',
            'default' => 15,
            'min' => 0,
            'step' => 1,
            'max' => 50,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Height', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to control the header height.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_height',
            'type' => 'slider',
            'default' => 45,
            'min' => 0,
            'step' => 1,
            'max' => 500,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_bg',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array( 'header.ninetheme-header-default .ninetheme-header-default-topbar' ),
        ),
        array(
            'title' => esc_html__( 'Header Top On Mobile Display', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_mobile_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'Yes', 'crisop' ),
            'off' => esc_html__( 'No', 'crisop' )
        )
    )
));
//HEADER MENU
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Header Middle', 'crisop' ),
    'id' => 'headermiddlesubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'id' => 'header_center_start',
            'type' => 'section',
            'title' => esc_html__('Header Middle Main Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'header_center_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Header Middle Layout Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme header center', 'crisop' ),
            'options' => array(
                'left' => array(
                    'sidemenu' => esc_html__( 'Canvas Menu Toggle', 'crisop' ),
                    'logo' => esc_html__( 'Logo', 'crisop' )
                ),
                'center'=> array(
                    'search-form' => esc_html__( 'Search Form', 'crisop' ),
                ),
                'right'=> array(
                    'buttons' => esc_html__( 'Buttons', 'crisop' )
                ),
                'hide'  => array(
                    'cats-menu' => esc_html__( 'Department Menu', 'crisop' ),
                    'menu' => esc_html__( 'Main Menu', 'crisop' ),
                    'location' => esc_html__( 'Location', 'crisop' ),
                    'discount' => esc_html__( 'Discount Products', 'crisop' ),
                    'mini-menu' => esc_html__( 'Mini Menu', 'crisop' ),
                    'custom-html' => esc_html__( 'Custom Text', 'crisop' ),
                    'search-icon' => esc_html__( 'Search Icon', 'crisop' ),
                    'lang-switcher' => esc_html__( 'Lang Switcher', 'crisop' ),
                    'currency-switcher' => esc_html__( 'Currency Switcher', 'crisop' ),
                    'socials' => esc_html__( 'Socials', 'crisop' )
                )
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Middle Custom Text', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom html here.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_center_custom_html',
            'type' => 'textarea',
            'default' => '',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Middle Socials Icons', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom html here.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_center_socials',
            'type' => 'textarea',
            'default' => '',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Left Items Spacing', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to adjust the spacing between header left items.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_left_item_spacing',
            'type' => 'slider',
            'default' => 20,
            'min' => 0,
            'step' => 1,
            'max' => 50,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Right Items Spacing', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to adjust the spacing between header right items.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_right_item_spacing',
            'type' => 'slider',
            'default' => 15,
            'min' => 0,
            'step' => 1,
            'max' => 50,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Height', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to control the header height.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_middle_height',
            'type' => 'slider',
            'default' => 54,
            'min' => 0,
            'step' => 1,
            'max' => 500,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'header_middle_bg',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array( 'header.ninetheme-header-default .ninetheme-header-default-center' ),
        )
    )
));
//HEADER MENU
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Header Bottom', 'crisop' ),
    'id' => 'headerbottomsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'id' => 'header_bottom_start',
            'type' => 'section',
            'title' => esc_html__('Header Bottom Main Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Bottom Type - Boxed or Fullwidth', 'crisop' ),
            'subtitle' => esc_html__( 'Select the ON button for the boxed header', 'crisop' ),
            'customizer' => true,
            'id' => 'header_bottom_boxed',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'id' =>'header_bottom_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Header Bottom Layout Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme header bottom', 'crisop' ),
            'options' => array(
                'left' => array(
                    'cats-menu' => esc_html__( 'Department Menu', 'crisop' ),
                    'menu' => esc_html__( 'Main Menu', 'crisop' ),
                ),
                'center'=> array(
                ),
                'right'=> array(
                    'custom-html' => esc_html__( 'Custom Text', 'crisop' )
                ),
                'hide'  => array(
                    'sidemenu' => esc_html__( 'Canvas Menu Toggle', 'crisop' ),
                    'mini-menu1' => esc_html__( 'Mini Menu 1', 'crisop' ),
                    'location' => esc_html__( 'Location', 'crisop' ),
                    'discount' => esc_html__( 'Discount Products', 'crisop' ),
                    'logo' => esc_html__( 'Logo', 'crisop' ),
                    'search-form' => esc_html__( 'Search Form', 'crisop' ),
                    'search-icon' => esc_html__( 'Search Icon', 'crisop' ),
                    'buttons' => esc_html__( 'Buttons', 'crisop' ),
                    'lang-switcher' => esc_html__( 'Lang Switcher', 'crisop' ),
                    'currency-switcher' => esc_html__( 'Currency Switcher', 'crisop' ),
                    'socials' => esc_html__( 'Socials', 'crisop' )
                )
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Bottom Custom Text', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom html here.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_bottom_custom_html',
            'type' => 'textarea',
            'default' => '<a class="header-phone-number" href="tel:2809003434"><i aria-hidden="true" class="ninetheme-icons flaticon-24-hours-support"></i><span><span class="phone-text">Call Anytime</span><span class="phone-number">280 900 3434</span></span></a>',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Bottom Socials Icons', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom html here.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_bottom_socials',
            'type' => 'textarea',
            'default' => '',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Bottom Left Items Spacing', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to adjust the spacing between header top left items.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_left_item_spacing',
            'type' => 'slider',
            'default' => 20,
            'min' => 0,
            'step' => 1,
            'max' => 50,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Bottom Right Items Spacing', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to adjust the spacing between header top right items.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_top_right_item_spacing',
            'type' => 'slider',
            'default' => 15,
            'min' => 0,
            'step' => 1,
            'max' => 50,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Height', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to control the header height.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_bottom_height',
            'type' => 'slider',
            'default' => 54,
            'min' => 0,
            'step' => 1,
            'max' => 500,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'header_bottom_bg',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array( 'header.ninetheme-header-default .ninetheme-header-default-bottom, header.ninetheme-header-default .ninetheme-header-default-bottom-sticky' ),
        ),
        array(
            'title' => esc_html__( 'Header Last Child Item Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'header_bottom_last_item_bg',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-default-bottom .ninetheme-header-top-right .ninetheme-header-default-inner>div:last-child' ),
        )
    )
));
//HEADER MENU
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Header Action Buttons', 'crisop' ),
    'id' => 'headerbuttonssubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'id' => 'header_buttons_start',
            'type' => 'section',
            'title' => esc_html__('Header Buttons Main Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'header_buttons_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Header Buttons Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme header for buttons', 'crisop' ),
            'options' => array(
                'show'  => array(
                    'cart' => esc_html__( 'Cart', 'crisop' ),
                    'wishlist' => esc_html__( 'Wishlist', 'crisop' ),
                    'compare' => esc_html__( 'Compare', 'crisop' ),
                    'account' => esc_html__( 'Account', 'crisop' )
                ),
                'hide'  => array(
                    'search' => esc_html__( 'Search', 'crisop' )
                )
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Header Buttons Spacing', 'crisop' ),
            'subtitle' => esc_html__( 'You can use this option to adjust the spacing between header buttons.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_buttons_spacing',
            'type' => 'slider',
            'default' => 15,
            'min' => 0,
            'step' => 1,
            'max' => 50,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'header_top_end',
            'type' => 'section',
            'customizer' => true,
            'indent' => false,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));

if ( class_exists('WooCommerce') ) {
    $terms = get_terms( array(
        'taxonomy' => 'product_cat',
        'hide_empty' => false,
        'parent'    => 0,
    ) );

    //HEADER MOBILE TOP
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Header Department Menu', 'crisop' ),
        'id' => 'headerwoocategorymenusection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__( 'Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'You can exclude the categories from menu.', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_exclude',
                'type' => 'select',
                'data' => 'terms',
                'args' => array(
                    'taxonomies' => array( 'product_cat' )
                ),
                'sortable' => true,
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Hide Empty Categories', 'crisop' ),
                'on' => esc_html__( 'Yes', 'crisop' ),
                'off' => esc_html__( 'No', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_hide_empty_cats',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Show Category Thumbnail', 'crisop' ),
                'on' => esc_html__( 'Yes', 'crisop' ),
                'off' => esc_html__( 'No', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_category_thumb_visibility',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Button Background Color', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_menu_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-header-default .ninetheme-header-wc-categories.ninetheme-wc-vertical-menu .ninetheme-vertical-catmenu-title' ),
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Button Background Color ( Hover )', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_menu_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-header-default .ninetheme-header-wc-categories.ninetheme-wc-vertical-menu .ninetheme-vertical-catmenu-title:hover' ),
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Button Title Color', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_menu_color',
                'type' => 'color',
                'mode' => 'color',
                'output' => array( '.ninetheme-header-wc-categories .ninetheme-vertical-catmenu-title' ),
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Button Title Color', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_menu_hvrcolor',
                'type' => 'color',
                'mode' => 'color',
                'output' => array( '.ninetheme-header-wc-categories .ninetheme-vertical-catmenu-title:hover' ),
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Submenu Background Color', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_submenu_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-header-wc-categories .submenu' ),
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Submenu Item Color', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_submenu_item_color',
                'type' => 'color',
                'mode' => 'color',
                'output' => array( '.ninetheme-header-wc-categories .submenu>li>a' ),
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Submenu Item Color ( Hover / Active )', 'crisop' ),
                'customizer' => true,
                'id' => 'header_woo_categories_submenu_item_hvrcolor',
                'type' => 'color',
                'mode' => 'color',
                'output' => array( '.ninetheme-header-wc-categories .submenu>li:hover>a, .ninetheme-header-wc-categories .submenu>li.current-cat>a' ),
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            )
        )
    ));

    //HEADER MENU
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Header Discount Query', 'crisop' ),
        'id' => 'headerproductsquerysubsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' => 'header_buttons_start',
                'type' => 'section',
                'title' => esc_html__('Header Discount Products Main Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'id' =>'header_products_scenario',
                'type' => 'button_set',
                'title' => esc_html__( 'Products Scenario', 'crisop' ),
                'subtitle' => esc_html__( 'Select your header container type.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'new' => esc_html__( 'Newest', 'crisop' ),
                    'featured' => esc_html__( 'Featured', 'crisop' ),
                    'on-sale' => esc_html__( 'On-Sale', 'crisop' ),
                    'best' => esc_html__( 'Best', 'crisop' ),
                ),
                'default' => 'featured',
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Category(s) Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'Select product(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'header_products_category_exclude',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_cat' ),
                ],
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Category(s) Include', 'crisop' ),
                'subtitle' => esc_html__( 'Select category(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'header_products_category_include',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_cat' ),
                ],
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'id' =>'header_products_order',
                'type' => 'button_set',
                'title' => esc_html__( 'Order', 'crisop' ),
                'subtitle' => esc_html__( 'Select your header container type.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'ASC' => esc_html__( 'Ascending', 'crisop' ),
                    'DESC' => esc_html__( 'Descending', 'crisop' )
                ),
                'default' => 'DESC',
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'id' =>'header_products_orderby',
                'type' => 'button_set',
                'title' => esc_html__( 'Order by', 'crisop' ),
                'subtitle' => esc_html__( 'Select your header container type.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'rand' => esc_html__( 'Random', 'crisop' ),
                    'date' => esc_html__( 'Date', 'crisop' ),
                    'title' => esc_html__( 'Title', 'crisop' )
                ),
                'default' => 'id',
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Products Count', 'crisop' ),
                'subtitle' => esc_html__( 'How many products do you want to show in total?', 'crisop' ),
                'customizer' => true,
                'id' => 'header_products_count',
                'type' => 'slider',
                'default' => 15,
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'id' => 'header_top_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
        )
    ));
}
//HEADER MENU
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Main Header Color', 'crisop' ),
    'id' => 'headercolorssubsection',
    'subsection' => true,
    'icon' => 'el el-brush',
    'fields' => array(
        // DEFAULT HEADER OPTIONS
        array(
            'id' => 'header_menu_items_customize_start',
            'type' => 'section',
            'title' => esc_html__('Header Customize Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Typography', 'crisop' ),
            'id' => 'nav_a_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.ninetheme-header-top-menu-area>ul>li.menu-item>a' ),
        ),
        array(
            'title' => esc_html__( 'Menu Item Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the navigation menu item.', 'crisop' ),
            'customizer' => true,
            'id' => 'nav_a',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-top-menu-area>ul>li.menu-item>a' ),
        ),
        array(
            'title' => esc_html__( 'Menu Item Color ( Hover and Active )', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the navigation menu item.', 'crisop' ),
            'customizer' => true,
            'id' => 'nav_hvr_a',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.current-menu-parent>a, .current-menu-item>a, .ninetheme-header-top-menu-area>ul>li.menu-item>a:hover, .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a:hover' ),
        ),
        array(
            'title' => esc_html__( 'Sticky Header Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'nav_top_sticky_bg',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array( '.has-sticky-header.scroll-start header.ninetheme-header-default' ),
            'required' => array( 'header_sticky_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Sticky Menu Item Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the sticky navigation menu item.', 'crisop' ),
            'customizer' => true,
            'id' => 'sticky_nav_a',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.has-sticky-header.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item>a' ),
        ),
        array(
            'title' => esc_html__( 'Sticky Menu Item Color ( Hover and Active )', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the sticky navigation menu item.', 'crisop' ),
            'customizer' => true,
            'id' => 'sticky_nav_hvr_a',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.has-sticky-header.scroll-start .current-menu-parent>a, .has-sticky-header.scroll-start .current-menu-item>a, .has-sticky-header.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item>a:hover, .has-sticky-header.scroll-start .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a:hover' ),
        ),
        array(
            'id' => 'header_menu_items_style_end',
            'type' => 'section',
            'customizer' => true,
            'indent' => false,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'header_submenumenu_items_style_end',
            'type' => 'section',
            'title' => esc_html__('Header Sub Menu Customize Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Sub Menu Background Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the sticky navigation sub menu item.', 'crisop' ),
            'customizer' => true,
            'id' => 'nav_submenu_bg',
            'type' => 'color',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-top-menu-area ul li .submenu' ),
        ),
        array(
            'title' => esc_html__( 'Menu Item Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the sticky navigation sub menu item.', 'crisop' ),
            'customizer' => true,
            'id' => 'nav_submenu_a',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a' ),
        ),
        array(
            'title' => esc_html__( 'Menu Item Color ( Hover and Active )', 'crisop' ),
            'desc' => esc_html__( 'Set your own hover color for the sticky navigation sub menu item.', 'crisop' ),
            'customizer' => true,
            'id' => 'nav_submenu_hvr_a',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a:hover,.ninetheme-header-top-menu-area ul li .submenu>li.menu-item.active>a' ),
        ),
        array(
            'id' => 'header_submenu_items_style_end',
            'type' => 'section',
            'customizer' => true,
            'indent' => false,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'header_svgbuttons_items_style_start',
            'type' => 'section',
            'title' => esc_html__('Header SVG Buttons Customize Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'SVG Icon Color', 'crisop' ),
            'desc' => esc_html__( 'Cart, Wishlist, Compare, Account, Search, Sidemenu bar', 'crisop' ),
            'customizer' => true,
            'id' => 'header_buttons_svg_color',
            'type' => 'color',
            'mode' => 'fill',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-default .header-top-buttons .top-action-btn, ' ),
        ),
        array(
            'title' => esc_html__( 'Buttons Counter Position', 'crisop' ),
            'subtitle' => esc_html__( 'Select your counter position type.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_buttons_counter_position',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'top' => esc_html__( 'Top', 'crisop' ),
                'bottom' => esc_html__( 'Bottom', 'crisop' ),
                'right' => esc_html__( 'Right', 'crisop' ),
                'left' => esc_html__( 'Left', 'crisop' )
            ),
            'default' => 'right',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Counter Background Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your counter position type.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_buttons_counter_bgcolor_type',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'primary' => esc_html__( 'Primary', 'crisop' ),
                'dark' => esc_html__( 'Black', 'crisop' ),
                'gray' => esc_html__( 'Gray', 'crisop' ),
                'gray-soft' => esc_html__( 'Gray Soft', 'crisop' ),
                'crisop' => esc_html__( 'crisop', 'crisop' ),
                'green-soft' => esc_html__( 'Green Soft', 'crisop' ),
                'brown' => esc_html__( 'Brown', 'crisop' ),
                'red' => esc_html__( 'Red', 'crisop' ),
                'bg-custom' => esc_html__( 'Custom', 'crisop' )
            ),
            'default' => 'primary',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Button Counter Background Color', 'crisop' ),
            'desc' => esc_html__( 'Cart, Wishlist, Compare', 'crisop' ),
            'customizer' => true,
            'id' => 'header_buttons_counter_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-default .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' ),
                array( 'header_buttons_counter_bgcolor_type', '=', 'bg-custom' )
            )
        ),
        array(
            'title' => esc_html__( 'Button Counter Color', 'crisop' ),
            'desc' => esc_html__( 'Cart, Wishlist, Compare', 'crisop' ),
            'customizer' => true,
            'id' => 'header_buttons_counter_color',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-default .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' ),
                array( 'header_buttons_counter_bgcolor_type', '=', 'bg-custom' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Counter Radius Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your counter radius type.', 'crisop' ),
            'customizer' => true,
            'id' => 'header_buttons_counter_radius_type',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'radius' => esc_html__( 'Circle', 'crisop' ),
                'square' => esc_html__( 'Square', 'crisop' )
            ),
            'default' => 'ninetheme-counter-radius',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'header_svgbuttons_items_style_end',
            'type' => 'section',
            'customizer' => true,
            'indent' => false,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        //information on-off
        array(
            'id' =>'info_nav0',
            'type' => 'info',
            'style' => 'success',
            'title' => esc_html__( 'Success!', 'crisop' ),
            'icon' => 'el el-info-circle',
            'customizer' => true,
            'desc' => sprintf(esc_html__( '%s is disabled on the site. Please activate to view options.', 'crisop' ), '<b>Header</b>' ),
            'required' => array( 'header_visibility', '=', '0' )
        ),
    )
));
//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Mobile Header Top', 'crisop' ),
    'id' => 'headermobilesection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'id' => 'mobile_header_start',
            'type' => 'section',
            'title' => esc_html__('Mobile Top Header Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__('Mobile Ajax Search Form', 'crisop'),
            'customizer' => true,
            'id' => 'mobile_header_search',
            'type' => 'switch',
            'default' => 1,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'mobile_header_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Mobile Top Header Layouts Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme mobile header', 'crisop' ),
            'options' => array(
                'show'  => array(
                    'toggle' => esc_html__( 'Toggle Button', 'crisop' ),
                    'logo' => esc_html__( 'Logo', 'crisop' ),
                    'buttons' => esc_html__( 'Buttons', 'crisop' )
                ),
                'hide'  => array(
                )
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'mobile_header_buttons_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Mobile Header Buttons Layouts Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme mobile header', 'crisop' ),
            'options' => array(
                'show'  => array(
                    'cart' => esc_html__( 'Cart', 'crisop' ),
                ),
                'hide'  => array(
                    'account' => esc_html__( 'Account', 'crisop' ),
                    'search' => esc_html__( 'Search Form', 'crisop' )
                )
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_header_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-mobile-top' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Menu Button Bar Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_header_menu_bars_color',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-mobile-top .mobile-toggle' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'SVG Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_header_svg_icon_color',
            'type' => 'color',
            'mode' => 'fill',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-mobile-top .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'SVG Icon Counter Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_header_counter_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-mobile-top .top-action-btn .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'SVG Icon Counter Number Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_header_counter_color',
            'type' => 'color',
            'validate' => 'color',
            'output' => array( '.ninetheme-header-mobile-top .top-action-btn .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'mobile_header_end',
            'type' => 'section',
            'customizer' => true,
            'indent' => false,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));
//MOBILE BOTTOM MENU BAR SECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Mobile Bottom Menu Bar', 'crisop' ),
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'id' => 'mobilebottommenusubsection',
    'subsection' => false,
    'icon' => 'el el-photo',
    'fields' => array(
        array(
            'title' => esc_html__( 'Mobile Bottom Menu Bar Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site mobile bottom menu bar.', 'crisop' ),
            'customizer' => true,
            'id' => 'bottom_mobile_nav_visibility',
            'type' => 'switch',
            'default' => 0
        ),
        array(
            'title' => esc_html__( 'Mobile Bottom Menu Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your mobile bottom menu popup search type.', 'crisop' ),
            'customizer' => true,
            'id' => 'bottom_mobile_menu_type',
            'type' => 'button_set',
            'customizer' => true,
            'options' => array(
                'default' => esc_html__( 'Default', 'crisop' ),
                'wp-menu' => esc_html__( 'WP Menu', 'crisop' ),
                'elementor' => esc_html__( 'Elementor Template', 'crisop' ),
            ),
            'default' => 'default',
            'required' => array( 'bottom_mobile_nav_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Mobile Bottom Menu Display Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your mobile bottom menu popup search type.', 'crisop' ),
            'customizer' => true,
            'id' => 'bottom_mobile_menu_display_type',
            'type' => 'button_set',
            'customizer' => true,
            'options' => array(
                'show-allways' => esc_html__( 'Always show', 'crisop' ),
                'show-onscroll' => esc_html__( 'Show on scroll', 'crisop' ),
            ),
            'default' => 'show-allways',
            'required' => array( 'bottom_mobile_nav_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'elementor' )
            )
        ),
        array(
            'id' =>'mobile_bottom_menu_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Layout Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme bottom mobile menu bar', 'crisop' ),
            'options' => array(
                'show' => array(
                    'home' => esc_html__( 'Home', 'crisop' ),
                    'shop' => esc_html__( 'Shop', 'crisop' ),
                    'cart' => esc_html__( 'Cart', 'crisop' ),
                    'account' => esc_html__( 'Account', 'crisop' ),
                    'search' => esc_html__( 'Search', 'crisop' ),
                    'cats' => esc_html__( 'Categories', 'crisop' ),
                    'location' => esc_html__( 'Location', 'crisop' ),
                ),
                'hide'  => array()
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' )
            )
        ),
        array(
            'desc' => sprintf( '%s <b>"%s"</b> <a class="button" href="'.admin_url('nav-menus.php?action=edit&menu=0').'" target="_blank">%s</a>',
                esc_html__( 'Please create new menu and assign it as', 'crisop' ),
                esc_html__( 'Mobile Bottom Menu', 'crisop' ),
                esc_html__( 'Create New Menu', 'crisop' )
            ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_menu_info',
            'type' => 'info',
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'wp-menu' )
            )
        ),
        array(
            'title' => esc_html__( 'Change Default Menu Item HTML', 'crisop' ),
            'subtitle' => esc_html__( 'You can change the site mobile bottom menu item html.', 'crisop' ),
            'customizer' => true,
            'id' => 'bottom_mobile_nav_item_customize',
            'type' => 'switch',
            'default' => 0,
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Home HTML ( optional )', 'crisop' ),
            'desc' => esc_html__( 'If you do not want to make any changes in this part, please clear the default html from the field.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_home_html',
            'type' => 'textarea',
            'default' => sprintf( '<li class="menu-item"><a href="%s">%s<span>Home</span></a></li>',
                esc_url( home_url( '/' ) ),
                ninetheme_svg_lists( 'arrow-left', 'ninetheme-svg-icon' )
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' ),
                array( 'bottom_mobile_nav_item_customize', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Shop HTML ( optional )', 'crisop' ),
            'desc' => esc_html__( 'If you do not want to make any changes in this part, please clear the default html from the field.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_shop_html',
            'type' => 'textarea',
            'default' => sprintf( '<li class="menu-item"><a href="%s">%s<span>Shop</span></a></li>',
                function_exists('wc_get_page_permalink') ? esc_url( wc_get_page_permalink( 'shop' ) ) : '#0',
                ninetheme_svg_lists( 'store', 'ninetheme-svg-icon' )
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' ),
                array( 'bottom_mobile_nav_item_customize', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Cart HTML ( optional )', 'crisop' ),
            'desc' => esc_html__( 'If you do not want to make any changes in this part, please clear the default html from the field.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_cart_html',
            'type' => 'textarea',
            'default' => sprintf( '<li class="menu-item"><a href="%s">%s<span class="ninetheme-cart-count ninetheme-wc-count"></span><span>Cart</span></a></li>',
                function_exists('wc_get_page_permalink') ? esc_url( wc_get_page_permalink( 'cart' ) ) : '#0',
                ninetheme_svg_lists( 'bag', 'ninetheme-svg-icon' )
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' ),
                array( 'bottom_mobile_nav_item_customize', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Account HTML ( optional )', 'crisop' ),
            'desc' => esc_html__( 'If you do not want to make any changes in this part, please clear the default html from the field.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_account_html',
            'type' => 'textarea',
            'default' => sprintf( '<li class="menu-item"><a href="%s">%s<span>Account</span></a></li>',
                function_exists('wc_get_page_permalink') ? esc_url( wc_get_page_permalink( 'myaccount' ) ) : '#0',
                ninetheme_svg_lists( 'user-1', 'ninetheme-svg-icon' )
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' ),
                array( 'bottom_mobile_nav_item_customize', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Search HTML ( optional )', 'crisop' ),
            'desc' => esc_html__( 'If you do not want to make any changes in this part, please clear the default html from the field.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_search_html',
            'type' => 'textarea',
            'default' => sprintf( '<li class="menu-item"><a href="#0" data-name="search-popup">%s<span>Search</span></a></li>',
                ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' )
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' ),
                array( 'bottom_mobile_nav_item_customize', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Categories HTML ( optional )', 'crisop' ),
            'desc' => esc_html__( 'If you do not want to make any changes in this part, please clear the default html from the field.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_cats_html',
            'type' => 'textarea',
            'default' => sprintf( '<li class="menu-item"><a href="#0" data-name="search-cats">%s<span>Categories</span></a></li>',
                ninetheme_svg_lists( 'paper-search', 'ninetheme-svg-icon' )
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' ),
                array( 'bottom_mobile_nav_item_customize', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Location HTML ( optional )', 'crisop' ),
            'desc' => esc_html__( 'If you do not want to make any changes in this part, please clear the default html from the field.', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_custom_location_html',
            'type' => 'textarea',
            'default' => sprintf( '<li class="menu-item"><a href="#0" data-name="search-cats">%s<span>Categories</span></a></li>',
                ninetheme_svg_lists( 'location', 'ninetheme-svg-icon' )
            ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '=', 'default' ),
                array( 'bottom_mobile_nav_item_customize', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Backgroud Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_bg_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-bottom-mobile-nav' ),
            'required' => array( 'bottom_mobile_nav_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Menu Item Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-bottom-mobile-nav .menu-item a,.ninetheme-bottom-mobile-nav .menu-item a span' ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'Menu Item Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-bottom-mobile-nav .menu-item a:hover,.ninetheme-bottom-mobile-nav .menu-item a:hover span'),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'SVG Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_icon_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array('.ninetheme-bottom-mobile-nav .menu-item svg,.ninetheme-bottom-mobile-nav .ninetheme-svg-icon'),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'SVG Icon Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_icon_hvrcolor',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array('.ninetheme-bottom-mobile-nav .menu-item a:hover svg,.ninetheme-bottom-mobile-nav a:hover .ninetheme-svg-icon'),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'Font Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_icon2_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array('.ninetheme-bottom-mobile-nav a i,.ninetheme-bottom-mobile-nav a span' ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'Font Icon Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_icon2_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array('.ninetheme-bottom-mobile-nav a:hover i,.ninetheme-bottom-mobile-nav a:hover span' ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Count Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_cart_count_bg_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-bottom-mobile-nav .menu-item a span.ninetheme-wc-count, .ninetheme-bottom-mobile-nav .ninetheme-wc-count' ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Count Number Color', 'crisop' ),
            'customizer' => true,
            'id' => 'mobile_bottom_menu_item_cart_count_number_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-bottom-mobile-nav .menu-item a span.ninetheme-wc-count, .ninetheme-bottom-mobile-nav .ninetheme-wc-count' ),
            'required' => array(
                array( 'bottom_mobile_nav_visibility', '=', '1' ),
                array( 'bottom_mobile_menu_type', '!=', 'elementor' )
            )
        )
    )
));
//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Sidebar Panel', 'crisop' ),
    'id' => 'headermobilesidebarsection',
    'subsection' => false,
    'icon' => 'el el-th-list',
    'fields' => array(
        array(
            'id' => 'sidebar_menu_start',
            'type' => 'section',
            'title' => esc_html__('Sidebar Panel Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'sidebar_menu_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Minibar Layouts Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme mobile header sidebar', 'crisop' ),
            'options' => array(
                'show'  => array(
                    'buttons' => esc_html__( 'Buttons', 'crisop' ),
                    'logo' => esc_html__( 'Logo', 'crisop' ),
                    'socials' => esc_html__( 'Socials', 'crisop' )
                ),
                'hide'  => array()
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' =>'sidebar_menu_buttons_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Minibar Buttons Layouts Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme mobile header', 'crisop' ),
            'options' => array(
                'show'  => array(
                    'cart' => esc_html__( 'Cart', 'crisop' ),
                    'wishlist' => esc_html__( 'Wishlist', 'crisop' ),
                    'compare' => esc_html__( 'Compare', 'crisop' ),
                    'search' => esc_html__( 'Search Category', 'crisop' ),
                    'contact' => esc_html__( 'Contact Form', 'crisop' ),
                    'account' => esc_html__( 'Account', 'crisop' ),
                    'location' => esc_html__( 'Location', 'crisop' )
                ),
                'hide'  => array()
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Sidebar Menu Social Icons', 'crisop' ),
            'subtitle' => esc_html__( 'Add your social links here.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_socials',
            'type' => 'textarea',
            'default' => '<a href="#0" title="facebook"><i class="fab fa-facebook"></i></a>
<a href="#0" title="twitter"><i class="fab fa-twitter"></i></a>
<a href="#0" title="instagram"><i class="fab fa-instagram"></i></a>
<a href="#0" title="youtube"><i class="fab fa-youtube"></i></a>',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Sidebar Menu Container Max Width ( px )', 'crisop' ),
            'subtitle' => esc_html__( 'You can control sidebar menu content width.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_content_width',
            'type' => 'slider',
            'default' => 530,
            'min' => 0,
            'step' => 1,
            'max' => 4000,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_bg',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( 'body .ninetheme-header-mobile, .ninetheme-header-mobile .action-content' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'sidebar_menu_end',
            'type' => 'section',
            'customizer' => true,
            'indent' => false,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));

//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Sidebar Panel Minibar', 'crisop' ),
    'id' => 'headermobilesidebarminibarsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Sidebar Menu Minibar Min Width ( px )', 'crisop' ),
            'subtitle' => esc_html__( 'You can control sidebar menu bar width.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_width',
            'type' => 'slider',
            'default' => 80,
            'min' => 0,
            'step' => 1,
            'max' => 300,
            'display_value' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_bg',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-sidebar' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Close Icon Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_close_icon_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile .ninetheme-panel-close-button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Close Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_close_icon_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile .ninetheme-panel-close-button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar SVG Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_svg_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-header-mobile-sidebar .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Active SVG Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_active_svg_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-header-mobile-sidebar .sidebar-top-action .top-action-btn.active .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Active SVG Icon Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_active_svg_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-sidebar .sidebar-top-action .top-action-btn.active .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Counter Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_counter_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-sidebar .sidebar-top-action .top-action-btn .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Counter Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_counter_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-sidebar .sidebar-top-action .top-action-btn .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Text Logo Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_textlogo_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-sidebar .sidebar-top-action .top-action-btn.active .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Social Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_social_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-sidebar .ninetheme-header-mobile-sidebar-bottom a' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Minibar Social Icon Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_bar_social_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-sidebar .ninetheme-header-mobile-sidebar-bottom a:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));

//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Sidebar Panel Search', 'crisop' ),
    'id' => 'headermobilesidebarsearchsubsection',
    'subsection' => true,
    'icon' => 'el el-brush',
    'fields' => array(
        array(
            'title' => esc_html__( 'Search Placeholder Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_search_placeholder_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-slide-menu .search-area-top input::-webkit-input-placeholder' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Search Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_search_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-slide-menu .search-area-top input' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Search Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_search_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-slide-menu .search-area-top input' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Search Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_search_icon_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-header-slide-menu .search-area-top svg' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Search Border Bottom Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_search_brdcolor',
            'type' => 'color',
            'mode' => 'border-bottom-color',
            'output' => array( '.ninetheme-header-slide-menu .search-area-top' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Search Result Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_search_result_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-slide-menu .ninetheme-asform-container .autocomplete-suggestions' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Search Result Item Price Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_search_result_item_price_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-slide-menu .ninetheme-asform-container .autocomplete-suggestion .woocommerce-variation-price .price, .ninetheme-header-slide-menu .ninetheme-asform-container .autocomplete-suggestion .ninetheme-price' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));

//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Sidebar Panel Sliding Menu', 'crisop' ),
    'id' => 'headermobilesidebarslidingmenusubsection',
    'subsection' => true,
    'icon' => 'el el-brush',
    'fields' => array(
        array(
            'title' => esc_html__( 'Panel Sliding Menu Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_menuitem_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .sliding-menu' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Menu Item Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_menuitem_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.sliding-menu .sliding-menu-inner li a, .sliding-menu li .sliding-menu__nav,.sliding-menu .sliding-menu__nav:before' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Menu Item Color ( Hover/Active )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_menuitem_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.sliding-menu li.current-menu-parent>.sliding-menu__nav, .sliding-menu li.current-menu-item>.sliding-menu__nav, .sliding-menu li.current-menu-item>a, .sliding-menu li a:hover, .sliding-menu li.active a, .sliding-menu li .sliding-menu__nav:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Submenu Back Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_submenu_back_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.sliding-menu li .sliding-menu__nav.sliding-menu__back' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Submenu Back Title Border Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_submenu_back_title_brdcolor',
            'type' => 'color',
            'mode' => 'border-bottom-color',
            'output' => array( '.sliding-menu .sliding-menu__back:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Submenu Item Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_submenuitem_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.sliding-menu .sliding-menu-inner ul li a' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Submenu Item Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_submenuitem_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.sliding-menu .sliding-menu-inner ul li a:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Copyright Text', 'crisop' ),
            'subtitle' => esc_html__( 'Add your site copyright here.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_copyright',
            'type' => 'textarea',
            'default' => sprintf( '<p>&copy; %1$s, <a class="theme" href="%2$s">%3$s</a> Theme. %4$s <a class="dev" href="https://ninetheme.com/contact/">%5$s</a></p>',
                date( 'Y' ),
                esc_url( home_url( '/' ) ),
                get_bloginfo( 'name' ),
                esc_html__( 'Made with passion by', 'crisop' ),
                esc_html__( 'Ninetheme.', 'crisop' )
            ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Copyright Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_menu_copy_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-sidemenu-copyright,.ninetheme-sidemenu-copyright p' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Copyright Link Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_menu_copy_link_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-sidemenu-copyright a' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Copyright Link Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_menu_copy_link_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-sidemenu-copyright a:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Sidebar Menu Language Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the sidebar language switcher if you have.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_lang_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));
//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Categories Menu', 'crisop' ),
    'id' => 'sidebar_category_menu_subsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Exclude', 'crisop' ),
            'subtitle' => esc_html__( 'You can exclude the categories from sidebar menu.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidemenu_categories_exclude',
            'type' => 'select',
            'data' => 'terms',
            'args' => array(
                'taxonomies' => array( 'product_cat' )
            ),
            'sortable' => true,
        ),
        array(
            'title' => esc_html__( 'Sub-Categories', 'crisop' ),
            'on' => esc_html__( 'Yes', 'crisop' ),
            'off' => esc_html__( 'No', 'crisop' ),
            'customizer' => true,
            'id' => 'sidemenu_subcategories',
            'type' => 'switch',
            'default' => 0
        ),
        array(
            'title' => esc_html__( 'Hide Empty Categories', 'crisop' ),
            'on' => esc_html__( 'Yes', 'crisop' ),
            'off' => esc_html__( 'No', 'crisop' ),
            'customizer' => true,
            'id' => 'sidemenu_hide_empty_cats',
            'type' => 'switch',
            'default' => 1
        ),
        array(
            'title' => esc_html__( 'Show Category Thumbnail', 'crisop' ),
            'on' => esc_html__( 'Yes', 'crisop' ),
            'off' => esc_html__( 'No', 'crisop' ),
            'customizer' => true,
            'id' => 'sidemenu_cats_thumb_visibility',
            'type' => 'switch',
            'default' => 1
        ),
        array(
            'title' => esc_html__( 'Thumbnail Image Size', 'crisop' ),
            'customizer' => true,
            'id' => 'sidemenu_cats_thumb_imgsize',
            'type' => 'select',
            'data' => 'image_sizes',
            'required' => array( 'sidemenu_cats_thumb_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Typography', 'crisop' ),
            'id' => 'sidemenu_cat_title_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.category-area-inner .product-category .category-title' ),
        ),
        array(
            'title' => esc_html__( 'Category Count Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidemenu_cat_count_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.category-area-inner .product-category .cat-count' )
        ),
        array(
            'title' => esc_html__( 'Category Count Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidemenu_cat_count_color',
            'type' => 'color',
            'output' => array( '.category-area-inner .product-category .cat-count' )
        )
    )
));
//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Sidebar Panel WooCommerce', 'crisop' ),
    'desc' => esc_html__( 'Cart,Wishlist,Compare,Categories', 'crisop' ),
    'id' => 'headersidebarpanelcartsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Cart Panel Title', 'crisop' ),
            'subtitle' => esc_html__( 'You can change cart panel title if you want', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_custom_title',
            'type' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Wishlist Panel Title', 'crisop' ),
            'subtitle' => esc_html__( 'You can change wishlist panel title if you want', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_wishlist_custom_title',
            'type' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Compare Panel Title', 'crisop' ),
            'subtitle' => esc_html__( 'You can change compare panel title if you want', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_compare_custom_title',
            'type' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Categories Panel Title', 'crisop' ),
            'subtitle' => esc_html__( 'You can change categories panel title if you want', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_categories_custom_title',
            'type' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .panel-top-title, .ninetheme-side-panel .panel-top-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Border Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_title_brdcolor',
            'type' => 'color',
            'mode' => 'border-bottom-color',
            'output' => array( '.ninetheme-header-mobile-content .panel-top-title:after, .ninetheme-side-panel .panel-top-title:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .cart-name, .ninetheme-side-panel .cart-name' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Price Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_price_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .ninetheme-price, .ninetheme-side-panel .ninetheme-price' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Quantity Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_qty_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .quantity, .ninetheme-side-panel .quantity' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Quantity Plus Minus Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_qty_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .quantity-button.plus,.ninetheme-header-mobile-content .quantity-button.minus,.ninetheme-header-mobile-content .input-text::-webkit-input-placeholder,.ninetheme-header-mobile-content .input-text,.ninetheme-side-panel .quantity-button.plus,.ninetheme-side-panel .quantity-button.minus,.ninetheme-side-panel .input-text::-webkit-input-placeholder,.ninetheme-side-panel .input-text'),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Quantity Plus Minus Backgroud Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_qty_hvrbgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .quantity-button.plus:hover,.ninetheme-header-mobile-content .quantity-button.minus:hover,.ninetheme-side-panel .quantity-button.plus:hover,.ninetheme-side-panel .quantity-button.minus:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Wishlist,Compare Add to Cart Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_addtocart_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .ninetheme-content-info .add_to_cart_button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Wishlist,Compare Add to Cart Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_addtocart_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .ninetheme-content-info .add_to_cart_button:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Wishlist,Compare Stock Status Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_addtocart_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .ninetheme-content-info .product-stock' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Subtotal Border Top Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_subtotal_brdcolor',
            'type' => 'color',
            'mode' => 'border-top-color',
            'output' => array( '.ninetheme-header-mobile-content .cart-total-price,.ninetheme-side-panel .cart-total-price' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Subtotal Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_subtotal_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .cart-total-price,.ninetheme-side-panel .cart-total-price' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Subtotal Price Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_subtotal_price_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .cart-total-price .cart-total-price-right,.ninetheme-side-panel .cart-total-price .cart-total-price-right' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Delete Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_delete_icon_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-header-mobile-content .del-icon a svg,.ninetheme-side-panel .del-icon a svg' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Free Shipping Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_extra_text_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .minicart-extra-text,.ninetheme-side-panel .minicart-extra-text' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_buttons_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .cart-bottom-btn .ninetheme-btn,.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Background Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_buttons_hvrbgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .cart-bottom-btn .ninetheme-btn:hover,.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_buttons_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .cart-bottom-btn .ninetheme-btn,.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_buttons_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .cart-bottom-btn .ninetheme-btn:hover,.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Empty Cart Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_empty_svg_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-header-mobile-content svg,.ninetheme-side-panel .panel-content svg' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Empty Cart Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_cart_item_empty_text_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .cart-empty-content .ninetheme-small-title,.ninetheme-side-panel  .ninetheme-small-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Category Item Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_categories_item_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .category-area .category-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Category Item Counter Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_categories_item_counter_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .category-area .cat-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Category Item Counter Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_categories_item_counter_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .category-area .cat-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));
//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Sidebar Panel Contact Form', 'crisop' ),
    'id' => 'headersidebarpanelcontactsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Contact Form 7', 'crisop' ),
            'subtitle' => esc_html__( 'Select a form from the list.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_cf7',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $wpcf7_args,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Contact Form Shotcode', 'crisop' ),
            'subtitle' => esc_html__( 'Add your shortcode here, if you want to use different contact form instead of Contact Form 7.', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_menu_custom_form',
            'type' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom Panel Title', 'crisop' ),
            'subtitle' => esc_html__( 'You can change contact form panel title if you want', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_custom_title',
            'type' => 'text',
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area .panel-top-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Border Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_title_brdcolor',
            'type' => 'color',
            'mode' => 'border-bottom-color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area .panel-top-title:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Placeholder Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_placeholder_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array('.ninetheme-header-mobile-content .contact-area .wpcf7-form-control::-webkit-input-placeholder'),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_input_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input:not([type="submit"]),.ninetheme-header-mobile-content .contact-area textarea,.ninetheme-header-mobile-content .contact-area select' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_input_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input:not([type="submit"]),.ninetheme-header-mobile-content .contact-area textarea,.ninetheme-header-mobile-content .contact-area select' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Background Color ( Focus )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_input_focus_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input:not([type="submit"]):focus,.ninetheme-header-mobile-content .contact-area textarea:focus,.ninetheme-header-mobile-content .contact-area select:focus' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Border', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_input_brdcolor',
            'type' => 'border',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input:not([type="submit"]),.ninetheme-header-mobile-content .contact-area textarea,.ninetheme-header-mobile-content .contact-area select' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Border ( Focus )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_input_focus_brdcolor',
            'type' => 'border',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input:not([type="submit"]):focus,.ninetheme-header-mobile-content .contact-area textarea:focus,.ninetheme-header-mobile-content .contact-area select:focus' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_submit_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input[type="submit"],.ninetheme-header-mobile-content .contact-area .wpcf7-submit' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Background Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_submit_hvrbgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input[type="submit"]:hover,.ninetheme-header-mobile-content .contact-area .wpcf7-submit:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_submit_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input[type="submit"],.ninetheme-header-mobile-content .contact-area .wpcf7-submit' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_submit_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input[type="submit"]:hover,.ninetheme-header-mobile-content .contact-area .wpcf7-submit:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Border', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_submit_brdcolor',
            'type' => 'border',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input[type="submit"],.ninetheme-header-mobile-content .contact-area .wpcf7-submit' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Border ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_submit_hvrbrdcolor',
            'type' => 'border',
            'output' => array( '.ninetheme-header-mobile-content .contact-area input[type="submit"]:hover,.ninetheme-header-mobile-content .contact-area .wpcf7-submit:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Element Label Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_label_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area label,.ninetheme-header-mobile-content .contact-area .label' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Contact Details Heading Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_h_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area h2,.ninetheme-header-mobile-content .contact-area h3,.ninetheme-header-mobile-content .contact-area h4,.ninetheme-header-mobile-content .contact-area h5,.ninetheme-header-mobile-content .contact-area h6, .ninetheme-header-mobile-content .contact-area .ninetheme-meta-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Contact Details Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_contact_form_p_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .contact-area div,.ninetheme-header-mobile-content .contact-area p' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));
//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Sidebar Panel Account', 'crisop' ),
    'id' => 'headersidebarpanelaccountsubsection',
    'subsection' => true,
    'icon' => 'el el-brush',
    'fields' => array(
        array(
            'id' => 'sidebar_account_logout_start',
            'title' => esc_html__( 'Log Out Options', 'crisop' ),
            'type' => 'section',
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .account-area .panel-top-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_title_icon_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .account-area .form-action-btn svg' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Border Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_title_brdcolor',
            'type' => 'color',
            'mode' => 'border-bottom-color',
            'output' => array( '.ninetheme-header-mobile-content .account-area .panel-top-title:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Placeholder Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_placeholder_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array('.woocommerce .ninetheme-header-mobile-content .account-area form .form-row input.input-text::-webkit-input-placeholder'),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_input_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.woocommerce .ninetheme-header-mobile-content .account-area form .form-row input.input-text' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_input_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.woocommerce .ninetheme-header-mobile-content .account-area form .form-row input.input-text' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Background Color ( Focus )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_input_focus_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.woocommerce .ninetheme-header-mobile-content .account-area form .form-row input.input-text:focus' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Border', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_input_brdcolor',
            'type' => 'border',
            'output' => array( '.woocommerce .ninetheme-header-mobile-content .account-area form .form-row input.input-text' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Input Border ( Focus )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_input_focus_brdcolor',
            'type' => 'border',
            'output' => array( '.woocommerce .ninetheme-header-mobile-content .account-area form .form-row input.input-text:focus' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Checkbox Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_check_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .account-area input[type="checkbox"]:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Checkbox Background Color ( Checked )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_check_actbgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .account-area input[type="checkbox"]:checked:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_submit_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .account-area button[type="submit"],.woocommerce-page .ninetheme-header-mobile-content .account-area button.button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Background Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_submit_hvrbgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .account-area button[type="submit"]:hover,.woocommerce-page .ninetheme-header-mobile-content .account-area button.button:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_submit_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .account-area button[type="submit"],.woocommerce-page .ninetheme-header-mobile-content .account-area button.button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_submit_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .account-area button[type="submit"]:hover,.woocommerce-page .ninetheme-header-mobile-content .account-area button.button:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Border', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_submit_brdcolor',
            'type' => 'border',
            'output' => array( '.ninetheme-header-mobile-content .account-area button[type="submit"],.woocommerce-page .ninetheme-header-mobile-content .account-area button.button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Submit Button Border ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_submit_hvrbrdcolor',
            'type' => 'border',
            'output' => array( '.ninetheme-header-mobile-content .account-area button[type="submit"]:hover,.woocommerce-page .ninetheme-header-mobile-content .account-area button.button:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Form Element Label Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_label_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.woocommerce .ninetheme-header-mobile-content .account-area form .form-row label' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Lost Password Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_form_p_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .account-area .lost_password a' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'sidebar_account_logout_end',
            'title' => esc_html__( 'Log In Options', 'crisop' ),
            'type' => 'section',
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Menu Item Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_menu_item_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .account-area li.menu-item a' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Menu Item Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_menu_item_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-header-mobile-content .account-area li.menu-item a:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Menu Item Border Bootm Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_panel_account_menu_item_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-header-mobile-content .account-area li.menu-item a:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'id' => 'sidebar_account_end',
            'type' => 'section',
            'customizer' => true,
            'indent' => false,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));
//HEADER MOBILE TOP
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Right Panel WooCommerce', 'crisop' ),
    'desc' => esc_html__( 'Cart,Wishlist,Compare', 'crisop' ),
    'id' => 'headerrightpanelsubsection',
    'subsection' => true,
    'icon' => 'el el-brush',
    'fields' => array(
        array(
            'title' => esc_html__( 'Disable Panel Auto-Open', 'crisop' ),
            'subtitle' => esc_html__( 'You can disable automatic opening of the right panel( mini cart ) when a product is added to the cart', 'crisop' ),
            'customizer' => true,
            'id' => 'disable_right_panel_auto',
            'on' => esc_html__( 'Yes', 'crisop' ),
            'off' => esc_html__( 'No', 'crisop' ),
            'type' => 'switch',
            'customizer' => true,
            'default' => 1,
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_bg',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( 'body .ninetheme-side-panel, .has-default-header-type-trans .ninetheme-side-panel, .header-trans-dark  .ninetheme-side-panel' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Border Bottom Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_header_brdcolor',
            'type' => 'color',
            'mode' => 'border-bottom-color',
            'output' => array( '.ninetheme-side-panel .panel-header' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Close Icon Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_close_icon_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .ninetheme-panel-close-button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Close Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_close_icon_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .ninetheme-panel-close-button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header SVG Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_svg_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-side-panel .panel-header .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Active SVG Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_active_svg_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-side-panel .panel-header .panel-header-btn.active .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Active SVG Icon Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_active_svg_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .panel-header .panel-header-btn.active .ninetheme-svg-icon' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Counter Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_counter_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .panel-header .panel-header-btn .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Counter Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_counter_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .panel-header .panel-header-btn  .ninetheme-wc-count' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Header Cart Total Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_total_text_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .panel-header .panel-header-btn span.ninetheme-cart-total' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .panel-top-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Panel Title Border Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_title_brdcolor',
            'type' => 'color',
            'mode' => 'border-bottom-color',
            'output' => array( '.ninetheme-side-panel .panel-top-title:after' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_title_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .cart-name' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Price Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_price_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .ninetheme-price' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Quantity Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_qty_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .quantity' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Quantity Plus Minus Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_qty_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .quantity-button.plus,.ninetheme-side-panel .quantity-button.minus,.ninetheme-side-panel .input-text::-webkit-input-placeholder,.ninetheme-side-panel .input-text'),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Cart Item Quantity Plus Minus Backgroud Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_qty_hvrbgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .quantity-button.plus:hover,.ninetheme-side-panel .quantity-button.minus:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Wishlist,Compare Add to Cart Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_addtocart_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .ninetheme-content-info .add_to_cart_button' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Wishlist,Compare Add to Cart Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_addtocart_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .ninetheme-content-info .add_to_cart_button:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Wishlist,Compare Stock Status Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_addtocart_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .ninetheme-content-info .product-stock' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Subtotal Border Top Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_subtotal_brdcolor',
            'type' => 'color',
            'mode' => 'border-top-color',
            'output' => array( '.ninetheme-side-panel .cart-total-price' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Subtotal Title Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_subtotal_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .cart-total-price' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Subtotal Price Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_subtotal_price_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .cart-total-price .cart-total-price-right' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Delete Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_delete_icon_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-side-panel .del-icon a svg' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Free Shipping Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_extra_text_color',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .minicart-extra-text' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Background Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_buttons_bgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn, .ninetheme-side-panel .checkout-area .ninetheme-bg-black' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Background Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_buttons_hvrbgcolor',
            'type' => 'color',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn:hover, .ninetheme-side-panel .checkout-area .ninetheme-bg-black:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_buttons_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn, .ninetheme-side-panel .checkout-area .ninetheme-bg-black' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Buttons Color ( Hover )', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_buttons_hvrcolor',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .cart-bottom-btn .ninetheme-btn:hover, .ninetheme-side-panel .checkout-area .ninetheme-bg-black:hover' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Empty Cart Icon Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_empty_svg_color',
            'type' => 'color',
            'mode' => 'fill',
            'output' => array( '.ninetheme-side-panel .panel-content svg' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Empty Cart Text Color', 'crisop' ),
            'customizer' => true,
            'id' => 'sidebar_right_panel_cart_item_empty_text_color',
            'type' => 'color',
            'mode' => 'color',
            'output' => array( '.ninetheme-side-panel .ninetheme-small-title' ),
            'required' => array(
                array( 'header_visibility', '=', '1' ),
                array( 'header_template', '=', 'default' )
            )
        )
    )
));

//FOOTER SECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Footer', 'crisop' ),
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'id' => 'footersection',
    'icon' => 'el el-photo',
    'fields' => array(
        array(
            'title' => esc_html__( 'Footer Section Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site footer copyright and footer widget area on the site with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Footer Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your footer type.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_template',
            'type' => 'select',
            'customizer' => true,
            'options' => array(
                'default' => esc_html__( 'Deafult Site Footer', 'crisop' ),
                'elementor' => esc_html__( 'Elementor Templates', 'crisop' )
            ),
            'default' => 'default',
            'required' => array( 'footer_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'elementor' )
            )
        ),
        array(
            'id' =>'edit_footer_template',
            'type' => 'info',
            'desc' => 'Edit template',
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'elementor' ),
                array( 'footer_elementor_templates', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Copyright Text', 'crisop' ),
            'subtitle' => esc_html__( 'HTML allowed (wp_kses)', 'crisop' ),
            'desc' => esc_html__( 'Enter your site copyright text here.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_copyright',
            'type' => 'textarea',
            'validate' => 'html',
            'default' => sprintf( '<p>&copy; %1$s, <a class="theme" href="%2$s">%3$s</a> Theme. %4$s <a class="dev" href="https://ninetheme.com/contact/">%5$s</a></p>',
                date( 'Y' ),
                esc_url( home_url( '/' ) ),
                get_bloginfo( 'name' ),
                esc_html__( 'Made with passion by', 'crisop' ),
                esc_html__( 'Ninetheme.', 'crisop' )
            ),
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'default' )
            )
        ),
        //information on-off
        array(
            'id' =>'info_f0',
            'type' => 'info',
            'style' => 'success',
            'title' => esc_html__( 'Success!', 'crisop' ),
            'icon' => 'el el-info-circle',
            'customizer' => true,
            'desc' => sprintf(esc_html__( '%s section is disabled on the site.Please activate to view subsection options.', 'crisop' ), '<b>Site Main Footer</b>' ),
            'required' => array( 'footer_visibility', '=', '0' )
        )
    )
));
//FOOTER SECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Footer Style', 'crisop' ),
    'desc' => esc_html__( 'These are main settings for general theme!', 'crisop' ),
    'id' => 'footerstylesubsection',
    'icon' => 'el el-photo',
    'subsection' => true,
    'fields' => array(
        array(
            'id' =>'footer_color_customize',
            'type' => 'info',
            'icon' => 'el el-brush',
            'customizer' => false,
            'desc' => sprintf(esc_html__( '%s', 'crisop' ), '<h2>Footer Color Customize</h2>' ),
            'customizer' => true,
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Footer Padding', 'crisop' ),
            'subtitle' => esc_html__( 'You can set the top spacing of the site main footer.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_pad',
            'type' => 'spacing',
            'output' => array('#nt-footer' ),
            'mode' => 'padding',
            'units' => array('em', 'px' ),
            'units_extended' => 'false',
            'default' => array(
                'padding-top' => '',
                'padding-right' => '',
                'padding-bottom' => '',
                'padding-left' => '',
                'units' => 'px'
            ),
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Footer Background Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own colors for the footer.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_bg_clr',
            'type' => 'color',
            'validate' => 'color',
            'mode' => 'background-color',
            'output' => array( '#nt-footer' ),
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Copyright Text Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own colors for the copyright.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_copy_clr',
            'type' => 'color',
            'validate' => 'color',
            'transparent' => false,
            'output' => array( '#nt-footer, #nt-footer p' ),
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Link Color', 'crisop' ),
            'desc' => esc_html__( 'Set your own colors for the copyright.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_link_clr',
            'type' => 'color',
            'validate' => 'color',
            'transparent' => false,
            'output' => array( '#nt-footer a' ),
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'default' )
            )
        ),
        array(
            'title' => esc_html__( 'Link Color ( Hover )', 'crisop' ),
            'desc' => esc_html__( 'Set your own colors for the copyright.', 'crisop' ),
            'customizer' => true,
            'id' => 'footer_link_hvr_clr',
            'type' => 'color',
            'validate' => 'color',
            'transparent' => false,
            'output' => array( '#nt-footer a:hover' ),
            'required' => array(
                array( 'footer_visibility', '=', '1' ),
                array( 'footer_template', '=', 'default' )
            )
        ),
        //information on-off
        array(
            'id' =>'info_fc0',
            'type' => 'info',
            'style' => 'success',
            'title' => esc_html__( 'Success!', 'crisop' ),
            'icon' => 'el el-info-circle',
            'customizer' => true,
            'desc' => sprintf(esc_html__( '%s section is disabled on the site.Please activate to view subsection options.', 'crisop' ), '<b>Site Main Footer</b>' ),
            'required' => array( 'footer_visibility', '=', '0' )
        )
    )
));
/*************************************************
## WOOCOMMERCE SECTION
*************************************************/
if ( class_exists( 'WooCommerce' ) ) {
    // WooCommerce
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'WooCommerce', 'crisop' ),
        'id' => 'woocommerce_section',
        'icon' => 'el el-shopping-cart-sign',
        'fields' => array(
        )
    ));
    $ajax_fields = array();
    $ajax_fields[] = array(
        'title' => esc_html__('Ajax Shop', 'crisop'),
        'subtitle' => esc_html__('You can enable or disable the site shop page ajax filter actions.', 'crisop'),
        'customizer' => true,
        'id' => 'shop_ajax_filter',
        'type' => 'switch',
        'default' => 1
    );
    $ajax_fields[] = array(
        'title' => esc_html__('Ajax Login/Register', 'crisop'),
        'subtitle' => esc_html__('You can turn ajax login and registration process on or off here.', 'crisop'),
        'customizer' => true,
        'id' => 'wc_ajax_login_register',
        'type' => 'switch',
        'default' => 1
    );
    $ajax_fields[] = array(
        'title' => esc_html__('URL to Redirect After Login ( General )', 'crisop'),
        'customizer' => true,
        'id' => 'wc_ajax_login_redirect_url',
        'type' => 'text',
        'required' => array( 'wc_ajax_login_register', '=', '1' )
    );
    $ajax_fields[] = array(
        'title' => esc_html__('URL to Redirect After Registration ( General )', 'crisop'),
        'customizer' => true,
        'id' => 'wc_ajax_register_redirect_url',
        'type' => 'text',
        'required' => array( 'wc_ajax_login_register', '=', '1' )
    );
    $ajax_fields[] = array(
        'title' => esc_html__('Custom Rerdirect URL By User Role ( Login )', 'crisop'),
        'subtitle' => esc_html__('Redirect users to custom URL based on their role after login.', 'crisop'),
        'customizer' => true,
        'id' => 'wc_ajax_login_custom_roles',
        'type' => 'switch',
        'default' => 0,
        'required' => array( 'wc_ajax_login_register', '=', '1' )
    );
    $ajax_fields[] = array(
        'title' => esc_html__( 'Select User Role(s)', 'crisop' ),
        'subtitle' => esc_html__( 'Select Role(s) from the list.', 'crisop' ),
        'customizer' => true,
        'id' => 'wc_ajax_login_roles',
        'type' => 'select',
        'sortable' => true,
        'data'  => 'roles',
        'multi' => true,
        'required' => array(
            array( 'wc_ajax_login_register', '=', '1' ),
            array( 'wc_ajax_login_custom_roles', '=', '1' )
        )
    );
    global $wp_roles;
    $roles = $wp_roles->roles;
    foreach ( $roles as $key => $value ) {
        $ajax_fields[] = array(
            'title' => esc_html__('Redirect URL ( for '.$value['name'].' )', 'crisop'),
            'customizer' => true,
            'id' => 'redirect_url_'.$key,
            'type' => 'text',
            'required' => array(
                array( 'wc_ajax_login_register', '=', '1' ),
                array( 'wc_ajax_login_custom_roles', '=', '1' ),
                array( 'wc_ajax_login_roles', '=', $key ),
            )
        );
    }

    // SHOP PAGE SECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Ajax', 'crisop' ),
        'id' => 'woocommerce_ajax_subsection',
        'subsection' => true,
        'icon' => 'fa fa-cog',
        'fields' => $ajax_fields
    ));
    // Account
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Ajax Live Search', 'crisop'),
        'id' => 'ajax_live_search_form',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' =>'ajax_search_type',
                'type' => 'button_set',
                'title' => esc_html__('Search Template Type', 'crisop'),
                'customizer' => true,
                'options' => array(
                    'cat' => esc_html__( 'Search by Category', 'crisop' ),
                    'input' => esc_html__( 'Search Only', 'crisop' ),
                    'plugin' => esc_html__( 'Custom Plugin Shortcode', 'crisop' ),
                ),
                'default' => 'cat'
            ),
            array(
                'id' =>'ajax_search_custom_shortcode',
                'type' => 'text',
                'title' => esc_html__('Shortcode', 'crisop'),
                'customizer' => true,
                'default' => '',
                'required' => array( 'ajax_search_type', '=', 'plugin' )
            ),
            array(
                'id' =>'ajax_search_sku',
                'type' => 'switch',
                'title' => esc_html__('Search String by Product SKU', 'crisop'),
                'customizer' => true,
                'default' => '1',
                'required' => array( 'ajax_search_type', '!=', 'plugin' )
            ),
            array(
                'id' =>'ajax_search_content',
                'type' => 'switch',
                'title' => esc_html__('Search String by Product Content', 'crisop'),
                'customizer' => true,
                'default' => '1',
                'required' => array( 'ajax_search_type', '!=', 'plugin' )
            ),
            array(
                'title' => esc_html__('Max Strings', 'crisop'),
                'subtitle' => esc_html__('Maximum number of strings required to start the search', 'crisop'),
                'customizer' => true,
                'id' => 'ajax_search_max_char',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'ajax_search_type', '!=', 'plugin' )
            ),
            array(
                'id' =>'ajax_search_result_img',
                'type' => 'switch',
                'title' => esc_html__('Search Result Image Display', 'crisop'),
                'customizer' => true,
                'default' => '1',
                'required' => array( 'ajax_search_type', '!=', 'plugin' )
            ),
            array(
                'title' => esc_html__( 'Search Result Custom Image', 'crisop' ),
                'customizer' => true,
                'id' => 'ajax_search_custom_img',
                'type' => 'media',
                'url' => true,
                'customizer' => true,
                'required' => array(
                    array( 'ajax_search_type', '!=', 'plugin' ),
                    array( 'ajax_search_result_img', '=', '1' )
                )
            ),
            array(
                'id' =>'ajax_search_result_prc',
                'type' => 'switch',
                'title' => esc_html__('Search Result Price Display', 'crisop'),
                'customizer' => true,
                'default' => '1',
                'required' => array( 'ajax_search_type', '!=', 'plugin' )
            ),
            array(
                'id' =>'ajax_search_result_stock',
                'type' => 'switch',
                'title' => esc_html__('Search Result Stock Display', 'crisop'),
                'customizer' => true,
                'default' => '1',
                'required' => array( 'ajax_search_type', '!=', 'plugin' )
            ),
            array(
                'id' =>'ajax_search_result_btn',
                'type' => 'switch',
                'title' => esc_html__('Search Result Add To Cart Display', 'crisop'),
                'customizer' => true,
                'default' => '1',
                'required' => array( 'ajax_search_type', '!=', 'plugin' )
            ),
        )
    ));
    // Quick Shop SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Ajax Add To Cart', 'crisop'),
        'id' => 'shop_ajax_addtocart_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Product Page Ajax Add To Cart', 'crisop'),
                'customizer' => true,
                'id' => 'product_ajax_addtocart',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Ajax Add To Cart ( for Simple Products )', 'crisop'),
                'customizer' => true,
                'id' => 'ajax_addtocart_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Quantity Display ( for Simple Products )', 'crisop'),
                'customizer' => true,
                'id' => 'cart_quantity_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__( 'Ajax Add To Cart ( for Variable and Grouped Products ) Customize', 'crisop' ),
                'indent' => false,
                'id' => 'quick_shop_lightbox_divide',
                'type' => 'info',
                'style' => 'success',
                'color' => '#000',
                'icon' => 'el el-cog',
                'notice' => true,
                'required' => array( 'quick_shop_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Ajax Add To Cart ( for Variable and Grouped Products )', 'crisop'),
                'customizer' => true,
                'id' => 'quick_shop_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Popup Overlay Color', 'crisop'),
                'subtitle' => esc_html__('Change quick view overlay color.', 'crisop'),
                'customizer' => true,
                'id' => 'quick_shop_overlaycolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.mfp-bg.mfp-ninetheme-quickshop'),
                'required' => array( 'quick_shop_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Content Background Color', 'crisop'),
                'subtitle' => esc_html__('Change quick view background color.', 'crisop'),
                'customizer' => true,
                'id' => 'quick_shop_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-quickshop-wrapper'),
                'required' => array( 'quick_shop_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Content Border', 'crisop'),
                'subtitle' => esc_html__('Set your custom border styles for the posts.', 'crisop'),
                'customizer' => true,
                'id' => 'quick_shop_brd',
                'type' => 'border',
                'all' => false,
                'output' => array('.ninetheme-quickshop-wrapper'),
                'required' => array( 'quick_shop_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Content Padding', 'crisop'),
                'subtitle' => esc_html__('You can set the spacing of the site shop page post.', 'crisop'),
                'customizer' => true,
                'id' =>'quick_shop_pad',
                'type' => 'spacing',
                'output' => array('.ninetheme-quickshop-wrapper'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array(
                    'units' => 'px'
                ),
                'required' => array( 'quick_shop_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Max Width', 'crisop' ),
                'subtitle' => esc_html__( 'You can use this option to control the theme content width.', 'crisop' ),
                'customizer' => true,
                'id' => 'quick_shop_width',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 4000,
                'display_value' => 'text',
                'required' => array( 'quick_shop_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Max Width Responsive ( min-width 768px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can use this option to control the theme content width.', 'crisop' ),
                'customizer' => true,
                'id' => 'quick_shop_width_sm',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 1200,
                'display_value' => 'text',
                'required' => array( 'quick_shop_visibility', '=', '1' )
            )
        )
    ));
    // Account
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('My Account Page', 'crisop'),
        'id' => 'shop_myaccount_page_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' =>'myaccount_page_type',
                'type' => 'button_set',
                'title' => esc_html__('My Account Page Type', 'crisop'),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop account page.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'default' => esc_html__( 'Default', 'crisop' ),
                    'multisteps' => esc_html__( 'Multi Steps', 'crisop' )
                ),
                'default' => 'default'
            ),
            array(
                'id' =>'header_myaccount_action_type',
                'type' => 'select',
                'title' => esc_html__( 'Header My Account Buttons Action Type', 'crisop' ),
                'subtitle' => esc_html__( 'Select your action type.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'open-in-popup' => esc_html__( 'Open in popup', 'crisop' ),
                    'open-in-sidebar' => esc_html__( 'Open in sidebar', 'crisop' ),
                    'account-page' => esc_html__( 'Redirect to Account Page', 'crisop' ),
                ),
                'default' => 'open-in-popup',
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            ),
            array(
                'id' =>'header_myaccount_after_login_url',
                'type' => 'text',
                'title' => esc_html__( 'After Login Redirect URL', 'crisop' ),
                'subtitle' => esc_html__( 'Add your url for after logged in user.', 'crisop' ),
                'customizer' => true,
                'default' => '',
                'required' => array(
                    array( 'header_visibility', '=', '1' ),
                    array( 'header_template', '=', 'default' )
                )
            )
        )
    ));
    // Checkout
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Checkout Page', 'crisop'),
        'id' => 'shop_checkout_page_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' =>'checkout_enable_multistep',
                'type' => 'button_set',
                'title' => esc_html__('Checkout Page Type', 'crisop'),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop checkout page.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'default' => esc_html__( 'Default', 'crisop' ),
                    'multisteps' => esc_html__( 'Multi Steps', 'crisop' )
                ),
                'default' => 'default'
            ),
            array(
                'id' =>'checkout_form_customize',
                'type' => 'button_set',
                'title' => esc_html__('Custom Checkout Form Fields', 'crisop'),
                'subtitle' => esc_html__( 'If there is a field in the checkout form that you do not want to be, you can use this option.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'yes' => esc_html__( 'Yes', 'crisop' ),
                    'no' => esc_html__( 'No', 'crisop' )
                ),
                'default' => 'no'
            ),
            array(
                'id' =>'checkout_form_layouts',
                'type' => 'checkbox',
                'title' => esc_html__('Checkout Form Manager', 'crisop'),
                'subtitle' => esc_html__('Organize how you want the layout to appear on the theme Checkout Form.', 'crisop'),
                'options' => array(
                    'billing_first_name' => esc_html__('First name ( Billing Form )', 'crisop'),
                    'billing_last_name' => esc_html__('Last name ( Billing Form )', 'crisop'),
                    'billing_company' => esc_html__('Company ( Billing Form )', 'crisop'),
                    'billing_address_1' => esc_html__('Address 1 ( Billing Form )', 'crisop'),
                    'billing_address_2' => esc_html__('Address 2 ( Billing Form )', 'crisop'),
                    'billing_city' => esc_html__('City ( Billing Form )', 'crisop'),
                    'billing_postcode' => esc_html__('Postcode ( Billing Form )', 'crisop'),
                    'billing_country' => esc_html__('Country ( Billing Form )', 'crisop'),
                    'billing_state' => esc_html__('State ( Billing Form )', 'crisop'),
                    'billing_phone' => esc_html__('Phone ( Billing Form )', 'crisop'),
                    'billing_email' => esc_html__('Email ( Billing Form )', 'crisop'),
                    'order_comments' => esc_html__('Order comments ( Order )', 'crisop'),
                    'account_username' => esc_html__('Account username ( Account )', 'crisop'),
                    'account_password' => esc_html__('Account password ( Account )', 'crisop'),
                    'account_password-2' => esc_html__('Account password 2 ( Account )', 'crisop'),
                    'shipping_first_name' => esc_html__('First name ( Shipping Form )', 'crisop'),
                    'shipping_last_name' => esc_html__('Last name ( Shipping Form )', 'crisop'),
                    'shipping_company' => esc_html__('Company ( Shipping Form )', 'crisop'),
                    'shipping_address_1' => esc_html__('Address 1 ( Shipping Form )', 'crisop'),
                    'shipping_address_2' => esc_html__('Address 2 ( Shipping Form )', 'crisop'),
                    'shipping_city' => esc_html__('City ( Shipping Form )', 'crisop'),
                    'shipping_postcode' => esc_html__('Postcode ( Shipping Form )', 'crisop'),
                    'shipping_country' => esc_html__('Country ( Shipping Form )', 'crisop'),
                    'shipping_state' => esc_html__('State ( Shipping Form )', 'crisop')
                ),
                'default' => array(
                    'billing_first_name' => '1',
                    'billing_last_name' => '1',
                    'billing_company' => '1',
                    'billing_address_1' => '1',
                    'billing_address_2' => '1',
                    'billing_city' => '1',
                    'billing_postcode' => '1',
                    'billing_country' => '1',
                    'billing_state' => '1',
                    'billing_phone' => '1',
                    'billing_email' => '1',
                    'order_comments' => '1',
                    'account_username' => '1',
                    'account_password' => '1',
                    'account_password-2' => '1',
                    'shipping_first_name' => '1',
                    'shipping_last_name' => '1',
                    'shipping_company' => '1',
                    'shipping_address_1' => '1',
                    'shipping_address_2' => '1',
                    'shipping_city' => '1',
                    'shipping_postcode' => '1',
                    'shipping_country' => '1',
                    'shipping_state' => '1'
                ),
                'required' => array('checkout_form_customize', '=', 'yes')
            ),
            array(
                'id' =>'checkout_form_required_fields_layouts',
                'type' => 'checkbox',
                'title' => esc_html__('Required Fields', 'crisop'),
                'options' => array(
                    'billing_first_name' => esc_html__('First name ( Billing Form )', 'crisop'),
                    'billing_last_name' => esc_html__('Last name ( Billing Form )', 'crisop'),
                    'billing_company' => esc_html__('Company ( Billing Form )', 'crisop'),
                    'billing_address_1' => esc_html__('Address 1 ( Billing Form )', 'crisop'),
                    'billing_address_2' => esc_html__('Address 2 ( Billing Form )', 'crisop'),
                    'billing_city' => esc_html__('City ( Billing Form )', 'crisop'),
                    'billing_postcode' => esc_html__('Postcode ( Billing Form )', 'crisop'),
                    'billing_country' => esc_html__('Country ( Billing Form )', 'crisop'),
                    'billing_state' => esc_html__('State ( Billing Form )', 'crisop'),
                    'billing_phone' => esc_html__('Phone ( Billing Form )', 'crisop'),
                    'billing_email' => esc_html__('Email ( Billing Form )', 'crisop'),
                    'shipping_first_name' => esc_html__('First name ( Shipping Form )', 'crisop'),
                    'shipping_last_name' => esc_html__('Last name ( Shipping Form )', 'crisop'),
                    'shipping_company' => esc_html__('Company ( Shipping Form )', 'crisop'),
                    'shipping_address_1' => esc_html__('Address 1 ( Shipping Form )', 'crisop'),
                    'shipping_address_2' => esc_html__('Address 2 ( Shipping Form )', 'crisop'),
                    'shipping_city' => esc_html__('City ( Shipping Form )', 'crisop'),
                    'shipping_postcode' => esc_html__('Postcode ( Shipping Form )', 'crisop'),
                    'shipping_country' => esc_html__('Country ( Shipping Form )', 'crisop'),
                    'shipping_state' => esc_html__('State ( Shipping Form )', 'crisop')
                ),
                'default' => array(
                    'billing_first_name' => '1',
                    'billing_last_name' => '1',
                    'billing_company' => '0',
                    'billing_address_1' => '1',
                    'billing_address_2' => '0',
                    'billing_city' => '1',
                    'billing_postcode' => '1',
                    'billing_country' => '1',
                    'billing_state' => '1',
                    'billing_phone' => '1',
                    'billing_email' => '1',
                    'shipping_first_name' => '1',
                    'shipping_last_name' => '1',
                    'shipping_company' => '0',
                    'shipping_address_1' => '1',
                    'shipping_address_2' => '0',
                    'shipping_city' => '1',
                    'shipping_postcode' => '1',
                    'shipping_country' => '1',
                    'shipping_state' => '1'
                ),
                'required' => array('checkout_form_customize', '=', 'yes')
            )
        )
    ));
    // Cross-Sells Posts
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Cross-Sells Products', 'crisop'),
        'id' => 'shop_crosssells_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Cross-Sells Title', 'crisop'),
                'subtitle' => esc_html__('Add your cart page cross-sells section title here.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cross_sells_title',
                'type' => 'text',
                'default' => ''
            ),
            array(
                'id' =>'shop_cross_sells_type',
                'type' => 'button_set',
                'title' => esc_html__('Cross-Sells Layout Type', 'crisop'),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop product page cross-sells.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'slider' => esc_html__( 'Slider', 'crisop' ),
                    'grid' => esc_html__( 'Grid', 'crisop' )
                ),
                'default' => 'slider'
            ),
            array(
                'title' => esc_html__('Post Column', 'crisop'),
                'subtitle' => esc_html__('You can control cross-sells post column with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cross_sells_colxl',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 5,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'grid' )
            ),
            array(
                'title' => esc_html__('Post Column ( Desktop/Tablet )', 'crisop'),
                'subtitle' => esc_html__('You can control cross-sells post column for tablet device with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cross_sells_collg',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 4,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'grid' )
            ),
            array(
                'title' => esc_html__('Post Column ( Tablet )', 'crisop'),
                'subtitle' => esc_html__('You can control cross-sells post column for phone device with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cross_sells_colsm',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 3,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'grid' )
            ),
            array(
                'title' => esc_html__('Post Column ( Phone )', 'crisop'),
                'subtitle' => esc_html__('You can control cross-sells post column for phone device with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cross_sells_colxs',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 2,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'grid' )
            ),
            array(
                'id' => 'shop_cross_sells_section_slider_start',
                'type' => 'section',
                'title' => esc_html__('Cross-Sells Slider Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 1024px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control cross-sells post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_perview',
                'type' => 'slider',
                'default' => 4,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 768px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control cross-sells post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_mdperview',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 480px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control cross-sells post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_smperview',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Speed', 'crisop' ),
                'subtitle' => esc_html__( 'You can control cross-sells post slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_speed',
                'type' => 'slider',
                'default' => 1000,
                'min' => 100,
                'step' => 1,
                'max' => 10000,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Gap', 'crisop' ),
                'subtitle' => esc_html__( 'You can control cross-sells post slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_gap',
                'type' => 'slider',
                'default' => 30,
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Autoplay', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_autoplay',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Loop', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_loop',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Mousewheel', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_mousewheel',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Free Mode', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cross_sells_freemode',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            ),
            array(
                'id' => 'shop_cross_sells_section_slider_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array( 'shop_cross_sells_type', '=', 'slider' )
            )
        )
    ));
    // Cross-Sells Posts
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Recently Viewed Products', 'crisop'),
        'id' => 'shop_recently_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Recently Viewed Display', 'crisop'),
                'customizer' => true,
                'id' => 'shop_recently_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Recently Title', 'crisop'),
                'subtitle' => esc_html__('Add your recently viewed section title here.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_recently_title',
                'type' => 'text',
                'default' => '',
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'id' => 'shop_recently_section_slider_start',
                'type' => 'section',
                'title' => esc_html__('Recently Slider Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 1024px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control recently viewed product slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_recently_perview',
                'type' => 'slider',
                'default' => 4,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 768px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control recently viewed product slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_recently_mdperview',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 480px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control recently viewed product slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_recently_smperview',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Speed', 'crisop' ),
                'subtitle' => esc_html__( 'You can control recently viewed product slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_recently_speed',
                'type' => 'slider',
                'default' => 1000,
                'min' => 100,
                'step' => 1,
                'max' => 10000,
                'display_value' => 'text',
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Gap', 'crisop' ),
                'subtitle' => esc_html__( 'You can control recently viewed product slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_recently_gap',
                'type' => 'slider',
                'default' => 30,
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Autoplay', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_recently_autoplay',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Loop', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_recently_loop',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'shop_recently_visibility', '=', '1' )
            ),
            array(
                'id' => 'shop_recently_section_slider_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array( 'shop_recently_visibility', '=', '1' )
            )
        )
    ));
    // Quick View SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Quick View', 'crisop'),
        'id' => 'shop_quick_view_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Quick View Display', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Overlay Color', 'crisop'),
                'subtitle' => esc_html__('Change quick view overlay color.', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_overlaycolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.mfp-bg.mfp-ninetheme-quickview'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Content Background Color', 'crisop'),
                'subtitle' => esc_html__('Change quick view background color.', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Content Border', 'crisop'),
                'subtitle' => esc_html__('Set your custom border styles for the posts.', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_brd',
                'type' => 'border',
                'all' => false,
                'output' => array('.ninetheme-quickview-wrapper'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Content Padding', 'crisop'),
                'subtitle' => esc_html__('You can set the spacing of the site shop page post.', 'crisop'),
                'customizer' => true,
                'id' =>'quick_view_pad',
                'type' => 'spacing',
                'output' => array('.ninetheme-quickview-wrapper'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array(
                    'units' => 'px'
                ),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Content Width', 'crisop' ),
                'subtitle' => esc_html__( 'You can use this option to control the theme content width.', 'crisop' ),
                'customizer' => true,
                'id' => 'quick_view_width',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 4000,
                'display_value' => 'text',
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Content Width Responsive ( min-width 768px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can use this option to control the theme content width.', 'crisop' ),
                'customizer' => true,
                'id' => 'quick_view_width_sm',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 1200,
                'display_value' => 'text',
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Close Button Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_close_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.mfp-ninetheme-quickview .ninetheme-panel-close-button'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Close Button Color', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_close_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .mfp-close.ninetheme-panel-close-button:before,.ninetheme-quickview-wrapper .mfp-close.ninetheme-panel-close-button:after'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Product Title Color', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_title_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-product-title'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Product Price Color', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_price_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-price'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Product Description Color', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_desc_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-product-summary .ninetheme-summary-item p'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Add to Cart Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_btn_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-btn-small'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Add to Cart Background Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_btn_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-btn-small:hover'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Add to Cart Color', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_btn_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-btn-small'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Add to Cart Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_btn_hvrcolor',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-btn-small:hover'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Meta Label Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_meta_label_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .ninetheme-attr-label'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Meta Label Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'quick_view_meta_value_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-quickview-wrapper .product_meta>span a, .ninetheme-quickview-wrapper .ninetheme-attr-value, .ninetheme-quickview-wrapper .ninetheme-attr-value a'),
                'required' => array( 'quick_view_visibility', '=', '1' )
            )
        )
    ));
    // Popup Notices SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Popup Notices', 'crisop'),
        'id' => 'shop_popup_notices_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Ajax Add to Cart Notices Display', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cart_popup_notices_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'id' =>'shop_cart_popup_notices_position',
                'type' => 'button_set',
                'title' => esc_html__( 'Notices position', 'crisop' ),
                'options' => array(
                    'bottom-left' => esc_html__( 'Bottom-Left', 'crisop' ),
                    'bottom-center' => esc_html__( 'Bottom-Center', 'crisop' ),
                    'bottom-right' => esc_html__( 'Bottom-Right', 'crisop' ),
                    'top-left' => esc_html__( 'Top-Left', 'crisop' ),
                    'top-center' => esc_html__( 'Top-Center', 'crisop' ),
                    'top-right' => esc_html__( 'Top-Right', 'crisop' ),
                    'centered' => esc_html__( 'Center-Center', 'crisop' )
                ),
                'default' => 'bottom-right',
                'required' => array( 'shop_cart_popup_notices_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Notices Duration ( ms )', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cart_popup_notices_duration',
                'type' => 'slider',
                'default' => 3500,
                'min' => 0,
                'step' => 100,
                'max' => 20000,
                'display_value' => 'text',
                'required' => array( 'shop_cart_popup_notices_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'subtitle' => esc_html__('Change popup notices background color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cart_popup_notices_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-shop-popup-notices'),
                'required' => array( 'shop_cart_popup_notices_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'subtitle' => esc_html__('Change popup notices text color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cart_popup_notices_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-shop-popup-notices'),
                'required' => array( 'shop_cart_popup_notices_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Close Background Color', 'crisop'),
                'subtitle' => esc_html__('Change popup notices close background color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cart_popup_notices_close_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-shop-popup-notices .ninetheme-panel-close-button'),
                'required' => array( 'shop_cart_popup_notices_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Close Color', 'crisop'),
                'subtitle' => esc_html__('Change popup notices close color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_cart_popup_notices_close_bgcolor',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-shop-popup-notices .ninetheme-panel-close-button'),
                'required' => array( 'shop_cart_popup_notices_visibility', '=', '1' )
            )
        )
    ));
    // Buy Now Button SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Buy Now Button', 'crisop'),
        'id' => 'shop_buynow_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Buy Now Button Display', 'crisop'),
                'customizer' => true,
                'id' => 'buy_now_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__( 'Button Text', 'crisop' ),
                'subtitle' => esc_html__('Leave blank to use the default text or its equivalent translation in multiple languages.', 'crisop'),
                'customizer' => true,
                'id' => 'buy_now_btn_title',
                'type' => 'text',
                'default' => '',
                'required' => array( 'buy_now_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Reset Cart', 'crisop'),
                'subtitle' => esc_html__('Reset the cart before doing buy now.', 'crisop'),
                'on' => esc_html__('Yes', 'crisop'),
                'off' => esc_html__('No', 'crisop'),
                'customizer' => true,
                'id' => 'buy_now_reset_cart',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'buy_now_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Parameter', 'crisop' ),
                'customizer' => true,
                'id' => 'buy_now_param',
                'type' => 'text',
                'default' => 'ninetheme-buy-now',
                'required' => array( 'buy_now_visibility', '=', '1' )
            ),
            array(
                'id' =>'buy_now_redirect',
                'type' => 'button_set',
                'title' => esc_html__( 'Redirect to', 'crisop' ),
                'options' => array(
                    'checkout' => esc_html__( 'Checkout page', 'crisop' ),
                    'cart' => esc_html__( 'Cart page', 'crisop' ),
                    'custom' => esc_html__( 'Custom', 'crisop' ),
                ),
                'default' => 'checkout',
                'required' => array( 'buy_now_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom Page URL', 'crisop' ),
                'customizer' => true,
                'id' => 'buy_now_redirect_custom',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'buy_now_visibility', '=', '1' ),
                    array( 'buy_now_redirect', '=', 'custom' ),
                )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'subtitle' => esc_html__('Change button background color.', 'crisop'),
                'customizer' => true,
                'id' => 'buy_now_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-btn.ninetheme-btn-buynow'),
                'required' => array( 'buy_now_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Background Color ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover background color.', 'crisop'),
                'customizer' => true,
                'id' => 'buy_now_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-btn.ninetheme-btn-buynow:hover'),
                'required' => array( 'buy_now_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'subtitle' => esc_html__('Change button text color.', 'crisop'),
                'customizer' => true,
                'id' => 'buy_now_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-btn.ninetheme-btn-buynow'),
                'required' => array( 'buy_now_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover text color.', 'crisop'),
                'customizer' => true,
                'id' => 'buy_now_hvrcolor',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-btn.ninetheme-btn-buynow:hover'),
                'required' => array( 'buy_now_visibility', '=', '1' )
            )
        )
    ));
    // Whatsapp Button SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Whatsapp Button', 'crisop'),
        'id' => 'shop_whatsapp_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Whatsapp Display', 'crisop'),
                'customizer' => true,
                'id' => 'product_whatsapp_button_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__( 'Button Text', 'crisop' ),
                'subtitle' => esc_html__('Leave blank to use the default text or its equivalent translation in multiple languages.', 'crisop'),
                'customizer' => true,
                'id' => 'whatsapp_btn_title',
                'type' => 'text',
                'default' => '',
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Whatsapp Desktop URL', 'crisop' ),
                'subtitle' => 'Default: <code>https://api.whatsapp.com/send?text=</code> product_link',
                'customizer' => true,
                'id' => 'product_whatsapp_link',
                'type' => 'text',
                'default' => '',
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Whatsapp Mobile URL', 'crisop' ),
                'subtitle' => 'Default: <code>whatsapp://send?text=</code> product_link',
                'customizer' => true,
                'id' => 'product_whatsapp_mobile_link',
                'type' => 'text',
                'default' => '',
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'id' =>'product_whatsapp_target',
                'type' => 'select',
                'title' => esc_html__( 'Target', 'crisop' ),
                'options' => array(
                    '' => esc_html__( 'Select an option', 'crisop' ),
                    '_blank' => esc_html__( 'Open in a new window', 'crisop' ),
                    '_self' => esc_html__( 'Open in the same frame', 'crisop' ),
                    '_parent' => esc_html__( 'Open in the parent frame', 'crisop' ),
                    '_top' => esc_html__( 'Open in the full body of the window', 'crisop' )
                ),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'subtitle' => esc_html__('Change button background color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_whatsapp_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-summary-item .ninetheme-btn.social-whatsapp'),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Background Color ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover background color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_whatsapp_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-summary-item .ninetheme-btn.social-whatsapp:hover'),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'subtitle' => esc_html__('Change button text color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_whatsapp_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-summary-item .ninetheme-btn.social-whatsapp'),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover text color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_whatsapp_hvrcolor',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-summary-item .ninetheme-btn.social-whatsapp:hover'),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'subtitle' => esc_html__('Change button border.', 'crisop'),
                'customizer' => true,
                'id' => 'product_whatsapp_border',
                'type' => 'border',
                'output' => array('.ninetheme-summary-item .ninetheme-btn.social-whatsapp'),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover border color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_whatsapp_hvrborder',
                'type' => 'border',
                'output' => array('.ninetheme-summary-item .ninetheme-btn.social-whatsapp:hover'),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            )
        )
    ));
    // Whatsapp Button SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Product Page Action Button', 'crisop'),
        'id' => 'shop_product_custom_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Product Page Action Button Display', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__( 'Button Text', 'crisop' ),
                'subtitle' => esc_html__('Leave blank to use the default text or its equivalent translation in multiple languages.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_title',
                'type' => 'text',
                'default' => 'Request Information',
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'id' =>'product_custom_btn_action',
                'type' => 'select',
                'title' => esc_html__( 'Action', 'crisop' ),
                'options' => array(
                    'link' => esc_html__( 'Custom Link', 'crisop' ),
                    'form' => esc_html__( 'Open Popup Form', 'crisop' ),
                    'whatsapp' => esc_html__( 'Open Whatsapp', 'crisop' ),
                ),
                'default' => 'link',
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom Link', 'crisop' ),
                'customizer' => true,
                'id' => 'product_custom_btn_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'product_custom_btn_visibility', '=', '1' ),
                    array( 'product_custom_btn_action', '=', 'link' )
                )
            ),
            array(
                'title' => esc_html__( 'Form Shortcode or Custom HTML', 'crisop' ),
                'subtitle' => esc_html__('Add your form shortcode here.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_form_shortcode',
                'type' => 'textarea',
                'default' => '',
                'required' => array(
                    array( 'product_custom_btn_visibility', '=', '1' ),
                    array( 'product_custom_btn_action', '=', 'form' )
                )
            ),
            array(
                'title' => esc_html__( 'Whatsapp Desktop Link', 'crisop' ),
                'subtitle' => esc_html__('Add your whatsapp link here.Deafult: https://api.whatsapp.com/send?text=', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_whatsapp_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'product_custom_btn_visibility', '=', '1' ),
                    array( 'product_custom_btn_action', '=', 'whatsapp' )
                )
            ),
            array(
                'title' => esc_html__( 'Whatsapp Mobile Link', 'crisop' ),
                'subtitle' => esc_html__('Add your whatsapp link here.Deafult: whatsapp://send?text=', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_whatsapp_mobile_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'product_custom_btn_visibility', '=', '1' ),
                    array( 'product_custom_btn_action', '=', 'whatsapp' )
                )
            ),
            array(
                'id' =>'product_custom_btn_target',
                'type' => 'select',
                'title' => esc_html__( 'Target', 'crisop' ),
                'options' => array(
                    '' => esc_html__( 'Select an option', 'crisop' ),
                    '_blank' => esc_html__( 'Open in a new window', 'crisop' ),
                    '_self' => esc_html__( 'Open in the same frame', 'crisop' ),
                    '_parent' => esc_html__( 'Open in the parent frame', 'crisop' ),
                    '_top' => esc_html__( 'Open in the full body of the window', 'crisop' )
                ),
                'required' => array(
                    array( 'product_custom_btn_visibility', '=', '1' ),
                    array( 'product_custom_btn_action', '!=', 'form' )
                )
            ),
            array(
                'title' => esc_html__('Button Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_info',
                'type' => 'info',
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'subtitle' => esc_html__('Change button background color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-product-action-button .ninetheme-btn'),
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Background Color ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover background color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-product-action-button .ninetheme-btn:hover'),
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'subtitle' => esc_html__('Change button text color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-product-action-button .ninetheme-btn'),
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover text color.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_hvrcolor',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-product-action-button .ninetheme-btn:hover'),
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'subtitle' => esc_html__('Change button border.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_brdcolor',
                'type' => 'border',
                'output' => array('.ninetheme-product-action-button .ninetheme-btn'),
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change button hover border.', 'crisop'),
                'customizer' => true,
                'id' => 'product_custom_btn_hvrbrdcolor',
                'type' => 'border',
                'output' => array('.ninetheme-product-action-button .ninetheme-btn:hover'),
                'required' => array( 'product_custom_btn_visibility', '=', '1' )
            )
        )
    ));
    // Free Shipping Progressbar
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Free Shipping Progressbar', 'crisop' ),
        'id' => 'shopshippingprogressbarsubsection',
        'subsection'=> true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Progressbar Display', 'crisop'),
                'subtitle' => esc_html__('You can enable or disable the site shop free shipping progressbar with switch option.', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Targeted Amount', 'crisop'),
                'subtitle' => esc_html__('Please enter the targeted amount without currency for free shipping in this field.', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_amount',
                'validate' => array( 'numeric', 'not_empty' ),
                'type' => 'text',
                'default' => 500
            ),
            array(
                'title' => esc_html__('Initial Message', 'crisop'),
                'subtitle' => sprintf('%s <code>[remainder]</code> %s',
                	esc_html__('Please enter the initial message with', 'crisop'),
                	esc_html__('for free shipping in this field.', 'crisop')
                ),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_message_initial',
                'type' => 'textarea',
                'default' => 'Buy [remainder] more to enjoy FREE Shipping'
            ),
            array(
                'title' => esc_html__('Success Message', 'crisop'),
                'subtitle' => esc_html__('Please enter the success message with for free shipping in this field.', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_message_success',
                'type' => 'textarea',
                'default' => 'Congrats! You are eligible for more to enjoy FREE Shipping'
            ),
            array(
                'title' => esc_html__('Message Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_message_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-cart-goal-wrapper .ninetheme-cart-goal-text'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Price Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_message_price_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-cart-goal-wrapper .ninetheme-cart-goal-text .woocommerce-Price-amount.amount'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Progress Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progress_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-free-shipping-progress .ninetheme-progress-bar-wrap:before'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Progressbar Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-free-shipping-progress .ninetheme-progress-bar:before'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_icon_brdcolor',
                'type' => 'color',
                'mode' => 'border-color',
                'default' => '',
                'output' => array('.ninetheme-free-shipping-progress .ninetheme-progress-value'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_icon_color',
                'type' => 'color',
                'mode' => 'fill',
                'default' => '',
                'output' => array('.ninetheme-free-shipping-progress .ninetheme-progress-value svg *'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Success Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_progressbar_success_info',
                'type' => 'info',
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Message Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_success_progressbar_message_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-cart-goal-wrapper.free-shipping-success .ninetheme-cart-goal-text'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Progress Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_success_progress_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.free-shipping-success .ninetheme-free-shipping-progress .ninetheme-progress-bar-wrap:before'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Progressbar Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_success_progressbar_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.free-shipping-success .ninetheme-free-shipping-progress .ninetheme-progress-bar:before'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_success_progressbar_icon_brdcolor',
                'type' => 'color',
                'mode' => 'border-color',
                'default' => '',
                'output' => array('.free-shipping-success .ninetheme-free-shipping-progress .ninetheme-progress-value'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'free_shipping_success_progressbar_icon_color',
                'type' => 'color',
                'mode' => 'fill',
                'default' => '',
                'output' => array('.free-shipping-success .ninetheme-free-shipping-progress .ninetheme-progress-value svg *'),
                'required' => array( 'free_shipping_progressbar_visibility', '=', '1' )
            ),
        )
    ));
    // Free Shipping Progressbar
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Product Hints', 'crisop' ),
        'id' => 'shop_product_hints_subsection',
        'subsection'=> true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Hints Display', 'crisop'),
                'customizer' => true,
                'id' => 'product_hints_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_hints_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-hint,.ninetheme-social-icons a:after'),
                'required' => array( 'product_hints_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_hints_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-hint,.ninetheme-social-icons a:after'),
                'required' => array( 'product_hints_visibility', '=', '1' )
            )
        )
    ));
    // Free Shipping Progressbar
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Taxonomies && Metaboxes', 'crisop' ),
        'id' => 'shop_theme_taxonomies_subsection',
        'subsection'=> true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Brands Taxonomy Display', 'crisop'),
                'customizer' => true,
                'id' => 'brands_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Locations Taxonomy Display', 'crisop'),
                'customizer' => true,
                'id' => 'locations_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Campaigns Taxonomy Display', 'crisop'),
                'customizer' => true,
                'id' => 'campains_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Product 360 Degree Display', 'crisop'),
                'customizer' => true,
                'id' => 'product360_visibility',
                'type' => 'switch',
                'default' => 1
            )
        )
    ));
    // Free Shipping Progressbar
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Min/Max Quantity', 'crisop' ),
        'id' => 'shop_minmax_quantity_subsection',
        'subsection'=> true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Min/Max Quantity Display', 'crisop'),
                'customizer' => true,
                'id' => 'minmax_quantity_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'id'       => 'minimum_quantity',
                'type'     => 'text',
                'title'    => esc_html__('Minimum order quantity', 'crisop'),
                'subtitle' => esc_html__('The minimum allowed quantity of items in an order.','crisop'),
                'validate' => array( 'numeric' )
            ),
            array(
                'id'       => 'maximum_quantity',
                'type'     => 'text',
                'title'    => esc_html__('Maximum order quantity', 'crisop'),
                'subtitle' => esc_html__('The maximum allowed quantity of items in an order.','crisop'),
                'validate' => array( 'numeric' )
            ),
            array(
                'id'       => 'minimum_order',
                'type'     => 'text',
                'title'    => esc_html__('Minimum order value', 'crisop'),
                'subtitle' => esc_html__('The minimum allowed value of items in an order.','crisop'),
                'validate' => array( 'numeric' )
            ),
            array(
                'id'       => 'maximum_order',
                'type'     => 'text',
                'title'    => esc_html__('Maximum order value', 'crisop'),
                'subtitle' => esc_html__('The maximum allowed quantity of items in an order.','crisop'),
                'validate' => array( 'numeric' )
            ),
        )
    ));

    // create sections in the theme options
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('SHOP PAGE', 'crisop'),
        'id' => 'shop_page_section',
        'icon' => 'el el-shopping-cart-sign',
    ));
    function crisop_shop_loop_custom_query(){
        $filters_field = array();
        $filters_field[] = array(
            'title' => esc_html__('Custom Query', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_visibility',
            'type' => 'switch',
            'default' => 0
        );
        $filters_field[] = array(
            'title' => esc_html__('Scenario', 'crisop'),
            'subtitle' => esc_html__('Choose the your scenario.', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_scenario',
            'type' => 'button_set',
            'options' => array(
                '' => esc_html__( 'Newest', 'crisop' ),
                'featured' => esc_html__( 'Featured', 'crisop' ),
                'on-sale' => esc_html__( 'On Sale', 'crisop' ),
                'best' => esc_html__( 'Best Selling', 'crisop' ),
                'rated' => esc_html__( 'Top-rated', 'crisop' ),
                'popularity' => esc_html__( 'Popularity', 'crisop' ),
                'custom' => esc_html__( 'Specific Categories', 'crisop' ),
            ),
            'default' => '',
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );
        $filters_field[] = array(
            'title' => esc_html__('Order', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_order',
            'type' => 'button_set',
            'options' => array(
                'ASC' => esc_html__( 'Ascending', 'crisop' ),
                'DESC' => esc_html__( 'Descending', 'crisop' )
            ),
            'default' => 'DESC',
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );
        $filters_field[] = array(
            'title' => esc_html__('Order By', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_orderby',
            'type' => 'button_set',
            'options' => array(
                'ID' => esc_html__( 'Post ID', 'crisop' ),
                'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                'rand' => esc_html__( 'Random', 'crisop' ),
                'date' => esc_html__( 'Date', 'crisop' ),
                'title' => esc_html__( 'Title', 'crisop' ),
                'popularity' => esc_html__( 'Popularity', 'crisop' ),
            ),
            'default' => 'title',
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );
        $filters_field[] = array(
            'title' => esc_html__('Show Products ( for Per Page )', 'crisop'),
            'subtitle' => esc_html__('Here you can set the maximum number of products you want to show on your shop page.', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_perpage',
            'type' => 'slider',
            'default' => 20,
            'min' => 1,
            'step' => 1,
            'max' => 1000,
            'display_value' => 'text',
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );
        $filters_field[] = array(
            'title' => esc_html__('Mobile Device Show Products ( for Per Page )', 'crisop'),
            'subtitle' => esc_html__('Here you can set the maximum number of products you want to show on mobile device.', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_mobile_perpage',
            'type' => 'slider',
            'default' => 20,
            'min' => 1,
            'step' => 1,
            'max' => 1000,
            'display_value' => 'text',
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );
        $filters_field[] = array(
            'title' => esc_html__('Category(s)', 'crisop'),
            'subtitle' => esc_html__('Select category(s) from the list.', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_cats',
            'type' => 'select',
            'data' => 'terms',
            'multi' => true,
            'args' => [ 'taxonomies' => array('product_cat') ],
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );
        $filters_field[] = array(
            'title' => esc_html__('Category(s) Filter Type', 'crisop'),
            'subtitle' => esc_html__('Choose the your product category filter type.', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_cats_operator',
            'type' => 'button_set',
            'options' => array(
                'include' => esc_html__('Include', 'crisop'),
                'exclude' => esc_html__('Exclude', 'crisop'),
            ),
            'default' => 'exclude',
            'required' => array(
                array( 'shop_custom_query_visibility', '=', '1' ),
                array( 'shop_custom_query_cats', '!=', '' )
            )
        );
        $filters_field[] = array(
            'title' => esc_html__('Tags(s)', 'crisop'),
            'subtitle' => esc_html__('Select category(s) from the list.', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_tags',
            'type' => 'select',
            'data' => 'terms',
            'multi' => true,
            'args' => [ 'taxonomies' => array('product_tag') ],
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );
        $filters_field[] = array(
            'title' => esc_html__('Tag(s) Filter Type', 'crisop'),
            'subtitle' => esc_html__('Choose the your product tag filter type.', 'crisop'),
            'customizer' => true,
            'id' => 'shop_custom_query_tags_operator',
            'type' => 'button_set',
            'options' => array(
                'include' => esc_html__('Include', 'crisop'),
                'exclude' => esc_html__('Exclude', 'crisop'),
            ),
            'default' => 'exclude',
            'required' => array(
                array( 'shop_custom_query_visibility', '=', '1' ),
                array( 'shop_custom_query_tags', '!=', '' )
            )
        );
        $filters_field[] = array(
            'title' => esc_html__( 'Select Attributes', 'crisop' ),
            'subtitle' => esc_html__( 'Select Attribute(s) from the list.', 'crisop' ),
            'customizer' => true,
            'id' => 'shop_custom_query_attr',
            'type' => 'select',
            'sortable' => true,
            'options' => crisop_wc_attributes(),
            'multi' => true,
            'required' => array( 'shop_custom_query_visibility', '=', '1' )
        );

        $attribute_taxonomies = wc_get_attribute_taxonomies();
        foreach ( $attribute_taxonomies as $tax ) {
            $options = array();
            $tax_name = $tax->attribute_name;
            $tax_label = $tax->attribute_label;
            $filters_field[] = array(
                'title' => esc_html__( 'Attributes Terms ( for '.$tax_label.' )', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_custom_query_attr_terms_'.$tax_name,
                'type' => 'select',
                'sortable' => true,
                'data' => 'terms',
                'args' => array( 'taxonomies' => array( 'pa_'.$tax_name ) ),
                'multi' => true,
                'required' => array(
                    array( 'shop_custom_query_visibility', '=', '1' ),
                    array( 'shop_custom_query_attr', '=', $tax_name )
                )
            );
            $filters_field[] = array(
                'title' => esc_html__('Filter Type ( for '.$tax_label.' )', 'crisop'),
                'subtitle' => esc_html__('Choose the your product attribute terms filter type.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_custom_query_attr_terms_operator_'.$tax_name,
                'type' => 'button_set',
                'options' => array(
                    'include' => esc_html__('Include', 'crisop'),
                    'exclude' => esc_html__('Exclude', 'crisop'),
                ),
                'default' => 'include',
                'required' => array(
                    array( 'shop_custom_query_visibility', '=', '1' ),
                    array( 'shop_custom_query_attr', '=', $tax_name ),
                    array( 'shop_custom_query_attr_terms_'.$tax_name, '!=', '' ),
                )
            );
        }

        return $filters_field;
    }
    // SINGLE CONTENT SUBSECTION
    Redux::setSection($ninetheme_pre,
        array(
            'title' => esc_html__('Shop Custom Query', 'crisop'),
            'id' => 'shop_loop_custom_query_subsection',
            'subsection' => true,
            'icon' => 'el el-cog',
            'fields' => crisop_shop_loop_custom_query()
        )
    );
    // Shop Page Hero SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Shop Page Hero', 'crisop'),
        'desc' => esc_html__('These are shop page hero section settings', 'crisop'),
        'id' => 'shop_hero_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Hero display', 'crisop'),
                'subtitle' => esc_html__('You can enable or disable the site shop page hero section with switch option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_hero_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Custom Page Title', 'crisop'),
                'subtitle' => esc_html__('Add your shop page custom title here.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_title',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'shop_hero_visibility', '=', '1' ),
                    array( 'shop_hero_type', '=', 'default' )
                )
            ),
            array(
                'id' =>'shop_hero_type',
                'type' => 'button_set',
                'title' => esc_html__('Shop Hero Type', 'crisop'),
                'subtitle' => esc_html__('Select your pagination type.', 'crisop'),
                'options' => array(
                    'default' => esc_html__('Default Hero', 'crisop'),
                    'elementor' => esc_html__('Elementor Templates', 'crisop'),
                ),
                'default' => 'default',
                'required' => array( 'shop_hero_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates.If you want to show the theme default hero template please leave a blank.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_hero_elementor_templates',
                'type' => 'select',
                'customizer' => true,
                'data' => 'posts',
                'args' => $el_args,
                'required' => array(
                    array( 'shop_hero_visibility', '=', '1' ),
                    array( 'shop_hero_type', '=', 'elementor' ),
                )
            ),
            array(
                'title' => esc_html__( 'Category Pages Hero Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates.If you want to show the theme default hero template please leave a blank.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_cats_hero_elementor_templates',
                'type' => 'select',
                'customizer' => true,
                'data' => 'posts',
                'args' => $el_args,
                'required' => array( 'shop_hero_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Tags Pages Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates.If you want to show the theme default hero template please leave a blank.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_tax_hero_elementor_templates',
                'type' => 'select',
                'customizer' => true,
                'data' => 'posts',
                'args' => $el_args,
                'required' => array( 'shop_hero_visibility', '=', '1' )
            ),
            array(
                'id' =>'shop_hero_layout_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Default Hero Layouts', 'crisop' ),
                'subtitle' => esc_html__( 'Select how you want the layout to appear on the theme shop page sidebar area.', 'crisop' ),
                'options' => array(
                    'mini' => esc_html__( 'Title + Breadcrumbs', 'crisop' ),
                    'small' => esc_html__( 'Title Center', 'crisop' ),
                    'big' => esc_html__( 'Title + Categories', 'crisop' ),
                    'cat-slider' => esc_html__( 'Title + Categories Slider', 'crisop' ),
                ),
                'default' => 'big',
                'required' => array(
                    array( 'shop_hero_visibility', '=', '1' ),
                    array( 'shop_hero_type', '=', 'default' ),
                )
            ),
            array(
                'title' => esc_html__('Hero Customize Options', 'crisop'),
                'customizer' => true,
                'id' => 'shop_hero_customize_section_start',
                'type' => 'section',
                'indent' => true,
                'required' => array(
                    array( 'shop_hero_visibility', '=', '1' ),
                    array( 'shop_hero_type', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__('Hero Background', 'crisop'),
                'customizer' => true,
                'id' => 'shop_hero_bg',
                'type' => 'background',
                'output' => array( '#nt-shop-page .ninetheme-page-hero' ),
                'required' => array(
                    array( 'shop_hero_visibility', '=', '1' ),
                    array( 'shop_hero_type', '=', 'default' )
                )
            ),
            array(
                'title' => esc_html__( 'Hero height', 'crisop' ),
                'subtitle' => esc_html__( 'Set the logo width and height of the image.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_hero_height',
                'type' => 'dimensions',
                'width' => false,
                'output' => array( '#nt-shop-page .ninetheme-page-hero' ),
                'required' => array(
                    array( 'shop_hero_visibility', '=', '1' ),
                    array( 'shop_hero_type', '=', 'default' )
                )
            ),
            array(
                'customizer' => true,
                'id' => 'shop_hero_customize_section_end',
                'type' => 'section',
                'indent' => false,
                'required' => array(
                    array( 'shop_hero_visibility', '=', '1' ),
                    array( 'shop_hero_type', '=', 'default' )
                )
            )
        )
    ));
    // Shop Page Layout SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Shop Page Layout', 'crisop' ),
        'id' => 'shop_layout_subsection',
        'subsection'=> true,
        'icon' => 'el el-website',
        'fields' => array(
            array(
                'id' =>'shop_template_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Shop Template', 'crisop' ),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop page.', 'crisop' ),
                'options' => array(
                    'theme' => esc_html__( 'Theme Template', 'crisop' ),
                    'elementor' => esc_html__( 'Elementor template', 'crisop' )
                ),
                'default' => 'theme'
            ),
            array(
                'title' => esc_html__( 'Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates.If you want to show the theme default hero template please leave a blank.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_elementor_template',
                'type' => 'select',
                'customizer' => true,
                'data' => 'posts',
                'args' => $el_args,
                'required' => array( 'shop_template_type', '=', 'elementor' )
            ),
            array(
                'id' =>'shop_layout',
                'type' => 'button_set',
                'title' => esc_html__( 'Shop Layouts', 'crisop' ),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop page sidebar area.', 'crisop' ),
                'options' => array(
                    'left-sidebar' => esc_html__( 'Left Sidebar', 'crisop' ),
                    'right-sidebar' => esc_html__( 'Right Sidebar', 'crisop' ),
                    'top-sidebar' => esc_html__( 'Top Sidebar', 'crisop' ),
                    'fixed-sidebar' => esc_html__( 'Left Fixed Sidebar', 'crisop' ),
                    'no-sidebar' => esc_html__( 'No Sidebar', 'crisop' )
                ),
                'default' => 'left-sidebar'
            ),
            array(
                'id' =>'shop_top_sidebar_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Top Sidebar Type', 'crisop' ),
                'subtitle' => esc_html__( 'Select your shop top sidebar type', 'crisop' ),
                'options' => array(
                    'dropdown' => esc_html__( 'Dropdown', 'crisop' ),
                    'hidden' => esc_html__( 'Hidden', 'crisop' ),
                ),
                'default' => 'dropdown',
                'required' => array( 'shop_layout', '=', 'top-sidebar' )
            ),
            array(
                'id' =>'shop_top_sidebar_column',
                'type' => 'button_set',
                'title' => esc_html__( 'Top Sidebar Widget Column Width', 'crisop' ),
                'subtitle' => esc_html__( 'Select your shop sidebar widget column width', 'crisop' ),
                'options' => array(
                    '1' => esc_html__( '1 Column', 'crisop' ),
                    '2' => esc_html__( '2 Column', 'crisop' ),
                    '3' => esc_html__( '3 Column', 'crisop' ),
                    '4' => esc_html__( '4 Column', 'crisop' ),
                    '5' => esc_html__( '5 Column', 'crisop' ),
                    '6' => esc_html__( '6 Column', 'crisop' ),
                ),
                'default' => '5',
                'required' => array( 'shop_layout', '=', 'top-sidebar' )
            ),
            array(
                'id' =>'shop_layout_style',
                'type' => 'button_set',
                'title' => esc_html__('Shop Layout Style', 'crisop'),
                'customizer' => true,
                'options' => array(
                    'default' => esc_html__( 'Default', 'crisop' ),
                    'bordered' => esc_html__( 'Bordered', 'crisop' ),
                ),
                'default' => 'default'
            ),
            array(
                'id' =>'shop_grid_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Shop Grid Type', 'crisop' ),
                'options' => array(
                    'grid' => esc_html__( 'Default Grid', 'crisop' ),
                    'masonry' => esc_html__( 'Masonry', 'crisop' ),
                ),
                'default' => 'grid',
                'required' => array(
                    array( 'shop_layout', '!=', 'left-sidebar' ),
                    array( 'shop_layout', '!=', 'right-sidebar' ),
                )
            ),
            array(
                'id' =>'shop_masonry_column',
                'type' => 'button_set',
                'title' => esc_html__( 'Shop Masonry Column Width', 'crisop' ),
                'subtitle' => esc_html__( 'Select your shop masonry type column width', 'crisop' ),
                'options' => array(
                    '3' => esc_html__( '3 Column', 'crisop' ),
                    '4' => esc_html__( '4 Column', 'crisop' ),
                    '5' => esc_html__( '5 Column', 'crisop' )
                ),
                'default' => '4',
                'required' => array(
                    array( 'shop_layout', '!=', 'left-sidebar' ),
                    array( 'shop_layout', '!=', 'right-sidebar' ),
                    array( 'shop_grid_type', '=', 'masonry' )
                )
            ),
            array(
                'id' =>'shop_container_width',
                'type' => 'select',
                'title' => esc_html__( 'Container Width', 'crisop' ),
                'subtitle' => esc_html__( 'Select your header background type.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'default' => esc_html__( 'Deafult ( theme Content Width from Main settings )', 'crisop' ),
                    'stretch' => esc_html__( 'Stretch', 'crisop' ),
                ),
                'default' => 'default'
            )
        )
    ));
    // Shop Filter Bar SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Shop Filter Bar', 'crisop'),
        'desc' => esc_html__('These are shop page header section settings', 'crisop'),
        'id' => 'shop_filterbar_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' =>'shop_loop_filters_layouts',
                'type' => 'sorter',
                'title' => esc_html__( 'Shop Filter Area Layouts Manager', 'crisop' ),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop page filter area.', 'crisop' ),
                'options' => array(
                    'left' => array(
                        'breadcrumbs' => esc_html__( 'Breadcrumbs', 'crisop' ),
                    ),
                    'right' => array(
                        'sidebar-filter' => esc_html__( 'Sidebar Toggle', 'crisop' ),
                        'per-page' => esc_html__( 'Perpage Selection', 'crisop' ),
                        'column-select' => esc_html__( 'Column Selection', 'crisop' ),
                        'ordering' => esc_html__( 'Ordering', 'crisop' )
                    ),
                    'hide' => array(
                        'result-count' => esc_html__( 'Result Count', 'crisop' ),
                        'search' => esc_html__( 'Search Popup', 'crisop' ),
                    )
                )
            ),
            array(
                'title' => esc_html__('Per Page Select Options', 'crisop'),
                'subtitle' => esc_html__('Separate each number with a comma.For example: 12,24,36', 'crisop'),
                'customizer' => true,
                'id' => 'per_page_select_options',
                'type' => 'text',
                'default' => '9,12,18,24'
            ),
            array(
                'title' => esc_html__( 'Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_filter_bar_info_divider',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__( 'Background Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_filter_bar_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'validate' => 'color',
                'output' => array( '.ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray' )
            ),
            array(
                'title' => esc_html__( 'Border', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_filter_bar_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray' )
            ),
            array(
                'title' => esc_html__( 'SVG Icon Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_filter_bar_svg_color',
                'type' => 'color',
                'mode' => 'fill',
                'validate' => 'color',
                'output' => array( '.ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray, .ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray ul li a, .ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray span, .ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray svg, .ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray li a svg' )
            ),
            array(
                'title' => esc_html__( 'SVG Icon Color ( Active / Hover )', 'crisop' ),
                'desc' => esc_html__( 'Search, Column Selection', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_filter_bar_svg_active_color',
                'type' => 'color',
                'mode' => 'fill',
                'validate' => 'color',
                'output' => array( '.ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray ul li.ninetheme-per-page-item.active a, .ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray ul li.ninetheme-per-page-item a:hover, .ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray li.active svg, .ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray li a:hover svg' )
            ),
            array(
                'title' => esc_html__( 'Text Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_filter_bar_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-shop-filter-top-area .ninetheme-woo-result-count .woocommerce-result-count,.ninetheme-shop-filter-top-area .ninetheme-per-page-title,.ninetheme-shop-filter-top-area .ninetheme-toggle-hidden-sidebar span,.ninetheme-shop-filter-top-area .ninetheme-breadcrumb li span,.ninetheme-shop-filter-top-area .ninetheme-breadcrumb li a,.ninetheme-before-loop.ninetheme-shop-filter-top-area.ninetheme-bg-gray .ninetheme-breadcrumb span')
            )
        )
    ));
    // Shop Grid Layout SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Shop Grid Layout', 'crisop'),
        'id' => 'shop_grid_layout_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Product Count for Per Page', 'crisop'),
                'subtitle' => esc_html__('Here you can set the maximum number of products you want to show on your shop page.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_perpage',
                'type' => 'slider',
                'default' => 20,
                'min' => 1,
                'step' => 1,
                'max' => 1000,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Column', 'crisop'),
                'subtitle' => esc_html__('You can control product column with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_colxl',
                'type' => 'slider',
                'default' => 5,
                'min' => 1,
                'step' => 1,
                'max' => 6,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Column 992px ( Responsive: Desktop, Tablet )', 'crisop'),
                'subtitle' => esc_html__('You can control product column on max-device width 992px with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_collg',
                'type' => 'slider',
                'default' =>3,
                'min' => 1,
                'step' => 1,
                'max' => 4,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Column 768px ( Responsive: Tablet, Phone )', 'crisop'),
                'subtitle' => esc_html__('You can control product column on max-device-width 768px with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_colsm',
                'type' => 'slider',
                'default' =>2,
                'min' => 1,
                'step' => 1,
                'max' => 3,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Column 480px ( Responsive: Phone )', 'crisop'),
                'subtitle' => esc_html__('You can control product column on max-device-width 768px with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_colxs',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 2,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Shop List Type Column for Per Row', 'crisop'),
                'subtitle' => esc_html__('You can control product column with this option for shop list type.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_list_type_colxl',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 3,
                'display_value' => 'text'
            )
        )
    ));
    // Shop Product Style SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Shop Product Style', 'crisop'),
        'id' => 'shop_product_style_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__( 'Product Box Pre-layouts', 'crisop' ),
                'subtitle' => esc_html__( 'Choose the your product box type.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_product_type',
                'type' => 'button_set',
                'options' => array(
                    '1' => esc_html__('Type 1', 'crisop'),
                    '2' => esc_html__('Type 2', 'crisop'),
                    '3' => esc_html__('Type 3', 'crisop'),
                    '4' => esc_html__('Type 4', 'crisop'),
                    'list' => esc_html__('Type List', 'crisop'),
                    'custom' => esc_html__('Custom', 'crisop')
                ),
                'default' => '4'
            ),
            array(
                'id' =>'shop_loop_product_layouts',
                'type' => 'sorter',
                'title' => esc_html__( 'Custom Product Layouts', 'crisop' ),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the shop loop product item.', 'crisop' ),
                'options' => array(
                    'show'  => array(
                        'thumb' => esc_html__( 'Image', 'crisop' ),
                        'stock' => esc_html__( 'Stock Status', 'crisop' ),
                        'title' => esc_html__( 'Title', 'crisop' ),
                        'price' => esc_html__( 'Price', 'crisop' ),
                        'cart' => esc_html__( 'Add to Cart', 'crisop' ),
                        'buttons' => esc_html__( 'Buttons', 'crisop' ),
                        'discount' => esc_html__( 'Discount', 'crisop' ),
                        'rating' => esc_html__( 'Rating', 'crisop' ),
                        'sale' => esc_html__( 'Sale Label', 'crisop' ),
                    ),
                    'hide'  => array(
                    )
                ),
                'required' => array('shop_product_type', '=', 'custom' )
            ),
            array(
                'id' =>'shop_loop_product_buttons_layouts',
                'type' => 'sorter',
                'title' => esc_html__( 'Custom Product Buttons Layouts', 'crisop' ),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the shop loop product item buttons.', 'crisop' ),
                'options' => array(
                    'show'  => array(
                        'quickview' => esc_html__( 'Quick View', 'crisop' ),
                        'compare' => esc_html__( 'Compare', 'crisop' ),
                        'wishlist' => esc_html__( 'Wishlist', 'crisop' ),
                    ),
                    'hide'  => array(
                    )
                ),
                'required' => array('shop_product_type', '=', 'custom' )
            ),
            array(
                'id' => 'shop_product_style_customize_start',
                'type' => 'section',
                'title' => esc_html__('Product Style Customize Options', 'crisop'),
                'customizer' => true,
                'indent' => true
            ),
            array(
                'title' => esc_html__('Product Box Short Details Display', 'crisop'),
                'customizer' => true,
                'id' => 'shop_product_box_details_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'subtitle' => esc_html__('Change post background color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_post_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('body:not(.shop-content-style-bordered) .ninetheme-loop-product')
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'subtitle' => esc_html__('Set your custom border styles for the posts.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_post_brd',
                'type' => 'border',
                'all' => false,
                'output' => array('body:not(.shop-content-style-bordered) .ninetheme-loop-product')
            ),
            array(
                'title' => esc_html__('Padding', 'crisop'),
                'subtitle' => esc_html__('You can set the spacing of the site shop page post.', 'crisop'),
                'customizer' => true,
                'id' =>'shop_post_pad',
                'type' => 'spacing',
                'output' => array('body:not(.shop-content-style-bordered) .ninetheme-loop-product'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array(
                    'units' => 'px'
                )
            ),
            array(
                'title' => esc_html__('Title Customize Options', 'crisop'),
                'customizer' => false,
                'id' => 'shop_loop_title_customize_divider',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Title Typography', 'crisop' ),
                'id' => 'shop_loop_post_title_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array('.ninetheme-loop-product .ninetheme-loop-product-name')
            ),
            array(
                'title' => esc_html__('Title', 'crisop'),
                'subtitle' => esc_html__('Change product title color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_title_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-loop-product-name a')
            ),
            array(
                'title' => esc_html__('Title ( Hover )', 'crisop'),
                'subtitle' => esc_html__('Change product title color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_title_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-loop-product-name a:hover')
            ),
            array(
                'title' => esc_html__('Stock Status Customize Options', 'crisop'),
                'customizer' => false,
                'id' => 'shop_loop_stock_customize_divider',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('In Stock', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_instock_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-stock-status.ninetheme-instock')
            ),
            array(
                'title' => esc_html__('Out of Stock', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_outofstock_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-stock-status.ninetheme-outofstock')
            ),
            array(
                'title' => esc_html__('Price Customize Options', 'crisop'),
                'customizer' => false,
                'id' => 'shop_loop_price_customize_divider',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__( 'Price Typography', 'crisop' ),
                'id' => 'shop_loop_post_price_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array('.woocommerce .ninetheme-price,.ninetheme-loop-product .ninetheme-price')
            ),
            array(
                'title' => esc_html__( 'Price Sale Typography', 'crisop' ),
                'id' => 'shop_loop_post_price_sale_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array('.woocommerce .ninetheme-price .ins,.ninetheme-loop-product .ninetheme-price .ins,.ninetheme-loop-product .ninetheme-price .ins>span')
            ),
            array(
                'title' => esc_html__('Price Regular', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_price_reg_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-price,.woocommerce .ninetheme-price .del,.woocommerce-variation-price .price span.del>span, .ninetheme-price span.del>span')
            ),
            array(
                'title' => esc_html__('Price Sale', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_price_sale_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-price .ins,.ninetheme-loop-product .ninetheme-price .ins,.ninetheme-loop-product .ninetheme-price .ins>span')
            ),
            array(
                'title' => esc_html__('Discount & Labels Customize Options', 'crisop'),
                'customizer' => false,
                'id' => 'shop_loop_discount_customize_divider',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('Discount Background', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_discount_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-label.ninetheme-discount')
            ),
            array(
                'title' => esc_html__('Discount Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_discount_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-label.ninetheme-discount')
            ),
            array(
                'title' => esc_html__('Labels Background', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_labels_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-label.ninetheme-bg-default')
            ),
            array(
                'title' => esc_html__('Labels Background', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_post_labels_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-label.ninetheme-bg-default')
            ),
            array(
                'title' => esc_html__('Extra Features Customize Options', 'crisop'),
                'customizer' => false,
                'id' => 'shop_loop_extra_features_customize_divider',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('Extra Features Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_product_extra_features_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-product-extra-features')
            ),
            array(
                'title' => esc_html__('Extra Features Checked Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_product_extra_features_icon_color',
                'type' => 'color',
                'mode' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-product-extra-features li .checked')
            ),
            array(
                'title' => esc_html__('Add to Cart Customize Options', 'crisop'),
                'customizer' => false,
                'id' => 'shop_loop_addtocartbtn_customize_divider',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_addtocartbtn_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-btn, .ninetheme-loop-product .ninetheme-product-button.btn-type-icon')
            ),
            array(
                'title' => esc_html__('Background Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'shop_addtocartbtn_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-btn:hover, .ninetheme-loop-product .ninetheme-product-button.btn-type-icon:hover')
            ),
            array(
                'title' => esc_html__('Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_addtocartbtn_brdcolor',
                'type' => 'color',
                'mode' => 'border-color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-btn, .ninetheme-loop-product .ninetheme-product-button.btn-type-icon')
            ),
            array(
                'title' => esc_html__('Border Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'shop_addtocartbtn_hvrbrdcolor',
                'type' => 'color',
                'mode' => 'border-color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-btn:hover, .ninetheme-loop-product .ninetheme-product-button.btn-type-icon:hover')
            ),
            array(
                'title' => esc_html__('Button Title', 'crisop'),
                'customizer' => true,
                'id' => 'shop_addtocartbtn_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-btn')
            ),
            array(
                'title' => esc_html__('Button Title ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'shop_addtocartbtn_hvrcolor',
                'type' => 'color',
                'default' => '',
                'output' => array('.woocommerce .ninetheme-btn:hover')
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'shop_addtocartbtn_brd_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Add to Cart Quantity Customize Options', 'crisop'),
                'customizer' => false,
                'id' => 'shop_loop_quantity_customize_divider',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_quantity_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-loop-quantity')
            ),
            array(
                'title' => esc_html__('Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_quantity_brdcolor',
                'type' => 'color',
                'mode' => 'border-color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-loop-quantity')
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_quantity_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Plus & Minus Color', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_quantity_buttons_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-loop-quantity-button')
            ),
            array(
                'title' => esc_html__('Plus & Minus ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_quantity_buttons_hvrcolor',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-loop-product .ninetheme-loop-quantity-button:hover')
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'shop_loop_quantity_buttons_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text'
            ),
            array(
                'id' => 'shop_product_style_customize_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false
            )
        )
    ));
    // Shop Pagination SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__( 'Shop Pagination', 'crisop' ),
        'id' => 'shop_pagination_subsection',
        'subsection'=> true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' =>'shop_paginate_type',
                'type' => 'button_set',
                'title' => esc_html__('Pagination Type', 'crisop'),
                'subtitle' => esc_html__('Select your pagination type.', 'crisop'),
                'options' => array(
                    'pagination' => esc_html__('Default Pagination', 'crisop'),
                    'ajax-pagination' => esc_html__('Ajax Pagination', 'crisop'),
                    'loadmore' => esc_html__('Ajax Load More', 'crisop'),
                    'infinite' => esc_html__('Ajax Infinite Scroll', 'crisop')
                ),
                'default' => 'ajax-pagination',
                'required' => array( 'shop_ajax_filter', '=', '1' )
            ),
            array(
                'title' => esc_html__('Pagination Background Color', 'crisop'),
                'subtitle' => esc_html__('Change shop page pagination background color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_pagination_bgcolor',
                'type' => 'color',
                'mode' => 'background',
                'default' => '',
                'output' => array('.woocommerce nav.ninetheme-woocommerce-pagination ul li a, .woocommerce nav.ninetheme-woocommerce-pagination ul li span')
            ),
            array(
                'title' => esc_html__('Active Pagination Background Color', 'crisop'),
                'subtitle' => esc_html__('Change shop page pagination hover and active item background color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_pagination_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background',
                'default' => '',
                'output' => array('.woocommerce nav.ninetheme-woocommerce-pagination ul li a:focus, .woocommerce nav.ninetheme-woocommerce-pagination ul li a:hover, .woocommerce nav.ninetheme-woocommerce-pagination ul li span.current')
            ),
            array(
                'title' => esc_html__('Pagination Text Color', 'crisop'),
                'subtitle' => esc_html__('Change shop page pagination text color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_pagination_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.woocommerce nav.ninetheme-woocommerce-pagination ul li a, .woocommerce nav.ninetheme-woocommerce-pagination ul li span')
            ),
            array(
                'title' => esc_html__('Active Pagination Text Color', 'crisop'),
                'subtitle' => esc_html__('Change shop page pagination hover and active item text color.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_pagination_hvrcolor',
                'type' => 'color',
                'default' => '',
                'output' => array('.woocommerce nav.ninetheme-woocommerce-pagination ul li a:focus, .woocommerce nav.ninetheme-woocommerce-pagination ul li a:hover, .woocommerce nav.ninetheme-woocommerce-pagination ul li span.current')
            )
        )
    ));
    // Shop Elementor Template SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Shop Elementor Templates', 'crisop'),
        'id' => 'shop_elementor_templates_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__( 'Before Shop Content Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after hero section.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_before_content_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'After Shop Content Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after products.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_after_content_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Before Loop Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content before products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_before_loop_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'After Loop Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_after_loop_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args,
            ),
            array(
                'title' => esc_html__( 'Category Pages Before Loop Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content before products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_category_pages_before_loop_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Category Pages After Loop Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_category_pages_after_loop_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args,
            ),
            array(
                'title' => esc_html__( 'Tag Pages Before Loop Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content before products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_tag_pages_before_loop_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Tag Pages After Loop Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_tag_pages_after_loop_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Category Pages Before Content Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content before products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_category_pages_before_content_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Category Pages After Content Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_category_pages_after_content_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Tag Pages Before Content Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content before products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_tag_pages_before_content_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Tag Pages After Content Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after products loop.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_tag_pages_after_content_templates',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            )
        )
    ));
    // Shop Elementor Template SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Shop Sidebar Colors', 'crisop'),
        'id' => 'shop_sidebar_colors_subsection',
        'subsection' => true,
        'icon' => 'el el-brush',
        'fields' => array(
            array(
                'title' => esc_html__( 'Background Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'validate' => 'color',
                'output' => array( '.nt-sidebar-inner-wrapper .nt-sidebar-inner' )
            ),
            array(
                'title' => esc_html__( 'Border', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.nt-sidebar-inner-wrapper .nt-sidebar-inner' )
            ),
            array(
                'title' => esc_html__( 'Widget Title Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_title_info_divider',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Typography', 'crisop' ),
                'id' => 'shop_sidebar_title_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-shop-sidebar .nt-sidebar-inner-widget-title' ),
            ),
            array(
                'title' => esc_html__( 'Widget Toggle Button Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_toggle_btn_info_divider',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Background Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_toggle_btn_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'validate' => 'color',
                'output' => array( '.nt-sidebar-widget-toggle' )
            ),
            array(
                'title' => esc_html__( 'Border', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_toggle_btn_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.nt-sidebar-widget-toggle' )
            ),
            array(
                'title' => esc_html__( 'Arrow Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_toggle_btn_color',
                'type' => 'color',
                'output' => array( '.nt-sidebar-widget-toggle' )
            ),
            array(
                'title' => esc_html__( 'Background Color ( Hover Active )', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_toggle_btn_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'validate' => 'color',
                'output' => array( '.nt-sidebar-widget-toggle:hover,.nt-sidebar-inner-widget.active .nt-sidebar-widget-toggle' )
            ),
            array(
                'title' => esc_html__( 'Border ( Hover Active )', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_toggle_btn_hvrbrd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.nt-sidebar-widget-toggle:hover,.nt-sidebar-inner-widget.active .nt-sidebar-widget-toggle' )
            ),
            array(
                'title' => esc_html__( 'Arrow Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_toggle_btn_hvrcolor',
                'type' => 'color',
                'output' => array( '.nt-sidebar-widget-toggle:hover,.nt-sidebar-inner-widget.active .nt-sidebar-widget-toggle' )
            ),
            array(
                'title' => esc_html__( 'Submenu Plus & Minus Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_subtoggle_hvrcolor',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.nt-sidebar-inner-widget span.subDropdown svg' )
            ),
            array(
                'title' => esc_html__( 'Widget Link Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_widget_link_info_divider',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_widget_link_color',
                'type' => 'color',
                'output' => array( '.site-scroll li a,.nt-sidebar-inner-widget a,.nt-sidebar-inner-widget .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item a' )
            ),
            array(
                'title' => esc_html__( 'Color ( Hover Active )', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_widget_link_hvrcolor',
                'type' => 'color',
                'output' => array( '.site-scroll li a:hover,.nt-sidebar-inner-widget a:hover,.site-scroll li.checked > a,.nt-sidebar-inner-widget li.checked > a.,.nt-sidebar-inner-widget .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item a:hover' )
            ),
            array(
                'title' => esc_html__( 'Widget Terms Count Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_widget_terms_count_info_divider',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'background Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_widget_terms_count_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.site-scroll .widget-list-span, .product-categories .widget-list-span, .woocommerce-widget-layered-nav-list__item .widget-list-span' )
            ),
            array(
                'title' => esc_html__( 'Color', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_sidebar_widget_terms_count_color',
                'type' => 'color',
                'output' => array( '.site-scroll .widget-list-span, .product-categories .widget-list-span, .woocommerce-widget-layered-nav-list__item .widget-list-span' )
            ),
        )
    ));
    /*************************************************
    ## SINGLE PRODUCT SECTION
    *************************************************/
    // create sections in the theme options
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('SHOP PRODUCT PAGE', 'crisop'),
        'id' => 'product_page_section',
        'icon' => 'el el-shopping-cart-sign'
    ));
    // Product Layout SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Layout', 'crisop'),
        'id' => 'product_general_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' =>'single_shop_layout',
                'type' => 'button_set',
                'title' => esc_html__( 'Page Sidebar Layouts', 'crisop' ),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop page sidebar area.', 'crisop' ),
                'options' => array(
                    'left-sidebar' => esc_html__( 'Left Sidebar', 'crisop' ),
                    'right-sidebar' => esc_html__( 'Right Sidebar', 'crisop' ),
                    'full-width' => esc_html__( 'Full width ( no-sidebar )', 'crisop' ),
                    'stretch' => esc_html__( 'Full width ( stretch )', 'crisop' ),
                    'showcase' => esc_html__( 'Showcase Style', 'crisop' ),
                ),
                'default' => 'full-width'
            ),
            array(
                'id' => 'product_summary_right_elementor_templates',
                'title' => esc_html__( 'Summary Right Column Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after summary right section.', 'crisop' ),
                'customizer' => true,
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args,
                'required' => array(
                    array( 'single_shop_layout', '!=', 'left-sidebar' ),
                    array( 'single_shop_layout', '!=', 'right-sidebar' ),
                )
            ),
            array(
                'id' => 'single_shop_stretch_elementor_template',
                'title' => esc_html__( 'After Tabs Elementor Templates', 'crisop' ),
                'subtitle' => esc_html__( 'Select a template from elementor templates, If you want to show any content after product page tabs section.', 'crisop' ),
                'customizer' => true,
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args,
                'required' => array( 'single_shop_layout', '=', 'stretch' )
            ),
            array(
                'id' =>'product_thumbs_layout',
                'type' => 'button_set',
                'title' => esc_html__('Thumbs Layout Type', 'crisop'),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop product page tumbs.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'grid' => esc_html__( 'Grid', 'crisop' ),
                    'slider' => esc_html__( 'Slider', 'crisop' ),
                    'wc' => esc_html__( 'WooCommerce Default Slider', 'crisop' ),
                ),
                'default' => 'slider',
                'required' => array( 'single_shop_layout', '!=', 'showcase' )
            ),
            array(
                'id' =>'product_gallery_slider_effect',
                'type' => 'button_set',
                'title' => esc_html__('Slider Effect', 'crisop'),
                'customizer' => true,
                'options' => array(
                    'creative' => esc_html__( 'Creative', 'crisop' ),
                    'slide' => esc_html__( 'Slide', 'crisop' ),
                ),
                'default' => 'slide',
                'required' => array( 'product_thumbs_layout', '=', 'slider' )
            ),
            array(
                'title' => esc_html__('Thumbs Column Width', 'crisop'),
                'customizer' => true,
                'id' => 'product_thumbs_column_width',
                'type' => 'spinner',
                'default' => '5',
                'min' => '1',
                'step' => '1',
                'max' => '12'
            ),
            array(
                'id' =>'ninetheme_product_gallery_grid_column',
                'type' => 'button_set',
                'title' => esc_html__('Grid Column', 'crisop'),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop product page tumbs.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    '1' => esc_html__( '1 Column', 'crisop' ),
                    '2' => esc_html__( '2 Column', 'crisop' ),
                    '3' => esc_html__( '3 Column', 'crisop' ),
                    '4' => esc_html__( '4 Column', 'crisop' ),
                ),
                'default' => '2',
                'required' => array(
                    array( 'single_shop_layout', '!=', 'showcase' ),
                    array( 'product_thumbs_layout', '=', 'grid' )
                )
            ),
            array(
                'id' =>'product_gallery_slider_layout',
                'type' => 'button_set',
                'title' => esc_html__('Slider Thumbs Type', 'crisop'),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop product page tumbs.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'top' => esc_html__( 'Horizontal Top', 'crisop' ),
                    'bottom' => esc_html__( 'Horizontal Bottom', 'crisop' ),
                    'left' => esc_html__( 'Vertical Left', 'crisop' ),
                    'right' => esc_html__( 'Vertical Right', 'crisop' ),
                ),
                'default' => 'bottom',
                'required' => array(
                    array( 'single_shop_layout', '!=', 'showcase' ),
                    array( 'product_thumbs_layout', '!=', 'grid' )
                )
            ),
            array(
                'title' => esc_html__( 'Custom Product Gallery Image Size', 'crisop' ),
                'subtitle' => esc_html__( '! Important: Cropping images will not work if the width of your images is less than the entered value.', 'crisop' ),
                'desc' => esc_html__( 'Default: 980', 'crisop' ),
                'placeholder' => esc_html__( '980', 'crisop' ),
                'customizer' => true,
                'id' => 'product_gallery_imgsize',
                'type' => 'text',
                'validate' => array( 'numeric' )
            ),
            array(
                'id' =>'single_shop_showcase_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Showcase Slider Type', 'crisop' ),
                'subtitle' => esc_html__( 'Select theme shop page showcase type.', 'crisop' ),
                'options' => array(
                    'carousel' => esc_html__( 'Carousel', 'crisop' ),
                    'full' => esc_html__( 'Full', 'crisop' ),
                ),
                'default' => 'carousel',
                'required' => array( 'single_shop_layout', '=', 'showcase' )
            ),
            array(
                'id' =>'single_shop_showcase_full_effect_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Showcase Full Effect Type', 'crisop' ),
                'subtitle' => esc_html__( 'Select theme shop page showcase full type effect.', 'crisop' ),
                'options' => array(
                    'slide' => esc_html__( 'Slide', 'crisop' ),
                    'flip' => esc_html__( 'flip', 'crisop' ),
                    'fade' => esc_html__( 'fade', 'crisop' ),
                    'creative' => esc_html__( 'creative', 'crisop' ),
                ),
                'default' => 'slide',
                'required' => array(
                    array( 'single_shop_layout', '=', 'showcase' ),
                    array( 'single_shop_showcase_type', '=', 'full' ),
                )
            ),
            array(
                'id' =>'single_shop_showcase_carousel_effect_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Showcase Carousel Effect Type', 'crisop' ),
                'subtitle' => esc_html__( 'Select theme shop page showcase carousel type effect.', 'crisop' ),
                'options' => array(
                    '' => esc_html__( 'Carousel', 'crisop' ),
                    'coverflow' => esc_html__( 'Coverflow', 'crisop' ),
                ),
                'default' => 'slide',
                'required' => array(
                    array( 'single_shop_layout', '=', 'showcase' ),
                    array( 'single_shop_showcase_type', '=', 'carousel' ),
                )
            ),
            array(
                'title' => esc_html__( 'Coverflow Rotate', 'crisop' ),
                'subtitle' => esc_html__( 'Set the rotate of the coverflow effect.', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_showcase_carousel_coverflow_rotate',
                'type' => 'slider',
                'default' => 30,
                'min' => -90,
                'step' => 1,
                'max' => 90,
                'required' => array(
                    array( 'single_shop_layout', '=', 'showcase' ),
                    array( 'single_shop_showcase_type', '=', 'carousel' ),
                    array( 'single_shop_showcase_carousel_effect_type', '=', 'coverflow' ),
                )
            ),
            array(
                'title' => esc_html__('Slider Loop', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_showcase_carousel_loop',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_layout', '=', 'showcase' ),
                    array( 'single_shop_showcase_type', '=', 'carousel' ),
                )
            ),
            array(
                'id' =>'single_shop_showcase_bg_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Showcase BG Style', 'crisop' ),
                'subtitle' => esc_html__( 'Select theme shop page showcase background style.', 'crisop' ),
                'options' => array(
                    'light' => esc_html__( 'Light', 'crisop' ),
                    'dark' => esc_html__( 'Dark', 'crisop' ),
                    'custom' => esc_html__( 'Custom Color', 'crisop' ),
                ),
                'default' => 'light',
                'required' => array( 'single_shop_layout', '=', 'showcase' )
            ),
            array(
                'title' => esc_html__('Showcase Background', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_showcase_custom_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-showcase.ninetheme-bg-custom' ),
                'required' => array(
                    array( 'single_shop_layout', '=', 'showcase' ),
                    array( 'single_shop_showcase_bg_type', '=', 'custom' )
                )
            ),
            array(
                'title' => esc_html__('Showcase Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_showcase_custom_textcolor',
                'type' => 'color',
                'output' => array( '.ninetheme-product-showcase.ninetheme-bg-custom' ),
                'required' => array(
                    array( 'single_shop_layout', '=', 'showcase' ),
                    array( 'single_shop_showcase_bg_type', '=', 'custom' )
                )
            ),
            array(
                'title' => esc_html__('Showcase Content Padding', 'crisop'),
                'subtitle' => esc_html__('You can set the spacing of the site single page showcase content.', 'crisop'),
                'customizer' => true,
                'id' =>'single_shop_showcase_content_pad',
                'type' => 'spacing',
                'output' => array('.product .ninetheme-product-showcase.ninetheme-bg-custom'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'required' => array( 'single_shop_layout', '=', 'showcase' )
            ),
            array(
                'title' => esc_html__( 'Sticky Sidebar', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_sticky_sidebar',
                'type' => 'switch',
                'default' => 0,
                'required' => array(
                    array( 'single_shop_layout', '!=', 'full-width' ),
                    array( 'single_shop_layout', '!=', 'showcase' )
                )
            ),
            array(
                'title' => esc_html__('Reviews Section', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_review_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Bottom Popup Cart on Scroll', 'crisop'),
                'customizer' => true,
                'id' => 'ninetheme_product_bottom_popup_cart',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Gallery Zoom Effect', 'crisop'),
                'subtitle' => esc_html__('You can enable or disable the site product image zoom option.', 'crisop'),
                'customizer' => true,
                'id' => 'ninetheme_product_zoom',
                'type' => 'switch',
                'default' => 1
            )
        )
    ));
    // Product Top Navigation SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Product Top', 'crisop'),
        'id' => 'product_hero_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Product Top', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_nav_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'id' =>'single_shop_nav_position',
                'type' => 'button_set',
                'title' => esc_html__( 'Product navigation position', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'top' => esc_html__( 'Top', 'crisop' ),
                    'bottom' => esc_html__( 'Bottom', 'crisop' ),
                    'both' => esc_html__( 'Both', 'crisop' )
                ),
                'default' => 'bottom',
                'required' => array( 'single_shop_nav_visibility', '=', '1' )
            ),
            array(
                'id' =>'single_shop_nav_bread_position',
                'type' => 'button_set',
                'title' => esc_html__( 'Product breadcrumbs position', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'top' => esc_html__( 'Before Summary', 'crisop' ),
                    'summary' => esc_html__( 'Before Product Title', 'crisop' )
                ),
                'default' => 'summary'
            )
        )
    ));
    // Product Summary SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Summary', 'crisop'),
        'id' => 'product_summary_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'id' => 'ninetheme_product_summary_start',
                'type' => 'section',
                'title' => esc_html__('Summary Elements Options', 'crisop'),
                'customizer' => true,
                'indent' => true
            ),
            array(
                'title' => esc_html__( 'Sticky Summary', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_sticky_summary',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'id' =>'single_shop_summary_layout_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Product Summary Layouts', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'default' => esc_html__( 'Default', 'crisop' ),
                    'custom' => esc_html__( 'Custom Layout', 'crisop' )
                ),
                'default' => 'default'
            ),
            array(
                'id' =>'single_shop_summary_layouts',
                'type' => 'sorter',
                'title' => esc_html__( 'Product Summary Layouts Manager', 'crisop' ),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme product page summary area.', 'crisop' ),
                'options' => array(
                    'show' => array(
                        'bread' => esc_html__( 'Breadcrumbs', 'crisop' ),
                        'title' => esc_html__( 'Title', 'crisop' ),
                        'rating' => esc_html__( 'Rating', 'crisop' ),
                        'price' => esc_html__( 'Price', 'crisop' ),
                        'excerpt' => esc_html__( 'Excerpt', 'crisop' ),
                        'cart' => esc_html__( 'Cart', 'crisop' ),
                        'meta' => esc_html__( 'Meta', 'crisop' ),
                    ),
                    'hide' => array()
                ),
                'required' => array( 'single_shop_summary_layout_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__( 'Product Title Customize', 'crisop' ),
                'customizer' => true,
                'id' => 'product_title_info',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__( 'Title Typography', 'crisop' ),
                'id' => 'product_title_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.nt-woo-single .ninetheme-summary-item.ninetheme-product-title' ),
            ),
            array(
                'id' =>'product_title_tag',
                'type' => 'select',
                'multiple' => false,
                'title' => esc_html__( 'Product Title Tag', 'crisop' ),
                'options' => array(
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'Div', 'crisop' )
                ),
                'default' => 'h1'
            ),
            array(
                'title' => esc_html__( 'Price Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'product_price_info',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Price Typography', 'crisop' ),
                'id' => 'product_price_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price > span,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price >.amount,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price > .ninetheme-primary-color.ins,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price .price,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price .price > .ninetheme-primary-color.ins' ),
            ),
            array(
                'title' => esc_html__( 'Price 2 Typography', 'crisop' ),
                'id' => 'product_price2_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price > .ninetheme-primary-color.del,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price .price > span.del,.ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price span.del>span' ),
            ),
            array(
                'title' => esc_html__( 'Product Add to Cart Variation Price Typography', 'crisop' ),
                'id' => 'product_variation_price_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.cart .woocommerce-variation-price .price,.ninetheme-product-summary .ninetheme-summary-item.cart .woocommerce-variation-price .price > span' ),
            ),
            array(
                'title' => esc_html__( 'Product Add to Cart Variation Price 2 Typography', 'crisop' ),
                'id' => 'product_variation_price2_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.cart .woocommerce-variation-price .price > span.del,.ninetheme-product-summary .ninetheme-summary-item.cart .woocommerce-variation-price .price > span.del > span' ),
            ),
            array(
                'title' => esc_html__( 'Excerpt Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'product_excerpt_info',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Excerpt Typography', 'crisop' ),
                'id' => 'product_excerpt_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.nt-woo-single .woocommerce-product-details__short-description' ),
            ),
            array(
                'title' => esc_html__( 'Stock Status Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'product_stock_status_info',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Stock Status Typography', 'crisop' ),
                'id' => 'product_stock_status_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'all_styles' => true,
                'output' => array( '.nt-woo-single .ninetheme-summary-item.ninetheme-price p.stock.ninetheme-stock-status' )
            ),
            array(
                'title' => esc_html__('Stock Status Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_stock_status_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.nt-woo-single .ninetheme-summary-item.ninetheme-price p.stock.ninetheme-stock-status' )
            ),
            array(
                'title' => esc_html__('Stock Status Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_stock_status_color',
                'type' => 'color',
                'output' => array( '.nt-woo-single .ninetheme-summary-item.ninetheme-price p.stock.ninetheme-stock-status' )
            ),
            array(
                'title' => esc_html__('Out of Stock Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_outofstock_status_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.nt-woo-single .ninetheme-summary-item.ninetheme-price p.stock.ninetheme-stock-status.out-of-stock' )
            ),
            array(
                'title' => esc_html__('Stock Status Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_outofstock_status_color',
                'type' => 'color',
                'output' => array( '.nt-woo-single .ninetheme-summary-item.ninetheme-price p.stock.ninetheme-stock-status.out-of-stock' )
            ),
            array(
                'title' => esc_html__( 'Add to Cart Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'product_addtocart_info',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn' )
            ),
            array(
                'title' => esc_html__('Background Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn:hover' )
            ),
            array(
                'title' => esc_html__('Title Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn' )
            ),
            array(
                'title' => esc_html__('Title Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_hvrcolor',
                'type' => 'color',
                'mode' => 'color',
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn:hover' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn' )
            ),
            array(
                'title' => esc_html__('Border ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn:hover' )
            ),
            array(
                'title' => esc_html__('Background Color ( Loading )', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_loading_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn.loading .loading-wrapper' )
            ),
            array(
                'title' => esc_html__('Border ( Loading )', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_loading_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.ninetheme-product-summary .single_add_to_cart_button.ninetheme-btn.loading .loading-wrapper' )
            ),
            array(
                'title' => esc_html__('Point Color ( Loading )', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_loading_color',
                'type' => 'color'
            ),
            array(
                'title' => esc_html__('Point Color 2 ( Loading )', 'crisop'),
                'customizer' => true,
                'id' => 'product_addtocart_loading_color2',
                'type' => 'color'
            ),
            array(
                'title' => esc_html__( 'Quantity Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'product_quantity_info',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_quantity_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .quantity' )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_quantity_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .quantity' )
            ),
            array(
                'title' => esc_html__('Plus & Minus Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_quantity_btns_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .quantity .quantity-button.plus,.ninetheme-product-summary .ninetheme-summary-item .quantity-button.minus' )
            ),
            array(
                'title' => esc_html__('Plus & Minus Background Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_quantity_btns_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .quantity .quantity-button.plus:hover,.ninetheme-product-summary .ninetheme-summary-item .quantity-button.minus:hover' )
            ),
            array(
                'title' => esc_html__('Plus & Minus Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_quantity_btns_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .quantity .quantity-button.plus,.ninetheme-product-summary .ninetheme-summary-item .quantity-button.minus' )
            ),
            array(
                'title' => esc_html__('Plus & Minus Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_quantity_btns_hvrcolor',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .quantity .quantity-button.plus:hover,.ninetheme-product-summary .ninetheme-summary-item .quantity-button.minus:hover' )
            ),
            array(
                'title' => esc_html__( 'Wishlist & Compare Customize Options', 'crisop' ),
                'customizer' => true,
                'id' => 'product_buttons_info',
                'type' => 'info',
            ),
            array(
                'title' => esc_html__( 'Wishlist Button', 'crisop' ),
                'customizer' => true,
                'id' => 'product_wishlist_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__( 'Compare Button', 'crisop' ),
                'customizer' => true,
                'id' => 'product_compare_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Wishlist & Compare Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_action_buttons_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button' )
            ),
            array(
                'title' => esc_html__('Wishlist & Compare Background Color ( Hover/Active )', 'crisop'),
                'customizer' => true,
                'id' => 'product_action_buttons_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button:hover,.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button.icon-added,.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button.woosc-added' )
            ),
            array(
                'title' => esc_html__('Wishlist & Compare Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_action_buttons_color',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button svg' )
            ),
            array(
                'title' => esc_html__('Wishlist & Compare Color ( Hover/Active )', 'crisop'),
                'customizer' => true,
                'id' => 'product_action_buttons_hvrcolor',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button:hover svg,.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button.icon-added svg,.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button.woosc-added svg' )
            ),
            array(
                'title' => esc_html__('Wishlist & Compare Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_action_buttons_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button' )
            ),
            array(
                'title' => esc_html__('Wishlist & Compare Border ( Hover/Active )', 'crisop'),
                'customizer' => true,
                'id' => 'product_action_buttons_brd',
                'type' => 'border',
                'all' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button:hover,.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button.icon-added,.ninetheme-product-summary .ninetheme-summary-item .ninetheme-after-single-cart-button .ninetheme-product-button.woosc-added' )
            ),
            array(
                'title' => esc_html__( 'Product Popups Section Customize', 'crisop' ),
                'customizer' => true,
                'id' => 'product_popups_section_info',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__( 'Product Popups Section', 'crisop' ),
                'subtitle' => esc_html__('Size Guide, Delivery & Return, Estimated Delivery, Fake Visitor', 'crisop'),
                'customizer' => true,
                'id' => 'product_popups_section_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Backgorund Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_popups_section_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array('.ninetheme-product-summary .ninetheme-product-popup-details'),
                'required' => array( 'product_popups_section_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_popups_section_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-product-summary .ninetheme-product-popup-details'),
                'required' => array( 'product_popups_section_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'product_popups_section_brd_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'product_popups_section_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Padding', 'crisop'),
                'customizer' => true,
                'id' =>'product_popups_section_pad',
                'type' => 'spacing',
                'output' => array('.ninetheme-product-summary .ninetheme-product-popup-details'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array('units' => 'px')
            ),
            array(
                'title' => esc_html__('Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_popups_section_item_icon_color',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array('.ninetheme-product-popup-details svg'),
                'required' => array( 'product_popups_section_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_popups_section_item_text_color',
                'type' => 'color',
                'output' => array('.ninetheme-product-popup-details div,.ninetheme-product-popup-details div a,.ninetheme-product-popup-details div span'),
                'required' => array( 'product_popups_section_visibility', '=', '1' )
            ),
            array(
                'id' => 'ninetheme_product_summary_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false
            )
        )
    ));
    // Product Variable Products Terms SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Product Labels', 'crisop'),
        'id' => 'product_labels_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Product Labels', 'crisop'),
                'subtitle' => esc_html__('Sale, Stock, Discount', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_top_labels_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Sale Style', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_sale_info',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('Backgorund Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_sale_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-badge'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_sale_color',
                'type' => 'color',
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-badge'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_sale_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-badge'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_sale_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Discount Style', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_discount_info',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('Backgorund Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_discount_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-discount'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_discount_color',
                'type' => 'color',
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-discount'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_discount_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-discount'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_discount_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Stock Status Style', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_stock_info',
                'type' => 'info'
            ),
            array(
                'title' => esc_html__('Backgorund Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_stock_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-discount'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_stock_color',
                'type' => 'color',
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-discount'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_stock_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-product-labels .ninetheme-label.ninetheme-discount'),
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'product_labels_stock_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'single_shop_top_labels_visibility', '=', '1' )
            ),
        )
    ));
    // Product Variable Products Terms SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Variable Products Terms ( Swatches )', 'crisop'),
        'id' => 'product_variations_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Theme Swatches', 'crisop'),
                'customizer' => true,
                'id' => 'swatches_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'id' => 'crisop_product_variations_attr_start',
                'type' => 'section',
                'title' => esc_html__('Product Attribute Terms Customize Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'id' =>'variations_terms_shape',
                'type' => 'button_set',
                'title' => esc_html__( 'Terms Box Type', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'default' => esc_html__( 'default', 'crisop' ),
                    'circle' => esc_html__( 'circle', 'crisop' ),
                    'square' => esc_html__( 'square', 'crisop' ),
                    'radius' => esc_html__( 'radius', 'crisop' )
                ),
                'default' => 'default',
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'id' =>'variations_terms_checked_closed_icon_visibility',
                'type' => 'button_set',
                'title' => esc_html__( 'Checked Icon', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    '1' => esc_html__( 'Show', 'crisop' ),
                    '0' => esc_html__( 'Hide', 'crisop' )
                ),
                'default' => '1',
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Attribute Customize ( for genaral )', 'crisop' ),
                'indent' => false,
                'id' => 'product_attr_genaral_term_divide',
                'type' => 'info',
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Term Size', 'crisop' ),
                'customizer' => true,
                'id' => 'product_attr_term_size',
                'type' => 'dimensions',
                'output' => array('.ninetheme-terms.ninetheme-type-color .ninetheme-term,.ninetheme-terms.ninetheme-type-button .ninetheme-term:after'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_term_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-terms.ninetheme-type-color .ninetheme-term-wrapper,.ninetheme-terms.ninetheme-type-image .ninetheme-term,.ninetheme-terms.ninetheme-type-button .ninetheme-term:after'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Active Term Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_term_active_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-terms.ninetheme-type-button .ninetheme-term.ninetheme-selected:after,.ninetheme-terms.ninetheme-type-color .ninetheme-term-wrapper.ninetheme-selected,.ninetheme-terms.ninetheme-type-image .ninetheme-term.ninetheme-selected'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Disabled Term Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_term_inactive_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-terms.ninetheme-type-color .ninetheme-term.ninetheme-disabled,.ninetheme-terms.ninetheme-type-image .ninetheme-term.ninetheme-disabled,.ninetheme-terms.ninetheme-type-button .ninetheme-term.ninetheme-disabled:after'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Disabled Terms Opacity', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_term_inactive_opacity',
                'type' => 'slider',
                'default' => 0.4,
                'min' => 0,
                'step' => 0.01,
                'max' => 1,
                'resolution' => 0.01,
                'display_value' => 'text',
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Attribute Customize ( for type Color )', 'crisop' ),
                'indent' => false,
                'id' => 'product_attr_type_color_term_divide',
                'type' => 'info',
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Term Size', 'crisop' ),
                'customizer' => true,
                'id' => 'product_attr_type_color_term_size',
                'type' => 'dimensions',
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-color .ninetheme-term'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Padding', 'crisop'),
                'customizer' => true,
                'id' =>'product_attr_type_color_term_pad',
                'type' => 'spacing',
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-color .ninetheme-term-wrapper'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array('units' => 'px'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_color_term_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-color .ninetheme-term-wrapper'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Active Term Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_color_term_active_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-color .ninetheme-term-wrapper.ninetheme-selected'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Attribute Customize ( for type Button )', 'crisop' ),
                'indent' => false,
                'id' => 'product_attr_type_button_term_divide',
                'type' => 'info',
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Term Size', 'crisop' ),
                'customizer' => true,
                'id' => 'product_attr_type_button_term_size',
                'type' => 'dimensions',
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-button .ninetheme-term:after'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Padding', 'crisop'),
                'customizer' => true,
                'id' =>'product_attr_type_button_term_pad',
                'type' => 'spacing',
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-button .ninetheme-term'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array('units' => 'px'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_button_term_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-button .ninetheme-term:after'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Active Term Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_button_term_active_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-terms.ninetheme-type-button .ninetheme-term.ninetheme-enabled.ninetheme-selected:after'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Term Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_button_term_color',
                'type' => 'color',
                'output' => array( '.variations-items .ninetheme-terms.ninetheme-type-button .ninetheme-term:after' ),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Active Term Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_button_term_active_color',
                'type' => 'color',
                'output' => array( '.ninetheme-terms.ninetheme-type-button .ninetheme-term.ninetheme-enabled.ninetheme-selected:after' ),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Term Backgorund Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_button_term_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.variations-items .ninetheme-terms.ninetheme-type-button .ninetheme-term:after' ),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Active Term Backgorund Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_button_term_active_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.variations-items .ninetheme-terms.ninetheme-type-button .ninetheme-term.ninetheme-enabled.ninetheme-selected:after' ),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Attribute Customize ( for type Image )', 'crisop' ),
                'indent' => false,
                'id' => 'product_attr_type_image_term_divide',
                'type' => 'info',
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Term Size', 'crisop' ),
                'customizer' => true,
                'id' => 'product_attr_type_image_term_size',
                'type' => 'dimensions',
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-image .ninetheme-term'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Padding', 'crisop'),
                'customizer' => true,
                'id' =>'product_attr_type_image_term_pad',
                'type' => 'spacing',
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-image .ninetheme-term'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array('units' => 'px'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_image_term_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-image .ninetheme-term'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Active Term Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_attr_type_image_term_active_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.variations-items .ninetheme-terms.ninetheme-type-image .ninetheme-term.ninetheme-enabled.ninetheme-selected'),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'id' => 'crisop_product_variations_attr_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'id' => 'product_attr_title_typo_start',
                'type' => 'section',
                'title' => esc_html__('Attribute Title Customize Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Attribute Title Typography', 'crisop' ),
                'id' => 'product_attr_title_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-variations-items .ninetheme-small-title' ),
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'id' => 'product_attr_title_typo_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            //
            array(
                'id' => 'product_variations_hints_start',
                'type' => 'section',
                'title' => esc_html__('Attribute Hints Customize Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Show Hints', 'crisop'),
                'customizer' => true,
                'id' => 'variations_terms_hints_visibility',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Hints Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_hints_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-terms .ninetheme-term .ninetheme-hint' ),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'variations_terms_hints_visibility', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Hints Arrow Color', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_hints_bgcolor2',
                'type' => 'color',
                'mode' => 'border-top-color',
                'output' => array( '.ninetheme-terms .ninetheme-term .ninetheme-hint:before' ),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'variations_terms_hints_visibility', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Hints Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_hints_titlecolor',
                'type' => 'color',
                'output' => array( '.ninetheme-terms .ninetheme-term .ninetheme-hint' ),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'variations_terms_hints_visibility', '=', '1' ),
                )
            ),
            array(
                'id' => 'product_variations_hints_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            //
            array(
                'id' => 'product_selected_variations_terms_start',
                'type' => 'section',
                'title' => esc_html__('Product Selected Variations Customize Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Selected Variations', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_terms_visibility',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'swatches_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Selected Terms Tiltle', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_terms_title',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__( 'Title Typography', 'crisop' ),
                'id' => 'selected_variations_terms_title_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array('.ninetheme-selected-variations-terms-wrapper .ninetheme-selected-variations-terms-title'),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_terms_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array('.ninetheme-selected-variations-terms-wrapper .ninetheme-selected-variations-terms'),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_terms_brd',
                'type' => 'border',
                'all' => false,
                'output' => array('.ninetheme-selected-variations-terms-wrapper .ninetheme-selected-variations-terms'),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_terms_brd_radius',
                'type' => 'slider',
                'default' => 4,
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__('Padding', 'crisop'),
                'customizer' => true,
                'id' =>'selected_variations_terms_pad',
                'type' => 'spacing',
                'output' => array('.ninetheme-selected-variations-terms-wrapper .ninetheme-selected-variations-terms'),
                'mode' => 'padding',
                'units' => array('em', 'px'),
                'units_extended' => 'false',
                'default' => array(
                    'units' => 'px'
                ),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__('Terms Color', 'crisop'),
                'customizer' => true,
                'id' => 'selected_variations_terms_value_color',
                'type' => 'color',
                'output' => array( '.ninetheme-selected-variations-terms-wrapper .selected-features' ),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__( 'Selected Terms Typography', 'crisop' ),
                'id' => 'selected_variations_terms_value_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-selected-variations-terms-wrapper .selected-features' ),
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' )
                )
            ),
            array(
                'id' => 'product_selected_variations_terms_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array(
                    array( 'swatches_visibility', '=', '1' ),
                    array( 'selected_variations_terms_visibility', '=', '1' )
                )
            ),
        )
    ));
    // Product Countdown SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Countdown', 'crisop'),
        'id' => 'product_countdown_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Countdown', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('General Date', 'crisop'),
                'subtitle' => esc_html__('If you want to use different time for each product, you can set or change time in product settings', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_date',
                'type' => 'date',
                'placeholder' => esc_html__('Click to enter a date', 'crisop'),
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Update Countdown When Expires', 'crisop'),
                'subtitle' => esc_html__('When the time is expired, update the date every next X days', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_update',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Update Per Next Day', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_update_next',
                'type' => 'text',
                'default' => '7',
                'validate' => array('numeric'),
                'required' => array(
                    array( 'product_countdown_visibility', '=', '1' ),
                    array( 'product_countdown_update', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Text Before Countdown', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_text',
                'type' => 'textarea',
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Expired Text', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_expired',
                'type' => 'text',
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_icon_visibilty',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon HTML', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_icon',
                'type' => 'textarea',
                'default' => '<svg class="svgFlash ninetheme-svg-icon" fill="currentColor" viewBox="0 0 512 512" width="512" xmlns="http://www.w3.org/2000/svg"><g id="a"><g><path d="m452.51 194.38c3.59-3.25 21.83-19.17 24.92-21.99 5 5.57 9.58 10.59 10.24 11.13 2.28 2.05 6.34 2.46 9.4.71 1.83-1.06 4.24-2.64 7.18-5.21 2.93-2.58 4.81-4.76 6.11-6.45 2.15-2.81 2.32-6.93.62-9.5-.96-1.62-20.53-25.25-22.82-27.75-2.13-2.64-22.54-25.53-24-26.72-2.28-2.06-6.34-2.46-9.4-.71-1.83 1.06-4.24 2.64-7.18 5.21-2.93 2.58-4.81 4.76-6.11 6.44-2.15 2.81-2.32 6.93-.62 9.5.44.74 4.72 6.02 9.47 11.8-2.85 2.39-20.75 17.81-24.02 20.59l26.21 32.94z" fill="#454565"></path><path d="m356.57 126.14c.5-4.1 5.2-25.34 5.62-28.97 11.36-.21 21.68-.47 22.98-.67 4.69-.51 9.73-4.21 11.42-8.77 1-2.74 2.14-6.49 2.87-11.63.71-5.14.63-8.89.4-11.63-.41-4.55-4.41-8.25-8.95-8.77-2.74-.44-49.07-1.17-54.22-1.03-5.11-.14-51.64.59-54.5 1.03-4.69.51-9.73 4.22-11.42 8.77-1 2.74-2.14 6.49-2.87 11.63-.71 5.13-.63 8.89-.4 11.63.41 4.55 4.41 8.25 8.95 8.77 1.25.2 11.5.46 22.79.67-.59 3.63-5.47 24.87-6.12 28.97h63.44z" fill="#454565"></path><rect fill="#f04760" height="37.83" rx="18.91" width="37.83" x="15.97" y="225.7"></rect><path d="m327.25 121.9c-34.31 0-67.66 10.31-96.71 27.99l-67.56-.03h-.13l-.06-.02-.04.02h-116.87c-10.42 0-18.86 8.45-18.86 18.86v.19c0 10.42 8.45 18.86 18.86 18.86l92.75.05c9.78.7 17.49 8.85 17.49 18.81v.19c0 10.42-8.45 18.86-18.86 18.86h-51.97c-10.42 0-18.86 8.45-18.86 18.86v.19c0 10.42 8.45 18.86 18.86 18.86h20.4c10.42 0 18.86 8.45 18.86 18.86v.19c0 10.42-8.45 18.86-18.86 18.86h-86.71c-10.42 0-18.86 8.45-18.86 18.86v.19c0 10.42 8.45 18.86 18.86 18.86h101.67c10.42 0 18.86 8.44 18.86 18.86v.19c0 10.42-8.45 18.86-18.86 18.86h-49.4c-10.42 0-18.86 8.45-18.86 18.86v.19c0 10.42 8.45 18.86 18.86 18.86h103.7c25.91 26.16 62.55 42.06 105.15 42.06 92.63 0 178.27-75.09 191.29-167.72s-51.52-167.72-144.15-167.72z" fill="#e03757"></path><path d="m135.64 369.91c131.56-6.76 238.81-105.43 258.84-233.05-19.78-9.61-42.51-14.96-67.24-14.96-34.31 0-67.66 10.31-96.71 27.99l-67.56-.03h-.13l-.06-.02-.04.02h-116.86c-10.42 0-18.86 8.45-18.86 18.86v.19c0 10.42 8.45 18.86 18.86 18.86l92.75.05c9.78.7 17.49 8.85 17.49 18.81v.19c0 10.42-8.45 18.86-18.86 18.86h-51.97c-10.42 0-18.86 8.45-18.86 18.86v.19c0 10.42 8.45 18.86 18.86 18.86h20.4c10.42 0 18.86 8.45 18.86 18.86v.19c0 10.42-8.45 18.86-18.86 18.86h-86.71c-10.42 0-18.86 8.45-18.86 18.86v.19c0 10.42 8.45 18.86 18.86 18.86h101.67c10.42 0 18.86 8.44 18.86 18.86v.19c0 4.29-1.45 8.24-3.87 11.41z" fill="#f04760"></path><path d="m389.77 272.6-79.02 121.93c-1.82 2.8-4.93 4.49-8.27 4.49h-6.19c-6.38 0-11.08-5.97-9.57-12.17l19.47-80.36h-47.47c-5.69 0-9.88-5.32-8.54-10.85l26.34-108.72c.95-3.94 4.48-6.72 8.54-6.72h54.62c5.69 0 9.88 5.32 8.54 10.85l-16.07 66.33h49.35c7.81 0 12.51 8.65 8.27 15.21z"></path></g></g></svg>',
                'required' => array(
                    array( 'product_countdown_visibility', '=', '1' ),
                    array( 'product_countdown_icon_visibilty', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.ninetheme-viewed-offer-time .offer-time-text' ),
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-summary-item.ninetheme-viewed-offer-time' ),
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Count Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_brdcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-summary-item.ninetheme-viewed-offer-time .ninetheme-coming-time .time-count' ),
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Count Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_count_color',
                'type' => 'color',
                'output' => array( '.ninetheme-summary-item.ninetheme-viewed-offer-time .ninetheme-coming-time .time-count' ),
                'required' => array( 'product_countdown_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Count Separator Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_countdown_count_separator_color',
                'type' => 'color',
                'output' => array( '.ninetheme-summary-item.ninetheme-viewed-offer-time .separator' ),
                'required' => array( 'product_countdown_visibility', '=', '1' )
            )
        )
    ));
    // Product Stock Progress Bar SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Stock Progress Bar', 'crisop'),
        'id' => 'product_progressbar_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Stock Progress Bar', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_progressbar_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__('Container Style', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_wrapper_info',
                'type' => 'info',
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Container Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_wrapper_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.ninetheme-single-product-stock' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Pading', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_wrapper_padding',
                'type' => 'spacing',
                'mode' => 'padding',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.ninetheme-single-product-stock' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_wrapper_brd',
                'type' => 'border',
                'output' => array( '.ninetheme-product-summary .ninetheme-summary-item.ninetheme-single-product-stock' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_wrapper_brd_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 0.01,
                'max' => 1,
                'resolution' => 0.1,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Progressbar Style', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_progressbar_info',
                'type' => 'info',
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Height', 'crisop' ),
                'customizer' => true,
                'width' => false,
                'id' => 'product_progressbar_progressbar_height',
                'type' => 'dimensions',
                'output' => array('.ninetheme-single-product-stock .ninetheme-product-stock-progressbar'),
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-single-product-stock .ninetheme-product-stock-progress' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Progress Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_progress_color',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-single-product-stock .ninetheme-product-stock-progressbar' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-single-product-stock .ninetheme-product-stock-progressbar .stock-details' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Value Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_value_color',
                'type' => 'color',
                'output' => array( '.ninetheme-single-product-stock .ninetheme-product-stock-progressbar .stock-details span' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Pading', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_padding',
                'type' => 'spacing',
                'mode' => 'padding',
                'output' => array( '.ninetheme-single-product-stock .ninetheme-product-stock-progress' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_brd',
                'type' => 'border',
                'output' => array( '.ninetheme-single-product-stock .ninetheme-product-stock-progress' ),
                'required' => array( 'single_shop_progressbar_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Border Radius', 'crisop'),
                'customizer' => true,
                'id' => 'product_progressbar_brd_radius',
                'type' => 'slider',
                'default' => '',
                'min' => 0,
                'step' => 0.01,
                'max' => 1,
                'resolution' => 0.1,
                'display_value' => 'text'
            )
        )
    ));
    // Pairs Section SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Pairs Section', 'crisop'),
        'id' => 'product_pairs_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__( 'Section Heading', 'crisop' ),
                'subtitle' => esc_html__('Leave blank to use the default text or its equivalent translation in multiple languages.', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_heading',
                'type' => 'text',
                'placeholder' => 'People Who Bought This Product Also Bought These',
                'default' => '',
            ),
            array(
                'title' => esc_html__( 'Typography', 'crisop' ),
                'id' => 'product_pairs_heading_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-products-pairs .pairs-main-title' )
            ),
            array(
                'title' => esc_html__( 'Heading Tag', 'crisop' ),
                'customizer' => true,
                'id' => 'product_pairs_heading_tag',
                'type' => 'select',
                'options' => array(
                    '' => esc_html__( 'Select type', 'crisop' ),
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'span' => esc_html__( 'span', 'crisop' )
                ),
                'default' => 'h6'
            ),
            array(
                'title' => esc_html__('Item Box Border', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_border',
                'type' => 'border',
                'output' => array('.ninetheme-products-pairs .ninetheme-widget-product-list-type .ninetheme-product-list-type-inner'),
            ),
            array(
                'title' => esc_html__('Border ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_hvrborder',
                'type' => 'border',
                'output' => array('.ninetheme-products-pairs .ninetheme-widget-product-list-type .ninetheme-product-list-type-inner:hover'),
                'required' => array( 'product_whatsapp_button_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Item Box Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-widget-product-list-type .ninetheme-product-list-type-inner'),
            ),
            array(
                'title' => esc_html__('Background Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-widget-product-list-type .ninetheme-product-list-type-inner:hover')
            ),
            array(
                'title' => esc_html__('Item Stock Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_stock_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-widget-product-list-type .ninetheme-stock-status')
            ),
            array(
                'title' => esc_html__('Item Title Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_title_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-widget-product-list-type .ninetheme-product-list-type-product-title')
            ),
            array(
                'title' => esc_html__('Item Price Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_price_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-price,.ninetheme-products-pairs .ninetheme-price span.del>span')
            ),
            array(
                'title' => esc_html__('Item Price Second Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_price_color',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-price,.ninetheme-products-pairs .ninetheme-primary-color')
            ),
            array(
                'title' => esc_html__('Action Buttons Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_buttons_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-product-list-type-product-actions .ninetheme-product-button')
            ),
            array(
                'title' => esc_html__('Action Buttons Background Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_buttons_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-product-list-type-product-actions .ninetheme-product-button:hover')
            ),
            array(
                'title' => esc_html__('Action Buttons Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_buttons_color',
                'type' => 'color',
                'mode' => 'fill',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-product-list-type-product-actions .ninetheme-product-button svg')
            ),
            array(
                'title' => esc_html__('Action Buttons Icon Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_buttons_hvrcolor',
                'type' => 'color',
                'mode' => 'fill',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-product-list-type-product-actions .ninetheme-product-button:hover svg')
            ),
            array(
                'title' => esc_html__('Action Buttons Hint Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_buttons_hint_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-product-button:after')
            ),
            array(
                'title' => esc_html__('Action Buttons Hint Arrow Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_buttons_hint_arrow_color',
                'type' => 'color',
                'mode' => 'border-top-color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .hint-top .ninetheme-product-button:beforer')
            ),
            array(
                'title' => esc_html__('Action Buttons Hint Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_pairs_item_buttons_hint_textcolor',
                'type' => 'color',
                'default' => '',
                'output' => array('.ninetheme-products-pairs .ninetheme-product-button:after')
            )
        )
    ));
    // Product Delivery & Return Popup SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Delivery & Return Popup', 'crisop'),
        'id' => 'product_delivery_popup_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Delivery & Return Popup', 'crisop'),
                'customizer' => true,
                'id' => 'product_delivery_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__( 'Delivery & Return', 'crisop' ),
                'subtitle' => esc_html__( 'Select an elementor template from list', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_delivery_template',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args,
                'required' => array( 'product_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Category(s) Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'Select category(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_delivery_template_category_exclude',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_cat' ),
                ],
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__( 'Tag(s) Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'Select category(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_delivery_template_tag_exclude',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_tag' ),
                ],
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__( 'Custom Text', 'crisop' ),
                'desc' => esc_html__( 'Text entered here will be used for Size Guide area', 'crisop' ),
                'customizer' => true,
                'id' => 'product_delivery_text',
                'type' => 'text',
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__( 'Custom SVG Icon HTML', 'crisop' ),
                'desc' => esc_html__( 'Icon entered here will be used for Size Guide area', 'crisop' ),
                'customizer' => true,
                'id' => 'product_delivery_icon',
                'type' => 'textarea',
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_delivery_popup_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-product-delivery-btn a' ),
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__('Text Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_delivery_popup_text_hvrcolor',
                'type' => 'color',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-product-delivery-btn a:hover' ),
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__('Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_delivery_popup_svg_color',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-product-delivery-btn svg' ),
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__('Icon Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_delivery_popup_svg_hvrcolor',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-product-delivery-btn:hover svg' ),
                'required' => array(
                    array( 'product_delivery_visibility', '=', '1' ),
                    array( 'single_shop_delivery_template', '!=', '' )
                )
            )
        )
    ));
    // Product Size Guide Popup SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Size Guide Popup', 'crisop'),
        'id' => 'product_size_guide_popup_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Size Guide', 'crisop'),
                'customizer' => true,
                'id' => 'product_size_guide_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__( 'Size Guide', 'crisop' ),
                'subtitle' => esc_html__( 'Select an elementor template from list', 'crisop' ),
                'customizer' => true,
                'id' => 'product_size_guide_template',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args,
                'required' => array( 'product_size_guide_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Category(s) Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'Select category(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'product_size_guide_category_exclude',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_cat' ),
                ],
                'required' => array(
                    array( 'product_size_guide_visibility', '=', '1' ),
                    array( 'product_size_guide_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__( 'Tag(s) Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'Select category(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'product_size_guide_tag_exclude',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_tag' ),
                ],
                'required' => array(
                    array( 'product_size_guide_visibility', '=', '1' ),
                    array( 'product_size_guide_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__( 'Custom Text', 'crisop' ),
                'desc' => esc_html__( 'Text entered here will be used for Size Guide area', 'crisop' ),
                'customizer' => true,
                'id' => 'size_guide_text',
                'type' => 'text',
                'required' => array(
                    array( 'product_size_guide_visibility', '=', '1' ),
                    array( 'product_size_guide_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__( 'Custom SVG Icon HTML', 'crisop' ),
                'desc' => esc_html__( 'Icon entered here will be used for Size Guide area', 'crisop' ),
                'customizer' => true,
                'id' => 'size_guide_icon',
                'type' => 'textarea',
                'required' => array(
                    array( 'product_size_guide_visibility', '=', '1' ),
                    array( 'product_size_guide_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_size_guide_popup_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-size-guide-btn a' ),
                'required' => array(
                    array( 'product_size_guide_visibility', '=', '1' ),
                    array( 'product_size_guide_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__('Text Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_size_guide_popup_text_hvrcolor',
                'type' => 'color',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-size-guide-btn a:hover,.ninetheme-product-popup-details .ninetheme-size-guide-btn:hover svg' ),
                'required' => array(
                    array( 'product_size_guide_visibility', '=', '1' ),
                    array( 'product_size_guide_template', '!=', '' )
                )
            ),
            array(
                'title' => esc_html__('Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_size_guide_popup_svg_color',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-size-guide-btn svg' ),
                'required' => array(
                    array( 'product_size_guide_visibility', '=', '1' ),
                    array( 'product_size_guide_template', '!=', '' )
                )
            )
        )
    ));
    // Product Tabs SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Estimated Delivery', 'crisop'),
        'id' => 'product_estimated_delivery_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Estimated Delivery', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_estimated_delivery_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__('Estimated Delivery ( Min )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_min_estimated_delivery',
                'type' => 'spinner',
                'default' => '3',
                'min' => '1',
                'step' => '1',
                'max' => '31',
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Estimated Delivery ( Max )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_max_estimated_delivery',
                'type' => 'spinner',
                'default' => '7',
                'min' => '1',
                'step' => '1',
                'max' => '31',
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom Text', 'crisop' ),
                'desc' => esc_html__( 'Text entered here will be used for Estimated Delivery area', 'crisop' ),
                'customizer' => true,
                'id' => 'estimated_delivery_text',
                'type' => 'text',
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom SVG Icon HTML', 'crisop' ),
                'desc' => esc_html__( 'Icon entered here will be used for Estimated Delivery area', 'crisop' ),
                'customizer' => true,
                'id' => 'estimated_delivery_icon',
                'type' => 'textarea',
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Typography', 'crisop' ),
                'id' => 'product_estimated_delivery_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-popup-details .ninetheme-estimated-delivery span' ),
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_estimated_delivery_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-estimated-delivery span' ),
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Date Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_estimated_delivery_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-estimated-delivery .estimated-date' ),
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_estimated_delivery_svg_color',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-estimated-delivery svg' ),
                'required' => array( 'single_shop_estimated_delivery_visibility', '=', '1' )
            )
        )
    ));
    // Product Tabs SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Visitor Count', 'crisop'),
        'id' => 'product_visit_count_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Fake Visitor Count', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_visit_count_visibility',
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__('Fake Visitor Count ( Min )', 'crisop'),
                'customizer' => true,
                'id' => 'visit_count_min',
                'type' => 'spinner',
                'default' => '10',
                'min' => '1',
                'step' => '1',
                'max' => '100',
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Fake Visitor Count ( Max )', 'crisop'),
                'customizer' => true,
                'id' => 'visit_count_max',
                'type' => 'spinner',
                'default' => '50',
                'min' => '1',
                'step' => '1',
                'max' => '100',
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Fake Visitor Count ( Delay )', 'crisop'),
                'customizer' => true,
                'id' => 'visit_count_delay',
                'type' => 'spinner',
                'default' => '30000',
                'min' => '1000',
                'step' => '100',
                'max' => '100000',
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Fake Visitor Count ( Change )', 'crisop'),
                'customizer' => true,
                'id' => 'visit_count_change',
                'type' => 'spinner',
                'default' => '5',
                'min' => '1',
                'step' => '1',
                'max' => '50',
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom Text', 'crisop' ),
                'subtitle' => 'Default: <code>people</code>',
                'desc' => esc_html__( 'Text entered here will be used for Fake Visitor Count', 'crisop' ),
                'customizer' => true,
                'id' => 'visitor_count_text',
                'type' => 'text',
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom Text', 'crisop' ),
                'subtitle' => 'Default: <code>are viewing this right now</code>',
                'desc' => esc_html__( 'Text entered here will be used for Fake Visitor Count', 'crisop' ),
                'customizer' => true,
                'id' => 'visitor_count_text2',
                'type' => 'text',
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom SVG Icon HTML', 'crisop' ),
                'desc' => esc_html__( 'Icon entered here will be used for Fake Visitor Count', 'crisop' ),
                'customizer' => true,
                'id' => 'visitor_count_icon',
                'type' => 'textarea',
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Typography', 'crisop' ),
                'id' => 'product_visitor_count_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-popup-details .ninetheme-product-view,.ninetheme-product-popup-details .ninetheme-product-view span' ),
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Count Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_visitor_count_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-product-view span' ),
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Icon Color', 'crisop'),
                'customizer' => true,
                'id' => 'product_visitor_count_svg_color',
                'type' => 'color',
                'mode' => 'fill',
                'output' => array( '.ninetheme-product-popup-details .ninetheme-product-view svg' ),
                'required' => array( 'single_shop_visit_count_visibility', '=', '1' )
            )
        )
    ));
    // Product Tabs SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Product Meta', 'crisop'),
        'id' => 'product_meta_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Meta', 'crisop'),
                'subtitle' => esc_html__('SKU, Categories, Tags', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_meta_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__( 'Meta Label Typography', 'crisop' ),
                'id' => 'product_meta_label_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-product-meta .ninetheme-brands .label, .ninetheme-product-summary .ninetheme-product-meta .posted_in .label, .ninetheme-product-summary .ninetheme-product-meta .tagged_as .label, .ninetheme-product-summary .ninetheme-product-meta .ninetheme-sku-wrapper .label' ),
                'required' => array( 'single_shop_meta_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Meta Link Typography', 'crisop' ),
                'id' => 'product_meta_link_typo',
                'type' => 'typography',
                'font-backup' => false,
                'letter-spacing' => true,
                'text-transform' => true,
                'text-decoration' => true,
                'all_styles' => true,
                'output' => array( '.ninetheme-product-summary .ninetheme-product-meta a,.ninetheme-product-summary .ninetheme-product-meta .ninetheme-brands a, .ninetheme-product-summary .ninetheme-product-meta .posted_in a, .ninetheme-product-summary .ninetheme-product-meta .tagged_as a' ),
                'required' => array( 'single_shop_meta_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Meta Link Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'product_visitor_count_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-product-meta a:hover,.ninetheme-product-summary .ninetheme-product-meta .ninetheme-brands a:hover, .ninetheme-product-summary .ninetheme-product-meta .posted_in a:hover, .ninetheme-product-summary .ninetheme-product-meta .tagged_as a:hover' ),
                'required' => array( 'single_shop_meta_visibility', '=', '1' )
            )
        )
    ));
    // Product Tabs SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Tabs', 'crisop'),
        'id' => 'product_tabs_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__( 'Tabs Display', 'crisop' ),
                'customizer' => true,
                'id' => 'product_tabs_visibility',
                'type' => 'switch',
                'default' => 1,
                'on' => esc_html__( 'On', 'crisop' ),
                'off' => esc_html__( 'Off', 'crisop' )
            ),
            array(
                'id' =>'product_tabs_type',
                'type' => 'button_set',
                'title' => esc_html__( 'Tabs Type', 'crisop' ),
                'options' => array(
                    'tabs' => esc_html__( 'Default Tabs', 'crisop' ),
                    'accordion' => esc_html__( 'Accordion In Summary', 'crisop' ),
                    'accordion-2' => esc_html__( 'Accordion After Summary', 'crisop' )
                ),
                'default' => 'tabs',
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Description Tab', 'crisop' ),
                'customizer' => true,
                'id' => 'product_hide_description_tab',
                'type' => 'switch',
                'default' => 1,
                'on' => esc_html__( 'Show', 'crisop' ),
                'off' => esc_html__( 'Hide', 'crisop' ),
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Hide Reviews Tab', 'crisop' ),
                'customizer' => true,
                'id' => 'product_hide_reviews_tab',
                'type' => 'switch',
                'default' => 1,
                'on' => esc_html__( 'Show', 'crisop' ),
                'off' => esc_html__( 'Hide', 'crisop' ),
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Hide Additional Information Tab', 'crisop' ),
                'customizer' => true,
                'id' => 'product_hide_additional_tab',
                'type' => 'switch',
                'default' => 1,
                'on' => esc_html__( 'Show', 'crisop' ),
                'off' => esc_html__( 'Hide', 'crisop' ),
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Hide Q & A Tab', 'crisop' ),
                'customizer' => true,
                'id' => 'product_hide_crqna_tab',
                'type' => 'switch',
                'default' => 1,
                'on' => esc_html__( 'Show', 'crisop' ),
                'off' => esc_html__( 'Hide', 'crisop' ),
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Custom Order', 'crisop' ),
                'customizer' => true,
                'id' => 'product_tabs_custom_order',
                'type' => 'switch',
                'default' => 0,
                'on' => esc_html__( 'Yes', 'crisop' ),
                'off' => esc_html__( 'No', 'crisop' ),
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'id' =>'product_tabs_order',
                'type' => 'sorter',
                'title' => esc_html__( 'Tabs Layouts Manager', 'crisop' ),
                'options' => array(
                    'show' => array(
                        'description' => esc_html__( 'Description', 'crisop' ),
                        'additional_information' => esc_html__( 'Additional Information', 'crisop' ),
                        'reviews' => esc_html__( 'Reviews', 'crisop' ),
                        'cr_qna' => esc_html__( 'Q & A', 'crisop' )
                    ),
                    'hide' => array()
                ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_description_tab_title_visibility', '=', '1' )
                )
            ),
            array(
                'id' =>'product_tabs_active_tab',
                'type' => 'button_set',
                'title' => esc_html__( 'Active Tab', 'crisop' ),
                'options' => array(
                    '' => esc_html__( 'None', 'crisop' ),
                    'all' => esc_html__( 'All Tabs', 'crisop' ),
                    ':first-child' => esc_html__( '1. Tab', 'crisop' ),
                    ':nth-child(2)' => esc_html__( '2. Tab', 'crisop' ),
                    ':nth-child(3)' => esc_html__( '3. Tab', 'crisop' ),
                    ':nth-child(4)' => esc_html__( '4. Tab', 'crisop' ),
                    ':nth-child(5)' => esc_html__( '5. Tab', 'crisop' ),
                    ':nth-child(6)' => esc_html__( '6. Tab', 'crisop' )
                ),
                'default' => '',
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Description Tab Content Title', 'crisop'),
                'customizer' => true,
                'id' => 'product_description_tab_title_visibility',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'product_tabs_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Description Tab Content Title', 'crisop'),
                'customizer' => true,
                'id' => 'product_description_tab_title',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_description_tab_title_visibility', '=', '1' )
                )
            ),
            array(
                'id' => 'ninetheme_product_accordion_start',
                'type' => 'section',
                'title' => esc_html__('Accordion Color Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Title Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_accordion_titlecolor',
                'type' => 'color',
                'output' => array( '.ninetheme-accordion-header' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Title Color ( Active )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_accordion_active_titlecolor',
                'type' => 'color',
                'output' => array( '.ninetheme-accordion-item.active .ninetheme-accordion-header' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Title Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_accordion_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-accordion-item' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Title Background Color ( Active )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_accordion_active_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-accordion-item.active .ninetheme-accordion-header' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Content Text Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_accordion_textcolor',
                'type' => 'color',
                'output' => array( '.ninetheme-accordion-body,.ninetheme-product-showcase.ninetheme-bg-custom .product-desc-content h4,.ninetheme-product-showcase.ninetheme-bg-custom .product-desc-content .title' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Border Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_accordion_bordercolor',
                'type' => 'color',
                'mode' => 'border-color',
                'output' => array( '.ninetheme-accordion-item' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'id' => 'ninetheme_product_accordion_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '!=', 'tabs' )
                )
            ),
            array(
                'id' => 'ninetheme_product_tabs_start',
                'type' => 'section',
                'title' => esc_html__('Tabs Color Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Title Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_tabs_titlecolor',
                'type' => 'color',
                'output' => array( '.ninetheme-product-tab-title-item' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Title Color ( Active )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_tabs_active_titlecolor',
                'type' => 'color',
                'output' => array( '.ninetheme-product-tab-title-item.active' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Title Border Color ( Active )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_tabs_active_bordercolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-tab-title-item::after' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '=', 'tabs' )
                )
            ),
            array(
                'title' => esc_html__('Tabs Border Bottom Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_tabs_bordercolor',
                'type' => 'color',
                'mode' => 'border-bottom-color',
                'output' => array( '.ninetheme-product-tab-title' ),
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '=', 'tabs' )
                )
            ),
            array(
                'id' => 'ninetheme_product_tabs_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array(
                    array( 'product_tabs_visibility', '=', '1' ),
                    array( 'product_tabs_type', '=', 'tabs' )
                )
            )
        )
    ));
    // Product Size Guide Popup SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Custom Reviews Slider', 'crisop'),
        'id' => 'product_custom_reviews_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__( 'Custom Reviews Elementor Template', 'crisop' ),
                'subtitle' => esc_html__( 'Select an elementor template from list', 'crisop' ),
                'customizer' => true,
                'id' => 'product_custom_reviews_template',
                'type' => 'select',
                'data' => 'posts',
                'args' => $el_args
            ),
            array(
                'title' => esc_html__( 'Category(s) Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'Select category(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'product_custom_reviews_category_exclude',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_cat' ),
                ],
                'required' => array( 'product_custom_reviews_template', '!=', '' )
            ),
            array(
                'title' => esc_html__( 'Tag(s) Exclude', 'crisop' ),
                'subtitle' => esc_html__( 'Select category(s) from the list.', 'crisop' ),
                'customizer' => true,
                'id' => 'product_custom_reviews_tag_exclude',
                'type' => 'select',
                'data' => 'terms',
                'multi' => true,
                'args'  => [
                    'taxonomies' => array( 'product_tag' ),
                ],
                'required' => array( 'product_custom_reviews_template', '!=', '' )
            )
        )
    ));
    // Product Related Posts SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Related Posts', 'crisop'),
        'id' => 'product_related_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Related Section', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_ralated_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'id' =>'product_ralated_same_category',
                'type' => 'switch',
                'title' => esc_html__('Show Related in Same Category', 'crisop'),
                'customizer' => true,
                'type' => 'switch',
                'default' => 0
            ),
            array(
                'title' => esc_html__('Related Title', 'crisop'),
                'subtitle' => esc_html__('Add your single shop page related section title here.', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_related_title',
                'type' => 'text',
                'default' => '',
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Post Count ( Per Page )', 'crisop'),
                'subtitle' => esc_html__('You can control show related post count with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_related_count',
                'type' => 'slider',
                'default' => 10,
                'min' => 1,
                'step' => 1,
                'max' => 24,
                'display_value' => 'text',
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'id' => 'shop_related_section_slider_start',
                'type' => 'section',
                'title' => esc_html__('Related Slider Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 1024px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_perview',
                'type' => 'slider',
                'default' => 4,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 768px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_mdperview',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 480px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_smperview',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Speed', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_speed',
                'type' => 'slider',
                'default' => 1000,
                'min' => 100,
                'step' => 1,
                'max' => 10000,
                'display_value' => 'text',
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Gap', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_gap',
                'type' => 'slider',
                'default' => 30,
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Autoplay', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_autoplay',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Loop', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_loop',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Mousewheel', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_mousewheel',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Free Mode', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_related_freemode',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            ),
            array(
                'id' => 'shop_related_section_slider_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array( 'single_shop_ralated_visibility', '=', '1' )
            )
        )
    ));
    // Upsells Products
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Upsells Products', 'crisop'),
        'id' => 'product_upsells_subsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Upsells Title', 'crisop'),
                'subtitle' => esc_html__('Add your single shop page upsells section title here.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_upsells_title',
                'type' => 'text',
                'default' => ''
            ),
            array(
                'id' =>'shop_upsells_type',
                'type' => 'button_set',
                'title' => esc_html__('Upsells Layout Type', 'crisop'),
                'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme shop product page upsells.', 'crisop' ),
                'customizer' => true,
                'options' => array(
                    'slider' => esc_html__( 'Slider', 'crisop' ),
                    'grid' => esc_html__( 'Grid', 'crisop' )
                ),
                'default' => 'slider'
            ),
            array(
                'title' => esc_html__('Column', 'crisop'),
                'subtitle' => esc_html__('You can control upsells post column with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_upsells_colxl',
                'type' => 'slider',
                'default' => 4,
                'min' => 1,
                'step' => 1,
                'max' => 6,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'grid' )
            ),
            array(
                'title' => esc_html__('Column ( Desktop/Tablet )', 'crisop'),
                'subtitle' => esc_html__('You can control upsells post column for tablet device with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_upsells_collg',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 4,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'grid' )
            ),
            array(
                'title' => esc_html__('Column ( Tablet )', 'crisop'),
                'subtitle' => esc_html__('You can control upsells post column for phone device with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_upsells_colsm',
                'type' => 'slider',
                'default' => 1,
                'min' => 1,
                'step' => 1,
                'max' => 3,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'grid' )
            ),
            array(
                'title' => esc_html__('Column ( Phone )', 'crisop'),
                'subtitle' => esc_html__('You can control upsells post column for phone device with this option.', 'crisop'),
                'customizer' => true,
                'id' => 'shop_upsells_colxs',
                'type' => 'slider',
                'default' => 1,
                'min' => 1,
                'step' => 1,
                'max' => 3,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'grid' )
            ),
            array(
                'id' => 'shop_upsells_section_slider_start',
                'type' => 'section',
                'title' => esc_html__('Upsells Slider Options', 'crisop'),
                'customizer' => true,
                'indent' => true,
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 1024px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_perview',
                'type' => 'slider',
                'default' => 4,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 768px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_mdperview',
                'type' => 'slider',
                'default' => 3,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Perview ( Min 480px )', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_smperview',
                'type' => 'slider',
                'default' => 2,
                'min' => 1,
                'step' => 1,
                'max' => 10,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Speed', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_speed',
                'type' => 'slider',
                'default' => 1000,
                'min' => 100,
                'step' => 1,
                'max' => 10000,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Gap', 'crisop' ),
                'subtitle' => esc_html__( 'You can control related post slider item gap.', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_gap',
                'type' => 'slider',
                'default' => 30,
                'min' => 0,
                'step' => 1,
                'max' => 100,
                'display_value' => 'text',
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Autoplay', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_autoplay',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Loop', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_loop',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Mousewheel', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_mousewheel',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'title' => esc_html__( 'Free Mode', 'crisop' ),
                'customizer' => true,
                'id' => 'shop_upsells_freemode',
                'type' => 'switch',
                'default' => 0,
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            ),
            array(
                'id' => 'shop_upsells_section_slider_end',
                'type' => 'section',
                'customizer' => true,
                'indent' => false,
                'required' => array( 'shop_upsells_type', '=', 'slider' )
            )
        )
    ));
    // Product Share Buttons SUBSECTION
    Redux::setSection($ninetheme_pre, array(
        'title' => esc_html__('Share Buttons', 'crisop'),
        'id' => 'singleshopsharesubsection',
        'subsection' => true,
        'icon' => 'el el-cog',
        'fields' => array(
            array(
                'title' => esc_html__('Products share', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_visibility',
                'type' => 'switch',
                'default' => 1
            ),
            array(
                'title' => esc_html__( 'Share type', 'crisop' ),
                'subtitle' => esc_html__( 'Select your product share type.', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_share_type',
                'type' => 'select',
                'multiple' => false,
                'options' => array(
                    'share' => esc_html__( 'Share', 'crisop' ),
                    'follow' => esc_html__( 'follow', 'crisop' )
                ),
                'default' => 'share',
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Color type', 'crisop' ),
                'subtitle' => esc_html__( 'Select your product share type.', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_share_color_type',
                'type' => 'select',
                'multiple' => false,
                'options' => array(
                    'official' => esc_html__( 'Official', 'crisop' ),
                    'custom' => esc_html__( 'Custom', 'crisop' )
                ),
                'default' => 'official',
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__( 'Shape type', 'crisop' ),
                'subtitle' => esc_html__( 'Select your product share type.', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_share_shape_type',
                'type' => 'select',
                'multiple' => false,
                'options' => array(
                    'square' => esc_html__( 'Square', 'crisop' ),
                    'circle' => esc_html__( 'Circle', 'crisop' ),
                    'round' => esc_html__( 'Round', 'crisop' ),
                ),
                'default' => 'circle',
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Share Label Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_label_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons span.share-title' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__( 'Size', 'crisop' ),
                'customizer' => true,
                'id' => 'single_shop_share_size',
                'type' => 'dimensions',
                'output' => array('.ninetheme-product-summary .ninetheme-social-icons a'),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons a' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Background Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_hvrbgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons a' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons a' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Color ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_hvrcolor',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons a:hover' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Border', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_brd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-product-summary .ninetheme-social-icons a'),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Border ( Hover )', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_hvrbrd',
                'type' => 'border',
                'all' => true,
                'output' => array('.ninetheme-product-summary .ninetheme-social-icons a:hover'),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Hint Background Color', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_hint_bgcolor',
                'type' => 'color',
                'mode' => 'background-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons a:after' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Hint Arrow Color ', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_hint_arrow_color',
                'type' => 'color',
                'mode' => 'border-top-color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons a:before' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Hint Text Color ', 'crisop'),
                'customizer' => true,
                'id' => 'single_shop_share_hint_text_color',
                'type' => 'color',
                'output' => array( '.ninetheme-product-summary .ninetheme-social-icons a:after' ),
                'required' => array( 'single_shop_share_color_type', '=', 'custom' )
            ),
            array(
                'title' => esc_html__('Facebook', 'crisop'),
                'customizer' => true,
                'id' => 'share_facebook',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Facebook', 'crisop'),
                'customizer' => true,
                'id' => 'share_facebook',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Facebook link', 'crisop'),
                'customizer' => true,
                'id' => 'facebook_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_facebook', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__('Twitter', 'crisop'),
                'customizer' => true,
                'id' => 'share_twitter',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Twitter link', 'crisop'),
                'customizer' => true,
                'id' => 'twitter_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_twitter', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__('Instagram', 'crisop'),
                'customizer' => true,
                'id' => 'share_instagram',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Instagram link', 'crisop'),
                'customizer' => true,
                'id' => 'instagram_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_instagram', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Youtube', 'crisop'),
                'customizer' => true,
                'id' => 'share_youtube',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Youtube link', 'crisop'),
                'customizer' => true,
                'id' => 'youtube_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_youtube', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Vimeo', 'crisop'),
                'customizer' => true,
                'id' => 'share_vimeo',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Vimeo link', 'crisop'),
                'customizer' => true,
                'id' => 'vimeo_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_vimeo', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Pinterest', 'crisop'),
                'customizer' => true,
                'id' => 'share_pinterest',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Pinterest link', 'crisop'),
                'customizer' => true,
                'id' => 'pinterest_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_pinterest', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Linkedin', 'crisop'),
                'customizer' => true,
                'id' => 'share_linkedin',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Linkedin link', 'crisop'),
                'customizer' => true,
                'id' => 'linkedin_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_linkedin', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Tumblr', 'crisop'),
                'customizer' => true,
                'id' => 'share_tumblr',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Tumblr link', 'crisop'),
                'customizer' => true,
                'id' => 'tumblr_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_tumblr', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Flickr', 'crisop'),
                'customizer' => true,
                'id' => 'share_flickr',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Flickr link', 'crisop'),
                'customizer' => true,
                'id' => 'flickr_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_flickr', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Github', 'crisop'),
                'customizer' => true,
                'id' => 'share_github',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Github link', 'crisop'),
                'customizer' => true,
                'id' => 'github_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_github', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Behance', 'crisop'),
                'customizer' => true,
                'id' => 'share_behance',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Behance link', 'crisop'),
                'customizer' => true,
                'id' => 'behance_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_behance', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Dribbble', 'crisop'),
                'customizer' => true,
                'id' => 'share_dribbble',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Dribbble link', 'crisop'),
                'customizer' => true,
                'id' => 'dribbble_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_dribbble', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Soundcloud', 'crisop'),
                'customizer' => true,
                'id' => 'share_soundcloud',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Soundcloud link', 'crisop'),
                'customizer' => true,
                'id' => 'soundcloud_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_soundcloud', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Spotify', 'crisop'),
                'customizer' => true,
                'id' => 'share_spotify',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Spotify link', 'crisop'),
                'customizer' => true,
                'id' => 'spotify_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_spotify', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Ok', 'crisop'),
                'customizer' => true,
                'id' => 'share_ok',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Ok link', 'crisop'),
                'customizer' => true,
                'id' => 'ok_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_ok', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Whatsapp', 'crisop'),
                'customizer' => true,
                'id' => 'share_whatsapp',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Whatsapp link', 'crisop'),
                'customizer' => true,
                'id' => 'whatsapp_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_whatsapp', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Telegram', 'crisop'),
                'customizer' => true,
                'id' => 'share_telegram',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' )
            ),
            array(
                'title' => esc_html__('Telegram link', 'crisop'),
                'customizer' => true,
                'id' => 'telegram_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_telegram', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Viber', 'crisop'),
                'customizer' => true,
                'id' => 'share_viber',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'share' )
                )
            ),
            array(
                'title' => esc_html__('Viber link', 'crisop'),
                'customizer' => true,
                'id' => 'viber_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'share' ),
                    array( 'share_viber', '=', '1' )
                )
            ),
            array(
                'title' => esc_html__('Tiktok', 'crisop'),
                'customizer' => true,
                'id' => 'share_tiktok',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Tiktok link', 'crisop'),
                'customizer' => true,
                'id' => 'tiktok_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_tiktok', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Snapchat', 'crisop'),
                'customizer' => true,
                'id' => 'share_snapchat',
                'type' => 'switch',
                'default' => 1,
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' )
                )
            ),
            array(
                'title' => esc_html__('Snapchat link', 'crisop'),
                'customizer' => true,
                'id' => 'snapchat_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'single_shop_share_type', '=', 'follow' ),
                    array( 'share_snapchat', '=', '1' ),
                )
            ),
            array(
                'title' => esc_html__('Vk', 'crisop'),
                'customizer' => true,
                'id' => 'share_vk',
                'type' => 'switch',
                'default' => 1,
                'required' => array( 'single_shop_share_visibility', '=', '1' ),
            ),
            array(
                'title' => esc_html__('Vk link', 'crisop'),
                'customizer' => true,
                'id' => 'vk_link',
                'type' => 'text',
                'default' => '',
                'required' => array(
                    array( 'single_shop_share_visibility', '=', '1' ),
                    array( 'share_vk', '=', '1' ),
                )
            )
        )
    ));
}
/*************************************************
## DEFAULT PAGE SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Default Page', 'crisop' ),
    'id' => 'defaultpagesection',
    'icon' => 'el el-home',
));
// BLOG HERO SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Default Page Hero', 'crisop' ),
    'desc' => esc_html__( 'These are default page hero settings!', 'crisop' ),
    'id' => 'pageherosubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Page Hero Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site default page hero section with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'page_hero_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Page Hero Background', 'crisop' ),
            'customizer' => true,
            'id' => 'page_hero_bg',
            'type' => 'background',
            'preview' => true,
            'preview_media' => true,
            'output' => array( '#nt-page-container .ninetheme-page-hero' ),
            'required' => array( 'blog_hero_visibility', '=', '1' )
        )
    )
));
/*************************************************
## BLOG PAGE SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Blog Posts Page', 'crisop' ),
    'id' => 'blogsection',
    'icon' => 'el el-home',
));
// BLOG HERO SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Blog Hero', 'crisop' ),
    'desc' => esc_html__( 'These are blog index page hero text settings!', 'crisop' ),
    'id' => 'blogherosubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Blog Hero Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site blog index page hero section with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'blog_hero_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Blog Hero Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates instead of default template.', 'crisop' ),
            'customizer' => true,
            'id' => 'blog_hero_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args
        ),
        array(
            'id' =>'edit_blog_hero_elementor_template',
            'type' => 'info',
            'desc' => 'Select template',
            'required' => array(
                array( 'blog_hero_visibility', '=', '1' ),
                array( 'blog_hero_templates', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Blog Hero Background', 'crisop' ),
            'customizer' => true,
            'id' => 'blog_hero_bg',
            'type' => 'background',
            'preview' => true,
            'preview_media' => true,
            'output' => array( '#nt-index .ninetheme-page-hero' ),
            'required' => array(
                array( 'blog_hero_visibility', '=', '1' ),
                array( 'blog_hero_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Blog Title', 'crisop' ),
            'subtitle' => esc_html__( 'Add your blog index page title here.', 'crisop' ),
            'customizer' => true,
            'id' => 'blog_title',
            'type' => 'text',
            'default' => '',
            'required' => array(
                array( 'blog_hero_visibility', '=', '1' ),
                array( 'blog_hero_templates', '=', '' )
            )
        ),
    )
));
// BLOG LAYOUT AND POST COLUMN STYLE
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Blog Layout', 'crisop' ),
    'id' => 'bloglayoutsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Blog Page Layout', 'crisop' ),
            'subtitle' => esc_html__( 'Choose the blog index page layout.', 'crisop' ),
            'customizer' => true,
            'id' => 'index_layout',
            'type' => 'image_select',
            'options' => array(
                'left-sidebar' => array(
                    'alt' => 'Left Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cl.png'
                ),
                'full-width' => array(
                    'alt' => 'Full Width',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/1col.png'
                ),
                'right-sidebar' => array(
                    'alt' => 'Right Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cr.png'
                )
            ),
            'default' => 'right-sidebar'
        ),
        array(
            'title' => esc_html__( 'Blog Sidebar Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'You can use elementor templates instead of default sidebar if you want.Select a template from elementor templates.', 'crisop' ),
            'customizer' => true,
            'id' => 'blog_sidebar_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array( 'index_layout', '!=', 'full-width' )
        ),
        array(
            'id' =>'edit_sidebar_elementor_template',
            'type' => 'info',
            'desc' => 'Select template',
            'required' => array(
                array( 'index_layout', '!=', 'full-width' ),
                array( 'blog_sidebar_templates', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Container Width', 'crisop' ),
            'subtitle' => esc_html__( 'Select blog page container width type.', 'crisop' ),
            'customizer' => true,
            'id' => 'index_container_type',
            'type' => 'select',
            'options' => array(
                '' => esc_html__( 'Select type', 'crisop' ),
                'container' => esc_html__( 'Default Boxed', 'crisop' ),
                'container-fluid' => esc_html__( 'Fluid', 'crisop' )
            ),
            'default' => 'container'
        )
    )
));
// BLOG LAYOUT AND POST COLUMN STYLE
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Blog Post', 'crisop' ),
    'id' => 'blogpostsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Layout Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select blog page layout type.', 'crisop' ),
            'customizer' => true,
            'id' => 'index_type',
            'type' => 'select',
            'options' => array(
                'grid' => esc_html__( 'grid', 'crisop' ),
                'masonry' => esc_html__( 'masonry', 'crisop' )
            ),
            'default' => 'masonry'
        ),
        array(
            'title' => esc_html__( 'Post Style', 'crisop' ),
            'subtitle' => esc_html__( 'Select blog page post style type.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_style',
            'type' => 'select',
            'options' => array(
                'classic' => esc_html__( 'Classic', 'crisop' ),
                'card' => esc_html__( 'Card', 'crisop' ),
                'split' => esc_html__( 'Split', 'crisop' )
            ),
            'default' => 'classic'
        ),
        array(
            'title' => esc_html__( 'Post Image Size Style', 'crisop' ),
            'subtitle' => esc_html__( 'Select blog page post image size style type.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_image_style',
            'type' => 'select',
            'options' => array(
                'default' => esc_html__( 'Default', 'crisop' ),
                'fit' => esc_html__( 'Fit', 'crisop' ),
                'split' => esc_html__( 'Split', 'crisop' )
            ),
            'default' => 'default'
        ),
        array(
            'title' => esc_html__( 'Post Overlay Color', 'crisop' ),
            'customizer' => true,
            'id' => 'post_card_style_overlay_color',
            'type' => 'color_rgba',
            'mode' => 'background-color',
            'output' => array( '.ninetheme-blog-posts-item.style-card .ninetheme-blog-post-item-inner:before' ),
            'required' => array( 'post_style', '=', 'card' )
        ),
        array(
            'title' => esc_html__( 'Post Min Height', 'crisop' ),
            'subtitle' => esc_html__( 'Set the logo width and height of the image.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_card_style_height',
            'type' => 'dimensions',
            'width' => false,
            'output' => array('.ninetheme-blog-posts-item.style-card .ninetheme-blog-post-item-inner' ),
            'required' => array( 'post_style', '=', 'card' )
        ),
        array(
            'title' => esc_html__( 'Column Width', 'crisop' ),
            'subtitle' => esc_html__( 'Select a column width.', 'crisop' ),
            'customizer' => true,
            'id' => 'grid_column',
            'type' => 'select',
            'options' => array(
                '1' => esc_html__( '1 column', 'crisop' ),
                '2' => esc_html__( '2 column', 'crisop' ),
                '3' => esc_html__( '3 column', 'crisop' ),
                '4' => esc_html__( '4 column', 'crisop' )
            ),
            'default' => '3'
        ),
        array(
            'title' => esc_html__( 'Mobile Column Width', 'crisop' ),
            'subtitle' => esc_html__( 'Select a column width for mobile device.', 'crisop' ),
            'customizer' => true,
            'id' => 'grid_mobile_column',
            'type' => 'select',
            'options' => array(
                '1' => esc_html__( '1 column', 'crisop' ),
                '2' => esc_html__( '2 column', 'crisop' ),
                '3' => esc_html__( '3 column', 'crisop' )
            ),
            'default' => '1'
        ),
        array(
            'title' => esc_html__( 'Post Image Size', 'crisop' ),
            'customizer' => true,
            'id' => 'post_imgsize',
            'type' => 'select',
            'data' => 'image_sizes'
        ),
        array(
            'title' => esc_html__( 'Custom Post Image Size', 'crisop' ),
            'customizer' => true,
            'id' => 'post_custom_imgsize',
            'unit' => false,
            'type' => 'dimensions'
        ),
        array(
            'title' => esc_html__( 'Post Title Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site blog index page post title with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_title_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Post Title Max Line', 'crisop' ),
            'subtitle' => esc_html__( 'Limit text length to n lines.Please use number', 'crisop' ),
            'customizer' => true,
            'id' => 'post_title_max_line',
            'type' => 'text',
            'default' => '',
            'validate' => array('numeric'),
            'required' => array('post_title_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Title Tag ( for SEO )', 'crisop' ),
            'customizer' => true,
            'id' => 'post_title_tag',
            'type' => 'select',
            'options' => array(
                'h1' => esc_html__( 'H1', 'crisop' ),
                'h2' => esc_html__( 'H2', 'crisop' ),
                'h3' => esc_html__( 'H3', 'crisop' ),
                'h4' => esc_html__( 'H4', 'crisop' ),
                'h5' => esc_html__( 'H5', 'crisop' ),
                'h6' => esc_html__( 'H6', 'crisop' ),
                'p' => esc_html__( 'p', 'crisop' ),
                'div' => esc_html__( 'div', 'crisop' ),
                'span' => esc_html__( 'span', 'crisop' )
            ),
            'default' => 'h6',
            'required' => array('post_title_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Title Typography', 'crisop' ),
            'id' => 'post_title_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.ninetheme-blog-post-content .ninetheme-post-title' ),
            'required' => array('single_post_title_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Excerpt Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site blog index page post meta with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_excerpt_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Excerpt Typography', 'crisop' ),
            'id' => 'post_excerpt_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.ninetheme-blog-post-content .ninetheme-post-excerpt' ),
            'required' => array('post_excerpt_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Post Excerpt Max Line', 'crisop' ),
            'subtitle' => esc_html__( 'Limit text length to n lines.Please use number', 'crisop' ),
            'customizer' => true,
            'id' => 'post_excerpt_max_line',
            'type' => 'text',
            'default' => '',
            'validate' => array('numeric'),
            'required' => array('post_excerpt_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Excerpt Size (max word count)', 'crisop' ),
            'subtitle' => esc_html__( 'You can control blog post excerpt size with this option.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_excerpt_limit',
            'type' => 'slider',
            'default' => 30,
            'min' => 0,
            'step' => 1,
            'max' => 100,
            'display_value' => 'text',
            'required' => array( 'post_excerpt_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Button Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site blog index page post read more button with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_button_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Read More Button Title', 'crisop' ),
            'subtitle' => esc_html__( 'Add your blog post read more button title here.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_button_title',
            'type' => 'text',
            'default' => '',
            'required' => array( 'post_button_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Read More Button Typography', 'crisop' ),
            'id' => 'post_button_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.ninetheme-blog-post-content .blog-read-more-link' ),
            'required' => array('post_button_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__('Post Meta Color ( Hover )', 'crisop'),
            'customizer' => true,
            'id' => 'post_button_hvrcolor',
            'type' => 'color',
            'default' => '',
            'output' => array( '.ninetheme-blog-post-content .blog-read-more-link:hover' ),
            'required' => array('post_button_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Post Meta Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site blog index page post meta with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'post_meta_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Post Meta Typography', 'crisop' ),
            'id' => 'post_meta_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.ninetheme-blog-post-meta.ninetheme-inline-two-block .ninetheme-post-meta-title.ninetheme-block-left a, .ninetheme-blog-post-meta.ninetheme-inline-two-block .ninetheme-post-meta-date.ninetheme-block-right a' ),
            'required' => array('post_meta_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__('Post Meta Color ( Hover )', 'crisop'),
            'customizer' => true,
            'id' => 'post_meta_hvrcolor',
            'type' => 'color',
            'default' => '',
            'output' => array( '.ninetheme-blog-post-meta.ninetheme-inline-two-block .ninetheme-post-meta-title.ninetheme-block-left a:hover, .ninetheme-blog-post-meta.ninetheme-inline-two-block .ninetheme-post-meta-date.ninetheme-block-right a:hover' ),
            'required' => array('post_meta_visibility', '=', '1' )
        )
    )
));

/*************************************************
## SINGLE PAGE SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Single Post Page', 'crisop' ),
    'id' => 'singlesection',
    'icon' => 'el el-home-alt',
));
// SINGLE HERO SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Single Hero', 'crisop' ),
    'desc' => esc_html__( 'These are single page hero section settings!', 'crisop' ),
    'id' => 'singleherosubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Single Hero Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page hero section with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_hero_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates instead of default template.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_hero_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array( 'single_hero_visibility', '=', '1' )
        ),
        array(
            'id' =>'edit_single_hero_template',
            'type' => 'info',
            'desc' => 'Select template',
            'required' => array(
                array( 'single_hero_visibility', '=', '1' ),
                array( 'single_hero_elementor_templates', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Single Hero Background', 'crisop' ),
            'customizer' => true,
            'id' => 'single_hero_bg',
            'type' => 'background',
            'output' => array( '#nt-single .ninetheme-page-hero' ),
            'required' => array(
                array( 'single_hero_visibility', '=', '1' ),
                array( 'single_hero_elementor_templates', '=', '' )
            )
        )
    )
));
// SINGLE CONTENT SUBSECTION
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Single Content', 'crisop' ),
    'id' => 'singlecontentsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Post Page Layout', 'crisop' ),
            'subtitle' => esc_html__( 'Choose the single post page layout.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_layout',
            'type' => 'image_select',
            'options' => array(
                'left-sidebar' => array(
                    'alt' => 'Left Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cl.png'
                ),
                'full-width' => array(
                    'alt' => 'Full Width',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/1col.png'
                ),
                'right-sidebar' => array(
                    'alt' => 'Right Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cr.png'
                )
            ),
            'default' => 'full-width'
        ),
        array(
            'title' => esc_html__('Column Width', 'crisop'),
            'customizer' => true,
            'id' => 'single_content_column',
            'type' => 'spinner',
            'default' => '9',
            'min' => '5',
            'step' => '1',
            'max' => '12',
            'required' => array('single_layout', '=', 'full-width' )
        ),
        array(
            'id' =>'single_content_layouts_type',
            'type' => 'button_set',
            'title' => esc_html__( 'Post Layouts', 'crisop' ),
            'customizer' => true,
            'options' => array(
                'default' => esc_html__( 'Default', 'crisop' ),
                'custom' => esc_html__( 'Custom Layout', 'crisop' )
            ),
            'default' => 'default'
        ),
        array(
            'id' =>'single_content_layouts',
            'type' => 'sorter',
            'title' => esc_html__( 'Content Layouts Manager', 'crisop' ),
            'subtitle' => esc_html__( 'Organize how you want the layout to appear on the theme single post page.', 'crisop' ),
            'options' => array(
                'show'  => array(
                    'thumbnail' => esc_html__( 'Thumbnail Image', 'crisop' ),
                    'title' => esc_html__( 'Post title', 'crisop' ),
                    'meta' => esc_html__( 'Post Meta', 'crisop' ),
                    'content' => esc_html__( 'Post Content', 'crisop' ),
                    'meta-bottom' => esc_html__( 'Post Meta Bottom', 'crisop' ),
                ),
                'hide'  => array()
            ),
            'required' => array('single_content_layouts_type', '=', 'custom' )
        ),
        array(
            'title' => esc_html__( 'Post Thumbnail Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post thumbnail with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_post_thumb_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Post Image Size', 'crisop' ),
            'customizer' => true,
            'id' => 'single_post_thumb_size',
            'type' => 'select',
            'data' => 'image_sizes',
            'required' => array('single_post_thumb_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Post Title Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post title with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_post_title_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Title Tag ( for SEO )', 'crisop' ),
            'customizer' => true,
            'id' => 'single_post_title_tag',
            'type' => 'select',
            'options' => array(
                'h1' => esc_html__( 'H1', 'crisop' ),
                'h2' => esc_html__( 'H2', 'crisop' ),
                'h3' => esc_html__( 'H3', 'crisop' ),
                'h4' => esc_html__( 'H4', 'crisop' ),
                'h5' => esc_html__( 'H5', 'crisop' ),
                'h6' => esc_html__( 'H6', 'crisop' ),
                'p' => esc_html__( 'p', 'crisop' ),
                'div' => esc_html__( 'div', 'crisop' ),
                'span' => esc_html__( 'span', 'crisop' )
            ),
            'default' => 'h2',
            'required' => array('single_post_title_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Typography', 'crisop' ),
            'id' => 'single_post_title_typo',
            'type' => 'typography',
            'font-backup' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'text-decoration' => true,
            'all_styles' => true,
            'output' => array( '.ninetheme-blog-details-area .ninetheme-blog-post-details .ninetheme-content .ninetheme-post-title' ),
            'required' => array('single_post_title_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Author Name Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post date with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_postmeta_author_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Date Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post date number with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_postmeta_date_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Categories Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post meta tags with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_postmeta_category_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Tags Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post meta tags with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_postmeta_tags_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Authorbox Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post authorbox with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_post_author_box_visibility',
            'type' => 'switch',
            'default' => 0,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Post Pagination Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page post next and prev pagination with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_navigation_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Post Comments Template Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page comments template with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_comments_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        )
    )
));
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Single Related Posts', 'crisop' ),
    'id' => 'singlerelatedsubsection',
    'subsection' => true,
    'icon' => 'el el-cog',
    'fields' => array(
        array(
            'title' => esc_html__( 'Related Post Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site single page related post with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_related_visibility',
            'type' => 'switch',
            'default' => 0,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates instead of default related post template.', 'crisop' ),
            'customizer' => true,
            'id' => 'single_related_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array( 'single_related_visibility', '=', '1' )
        ),
        array(
            'title' => esc_html__( 'Post Style', 'crisop' ),
            'subtitle' => esc_html__( 'Select single page related post style type.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_post_style',
            'type' => 'select',
            'options' => array(
                '' => esc_html__( 'Select style', 'crisop' ),
                'classic' => esc_html__( 'Classic', 'crisop' ),
                'card' => esc_html__( 'Card', 'crisop' ),
                'split' => esc_html__( 'Split', 'crisop' )
            ),
            'default' => 'classic',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'id' => 'related_section_heading_start',
            'type' => 'section',
            'title' => esc_html__('Related Section Heading', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Related Section Subtitle', 'crisop' ),
            'subtitle' => esc_html__( 'Add your single page related post section subtitle here.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_subtitle',
            'type' => 'text',
            'default' => '',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Subtitle Tag', 'crisop' ),
            'customizer' => true,
            'id' => 'related_subtitle_tag',
            'type' => 'select',
            'options' => array(
                '' => esc_html__( 'Select type', 'crisop' ),
                'h1' => esc_html__( 'H1', 'crisop' ),
                'h2' => esc_html__( 'H2', 'crisop' ),
                'h3' => esc_html__( 'H3', 'crisop' ),
                'h4' => esc_html__( 'H4', 'crisop' ),
                'h5' => esc_html__( 'H5', 'crisop' ),
                'h6' => esc_html__( 'H6', 'crisop' ),
                'p' => esc_html__( 'p', 'crisop' ),
                'div' => esc_html__( 'div', 'crisop' ),
                'span' => esc_html__( 'span', 'crisop' )
            ),
            'default' => 'p',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' ),
                array( 'related_subtitle', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Related Section Title', 'crisop' ),
            'subtitle' => esc_html__( 'Add your single page related post section title here.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_title',
            'type' => 'text',
            'default' => esc_html__( 'Related Post', 'crisop' ),
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Title Tag', 'crisop' ),
            'customizer' => true,
            'id' => 'related_title_tag',
            'type' => 'select',
            'options' => array(
                '' => esc_html__( 'Select type', 'crisop' ),
                'h1' => esc_html__( 'H1', 'crisop' ),
                'h2' => esc_html__( 'H2', 'crisop' ),
                'h3' => esc_html__( 'H3', 'crisop' ),
                'h4' => esc_html__( 'H4', 'crisop' ),
                'h5' => esc_html__( 'H5', 'crisop' ),
                'h6' => esc_html__( 'H6', 'crisop' ),
                'p' => esc_html__( 'p', 'crisop' ),
                'div' => esc_html__( 'div', 'crisop' ),
                'span' => esc_html__( 'span', 'crisop' )
            ),
            'default' => 'h3',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' ),
                array( 'related_title', '!=', '' )
            )
        ),
        array(
            'id' => 'related_section_heading_end',
            'customizer' => true,
            'type' => 'section',
            'indent' => false,
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'id' => 'related_section_posts_start',
            'type' => 'section',
            'title' => esc_html__('Related Post Options', 'crisop'),
            'customizer' => true,
            'indent' => true
        ),
        array(
            'title' => esc_html__( 'Posts Perpage', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post count with this option.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_perpage',
            'type' => 'slider',
            'default' => 3,
            'min' => 1,
            'step' => 1,
            'max' => 24,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Post Image Size', 'crisop' ),
            'customizer' => true,
            'id' => 'related_imgsize',
            'type' => 'select',
            'data' => 'image_sizes',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Post Excerpt Display', 'crisop' ),
            'id' => 'related_excerpt_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Post Excerpt Limit', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post excerpt word limit.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_excerpt_limit',
            'type' => 'slider',
            'default' => 30,
            'min' => 0,
            'step' => 1,
            'max' => 100,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' ),
                array( 'related_excerpt_visibility', '=', '1' )
            )
        ),
        array(
            'id' => 'related_section_posts_end',
            'customizer' => true,
            'type' => 'section',
            'indent' => false,
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'id' => 'related_section_slider_start',
            'type' => 'section',
            'title' => esc_html__('Related Slider Options', 'crisop'),
            'customizer' => true,
            'indent' => true,
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Perview ( Min 1200px )', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_perview',
            'type' => 'slider',
            'default' => 5,
            'min' => 1,
            'step' => 1,
            'max' => 10,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Slider Perview ( Min 992px )', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_mdperview',
            'type' => 'slider',
            'default' => 3,
            'min' => 1,
            'step' => 1,
            'max' => 10,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Perview ( Min 768px )', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_smperview',
            'type' => 'slider',
            'default' => 3,
            'min' => 1,
            'step' => 1,
            'max' => 10,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Perview ( Min 480px )', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post slider item count for big device with this option.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_xsperview',
            'type' => 'slider',
            'default' => 2,
            'min' => 1,
            'step' => 1,
            'max' => 10,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Speed', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post slider item gap.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_speed',
            'type' => 'slider',
            'default' => 1000,
            'min' => 100,
            'step' => 1,
            'max' => 10000,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Gap', 'crisop' ),
            'subtitle' => esc_html__( 'You can control related post slider item gap.', 'crisop' ),
            'customizer' => true,
            'id' => 'related_gap',
            'type' => 'slider',
            'default' => 30,
            'min' => 0,
            'step' => 1,
            'max' => 100,
            'display_value' => 'text',
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Autoplay', 'crisop' ),
            'customizer' => true,
            'id' => 'related_autoplay',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'title' => esc_html__( 'Loop', 'crisop' ),
            'customizer' => true,
            'id' => 'related_loop',
            'type' => 'switch',
            'default' => 0,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        ),
        array(
            'id' => 'related_section_slider_end',
            'customizer' => true,
            'type' => 'section',
            'indent' => false,
            'required' => array(
                array( 'single_related_visibility', '=', '1' ),
                array( 'single_related_elementor_templates', '=', '' )
            )
        )
    )
));
/*************************************************
## ARCHIVE PAGE SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Archive Page', 'crisop' ),
    'id' => 'archivesection',
    'icon' => 'el el-folder-open',
    'fields' => array(
        array(
            'title' => esc_html__( 'Archive Page Layout', 'crisop' ),
            'subtitle' => esc_html__( 'Choose the archive page layout.', 'crisop' ),
            'customizer' => true,
            'id' => 'archive_layout',
            'type' => 'image_select',
            'options' => array(
                'left-sidebar' => array(
                    'alt' => 'Left Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cl.png'
                ),
                'full-width' => array(
                    'alt' => 'Full Width',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/1col.png'
                ),
                'right-sidebar' => array(
                    'alt' => 'Right Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cr.png'
                )
            ),
            'default' => 'full-width'
        ),
        array(
            'title' => esc_html__( 'Archive Hero Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site archive page hero section with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'archive_hero_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Archive Hero Background', 'crisop' ),
            'customizer' => true,
            'id' => 'archive_hero_bg',
            'type' => 'background',
            'output' => array( '#nt-archive .ninetheme-page-hero' ),
            'required' => array( 'archive_hero_visibility', '=', '1' ),
        ),
        array(
            'title' => esc_html__( 'Custom Archive Title', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom archive page title here.', 'crisop' ),
            'customizer' => true,
            'id' => 'archive_title',
            'type' => 'text',
            'default' =>'',
            'required' => array( 'archive_hero_visibility', '=', '1' ),
        )
    )
));
/*************************************************
## SEARCH PAGE SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( 'Search Page', 'crisop' ),
    'id' => 'searchsection',
    'icon' => 'el el-search',
    'fields' => array(
        array(
            'title' => esc_html__( 'Search Page Layout', 'crisop' ),
            'subtitle' => esc_html__( 'Choose the search page layout.', 'crisop' ),
            'customizer' => true,
            'id' => 'search_layout',
            'type' => 'image_select',
            'options' => array(
                'left-sidebar' => array(
                    'alt' => 'Left Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cl.png'
                ),
                'full-width' => array(
                    'alt' => 'Full Width',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/1col.png'
                ),
                'right-sidebar' => array(
                    'alt' => 'Right Sidebar',
                    'img' => get_template_directory_uri() . '/inc/core/theme-options/img/2cr.png'
                )
            ),
            'default' => 'full-width'
        ),
        array(
            'title' => esc_html__( 'Search Hero Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site search page hero section with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'search_hero_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' )
        ),
        array(
            'title' => esc_html__( 'Search Hero Background', 'crisop' ),
            'customizer' => true,
            'id' =>'search_hero_bg',
            'type' => 'background',
            'output' => array( '#nt-search .ninetheme-page-hero' ),
            'required' => array( 'search_hero_visibility', '=', '1' )
        )
    )
));
/*************************************************
## 404 PAGE SECTION
*************************************************/
Redux::setSection($ninetheme_pre, array(
    'title' => esc_html__( '404 Page', 'crisop' ),
    'id' => 'errorsection',
    'icon' => 'el el-error',
    'fields' => array(
        array(
            'title' => esc_html__( '404 Type', 'crisop' ),
            'subtitle' => esc_html__( 'Select your 404 page type.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_page_type',
            'type' => 'select',
            'options' => array(
                'default' => esc_html__( 'Deafult', 'crisop' ),
                'elementor' => esc_html__( 'Elementor Templates', 'crisop' )
            ),
            'default' => 'default'
        ),
        array(
            'title' => esc_html__( 'Elementor Templates', 'crisop' ),
            'subtitle' => esc_html__( 'Select a template from elementor templates.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_page_elementor_templates',
            'type' => 'select',
            'data' => 'posts',
            'args'  => $el_args,
            'required' => array( 'error_page_type', '=', 'elementor' )
        ),
        array(
            'id' =>'edit_error_page_template',
            'type' => 'info',
            'desc' => 'Edit template',
            'required' => array(
                array( 'error_page_type', '=', 'elementor' ),
                array( 'error_page_elementor_templates', '!=', '' )
            )
        ),
        array(
            'title' => esc_html__( '404 Header Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site 404 page header with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_header_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array( 'error_page_type', '=', 'elementor' )
        ),
        array(
            'title' => esc_html__( '404 Footer Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site 404 page footer with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_footer_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array( 'error_page_type', '=', 'elementor' )
        ),
        array(
            'title' => esc_html__( '404 Hero Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site 404 page hero section with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_hero_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array( 'error_page_type', '=', 'default' )
        ),
        array(
            'title' => esc_html__( '404 Hero Background', 'crisop' ),
            'customizer' => true,
            'id' => 'error_hero_bg',
            'type' => 'background',
            'output' => array( '#nt-archive .ninetheme-page-hero' ),
            'required' => array(
                array( 'error_page_type', '=', 'default' ),
                array( 'error_hero_visibility', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Custom 404 Title', 'crisop' ),
            'subtitle' => esc_html__( 'Add your custom 404 page title here.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_title',
            'type' => 'text',
            'default' =>'',
            'required' => array(
                array( 'error_page_type', '=', 'default' ),
                array( 'error_hero_visibility', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Content Description Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site 404 page content description with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_content_desc_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array( 'error_page_type', '=', 'default' )
        ),
        array(
            'title' => esc_html__( 'Content Description', 'crisop' ),
            'subtitle' => esc_html__( 'Add your 404 page content description here.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_content_desc',
            'type' => 'textarea',
            'default' => '',
            'required' => array(
                array( 'error_page_type', '=', 'default' ),
                array( 'error_content_desc_visibility', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Button Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site 404 page content back to home button with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_content_btn_visibility',
            'type' => 'switch',
            'default' => 1,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array( 'error_page_type', '=', 'default' )
        ),
        array(
            'title' => esc_html__( 'Button Title', 'crisop' ),
            'subtitle' => esc_html__( 'Add your 404 page content back to home button title here.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_content_btn_title',
            'type' => 'text',
            'default' => '',
            'required' => array(
                array( 'error_page_type', '=', 'default' ),
                array( 'error_content_btn_visibility', '=', '1' )
            )
        ),
        array(
            'title' => esc_html__( 'Search Form Display', 'crisop' ),
            'subtitle' => esc_html__( 'You can enable or disable the site 404 page content search form with switch option.', 'crisop' ),
            'customizer' => true,
            'id' => 'error_content_form_visibility',
            'type' => 'switch',
            'default' => 0,
            'on' => esc_html__( 'On', 'crisop' ),
            'off' => esc_html__( 'Off', 'crisop' ),
            'required' => array( 'error_page_type', '=', 'default' )
        )
    )
));

Redux::setSection($ninetheme_pre, array(
    'id' => 'inportexport_settings',
    'title' => esc_html__( 'Import / Export', 'crisop' ),
    'desc' => esc_html__( 'Import and Export your Theme Options from text or URL.', 'crisop' ),
    'icon' => 'el el-hdd',
    'fields' => array(
        array(
            'id' => 'opt-import-export',
            'type' => 'import_export',
            'title' => '',
            'customizer' => false,
            'subtitle' => '',
            'full_width' => true
        )
    )
));
Redux::setSection($ninetheme_pre, array(
    'id' => 'nt_support_settings',
    'title' => esc_html__( 'Support', 'crisop' ),
    'icon' => 'el el-idea',
    'fields' => array(
        array(
            'id' => 'doc',
            'type' => 'raw',
            'markdown' => true,
            'class' => 'theme_support',
            'content' => '<div class="support-section">
            <h5>'.esc_html__( 'WE RECOMMEND YOU READ IT BEFORE YOU START', 'crisop' ).'</h5>
            <h2><i class="el el-website"></i> '.esc_html__( 'DOCUMENTATION', 'crisop' ).'</h2>
            <a target="_blank" class="button" href="https://ninetheme.com/docs/elementor-themes-documentation/">'.esc_html__( 'READ MORE', 'crisop' ).'</a>
            </div>'
        ),
        array(
            'id' => 'support',
            'type' => 'raw',
            'markdown' => true,
            'class' => 'theme_support',
            'content' => '<div class="support-section">
            <h5>'.esc_html__( 'DO YOU NEED HELP?', 'crisop' ).'</h5>
            <h2><i class="el el-adult"></i> '.esc_html__( 'SUPPORT CENTER', 'crisop' ).'</h2>
            <a target="_blank" class="button" href="https://ninetheme.com/support/">'.esc_html__( 'GET SUPPORT', 'crisop' ).'</a>
            </div>'
        ),
        array(
            'id' => 'portfolio',
            'type' => 'raw',
            'markdown' => true,
            'class' => 'theme_support',
            'content' => '<div class="support-section">
            <h5>'.esc_html__( 'SEE MORE THE NINETHEME WORDPRESS THEMES', 'crisop' ).'</h5>
            <h2><i class="el el-picture"></i> '.esc_html__( 'NINETHEME PORTFOLIO', 'crisop' ).'</h2>
            <a target="_blank" class="button" href="https://themeforest.net/user/ninetheme/portfolio">'.esc_html__( 'SEE MORE', 'crisop' ).'</a>
            </div>'
        ),
        array(
            'id' => 'like',
            'type' => 'raw',
            'markdown' => true,
            'class' => 'theme_support',
            'content' => '<div class="support-section">
            <h5>'.esc_html__( 'WOULD YOU LIKE TO REWARD OUR EFFORT?', 'crisop' ).'</h5>
            <h2><i class="el el-thumbs-up"></i> '.esc_html__( 'PLEASE RATE US!', 'crisop' ).'</h2>
            <a target="_blank" class="button" href="https://themeforest.net/downloads/">'.esc_html__( 'GET STARS', 'crisop' ).'</a>
            </div>'
        )
    )
));
/*
 * <--- END SECTIONS
 */


/** Action hook examples **/

function ninetheme_remove_demo()
{
    // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
    if (class_exists('ReduxFrameworkPlugin' )) {
        // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
        remove_action('admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ));
    }
}

function ninetheme_newIconFont() {
    wp_register_style(
        'redux-font-awesome',
        '//cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css',
        array(),
        time(),
        'all'
    );
    wp_enqueue_style( 'redux-font-awesome' );
}
//add_action( 'redux/page/crisop/enqueue', 'ninetheme_newIconFont' );
