<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

$crisop_options = get_option('crisop');

/*************************************************
## ADD THEME SUPPORT FOR WOOCOMMERCE
*************************************************/
if ( ! function_exists( 'ninetheme_wc_shop_per_page' ) ) {
    add_action( 'after_setup_theme', 'ninetheme_wc_theme_setup' );
    function ninetheme_wc_theme_setup()
    {
        $single_image_width = ninetheme_settings( 'product_gallery_imgsize', 980 );
        $single_image_width = $single_image_width ? $single_image_width : 980;
        add_theme_support( 'crisop' );
        add_theme_support( 'woocommerce', array(
            'thumbnail_image_width' => 450,
            'single_image_width'    => $single_image_width
        ) );
        if ( '1' == ninetheme_settings('ninetheme_product_zoom', '1') ) {
            add_theme_support( 'wc-product-gallery-zoom' );
        }
        $thumbs_layout = ninetheme_settings( 'product_thumbs_layout', 'slider' );
        if ( $thumbs_layout == 'wc' ) {
            add_theme_support( 'wc-product-gallery-lightbox' );
            add_theme_support( 'wc-product-gallery-slider' );
        }
    }
}

add_filter( 'woocommerce_single_product_carousel_options', 'filter_single_product_carousel_options' );
function filter_single_product_carousel_options( $options )
{
    $options['maxItems'] = 4; // Already "false" by default
    $options['slideshow'] = false; // Already "false" by default

    return $options;
}


// Remove each style one by one
add_filter( 'woocommerce_enqueue_styles', 'ninetheme_dequeue_wc_styles' );
function ninetheme_dequeue_wc_styles( $styles )
{
    unset( $styles['woocommerce-general'] ); // Remove the gloss
    unset( $styles['woocommerce-layout'] ); // Remove the layout
    unset( $styles['woocommerce-smallscreen'] ); // Remove the smallscreen optimisation
    return $styles;
}

/*************************************************
## Ajax Login/Register
*************************************************/

if ( isset($crisop_options['wc_ajax_login_register']) && '1' == $crisop_options[ 'wc_ajax_login_register' ] ) {
    include CRISOP_DIRECTORY . '/woocommerce/ajax-login/ajax-login.php';
}


/*************************************************
## REGISTER SIDEBAR FOR WOOCOMMERCE
*************************************************/

if ( ! function_exists( 'ninetheme_wc_widgets_init' ) ) {
    add_action( 'widgets_init', 'ninetheme_wc_widgets_init' );
    function ninetheme_wc_widgets_init()
    {
        //Shop page sidebar
        register_sidebar( array(
            'id' => 'shop-page-sidebar',
            'name' => esc_html__( 'Shop Page Sidebar', 'crisop' ),
            'description' => esc_html__( 'These widgets for the Shop page.','crisop' ),
            'before_widget' => '<div class="nt-sidebar-inner-widget shop-widget ninetheme-widget-show %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h6 class="nt-sidebar-inner-widget-title shop-widget-title"><span class="nt-sidebar-widget-title">',
            'after_title' => '</span><span class="nt-sidebar-widget-toggle"></span></h6>'
        ));
        //Shop page sidebar
        register_sidebar( array(
            'id' => 'shop-page-top-sidebar',
            'name' => esc_html__( 'Shop Page Top Sidebar', 'crisop' ),
            'description' => esc_html__( 'These widgets for the Shop page.','crisop' ),
            'before_widget' => '<div class="nt-sidebar-inner-widget shop-widget ninetheme-widget-show %2$s">',
            'after_widget' => '</div></div>',
            'before_title' => '<h6 class="nt-sidebar-inner-widget-title shop-widget-title"><span class="nt-sidebar-widget-title">',
            'after_title' => '</span><span class="nt-sidebar-widget-toggle type-arrow"></span></h6><div class="nt-sidebar-widget-body">'
        ));
        //Single product sidebar
        register_sidebar( array(
            'id' => 'shop-single-sidebar',
            'name' => esc_html__( 'Shop Single Page Sidebar', 'crisop' ),
            'description' => esc_html__( 'These widgets for the Shop Single page.','crisop' ),
            'before_widget' => '<div class="nt-sidebar-inner-widget shop-widget ninetheme-widget-show %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h6 class="nt-sidebar-inner-widget-title shop-widget-title"><span class="ninetheme-sidebar-widget-title">',
            'after_title' => '</span><span class="nt-sidebar-widget-toggle"></span></h6>'
        ));
    }
}


/*************************************************
## WOOCOMMERCE PAGE TITLE FUNCTION
*************************************************/

if ( ! function_exists( 'ninetheme_shop_page_title' ) ) {
    add_filter( 'woocommerce_page_title', 'ninetheme_shop_page_title');
    function ninetheme_shop_page_title( $page_title )
    {
        if ( 'Shop' == $page_title && ninetheme_settings( 'shop_title' ) ) {
            return '<h2 class="nt-hero-title page-title mb-10">'.ninetheme_settings( 'shop_title' ).'</h2>';
        } else {
            return '<h2 class="nt-hero-title page-title mb-10">'.$page_title.'</h2>';
        }
    }
}


/*************************************************
## WOOCOMMERCE HERO FUNCTION
*************************************************/

if ( ! function_exists( 'ninetheme_wc_hero_section' ) ) {
    add_action( 'ninetheme_before_shop_content', 'ninetheme_wc_hero_section', 10 );
    function ninetheme_wc_hero_section()
    {
        $name = is_product() ? 'single_shop' : 'shop';

        $hero_type        = ninetheme_settings( $name.'_hero_layout_type', 'big' );
        $template_id      = apply_filters( 'ninetheme_shop_hero_template_id', intval( ninetheme_settings( 'shop_hero_elementor_templates' ) ) );
        $cats_template_id = apply_filters( 'ninetheme_shop_category_hero_template_id', intval( ninetheme_settings( 'shop_cats_hero_elementor_templates' ) ) );
        $tax_template_id  = apply_filters( 'ninetheme_shop_tags_hero_template_id', intval( ninetheme_settings( 'shop_tax_hero_elementor_templates' ) ) );
        $is_elementor     = class_exists( '\Elementor\Frontend' ) ? true : false;
        $frontend         = $is_elementor ? new \Elementor\Frontend : false;

        if ( '0' != ninetheme_settings($name.'_hero_visibility', '1') ) {

            if ( is_product_category() ) {

                ninetheme_wc_archive_category_page_hero_section();

            } elseif ( is_product_tag() && $is_elementor && $tax_template_id  ) {

                printf( '<div class="ninetheme-shop-hero-tag">%1$s</div>', $frontend->get_builder_content_for_display( $tax_template_id, false ) );

            } elseif ( ( is_shop() || is_product() ) && $is_elementor && $template_id  ) {

                printf( '<div class="ninetheme-shop-custom-hero">%1$s</div>', $frontend->get_builder_content_for_display( $template_id, false ) );

            } else {
                ?>
                <div class="ninetheme-shop-hero-wrapper">
                    <div class="ninetheme-shop-hero ninetheme-page-hero page-hero-<?php echo esc_attr( $hero_type ); ?>">
                        <div class="container-xl ninetheme-container-xl">
                            <div class="row">
                                <div class="col-12">
                                    <div class="ninetheme-page-hero-content ninetheme-flex ninetheme-align-center ninetheme-justify-center">

                                        <?php
                                        if ( is_product() ) {
                                            the_title('<h2 class="ninetheme-page-title ninetheme-product-title">','</h2>');
                                        } else {
                                            woocommerce_page_title();
                                        }

                                        echo ninetheme_breadcrumbs();

                                        ?>
                                    </div>
                                    <?php
                                    if ( $hero_type == 'cat-slider' ) {
                                        ninetheme_wc_hero_category_slider();
                                    }
                                    ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }
        }
    }
}

if ( ! function_exists( 'ninetheme_wc_default_hero_section' ) ) {

    function ninetheme_wc_default_hero_section()
    {
        ?>
        <div class="ninetheme-shop-hero-wrapper">
            <div class="ninetheme-shop-hero ninetheme-page-hero page-hero-big">
                <div class="container-xl ninetheme-container-xl">
                    <div class="row">
                        <div class="col-12">
                            <div class="ninetheme-page-hero-content ninetheme-flex ninetheme-align-center ninetheme-justify-center">

                                <?php
                                    woocommerce_page_title();
                                    echo ninetheme_breadcrumbs();
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}

if ( ! function_exists( 'ninetheme_wc_archive_category_page_hero_section' ) ) {

    function ninetheme_wc_archive_category_page_hero_section()
    {
        $cats_template_id = apply_filters( 'ninetheme_shop_category_hero_template_id', intval( ninetheme_settings( 'shop_cats_hero_elementor_templates' ) ) );
        $is_elementor     = class_exists( '\Elementor\Frontend' ) ? true : false;
        $frontend         = $is_elementor ? new \Elementor\Frontend : false;
        $term_bg_id       = get_term_meta( get_queried_object_id(), 'ninetheme_product_cat_hero_bgimage_id', true );
        $term_bg_url      = wp_get_attachment_image_url( $term_bg_id, 'large' );

        if ( $term_bg_url ) {
            ?>
            <div class="ninetheme-shop-hero-wrapper">
                <div class="ninetheme-shop-hero ninetheme-page-hero page-hero-big has-bg-image" data-bg="<?php echo esc_url( $term_bg_url ); ?>">
                    <div class="container-xl ninetheme-container-xl">
                        <div class="row justify-content-center">
                            <div class="col-12 col-sm-10 col-md-8 col-lg-6 col-xl-5">
                                <div class="ninetheme-page-hero-content">
                                    <?php woocommerce_page_title(); ?>
                                    <?php do_action( 'woocommerce_archive_description' ); ?>
                                    <?php echo ninetheme_breadcrumbs(); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        } else {
            if ( $is_elementor && $cats_template_id ) {
                printf( '<div class="ninetheme-shop-hero-cats">%1$s</div>', $frontend->get_builder_content_for_display( $cats_template_id, false ) );
            } else {
                ninetheme_wc_default_hero_section();
            }
        }
    }
}



/*************************************************
## WOOCOMMERCE HERO CATEGORY SLIDER FUNCTION
*************************************************/

if ( ! function_exists( 'ninetheme_wc_hero_category_slider' ) ) {
    function ninetheme_wc_hero_category_slider()
    {
        $categories = get_terms( 'product_cat', array(
            'orderby'    => 'name',
            'order'      => 'asc',
            'hide_empty' => true,
        ));
        $options = '"spaceBetween":1,
        "centeredSlides":true,
        "centeredSlidesBounds":true,
        "loop":false,
        "autoplay":true,
        "spaceBetween": 0,
        "speed":2000,
        "slidesPerView":1,
        "pagination": false,
        "breakpoints": { "320": {"slidesPerView": 3},"768": {"slidesPerView": 3},"992": {"slidesPerView": 5},"1200": {"slidesPerView": 7}}';
        wp_enqueue_script( 'swiper' );
        if ( !empty( $categories ) ) {
            ?>
            <div class="ninetheme-category-slider ninetheme-swiper-slider swiper-container" data-swiper-options='{<?php echo esc_attr( $options ); ?>}'>
                <div class="swiper-wrapper">
                    <?php
                    foreach ( $categories as $category ) {
                        $thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true );
                        ?>
                        <div class="ninetheme-category-slide-item swiper-slide">
                            <a href="<?php echo esc_url( get_term_link( $category ) ); ?>">
                                <?php echo wp_get_attachment_image( $thumbnail_id, array(100,100), true ); ?>
                                <span class="cat-count"><?php echo esc_html( $category->count ); ?></span>
                                <span class="category-title"><?php echo esc_html( $category->name ); ?></span>
                            </a>
                        </div>
                        <?php
                    }
                    ?>
                </div>
            </div>
            <?php
        }
    }
}

/*************************************************
## WOOCOMMERCE HERO CATEGORY LIST FUNCTION
*************************************************/

if ( ! function_exists( 'ninetheme_wc_category_list' ) ) {
    function ninetheme_wc_category_list()
    {
        $categories = get_terms( 'product_cat', array(
            'orderby'    => 'name',
            'order'      => 'asc',
            'hide_empty' => true
        ));

        if ( !empty( $categories ) ) {
            ?>
            <ul class="ninetheme-wc-category-list">
                <?php
                    echo wp_list_categories(array(
                        'echo'       => true,
                        'taxonomy'   => 'product_cat',
                        'depth'      => 3,
                        'hide_empty' => 1,
                        'title_li'   => '',
                        'exclude'    => [],
                        'walker'     => new Ninetheme_WooCommerce_Categories_Walker()
                    ));
                ?>
            </ul>
            <?php
        }
    }
}


if ( ! function_exists( 'ninetheme_before_shop_elementor_templates' ) ) {
    add_action( 'ninetheme_before_shop_content', 'ninetheme_before_shop_elementor_templates', 15 );
    function ninetheme_before_shop_elementor_templates()
    {
        $cat_template = ninetheme_settings('shop_category_pages_before_content_templates', null );
        $tag_template = ninetheme_settings('shop_tag_pages_before_content_templates', null );
        if ( ( $cat_template || $tag_template ) && ( is_product_category() || is_product_tag() ) ) {
            if ( $cat_template && is_product_category() ) {
                echo ninetheme_print_elementor_templates( 'shop_category_pages_before_content_templates', 'shop-before-template-wrapper', true );
            } elseif ( $tag_template && is_product_tag() ) {
                echo ninetheme_print_elementor_templates( 'shop_tag_pages_before_content_templates', 'shop-before-template-wrapper', true );
            }
        } else {
            echo ninetheme_print_elementor_templates( 'shop_before_content_templates', 'shop-before-template-wrapper', true );
        }
    }
}

if ( ! function_exists( 'ninetheme_after_shop_loop_elementor_templates' ) ) {
    add_action( 'ninetheme_after_shop_loop', 'ninetheme_after_shop_loop_elementor_templates', 10 );
    function ninetheme_after_shop_loop_elementor_templates()
    {
        $cat_template = ninetheme_settings('shop_category_pages_after_loop_templates', null );
        $tag_template = ninetheme_settings('shop_tag_pages_after_loop_templates', null );
        if ( ( $cat_template || $tag_template ) && ( is_product_category() || is_product_tag() ) ) {
            if ( $cat_template && is_product_category() ) {
                echo ninetheme_print_elementor_templates( 'shop_category_pages_after_loop_templates', 'after-shop-template', true );
            } elseif ( $tag_template && is_product_tag() ) {
                echo ninetheme_print_elementor_templates( 'shop_tag_pages_after_loop_templates', 'after-shop-template', true );
            }
        } else {
            echo ninetheme_print_elementor_templates( 'shop_after_loop_templates', 'after-shop-template', true );
        }
    }
}

if ( ! function_exists( 'ninetheme_after_shop_page_elementor_templates' ) ) {
    add_action( 'ninetheme_after_shop_page', 'ninetheme_after_shop_page_elementor_templates', 10 );
    function ninetheme_after_shop_page_elementor_templates()
    {
        $cat_template = ninetheme_settings('shop_category_pages_after_content_templates', null );
        $tag_template = ninetheme_settings('shop_tag_pages_after_content_templates', null );
        if ( ( $cat_template || $tag_template ) && ( is_product_category() || is_product_tag() ) ) {
            if ( $cat_template && is_product_category() ) {
                echo ninetheme_print_elementor_templates( 'shop_category_pages_after_content_templates', 'shop-after-content-template-wrapper', true );
            } elseif ( $tag_template && is_product_tag() ) {
                echo ninetheme_print_elementor_templates( 'shop_tag_pages_after_content_templates', 'shop-after-content-template-wrapper', true );
            }
        } else {
            echo ninetheme_print_elementor_templates( 'shop_after_content_templates', 'shop-after-content-template-wrapper' );
        }
    }
}


/*************************************************
## Get Columns options
*************************************************/
if ( ! function_exists( 'ninetheme_get_shop_column' ) ) {
    function ninetheme_get_shop_column()
    {
        $column = isset( $_GET['column'] ) ? $_GET['column'] : '';
        return esc_html($column);
    }
}

/*************************************************
## Get location options
*************************************************/
function ninetheme_get_location()
{
    $location = isset( $_COOKIE['location'] ) ? $_COOKIE['location'] : 'all';
    if ( $location ) {
        return esc_html( $location );
    }
}


if ( ! function_exists( 'ninetheme_shop_pagination' ) ) {
    add_action( 'ninetheme_shop_pagination', 'ninetheme_shop_pagination', 15 );
    function ninetheme_shop_pagination()
    {
        $pagination = apply_filters('ninetheme_shop_pagination_type', ninetheme_settings('shop_paginate_type') );
        if ( $pagination == 'loadmore' ) {

            ninetheme_load_more_button();

        } elseif ( $pagination == 'infinite' ) {

            ninetheme_infinite_scroll();

        } else  {

            woocommerce_pagination();

        }
    }
}


if ( ! function_exists( 'ninetheme_wc_filters_for_ajax' ) ) {
    function ninetheme_wc_filters_for_ajax()
    {
        $type = isset( $_GET['product_style'] ) && $_GET['product_style'] ? esc_html ( $_GET['product_style'] ) : ninetheme_settings( 'shop_product_type', '4' );
        $type = apply_filters( 'ninetheme_loop_product_type', $type );

        return json_encode(
            array(
                'ajaxurl'        => esc_url( admin_url( 'admin-ajax.php' ) ),
                'current_page'   => get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1,
                'max_page'       => wc_get_loop_prop( 'total_pages' ),
                'per_page'       => isset( $_GET['per_page'] ) ? $_GET['per_page'] : wc_get_loop_prop( 'per_page' ),
                'layered_nav'    => WC_Query::get_layered_nav_chosen_attributes(),
                'cat_id'         => isset( get_queried_object()->term_id ) ? get_queried_object()->term_id : '',
                'brand_id'       => isset( get_queried_object()->term_id ) ? get_queried_object()->term_id : '',
                'campaign_id'    => isset( get_queried_object()->term_id ) ? get_queried_object()->term_id : '',
                'locations'      => ninetheme_get_location(),
                'filter_brand'   => isset( $_GET['filter_brand'] ) ? $_GET['filter_brand'] : '',
                'filter_cat'     => isset( $_GET['filter_cat'] ) ? $_GET['filter_cat'] : '',
                'filter_campaign'=> isset( $_GET['filter_campaign'] ) ? $_GET['filter_campaign'] : '',
                'on_sale'        => isset( $_GET['on_sale'] ) ? 'yes' : 'no',
                'in_stock'       => isset( $_GET['stock_status'] ) && $_GET['stock_status'] == 'instock' ? 'yes' : 'no',
                'orderby'        => isset( $_GET['orderby'] ) ? $_GET['orderby'] : '',
                'min_price'      => isset( $_GET['min_price'] ) ? $_GET['min_price'] : '',
                'max_price'      => isset( $_GET['max_price'] ) ? $_GET['max_price'] : '',
                'product_style'  => $type,
                'column'         => ninetheme_get_shop_column(),
                'no_more'        => esc_html__( 'All Products Loaded', 'crisop' ),
                'is_search'      => is_search() ? 'yes' : '',
                'is_shop'        => is_shop() ? 'yes' : '',
                'is_brand'       => is_tax( 'ninetheme_product_brands' ) ? 'yes' : '',
                'is_cat'         => is_tax( 'product_cat' ) ? 'yes' : '',
                'is_tag'         => is_tax( 'product_tag' ) ? 'yes' : '',
                's'              => isset($_GET['s']) ? $_GET['s'] : ''
            )
        );
    }
}


if ( ! function_exists( 'ninetheme_wc_get_tax_url' ) ) {
    function ninetheme_wc_get_tax_url( $termid, $tax = 'cat' )
    {
        global $wp;
        if ( '' === get_option( 'permalink_structure' ) ) {
            $link = remove_query_arg( array( 'page', 'paged' ), add_query_arg( $wp->query_string, '', home_url( $wp->request ) ) );
        } else {
            $link = preg_replace( '%\/page/[0-9]+%', '', add_query_arg( null, null ) );
        }

        if ( isset( $_GET[ 'filter_'.$tax ] ) ) {
            $explode_old    = explode( ',', $_GET[ 'filter_'.$tax ] );
            $explode_termid = explode( ',', $termid );

            if ( in_array( $termid, $explode_old ) ) {
                $data     = array_diff( $explode_old, $explode_termid );
                $checkbox = 'checked';
            } else {
                $data = array_merge( $explode_termid , $explode_old );
            }
        } else {
            $data = array( $termid );
        }

        $dataimplode = implode( ',', $data );

        if ( empty( $dataimplode ) ) {
            $link = remove_query_arg( 'filter_'.$tax, $link );
        } else {
            $link = add_query_arg( 'filter_'.$tax, implode( ',', $data ), $link );
        }

        return $link;
    }
}


if ( ! function_exists( 'ninetheme_wc_widget_get_current_page_url' ) ) {
    add_filter( 'woocommerce_widget_get_current_page_url', 'ninetheme_wc_widget_get_current_page_url', 10, 2 );
    function ninetheme_wc_widget_get_current_page_url( $link, $that )
    {
        if ( isset( $_GET['filter_cat'] ) ) {
            $link = add_query_arg( 'filter_cat', wc_clean( wp_unslash( $_GET['filter_cat'] ) ), $link );
        }

        if ( isset( $_GET['filter_brand'] ) ) {
            $link = add_query_arg( 'filter_brand', wc_clean( wp_unslash( $_GET['filter_brand'] ) ), $link );
        }

        if ( isset( $_GET['filter_campaign'] ) ) {
            $link = add_query_arg( 'filter_campaign', wc_clean( wp_unslash( $_GET['filter_campaign'] ) ), $link );
        }

        if ( isset( $_GET['shop_layouts'] ) ) {
            $link = add_query_arg( 'shop_layouts', wc_clean( wp_unslash( $_GET['shop_layouts'] ) ), $link );
        }

        if ( isset( $_GET['on_sale'] ) ) {
            $link = add_query_arg( 'on_sale', wc_clean( wp_unslash( $_GET['on_sale'] ) ), $link );
        }

        if ( isset( $_GET['stock_status'] ) ) {
            $link = add_query_arg( 'stock_status', wc_clean( wp_unslash( $_GET['stock_status'] ) ), $link );
        }

        if ( isset( $_GET['ft'] ) ) {
            $link = add_query_arg( 'ft', wc_clean( wp_unslash( $_GET['ft'] ) ), $link );
        }
        return $link;
    }
}


if ( ! function_exists( 'ninetheme_show_products_by_tax_query' ) ) {
    add_filter( 'woocommerce_product_query_tax_query', 'ninetheme_show_products_by_tax_query', 10, 2 );
    function ninetheme_show_products_by_tax_query( $tax_query, $instance )
    {
        if ( is_shop() ) {

            if ( taxonomy_exists( 'location' ) ) {
                if ( ninetheme_get_location()!= 'all' ) {
                    $tax_query[] = array(
                        'taxonomy' => 'location',
                        'field'    => 'slug',
                        'terms'    => ninetheme_get_location()
                    );
                }
            }

            if ( isset( $_GET['filter_campaign'] ) ) {
                $tax_query[] = array(
                    'taxonomy' => 'ninetheme_product_campaigns',
                    'field'    => 'id',
                    'terms'    => explode( ',', $_GET['filter_campaign'] )
                );
            }

            if ( isset( $_GET['filter_brand'] ) ) {
                $tax_query[] = array(
                    'taxonomy' => 'ninetheme_product_brands',
                    'field'    => 'id',
                    'terms'    => explode( ',', $_GET['filter_brand'] )
                );
            }

            if ( isset( $_GET['filter_cat'] ) ) {
                if ( !empty( $_GET['filter_cat'] ) ) {
                    $tax_query[] = array(
                        'taxonomy' => 'product_cat',
                        'field'    => 'id',
                        'terms'    => explode( ',',$_GET['filter_cat'] )
                    );
                }
            }

            if ( isset( $_GET['featured'] ) && $_GET['featured'] == 'yes' ) {
                $tax_query[] = array(
                    'taxonomy' => 'product_visibility',
                    'field'    => 'name',
                    'terms'    => array( 'featured' ),
                    'operator' => 'IN'
                );
            }
        }
        return $tax_query;
    }
}


/*************************************************
## Crisop Remove Filter
*************************************************/
if ( ! function_exists( 'ninetheme_choosen_filters' ) ) {
    add_action( 'ninetheme_choosen_filters', 'ninetheme_choosen_filters', 10 );
    function ninetheme_choosen_filters()
    {
        $_chosen_attributes = WC_Query::get_layered_nav_chosen_attributes();
        $min_price = isset( $_GET['min_price'] ) ? wc_clean( $_GET['min_price'] ) : 0;
        $max_price = isset( $_GET['max_price'] ) ? wc_clean( $_GET['max_price'] ) : 0;
        $rating    = isset( $_GET['rating_filter'] ) ? wc_clean( $_GET['rating_filter'] ) : '';
        $on_sale   = isset( $_GET['on_sale'] ) ? 'onsale' : '';
        $in_tock   = isset( $_GET['stock_status'] ) ? 'instock' : '';

        if ( ! empty( $_chosen_attributes ) || isset( $_GET['filter_cat'] ) || isset( $_GET['filter_brand'] ) || isset( $_GET['filter_campaign'] ) || $rating || 0 < $min_price || 0 < $max_price || $in_tock == 'instock' || $on_sale == 'onsale' ) {

            global $wp;

            if ( '' === get_option( 'permalink_structure' ) ) {
                $baselink = remove_query_arg( array( 'page', 'paged' ), add_query_arg( $wp->query_string, '', home_url( $wp->request ) ) );
            } else {
                $baselink = preg_replace( '%\/page/[0-9]+%', '', home_url( add_query_arg( null, null ) ) );
            }
            ?>
            <div class="ninetheme-choosen-filters">
                <ul class="ninetheme-remove-filter">

                    <li class="clear-li">
                        <a rel="noreferrer nofollow" href="<?php echo esc_url( remove_query_arg( array_keys( $_GET ) ) ); ?>" class="ninetheme-remove-filter-element clear-all">
                            <span class="remove-filter"></span><?php esc_html_e( 'Clear filters', 'crisop' ); ?>
                        </a>
                    </li>

                    <?php
                    if ( ! empty( $_chosen_attributes ) ) {
                        foreach ( $_chosen_attributes as $taxonomy => $data ) {
                            foreach ( $data['terms'] as $term_slug ) {
                                $term = get_term_by( 'slug', $term_slug, $taxonomy );

                                $filter_name    = 'filter_' . wc_attribute_taxonomy_slug( $taxonomy );
                                $explode_old    = explode( ',',$_GET[$filter_name] );
                                $explode_termid = explode( ',',$term->slug );
                                $diff_data      = array_diff( $explode_old, $explode_termid );
                                $data_implode   = implode( ',',$diff_data );

                                if ( empty( $data_implode ) ) {
                                    $link = remove_query_arg( $filter_name );
                                } else {
                                    $link = add_query_arg( $filter_name, implode(',', $diff_data ), $baselink );
                                }
                                ?>
                                <li>
                                    <a rel="noreferrer nofollow" href="<?php echo esc_url( $link ); ?>" class="ninetheme-remove-filter-element attributes">
                                        <span class="remove-filter"></span><?php echo esc_html( $term->name ); ?>
                                    </a>
                                </li>
                                <?php
                            }
                        }
                    }

                    if ( $in_tock == 'instock' ) {
                        ?>
                        <li>
                            <a rel="noreferrer nofollow" href="<?php echo esc_url(remove_query_arg('stock_status')); ?>" class="ninetheme-remove-filter-element stock_status">
                                <span class="remove-filter"></span><?php echo esc_html__('In Stock','crisop'); ?>
                            </a>
                        </li>
                        <?php
                    }

                    if ( $on_sale == 'onsale' ) {
                        ?>
                        <li>
                            <a rel="noreferrer nofollow" href="<?php echo esc_url(remove_query_arg('on_sale')); ?>" class="ninetheme-remove-filter-element on_sale">
                                <span class="remove-filter"></span><?php echo esc_html__('On Sale','crisop'); ?>
                            </a>
                        </li>
                        <?php
                    }

                    if ( $min_price ) {
                         ?>
                        <li>
                            <a rel="noreferrer nofollow" href="<?php echo esc_url(remove_query_arg('min_price')); ?>" class="ninetheme-remove-filter-element min_price">
                                <span class="remove-filter"></span><?php echo sprintf( esc_html__( 'Min %s', 'crisop' ), wc_price( $min_price ) ); ?>
                            </a>
                        </li>
                        <?php
                    }

                    if ( $max_price ) {
                        ?>
                        <li>
                            <a rel="noreferrer nofollow" href="<?php echo esc_url(remove_query_arg('max_price')); ?>" class="ninetheme-remove-filter-element max_price">
                                <span class="remove-filter"></span><?php echo sprintf( esc_html__( 'Max %s', 'crisop' ), wc_price( $max_price ) ); ?>
                            </a>
                        </li>
                        <?php
                    }

                    if ( $rating ) {
                        ?>
                        <li>
                            <a rel="noreferrer nofollow" href="<?php echo esc_url(remove_query_arg('rating_filter')); ?>" class="ninetheme-remove-filter-element rating_filter">
                                <span class="remove-filter"></span><?php echo sprintf( esc_html__( 'Rating: %s', 'crisop' ), $rating ); ?>
                            </a>
                        </li>
                        <?php
                    }

                    if ( isset( $_GET['filter_cat'] ) ) {
                        $terms = get_terms( array(
                            'taxonomy'   => 'product_cat',
                            'hide_empty' => false,
                            'parent'     => 0,
                            'include'    => explode(',',$_GET['filter_cat']),
                        ) );

                        foreach ( $terms as $term ) {
                            $term_children = get_term_children( $term->term_id, 'product_cat' );
                            echo '<li><a rel="noreferrer nofollow" href="'.esc_url( ninetheme_wc_get_tax_url( $term->term_id, 'cat' ) ).'" class="ninetheme-remove-filter-element product_cat" id="'.esc_attr( $term->term_id ).'"><span class="remove-filter"></span>'.esc_html( $term->name ).'</a></li>';
                            if( $term_children ) {
                                foreach( $term_children as $child ) {
                                    $childterm = get_term_by( 'id', $child, 'product_cat' );
                                    if ( in_array( $childterm->term_id, explode(',', $_GET['filter_cat'] ) ) ) {
                                        echo '<li><a rel="noreferrer nofollow" href="'.esc_url( ninetheme_wc_get_tax_url( $childterm->term_id, 'cat' ) ).'" class="ninetheme-remove-filter-element product_cat" id="'.esc_attr( $childterm->term_id ).'"><span class="remove-filter"></span>'.esc_html( $childterm->name ).'</a></li>';
                                    }
                                }
                            }
                        }
                    }

                    if ( isset( $_GET['filter_brand'] ) ) {
                        $terms = get_terms( array(
                            'taxonomy'   => 'ninetheme_product_brands',
                            'hide_empty' => false,
                            'parent'     => 0,
                            'include'    => explode( ',',$_GET['filter_brand'] )
                        ));

                        foreach ( $terms as $term ) {
                            ?>
                            <li>
                                <a rel="noreferrer nofollow" href="<?php echo esc_url( ninetheme_wc_get_tax_url( $term->term_id, 'brand' ) ); ?>" class="ninetheme-remove-filter-element ninetheme_product_brands" id="<?php echo esc_attr( $term->term_id ); ?>">
                                    <span class="remove-filter"></span><?php echo esc_html( $term->name ); ?>
                                </a>
                            </li>
                            <?php
                        }
                    }

                    if ( isset( $_GET['filter_campaign'] ) ) {
                        $terms = get_terms( array(
                            'taxonomy'   => 'ninetheme_product_campaigns',
                            'hide_empty' => false,
                            'parent'     => 0,
                            'include'    => explode( ',',$_GET['filter_campaign'] )
                        ));

                        foreach ( $terms as $term ) {
                            ?>
                            <li>
                                <a rel="noreferrer nofollow" href="<?php echo esc_url( ninetheme_wc_get_tax_url( $term->term_id, 'campaign' ) ); ?>" class="ninetheme-remove-filter-element ninetheme_product_campaigns" id="<?php echo esc_attr( $term->term_id ); ?>">
                                    <span class="remove-filter"></span><?php echo esc_html( $term->name ); ?>
                                </a>
                            </li>
                            <?php
                        }
                    }
                    ?>
                </ul>
            </div>
            <?php
        }
    }
}

/*************************************************
## MINICART AND QUICK-VIEW
*************************************************/

include get_template_directory() . '/woocommerce/minicart/actions.php';
include get_template_directory() . '/woocommerce/load-more/load-more.php';


/**
* Change number of products that are displayed per page (shop page)
*/
if ( ! function_exists( 'ninetheme_wc_shop_per_page' ) ) {
    add_filter( 'loop_shop_per_page', 'ninetheme_wc_shop_per_page', 20 );
    add_filter( 'dokan_store_products_per_page', 'ninetheme_wc_shop_per_page', 20 );
    function ninetheme_wc_shop_per_page( $cols )
    {
        if ( isset( $_GET['per_page'] ) && $_GET['per_page'] ) {
            return $_GET['per_page'];
        }

        $cols = apply_filters( 'ninetheme_wc_shop_per_page', ninetheme_settings( 'shop_perpage', '10' ) );

        if ( class_exists('WeDevs_Dokan') && dokan_is_store_page() ) {
            $store_user  = dokan()->vendor->get( get_query_var( 'author' ) );
            $store_info  = dokan_get_store_info( $store_user->get_id() );
            $cols        = dokan_get_option( 'store_products_per_page', 'dokan_general', 12 );

            return $cols;
        }

        return $cols;
    }
}


/**
* Change product column
*/
if ( ! function_exists( 'ninetheme_wc_product_column' ) ) {

    function ninetheme_wc_product_column()
    {
        if ( '1' == ninetheme_get_shop_column() || 'list' == ninetheme_settings('shop_product_type','4') ) {
            $listcol = 2;
            return apply_filters( 'ninetheme_product_column', 'row-cols-1 row-cols-md-2 row-cols-xl-'.$listcol );
        }
        if ( '2' == ninetheme_get_shop_column() ) {
            return apply_filters( 'ninetheme_product_column', 'row-cols-2 row-cols-sm-3 row-cols-lg-2' );
        }
        if ( '3' == ninetheme_get_shop_column() ) {
            return apply_filters( 'ninetheme_product_column', 'row-cols-2 row-cols-sm-3 row-cols-lg-3' );
        }
        if ( '4' == ninetheme_get_shop_column() ) {
            return apply_filters( 'ninetheme_product_column', 'row-cols-2 row-cols-sm-3 row-cols-lg-4' );
        }
        if ( '5' == ninetheme_get_shop_column() ) {
            return apply_filters( 'ninetheme_product_column', 'row-cols-2 row-cols-sm-3 row-cols-lg-3 row-cols-xl-5' );
        }
        if ( '6' == ninetheme_get_shop_column() ) {
            return apply_filters( 'ninetheme_product_column', 'row-cols-2 row-cols-sm-3 row-cols-lg-3 row-cols-xl-6' );
        }

        $col[] = 'row-cols-' . ninetheme_settings('shop_colxs', '2');
        $col[] = 'row-cols-sm-' . ninetheme_settings('shop_colsm', '2');
        $col[] = 'row-cols-lg-' . ninetheme_settings('shop_collg', '3');
        $col[] = 'row-cols-xl-' . ninetheme_settings('shop_colxl', '5');
        $col = implode( ' ', $col );

        return apply_filters( 'ninetheme_product_column', $col );
    }
}


/**
* Change number of upsells products column
*/
if ( ! function_exists( 'ninetheme_wc_sells_product_column' ) ) {

    function ninetheme_wc_sells_product_column()
    {
        $sells = is_cart() ? 'cross_sells' : 'upsells';
        $col[] = 'cart row-cols-' . ninetheme_settings('shop_'.$sells.'_colxs', '2');
        $col[] = 'row-cols-sm-' . ninetheme_settings('shop_'.$sells.'_colsm', '2');
        $col[] = 'row-cols-lg-' . ninetheme_settings('shop_'.$sells.'_collg', '3');
        $col[] = 'row-cols-xl-' . ninetheme_settings('shop_'.$sells.'_colxl', '4');
        $col   = implode( ' ', $col );
        return apply_filters( 'ninetheme_wc_sells_column', $col );
    }
}


/**
* Change number of related products output
*/
if ( ! function_exists( 'ninetheme_wc_related_products_limit' ) ) {

    add_filter( 'woocommerce_output_related_products_args', 'ninetheme_wc_related_products_limit', 20 );
    function ninetheme_wc_related_products_limit( $args )
    {
        $args['posts_per_page'] = ninetheme_settings('single_shop_related_count', 10 ); // 4 related products
        return $args;
    }
}


/**
* Theme custom filter and actions for woocommerce
*/

remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_output_all_notices', 10 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );

remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );

remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );


// add actions

add_action( 'woocommerce_single_product_summary', 'ninetheme_product_countdown', 25 );
add_action( 'woocommerce_single_product_summary', 'ninetheme_product_stock_progress_bar', 26 );
add_action( 'woocommerce_product_meta_end', 'ninetheme_product_brands', 10 );

add_action( 'woocommerce_widget_shopping_cart_before_buttons', 'ninetheme_minicart_before_buttons', 10 );


/**
* Clear Filters
*/
if ( ! function_exists( 'ninetheme_clear_filters' ) ) {
    function ninetheme_clear_filters() {

        $url = wc_get_page_permalink( 'shop' );
        $_chosen_attributes = WC_Query::get_layered_nav_chosen_attributes();

        $min_price = isset( $_GET['min_price'] ) ? esc_attr( $_GET['min_price'] ) : '';
        $max_price = isset( $_GET['max_price'] ) ? esc_attr( $_GET['max_price'] ) : '';

        if ( 0 < count( $_chosen_attributes ) || $min_price || $max_price ) {
            $reset_url = strtok( $url, '?' );
            if ( isset( $_GET['post_type'] ) ) {
                $reset_url = add_query_arg( 'post_type', wc_clean( wp_unslash( $_GET['post_type'] ) ), $reset_url );
            }
            ?>
            <div class="ninetheme-clear-filters">
                <a href="<?php echo esc_url( $reset_url ); ?>"><?php echo esc_html__( 'Clear filters', 'crisop' ); ?></a>
            </div>
            <?php
        }
    }
    add_action( 'ninetheme_before_choosen_filters', 'ninetheme_clear_filters' );
}



/**
* Product thumbnail
*/
if ( ! function_exists( 'ninetheme_minicart_before_buttons' ) ) {
    function ninetheme_minicart_before_buttons()
    {
        if ( ninetheme_settings('header_cart_before_buttons', '' ) ) {
            ?>
            <div class="minicart-extra-text">
                <?php echo ninetheme_settings('header_cart_before_buttons', '' ); ?>
            </div>
            <?php
        }
    }
}

/**
* wp_get_attachment_image_attributes
*/
if ( ! function_exists( 'ninetheme_wp_get_attachment_image_attributes' ) ) {
    add_filter( 'wp_get_attachment_image_attributes', 'ninetheme_wp_get_attachment_image_attributes');
    function ninetheme_wp_get_attachment_image_attributes($attr) {
        if ( '1' != ninetheme_settings('theme_lazyload_images', '1' ) ){
            return $attr;
        }
        $placeholder = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7';
        $blank_img = get_template_directory().'/images/blank.gif';
        $blank_img = file_exists( $blank_img ) ? get_template_directory_uri().'/images/blank.gif' : $placeholder;
        $attr['data-src'] = $attr['src'];

        $attr['src'] = is_admin() || isset($attr['loading']) != 'lazy' ? $attr['src'] : $blank_img;

        $attr['data-srcset'] = isset( $attr['srcset'] ) ? $attr['srcset'] : '';

        unset( $attr['srcset'] );

        $attr['data-sizes']  = isset( $attr['sizes'] ) ? $attr['sizes'] : '';

        unset( $attr['sizes'] );

        return $attr;
    }
}

/**
* Product thumbnail
*/
if ( ! function_exists( 'shop_related_thumb_size' ) ) {
    function shop_related_thumb_size()
    {
        return apply_filters( 'shop_related_thumb_size', 'medium_large' );
    }
}


/**
* Product thumbnail
*/
if ( ! function_exists( 'ninetheme_loop_product_thumb' ) ) {
    function ninetheme_loop_product_thumb()
    {
        global $product;
        $id     = $product->get_id();
        $link   = get_permalink();
        $images = $product->get_gallery_image_ids();
        $array  = ['"'.get_the_post_thumbnail_url( $id, 'woocommerce_thumbnail' ).'"'];
        $show_thumbs  = get_post_meta( $product->get_id(), 'ninetheme_loop_product_slider', true );

        foreach ( $images as $image ) {
            array_push($array,'"'.wp_get_attachment_image_url( $image, 'woocommerce_thumbnail' ).'"' );
        }
        ?>
        <a href="<?php echo esc_url( $link ) ?>" class="ninetheme-loop-product-link">
            <?php woocommerce_template_loop_product_thumbnail(); ?>
        </a>
        <?php
    }
}


/**
* Add stock to loop
*/
if ( ! function_exists( 'ninetheme_loop_product_stock_status' ) ) {
    function ninetheme_loop_product_stock_status()
    {
        global $product;
        $stock = get_post_meta( $product->get_id(), 'ninetheme_product_hide_stock', true );

        if ( 'yes' == $stock ) {
            return;
        }
        $status = $product->get_stock_status();
        if ( 'instock' == $status ) {
            echo '<span class="ninetheme-small-title ninetheme-stock-status ninetheme-instock">'.esc_html__('In stock', 'crisop').'</span>';
        }
        if ( 'outofstock' == $status ) {
            echo '<span class="ninetheme-small-title ninetheme-stock-status ninetheme-outofstock">'.esc_html__('Out of stock', 'crisop').'</span>';
        }
    }
}

/**
* Add stock to loop
*/
if ( ! function_exists( 'ninetheme_loop_product_stock_status_by_id' ) ) {
    function ninetheme_loop_product_stock_status_by_id( $id = '' )
    {
        if ( $id == '' ) {
            return;
        }

        $product = wc_get_product( $id );

        $stock = get_post_meta( $product->get_id(), 'ninetheme_product_hide_stock', true );

        if ( 'yes' == $stock ) {
            return;
        }
        $status = $product->get_stock_status();
        if ( 'instock' == $status ) {
            echo '<span class="ninetheme-small-title ninetheme-stock-status ninetheme-instock">'.esc_html__('In stock', 'crisop').'</span>';
        }
        if ( 'outofstock' == $status ) {
            echo '<span class="ninetheme-small-title ninetheme-stock-status ninetheme-outofstock">'.esc_html__('Out of stock', 'crisop').'</span>';
        }
    }
}

/**
* Add progressbar to loop
*/
if ( ! function_exists( 'ninetheme_loop_product_progressbar' ) ) {
    function ninetheme_loop_product_progressbar()
    {
        global $product;

        $pid           = $product->get_id();
        $current_stock = get_post_meta( $pid, '_stock', true );
        $total_sold    = $product->get_total_sales();
        $percentage    = $total_sold > 0 && $current_stock > 0 ? round( $total_sold / $current_stock * 100 ) : 0;
        $available    = $current_stock > 0 ? wc_trim_zeros($current_stock) : '';

        echo '<div class="progressbar-wrapper">';
            echo '<div class="stock-progress">';
                echo '<div class="stock-progressbar" style="width:'.$percentage.'%"></div>';
            echo '</div>';
            echo '<div class="stock-details">';
                echo '<div class="stock-sold"><span class="status-label">'.esc_html__('Sold:','crisop').' </span><span class="status-value">'.$total_sold.'</span></div>';
                echo '<div class="current-stock"><span class="status-label">'.esc_html__('Available:','crisop').' </span><span class="status-value">'.$available.'</span></div>';
            echo '</div>';
        echo '</div>';
    }
}

/**
* Add progressbar to loop
*/
if ( ! function_exists( 'ninetheme_loop_product_countdown' ) ) {
    function ninetheme_loop_product_countdown($expired,$time,$hide_sep)
    {
        global $product;

        $pid  = $product->get_id();
        $date = get_post_meta( $pid, '_sale_price_dates_to', true );
        $time = $time ? $time : date_i18n( 'Y/m/d', $date );

        if ( $time ) {
            $sep = $hide_sep ? ' separator-none' : '';
            $time = '"date":"'.$time.'","expired":"'.$expired.'"';
            echo '<div class="ninetheme-coming-time gradient-bg '.$sep.' countdown-'.$pid.'" data-timer=\'{'.$time.'}\'>';
                echo '<div class="time-count days"></div>';
                echo '<span class="separator">:</span>';
                echo '<div class="time-count hours"></div>';
                echo '<span class="separator">:</span>';
                echo '<div class="time-count minutes"></div>';
                echo '<span class="separator">:</span>';
                echo '<div class="time-count second"></div>';
            echo '</div>';
        }
    }
}


/**
* Product wishlist button
*/
if ( ! function_exists( 'ninetheme_single_product_buttons' ) ) {
    add_action( 'woocommerce_after_add_to_cart_button', 'ninetheme_single_product_buttons', 10 );
    function ninetheme_single_product_buttons()
    {
        $wishlist = ninetheme_settings('product_wishlist_visibility', '1');
        $compare  = ninetheme_settings('product_compare_visibility', '1');
        $whatsapp = ninetheme_settings( 'product_whatsapp_button_visibility', '1' );
        if ( '1' == $wishlist || '1' == $compare || '1' == $whatsapp ) {
            echo '<div class="ninetheme-after-single-cart-button hint-top">';
                if ( '1' == $wishlist ) {
                    echo ninetheme_wishlist_button();
                }
                if ( '1' == $compare ) {
                    echo ninetheme_compare_button();
                }
                ninetheme_product_whatsapp_button();
            echo '</div>';
        }
        ninetheme_add_buy_now_button_single();
    }
}

/**
* Product wishlist button html
*/
function ninetheme_allowed_svg( $tags ) {
    $tags['svg'] = array(
        'class' => array(),
        'xmlns' => array(),
        'fill' => array(),
        'viewbox' => array(),
        'role' => array(),
        'aria-hidden' => array(),
        'focusable' => array()
    );
    $tags['path'] = array(
        'd' => array(),
        'fill' => array()
    );
    $tags['use'] = array(
        'href' => array()
    );
    return $tags;
}

if ( ! function_exists( 'ninetheme_woosw_wishlist_button' ) ) {
    add_filter( 'woosw_button_html', 'ninetheme_woosw_wishlist_button',99,2 );
    function ninetheme_woosw_wishlist_button( $html, $id )
    {
        global $product;
        $id       = $product->get_id();
        $image_id = $product->get_image_id();
        $image    = wp_get_attachment_image_url( $image_id );
        $text     = esc_html__( 'Add to Wishlist', 'crisop' );
        $icon     = ninetheme_svg_lists( 'love', 'ninetheme-svg-icon' );
        $hint     = '<span class="ninetheme-hint">'.$text.'</span>';
        $html     = '<div class="ninetheme-product-button ninetheme-wishlist-btn woosw-btn wooswp-btn-'.esc_attr( $id ).' woosw-btn-has-icon woosw-btn-icon-only"
        data-id="'.esc_attr( $id ).'"
        data-product_name="'.esc_html($product->get_name()).'"
        data-product_image="'.esc_attr( $image ).'" data-label="'.$text.'">'.$hint.$icon.'</div>';

        return $html;
    }
}

/**
* Product wishlist button
*/
if ( ! function_exists( 'ninetheme_wishlist_button' ) ) {
    function ninetheme_wishlist_button()
    {
        if ( class_exists( 'WPCleverWoosw' ) ) {
            add_filter( 'wp_kses_allowed_html', 'ninetheme_allowed_svg');
            echo do_shortcode('[woosw type="link"]');
            remove_filter( 'wp_kses_allowed_html', 'ninetheme_allowed_svg');
        }
    }
}

/**
* Product wishlist button by id
*/
if ( ! function_exists( 'ninetheme_wishlist_button_by_id' ) ) {
    function ninetheme_wishlist_button_by_id($id = '')
    {
        if ( class_exists( 'WPCleverWoosw' ) && $id == '' ) {
            add_filter( 'wp_kses_allowed_html', 'ninetheme_allowed_svg');
            echo do_shortcode('[woosw type="link" id="'.$id.'"]');
            remove_filter( 'wp_kses_allowed_html', 'ninetheme_allowed_svg');
        }
    }
}

if ( ! function_exists( 'ninetheme_woosc_compare_button' ) ) {
    add_filter( 'woosc_button_html', 'ninetheme_woosc_compare_button',99,2 );
    function ninetheme_woosc_compare_button( $html, $id )
    {
        global $product;
        $id       = $product->get_id();
        $image_id = $product->get_image_id();
        $image    = wp_get_attachment_image_url( $image_id );
        $text     = esc_html__( 'Compare', 'crisop' );
        $icon     = ninetheme_svg_lists( 'compare', 'ninetheme-svg-icon' );
        $hint     = '<span class="ninetheme-hint">'.$text.'</span>';
        $html     = '<div class="ninetheme-product-button ninetheme-compare-btn woosc-btn wooscp-btn-'.esc_attr( $id ).' woosc-btn-has-icon woosc-btn-icon-only"
        data-id="'.esc_attr( $id ).'"
        data-product_name="'.esc_html($product->get_name()).'"
        data-product_image="' . esc_attr( $image ) . '" data-label="'.$text.'">'.$hint.$icon.'</div>';

        return $html;
    }
}

if ( ! function_exists( 'ninetheme_compare_button' ) ) {
    function ninetheme_compare_button()
    {
        if ( class_exists( 'WPCleverWoosc' ) ) {
            echo do_shortcode('[woosc type="link"]');
        }
    }
}

/**
* Product compare button by id
*/
if ( ! function_exists( 'ninetheme_compare_button_by_id' ) ) {
    function ninetheme_compare_button_by_id($id = '')
    {
        if ( class_exists( 'WPCleverWoosc' ) ) {
            echo do_shortcode('[woosc type="link" id="'.$id.'"]');
        }
    }
}


/**
* Product quickview button
*/
if ( ! function_exists( 'ninetheme_quickview_button' ) ) {
    function ninetheme_quickview_button()
    {
        if ( class_exists( 'Ninetheme_QuickView' ) && '1' == ninetheme_settings('quick_view_visibility', '1') ) {
            echo do_shortcode( '[ninetheme_quickview]' );
        }
    }
}

/**
* Product quickview button
*/
if ( ! function_exists( 'ninetheme_quickview_button_by_id' ) ) {
    function ninetheme_quickview_button_by_id($id = '')
    {
        if ( $id == '' ) {
            return;
        }
        if ( class_exists( 'Ninetheme_QuickView' ) && '1' == ninetheme_settings('quick_view_visibility', '1') ) {
            echo do_shortcode( '[ninetheme_quickview id="'.$id.'"]' );
        }
    }
}

/**
* Cart Button with Quantity Box
*/
if ( !function_exists( 'ninetheme_cart_with_quantity' ) ) {
    function ninetheme_cart_with_quantity( $btn_type = 'icon' )
    {
        global $product;
        $id       = $product->get_id();
        $type     = $product->get_type();
        $max      = $product->backorders_allowed() ? '' : $product->get_stock_quantity();
        $ajax     = ninetheme_settings( 'ajax_addtocart_visibility', 1 );
        $quantity = ninetheme_settings('cart_quantity_visibility', '0');
        $is_ajax  = $product->is_purchasable() && $product->is_in_stock() && $ajax == 1 ? true : false;
        $qty      = '';
        $key      = '';
        $item     = '';

        if ( isset( WC()->cart ) ) {
            foreach( WC()->cart->get_cart() as $cart_item ) {
                if ( $cart_item['product_id'] === $id ){
                    $qty  = $cart_item['quantity'];
                    $key  = $cart_item['key'];
                    $item = $cart_item;
                }
            }
        }

        $class  = $qty ? ' product-in-cart' : '';
        $class .= $quantity == '1' && $is_ajax && $type == 'simple' ? ' has-qunatity' : ' no-qty';

        echo '<div class="cart-quantity-wrapper'.esc_attr( $class ).'" data-product_id="'.esc_attr($id ).'" data-key="'.esc_attr($key ).'">';
        echo '<div class="quantity"></div>';
            echo ninetheme_add_to_cart( $btn_type );
        echo '</div>';
    }
}

/**
* Product add to cart icon button
*/
/**
* Product add to cart icon button
*/
if ( ! function_exists( 'ninetheme_add_to_cart' ) ) {
    function ninetheme_add_to_cart( $btn_type = 'button', $args = array() )
    {
        global $product;

        if ( $product ) {
            $id      = $product->get_id();
            $type    = $product->get_type();
            $text    = esc_html( $product->add_to_cart_text() );
            $ajax    = ninetheme_settings( 'ajax_addtocart_visibility', 1 );
            $icon    = $type == 'external' ? 'arrow-right' : 'bag';
            $icon    = ninetheme_svg_lists( $icon, 'ninetheme-svg-icon' );
            $hint    = '<span class="ninetheme-hint">'.$text.'</span>';
            $in_stock = $product->is_purchasable() && $product->is_in_stock() ? true : false;
            $class  = 'product_type_' . $type;
            $class .= $in_stock ? ' add_to_cart_button' : '';
            $class .= $type == 'variable' || $type == 'grouped' ? ' ninetheme-quick-shop-btn' : '';
            $class .= $product->supports( 'ajax_add_to_cart' ) && $in_stock && $ajax == 1 ? ' ninetheme_ajax_add_to_cart' : '';
            $in_cart = $p_type  = '';

            if ( 'simple' == $type ) {
                $qty = '';

                if ( isset(WC()->cart)) {
                    foreach( WC()->cart->get_cart() as $cart_item ) {
                        if ( $cart_item['product_id'] === $id ){
                            $qty = $cart_item['quantity'];
                        }
                    }
                }

                $in_cart = $qty ? ' added' : '';
                $p_type  = ninetheme_settings( 'shop_product_type', 3 );
                $class  .=  $qty && $p_type == 'custom' ? ' in-cart' : '';
            }

            $btn_type = ninetheme_settings( 'shop_product_type', 3 ) == 'custom' ? 'button' : $btn_type;

            $bclass = 'ninetheme-btn-text';
            if ( $btn_type == 'button' ) {
                $bclass = ' ninetheme-btn ninetheme-btn-primary';
            }

            if ( $btn_type == 'icon' ) {
                $bclass = ' ninetheme-add-to-cart-icon-link';
            }
            $class  .= $bclass;

            $btn = apply_filters( 'woocommerce_loop_add_to_cart_link',
                sprintf('<a href="%s" data-product_id="%s" data-product_sku="%s" data-quantity="%s" class="%s" aria-label="%s" rel="nofollow" data-title="'.$text.'">%s</a>',
                    esc_url( $product->add_to_cart_url() ),
                    $product->get_id(),
                    $product->get_sku(),
                    apply_filters( 'ninetheme_minmax_quantity', 1 ),
                    $class,
                    $product->add_to_cart_description(),
                    $btn_type == 'icon' ? '' : '<span class="text">'.$text.'</span>'
                ),
                $product
            );

            if ( $btn_type == 'icon' ) {
                return '<div class="ninetheme-add-to-cart-btn ninetheme-product-button btn-type-'.$btn_type.' product-type-'.$type.$in_cart.'" data-id="'.$id.'" data-label="'.$text.'">'.$hint.$btn.$icon.'</div>';
            } else {
                return $btn;
            }
        }
    }
}

/**
* Product add to cart icon button
*/
if ( ! function_exists( 'ninetheme_add_to_cart_by_id' ) ) {
    function ninetheme_add_to_cart_by_id( $id = '', $btn_type = 'button', $args = array() )
    {
        if ( $id == '' ) {
            return;
        }

        $product  = wc_get_product( $id );
        $id       = $product->get_id();
        $type     = $product->get_type();
        $text     = esc_html( $product->add_to_cart_text() );
        $icon     = $type == 'external'? 'arrow-right' : 'bag';
        $icon     = ninetheme_svg_lists( $icon, 'ninetheme-svg-icon' );
        $ajax     = ninetheme_settings( 'ajax_addtocart_visibility', 1 );
        $in_stock = $product->is_purchasable() && $product->is_in_stock() ? true : false;
        $p_type   = '';
        $hint     = '<span class="ninetheme-hint">'.$text.'</span>';
        $in_cart  = '';

        $in_cart  = '';

        if ( 'simple' == $type ) {
            $qty = '';

            if ( isset(WC()->cart)) {
                foreach( WC()->cart->get_cart() as $cart_item ) {
                    if ( $cart_item['product_id'] === $id ){
                        $qty = $cart_item['quantity'];
                    }
                }
            }

            $in_cart  = $qty ? ' added' : '';
            $p_type   = ninetheme_settings( 'shop_product_type', 3 );
            $p_type   = $qty && $p_type == 'custom' ? ' in-cart' : '';
        }

        if ( $btn_type == 'button' ) {
            $class = 'ninetheme-btn ninetheme-btn-primary';
        }
        if ( $btn_type == 'icon' ) {
            $class = 'ninetheme-add-to-cart-icon-link';
        }

        $defaults = array(
            'quantity' => 1,
            'class'    => implode(
                ' ',
                array_filter(
                    array(
                        $class,
                        'product_type_' . $type,
                        $in_stock ? 'add_to_cart_button' : '',
                        $type == 'variable' || $type == 'grouped' ? 'ninetheme-quick-shop-btn' : '',
                        $product->supports( 'ajax_add_to_cart' ) && $in_stock && $ajax == 1 ? 'ninetheme_ajax_add_to_cart' : ''
                    )
                )
            ),
            'attributes' => array(
                'data-product_id'  => $product->get_id(),
                'data-product_sku' => $product->get_sku(),
                'aria-label'       => wp_strip_all_tags( $product->add_to_cart_description() ),
                'rel'              => 'nofollow'
            )
        );

        $args     = wp_parse_args( $args, $defaults );
        $quantity = esc_attr( isset( $args['quantity'] ) ? $args['quantity'] : 1 );

        $btn = apply_filters( 'woocommerce_loop_add_to_cart_link',
            sprintf('<a href="%s" data-quantity="%s" class="%s" data-title="'.$text.'" %s>%s</a>',
                esc_url( $product->add_to_cart_url() ),
                apply_filters( 'ninetheme_minmax_quantity', $quantity ),
                esc_attr( isset( $args['class'] ) ? $args['class'].$p_type : '' ),
                isset( $args['attributes'] ) ? wc_implode_html_attributes( $args['attributes'] ) : '',
                $btn_type == 'icon' ? '' : '<span class="text">'.$text.'</span>'
            ),
            $product,
            $args
        );

        if ( $btn_type == 'icon' ) {
            return '<div class="ninetheme-add-to-cart-btn ninetheme-product-button btn-type-'.$btn_type.' product-type-'.$type.$in_cart.'" data-id="'.$id.'" data-label="'.$text.'">'.$hint.$btn.$icon.'</div>';
        } else {
            return $btn;
        }
    }
}


if ( !function_exists( 'ninetheme_wc_loop_add_to_cart_args' ) ) {
    add_filter( 'woocommerce_loop_add_to_cart_args', 'ninetheme_wc_loop_add_to_cart_args', 10, 2 );
    function ninetheme_wc_loop_add_to_cart_args() {
        global $product;
        $type     = $product->get_type();
        $ajax     = ninetheme_settings( 'ajax_addtocart_visibility', 1 );
        $in_stock = $product->is_purchasable() && $product->is_in_stock() ? true : false;
        $defaults = array(
            'quantity'   => 1,
            'class'      => implode(
                ' ',
                array_filter(
                    array(
                        'ninetheme-btn-text',
                        'product_type_' . $type,
                        $in_stock ? 'add_to_cart_button' : '',
                        $type == 'variable' || $type == 'grouped' ? 'ninetheme-quick-shop-btn' : '',
                        $product->supports( 'ajax_add_to_cart' ) && $in_stock && $ajax == 1 ? 'ninetheme_ajax_add_to_cart' : ''
                    )
                )
            ),
            'attributes' => array(
                'data-product_id'  => $product->get_id(),
                'data-product_sku' => $product->get_sku(),
                'aria-label'       => $product->add_to_cart_description(),
                'rel'              => 'nofollow'
            )
        );
        return $defaults;
    }
}


/**
* Product discount label
*/
if ( ! function_exists( 'ninetheme_product_discount' ) ) {
    function ninetheme_product_discount($echo=true)
    {
        global $product;
        $discount = get_post_meta( $product->get_id(), 'ninetheme_product_discount', true );
        if ( 'yes' != $discount && $product->is_on_sale() && ! $product->is_type('variable') ) {
            $regular = (float) $product->get_regular_price();
            $sale = (float) $product->get_sale_price();
            $precision = 1; // Max number of decimals
            $saving = $sale && $regular ? round( 100 - ( $sale / $regular * 100 ), 0 ) . '%' : '';
            if ( $echo == true ) {
                echo !empty( $saving ) ? '<span class="ninetheme-label ninetheme-discount ninetheme-bg-default">'.$saving.'</span>' : '';
            } else {
                return !empty( $saving ) ? '<span class="ninetheme-label ninetheme-discount ninetheme-bg-default">'.$saving.'</span>' : '';
            }
        }
    }
}


/**
* Get all product categories
*/
if ( ! function_exists( 'ninetheme_product_all_categories' ) ) {
    function ninetheme_product_all_categories()
    {
        $cats = get_terms( 'product_cat' );
        $categories = array();

        if ( empty( $cats ) ) {
            return;
        }

        foreach ( $cats as $cat ) {
            $categories[] = '<a href="'.esc_url( get_term_link( $cat ) ) .'" >'. esc_html( $cat->name ) .'</a>';
        }
        return implode( ', ', $categories );
    }
}


/**
* Get all product tags
*/
if ( ! function_exists( 'ninetheme_product_tags' ) ) {
    function ninetheme_product_tags()
    {
        $tags = get_terms( 'product_tag' );
        $alltags = array();
        if ( empty( $tags ) ) {
            return;
        }
        foreach ( $tags as $tag ) {
            $alltags[] = '<a href="'.esc_url( get_term_link( $tag ) ) .'" >'. esc_html( $tag->name ) .'</a>';
        }
        return implode( ', ', $alltags );
    }
}

/**
* Function to return list of the terms.
*/
if ( ! function_exists( 'ninetheme_product_terms' ) ) {
    function ninetheme_product_terms( $taxonomy, $label ) {

        $terms = get_the_terms( get_the_ID(), $taxonomy );

        if ( $terms && ! is_wp_error( $terms ) ) {

            $term_links = array();
            echo '<div class="ninetheme-meta-wrapper">';
                foreach ( $terms as $term ) {
                    $term_links[] = '<a href="' . esc_url( get_term_link( $term->slug, $taxonomy ) ) . '">' . $term->name . '</a>';
                }
                $all_terms = join( ', ', $term_links );

                echo !empty( $label ) ? '<span class="ninetheme-terms-label ninetheme-small-title">' . $label . '</span>' : '';
                echo '<span class="ninetheme-small-title terms-' . esc_attr( $term->slug ) . '">' . $all_terms . '</span>';
            echo '</div>';
        }
    }
}


/**
* Add product attribute name
*/
if ( ! function_exists( 'ninetheme_product_attr_label' ) ) {
    function ninetheme_product_attr_label()
    {
        global $product;

        $attributes = $product->get_attributes();
        foreach ( $attributes as $attribute ) {
            $values = array();
            $product_attributes[ 'attribute_' . sanitize_title_with_dashes( $attribute->get_name() ) ] = array(
                'label' => wc_attribute_label( $attribute->get_name() ),
                'value' => apply_filters( 'woocommerce_attribute', wpautop( wptexturize( implode( ', ', $values ) ) ), $attribute, $values ),
            );
            $label = $product_attributes[ 'attribute_' . sanitize_title_with_dashes( $attribute->get_name() ) ]['label'];
            $value = $product_attributes[ 'attribute_' . sanitize_title_with_dashes( $attribute->get_name() ) ]['value'];
            echo !empty( $label ) ? '<span class="product-attr_label">'.$label.'</span>' : '';
        }
    }
}


/**
* product page gallery
*/
if ( ! function_exists( 'ninetheme_product_gallery_slider' ) ) {
    function ninetheme_product_gallery_slider()
    {
        global $product;
        $images = $product->get_gallery_image_ids();
		$size   = apply_filters( 'ninetheme_product_thumb_size', 'woocommerce_single' );
		$id     = $product->get_id();
		$img    = get_the_post_thumbnail( $id, $size, [ 'class' => 'swiper-product-image' ] );
		$full   = get_the_post_thumbnail_url( $id, 'full' );
		$expand = '<span class="ninetheme-product-popup"><i class="fas fa-expand"></i></span>';

		if ( $images && count($images) > 1 ) {
			$type         = apply_filters( 'ninetheme_product_gallery_slider_layout', ninetheme_settings( 'product_gallery_slider_layout', 'bottom' ) );
			$direction    = 'left' == $type || 'right' == $type ? 'vertical' : 'horizontal';
			$iframe_video = get_post_meta( get_the_ID(), 'ninetheme_product_iframe_video', true );
			$popup_video  = get_post_meta( get_the_ID(), 'ninetheme_product_popup_video', true );
			$video_type   = apply_filters( 'ninetheme_product_video_type', get_post_meta( get_the_ID(), 'ninetheme_product_video_type', true ) );
			$col1_order   = '';
			$col2_order   = '';

			switch ( $type ) {
				case 'bottom':
					$col1_order = ' order-2';
					$col2_order = ' order-1';
					break;
				case 'left':
					$col1_order = ' col-md-2 order-1';
					$col2_order = ' col-md-10 order-md-2';
					break;
				case 'right':
					$col1_order = ' col-md-2 order-2';
					$col2_order = ' col-md-10 order-1';
					break;
				default:
					$col1_order = '';
					$col2_order = '';
					break;
			}
			?>
			<div class="ninetheme-swiper-slider-wrapper ninetheme-slider-thumbs-<?php echo esc_attr( $type ); ?>">
				<div class="row">

					<div class="col-12<?php echo esc_attr( $col1_order ); ?>">
						<div class="ninetheme-product-thumbnails ninetheme-swiper-thumbnails swiper-container">
							<div class="swiper-wrapper"></div>
						</div>
					</div>
					<div class="col-12<?php echo esc_attr( $col2_order ); ?>">
						<div class="ninetheme-product-gallery-main-slider ninetheme-swiper-main swiper-container">

							<?php
							if ( $popup_video && 'popup' == $video_type ) {
								echo '<a href="'.$popup_video.'" class="ninetheme-product-video-button" data-fancybox><i class="fa fa-play"></i></a>';
							}

							ninetheme_single_product_labels();
							?>
							<div class="swiper-wrapper ninetheme-gallery-items">
								<?php

								echo '<div class="swiper-slide ninetheme-swiper-slide-first" data-fancybox="gallery" data-src="'.esc_url( $full ).'">'.$expand.$img.'</div>';

								foreach ( $images as $image ) {
									$gimg = wp_get_attachment_image( $image, $size );
									$gurl = wp_get_attachment_image_url( $image, 'full' );
									echo '<div class="swiper-slide" data-fancybox="gallery" data-src="'.esc_url( $gurl ).'">'.$expand.$gimg.'</div>';
								}

								if ( $iframe_video && 'gallery' == $video_type ) {
									$iframe_html = '<iframe class="lazy" loading="lazy" data-src="https://www.youtube.com/embed/'.$iframe_video.'?modestbranding=1&rel=0&controls=0&autoplay=1&enablejsapi=1&showinfo=0&mute=1&loop=1" allow="autoplay; fullscreen; accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" frameborder="0" allowfullscreen></iframe>';
									echo '<div class="swiper-slide swiper-slide-video-item iframe-video"><div class="ninetheme-slide-iframe-wrapper" data-type="iframe" data-src="'.esc_url( $popup_video ).'" data-fancybox="gallery"><span class="ninetheme-product-popup"><i class="fas fa-expand"></i></span>'.$iframe_html.'</div></div>';
								}
								?>
							</div>

							<div class="swiper-button-next ninetheme-swiper-next"></div>
							<div class="swiper-button-prev ninetheme-swiper-prev"></div>

						</div>
					</div>

				</div>
			</div>
			<?php

		} else {
			echo '<div class="ninetheme-swiper-slider-wrapper">';
				echo '<div class="product-single-image" data-fancybox="gallery" data-src="'.esc_url( $full ).'">'.$expand.$img.'</div>';
			echo '</div>';
		}
    }
}

/**
* product page gallery strecth
*/
if ( ! function_exists( 'ninetheme_product_gallery_slider_stretch' ) ) {
    function ninetheme_product_gallery_slider_stretch()
    {
        global $product;
        $images = $product->get_gallery_image_ids();
        $size   = apply_filters( 'ninetheme_product_thumb_size', 'woocommerce_single' );
        $lazy = '1' == ninetheme_settings( 'theme_lazyload_images', 1 ) ? 'data-src' : 'src';
        $id     = $product->get_id();

        // gallery top first thumbnail
        $img    = get_the_post_thumbnail( $id, $size, [ 'class' => 'swiper-lazyy' ] );
        $full   = get_the_post_thumbnail_url( $id, 'full' );
        $url    = get_the_post_thumbnail_url( $id, $size );

        // gallery bottom first thumbnail
        $tsize = [90,0];
        $timg  = get_the_post_thumbnail( $id, $tsize );

        $type       = 'left';
        $direction  = 'vertical';

        $iframe_video = get_post_meta( get_the_ID(), 'ninetheme_product_iframe_video', true );
        $popup_video  = get_post_meta( get_the_ID(), 'ninetheme_product_popup_video', true );
        $video_type   = apply_filters( 'ninetheme_product_video_type', get_post_meta( get_the_ID(), 'ninetheme_product_video_type', true ) );
        $video_img    = get_template_directory_uri() . '/images/video-play.png';

        $col1_order = '';
        $col2_order = '';

        switch ( $type ) {
            case 'bottom':
                $col1_order = ' order-2';
                $col2_order = ' order-1';
                break;
            case 'left':
                $col1_order = ' col-md-2 order-1';
                $col2_order = ' col-md-10 order-md-2';
                break;
            case 'right':
                $col1_order = ' col-md-2 order-2';
                $col2_order = ' col-md-10 order-1';
                break;
            default:
                $col1_order = '';
                $col2_order = '';
                break;
        }
        $main_slider_options = json_encode( apply_filters('ninetheme_product_gallery_js_options',
            array(
                "loop"                 => false,
                "speed"                => 800,
                "spaceBetween"         => 0,
                "slidesPerView"        => 1,
                "direction"            => "horizontal",
                "autoPlay"             => false,
                "rewind"               => true,
                "observer"             => true,
                "observeParents"       => true,
                "observeSlideChildren" => true,
                "navigation"           => [
                    "nextEl" => ".ninetheme-product-gallery-main-slider .swiper-button-next",
                    "prevEl" => ".ninetheme-product-gallery-main-slider .swiper-button-prev"
                ]
            )
        ));
        $thumbs_slider_options = json_encode( apply_filters('ninetheme_product_gallery_thumbs_js_options',
            array(
                "spaceBetween"          => 10,
                "slidesPerView"         => 10,
                "direction"             => "horizontal",
                "breakpoints"   => [
                    "992" => [
                        "direction"     => "vertical",
                        "slidesPerView" => 5
                    ]
                ]
            )
        ));
        remove_action( 'woocommerce_product_thumbnails', 'woocommerce_show_product_thumbnails', 20 );

        ?>
        <div class="ninetheme-swiper-slider-wrapper ninetheme-slider-thumbs-vertical-left">

            <div class="ninetheme-product-gallery-main-slider ninetheme-swiper-main swiper-container" data-swiper-options="<?php echo esc_attr( $main_slider_options ); ?>">
                <?php
                if ( $popup_video && 'popup' == $video_type ) {
                    echo '<a href="'.$popup_video.'" class="ninetheme-product-video-button mfp-iframe" data-fancybox><i class="fa fa-play"></i></a>';

                }
                ninetheme_single_product_labels();
                do_action( 'woocommerce_product_thumbnails' );
                ?>
                <div class="swiper-wrapper ninetheme-gallery-items">
                    <?php
                    echo '<div class="swiper-slide ninetheme-swiper-slide-first" data-zoom-img="'.$full.'">'.$img.'</div>';
                    foreach ( $images as $image ) {
                        $gimg = wp_get_attachment_image( $image, $size );
                        $gurl = wp_get_attachment_image_url( $image, 'full' );
                        echo '<div class="swiper-slide" data-zoom-img="'.$gurl.'">'.$gimg.'</div>';
                    }
                    if ( $iframe_video && 'gallery' == $video_type ) {
                        $iframe_html = '<iframe class="lazy" loading="lazy" '.$lazy.'="https://www.youtube.com/embed/'.$iframe_video.'?modestbranding=1&rel=0&controls=0&autoplay=1&enablejsapi=1&showinfo=0&mute=1&loop=1" allow="autoplay; fullscreen; accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" frameborder="0" allowfullscreen></iframe>';
                        echo '<div class="swiper-slide swiper-slide-video-item iframe-video"><div class="ninetheme-slide-iframe-wrapper">'.$iframe_html.'</div></div>';
                    }
                    ?>
                </div>
                <div class="swiper-button-prev ninetheme-swiper-prev"></div>
                <div class="swiper-button-next ninetheme-swiper-next"></div>
            </div>

            <div class="ninetheme-product-thumbnails-vertical">
                <div class="ninetheme-product-thumbnails ninetheme-swiper-thumbnails swiper-container" data-swiper-options="<?php echo esc_attr( $thumbs_slider_options ); ?>">
                    <div class="swiper-wrapper">
                        <?php
                        echo '<div class="swiper-slide ninetheme-swiper-slide-first">'.$timg.'</div>';
                        foreach ( $images as $image ) {
                            echo '<div class="swiper-slide">'.wp_get_attachment_image( $image, $tsize ).'</div>';
                        }
                        if ( $iframe_video && 'gallery' == $video_type ) {
                            echo '<div class="swiper-slide swiper-slide-video-item"><img width="70" height="70" src="'.esc_url($video_img).'" /></div>';
                        }
                        ?>
                    </div>
                </div>
            </div>

        </div>
        <?php
    }
}

/**
* product page gallery
*/
if ( ! function_exists( 'ninetheme_product_gallery_slider_full' ) ) {
    function ninetheme_product_gallery_slider_full()
    {
        global $product;
        $images = $product->get_gallery_image_ids();
        $size   = apply_filters( 'ninetheme_product_thumb_size', 'woocommerce_single' );
        $lazy = '1' == ninetheme_settings( 'theme_lazyload_images', 1 ) ? 'data-src' : 'src';
        $id     = $product->get_id();

        // gallery top first thumbnail
        $img   = get_the_post_thumbnail( $id, $size );
        $url   = get_the_post_thumbnail_url( $id, $size );
        $full  = get_the_post_thumbnail_url( $id, 'full' );

        // gallery bottom first thumbnail
        $tsize = [90,0];
        $timg  = get_the_post_thumbnail( $id, $tsize );

        $iframe_video = get_post_meta( get_the_ID(), 'ninetheme_product_iframe_video', true );
        $popup_video  = get_post_meta( get_the_ID(), 'ninetheme_product_popup_video', true );
        $video_type   = apply_filters( 'ninetheme_product_video_type', get_post_meta( get_the_ID(), 'ninetheme_product_video_type', true ) );

        $main_slider_options = json_encode( apply_filters('ninetheme_product_gallery_showcase_js_options',
            array(
                "loop"                 => false,
                "speed"                => 800,
                "spaceBetween"         => 0,
                "slidesPerView"        => 1,
                "freeMode"             => false,
                "direction"            => "horizontal",
                "autoHeight"           => false,
                "observer"             => true,
                "observeParents"       => true,
                "observeSlideChildren" => true,
                "updateOnWindowResize" => true,
                "preventClicks"        => true,
                "preventClicksPropagation"        => true,
                "navigation"           => [
                    "nextEl" => ".ninetheme-product-gallery-main-slider .swiper-button-next",
                    "prevEl" => ".ninetheme-product-gallery-main-slider .swiper-button-prev"
                ]
            )
        ));
        $thumbs_slider_options = json_encode( apply_filters('ninetheme_product_gallery_thumbs_js_options',
            array(
                "loop"          => false,
                "speed"         => 1000,
                "spaceBetween"  => 10,
                "slidesPerView" => 6,
                "freeMode"      => false,
                "direction"     => "horizontal",
                "autoHeight"    => false,
                "preventClicks" => true,
                "navigation"    => [
                    "nextEl" => ".ninetheme-product-gallery-main-slider .swiper-button-next",
                    "prevEl" => ".ninetheme-product-gallery-main-slider .swiper-button-prev"
                ],
                "breakpoints"   => [
                    "768" => [
                        "slidesPerView" => 8
                    ]
                ]
            )
        ));

        remove_action( 'woocommerce_product_thumbnails', 'woocommerce_show_product_thumbnails', 20 );
        $fullscreen = '<span class="ninetheme-product-popup"><i class="fas fa-expand"></i></span>';
        ?>
        <div class="ninetheme-swiper-slider-wrapper ninetheme-slider-thumbs-bottom container-xl ninetheme-container-xl">

            <div class="ninetheme-product-gallery-main-slider ninetheme-swiper-main swiper-container col-12 col-lg-12" data-swiper-options="<?php echo esc_attr( $main_slider_options ); ?>">
                <?php
                if ( $popup_video && 'popup' == $video_type ) {
                    echo '<a href="'.$popup_video.'" class="ninetheme-product-video-button mfp-iframe" data-fancybox><i class="fa fa-play"></i></a>';
                }
                ninetheme_single_product_labels();
                do_action( 'woocommerce_product_thumbnails' );
                ?>
                <div class="swiper-wrapper ninetheme-gallery-items">
                    <?php
                    echo '<div class="swiper-slide ninetheme-swiper-slide-first" data-fancybox="gallery" data-src="'.esc_url( $full ).'">'.$fullscreen.$img.'</div>';
                    foreach ( $images as $image ) {
                        $gimg = wp_get_attachment_image( $image, $size );
                        $gurl = wp_get_attachment_image_url( $image, $size );
                        echo '<div class="swiper-slide" data-fancybox="gallery" data-src="'.esc_url( $gurl ).'">'.$fullscreen.$gimg.'</div>';
                    }
                    if ( $iframe_video && 'gallery' == $video_type ) {
                        $iframe_html = '<iframe class="lazy" loading="lazy" '.$lazy.'="https://www.youtube.com/embed/'.$iframe_video.'?playlist='.$iframe_video.'&modestbranding=1&rel=0&controls=0&autoplay=1&enablejsapi=1&showinfo=0&mute=1&loop=1&start=5&end=25" allow="autoplay; fullscreen; accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" frameborder="0" allowfullscreen></iframe>';
                        echo '<div class="swiper-slide swiper-slide-video-item iframe-video"><div class="ninetheme-slide-iframe-wrapper">'.$iframe_html.'</div></div>';
                    }
                    ?>
                </div>
                <div class="swiper-button-prev ninetheme-swiper-prev"></div>
                <div class="swiper-button-next ninetheme-swiper-next"></div>
            </div>

            <div class="ninetheme-product-thumbnails ninetheme-swiper-thumbnails ninetheme-slider-thumbnails-full swiper-container col-12 col-lg-12" data-swiper-options="<?php echo esc_attr( $thumbs_slider_options ); ?>">
                <div class="swiper-wrapper">
                    <?php
                    echo '<div class="swiper-slide ninetheme-swiper-slide-first">'.$timg.'</div>';
                    foreach ( $images as $image ) {
                        echo '<div class="swiper-slide">'.wp_get_attachment_image( $image, $tsize ).'</div>';
                    }
                    if ( $iframe_video && 'gallery' == $video_type ) {
                        echo '<div class="swiper-slide swiper-slide-video-item"><div class="ninetheme-slide-video-item-icon" data-height="90"><i class="fa fa-play"></i></div></div>';
                    }
                    ?>
                </div>
            </div>

        </div>
        <?php
    }
}

/**
* product page gallery
*/
if ( ! function_exists( 'ninetheme_product_gallery_slider_carousel' ) ) {
    function ninetheme_product_gallery_slider_carousel()
    {
        global $product;
        $images = $product->get_gallery_image_ids();
        $size   = apply_filters( 'ninetheme_product_carousel_lightbox_images_size', 'woocommerce_single' );
        $csize  = apply_filters( 'ninetheme_product_carousel_images_size', 'medium_large' );
        $lazy   = '1' == ninetheme_settings( 'theme_lazyload_images', 1 ) ? 'data-src' : 'src';
        $id     = $product->get_id();

        // gallery top first thumbnail
        $img = get_the_post_thumbnail( $id, $csize );
        $url = get_the_post_thumbnail_url( $id, 'full' );

        $iframe_video = get_post_meta( get_the_ID(), 'ninetheme_product_iframe_video', true );
        $popup_video  = get_post_meta( get_the_ID(), 'ninetheme_product_popup_video', true );
        $video_type   = apply_filters( 'ninetheme_product_video_type', get_post_meta( get_the_ID(), 'ninetheme_product_video_type', true ) );
        $loader       = '<div class="loading-wrapper"><span class="ajax-loading"></span></div>';

        $main_slider_options = json_encode( apply_filters('ninetheme_product_gallery_showcase_js_options',
            array(
                "loop"                 => '1' == ninetheme_settings('single_shop_showcase_carousel_loop', '1') ? true : false,
                "roundLengths"         => true,
                "speed"                => 800,
                "spaceBetween"         => 0,
                "slidesPerView"        => 1,
                "freeMode"             => false,
                "direction"            => "horizontal",
                "centeredSlides"       => true,
                "slideToClickedSlide"  => true,
                "grabCursor"           => true,
                "autoHeight"           => false,
                "preventClicks"        => false,
                "observer"             => true,
                "observeParents"       => true,
                "observeSlideChildren" => true,
                "navigation"           => [
                    "nextEl" => ".ninetheme-product-gallery-main-slider-carousel .swiper-button-next",
                    "prevEl" => ".ninetheme-product-gallery-main-slider-carousel .swiper-button-prev"
                ],
                "pagination"           => [
                    "el"        => ".ninetheme-product-gallery-main-slider-carousel .swiper-pagination",
                    "type"      => "bullets",
                    "clickable" => true
                ],
                "effect"               => ninetheme_settings('single_shop_showcase_carousel_effect_type', ''),
                "coverflowEffect"      => [
                    "rotate"       => ninetheme_settings('single_shop_showcase_carousel_coverflow_rotate', ''),
                    "slideShadows" => false
                ],
                "breakpoints"          => [
                    "768" => [
                        "slidesPerView" => 3
                    ],
                    "1024" => [
                        "slidesPerView" => 4
                    ]
                ]
            )
        ));
        remove_action( 'woocommerce_product_thumbnails', 'woocommerce_show_product_thumbnails', 20 );
        $fullscreen = '<span class="ninetheme-product-popup"><i class="fas fa-expand"></i></span>';
        ?>
        <div class="ninetheme-swiper-slider-wrapper">

            <div class="ninetheme-product-gallery-main-slider-carousel ninetheme-swiper-main swiper-container" data-swiper-options="<?php echo esc_attr( $main_slider_options ); ?>">
                <div class="swiper-wrapper ninetheme-gallery-items">
                    <?php
                    if ( $iframe_video && 'gallery' == $video_type ) {
                        $iframe_html = '<iframe class="lazy" loading="lazy" '.$lazy.'="https://www.youtube.com/embed/'.$iframe_video.'?modestbranding=1&rel=0&controls=0&autoplay=1&enablejsapi=1&showinfo=0&mute=1&loop=1" allow="autoplay; fullscreen; accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" frameborder="0" allowfullscreen></iframe>';
                        echo '<div class="swiper-slide swiper-slide-video-item iframe-video"><div class="ninetheme-slide-iframe-wrapper">'.$iframe_html.'</div></div>';
                    }
                    echo '<div class="swiper-slide ninetheme-swiper-slide-first" data-zoom-img="'.esc_url( $url ).'" data-fancybox="gallery" data-src="'.esc_url( $url ).'">'.$fullscreen.$img.'</div>';
                    foreach ( $images as $image ) {
                        $gimg = wp_get_attachment_image( $image, $csize );
                        $gurl = wp_get_attachment_image_url( $image, 'full' );
                        echo '<div class="swiper-slide" data-zoom-img="'.esc_url( $gurl ).'" data-fancybox="gallery" data-src="'.esc_url( $gurl ).'">'.$fullscreen.$gimg.'</div>';
                    }
                    ?>
                </div>
                <div class="swiper-pagination"></div>
                <div class="swiper-button-prev ninetheme-swiper-prev"></div>
                <div class="swiper-button-next ninetheme-swiper-next"></div>
            </div>

        </div>
        <?php
    }
}

/**
* product page gallery
*/
if ( ! function_exists( 'ninetheme_product_gallery_grid' ) ) {
    function ninetheme_product_gallery_grid()
    {
        global $product;
        $column = apply_filters( 'ninetheme_product_gallery_type_column', ninetheme_settings( 'ninetheme_product_gallery_grid_column', '2' ) );
        $images = $product->get_gallery_image_ids();
        $size   = apply_filters( 'ninetheme_product_thumb_size', 'woocommerce_single' );
        $lazy   = '1' == ninetheme_settings( 'theme_lazyload_images', 1 ) ? 'data-src' : 'src';
        $id     = $product->get_id();

        // gallery top first thumbnail
        $img   = get_the_post_thumbnail( $product->get_id(), $size );
        $url   = get_the_post_thumbnail_url( $product->get_id(), $size );

        $iframe_video = get_post_meta( get_the_ID(), 'ninetheme_product_iframe_video', true );
        $popup_video  = get_post_meta( get_the_ID(), 'ninetheme_product_popup_video', true );
        $video_type   = apply_filters( 'ninetheme_product_video_type', get_post_meta( get_the_ID(), 'ninetheme_product_video_type', true ) );

        switch ( $column ) {
            case '1':
                $tsize = 'woocommerce_single';
                break;
            case '2':
                $tsize = [500,600];
                break;
            case '3':
                $tsize = [300,500];
                break;
            case '4':
                $tsize = [200,300];
                break;
            default:
                $tsize = [400,500];
                break;
        }
        remove_action( 'woocommerce_product_thumbnails', 'woocommerce_show_product_thumbnails', 20 );
        ?>
        <div class="ninetheme-product-main-gallery-grid grid-column-<?php echo esc_attr( $column ); ?>">
            <?php
            if ( $iframe_video || $popup_video ) {
                if ( 'gallery' == $video_type ) {

                    if ( $iframe_video && 'gallery' == $video_type ) {
                        $iframe_html = '<iframe class="lazy" loading="lazy" '.$lazy.'="https://www.youtube.com/embed/'.$iframe_video.'?modestbranding=1&rel=0&controls=0&autoplay=1&enablejsapi=1&showinfo=0&mute=1&loop=1" allow="autoplay; fullscreen; accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" frameborder="0" allowfullscreen></iframe>';
                        echo '<div class="ninetheme-gallery-grid-item ninetheme-gallery-grid-video-item iframe-video" data-src="'.esc_url( $popup_video ).'" data-fancybox="gallery"><span class="ninetheme-product-popup"><i class="fas fa-expand"></i></span>'.$iframe_html.'</div>';
                    }
                } else {
                    if ( $popup_video ) {
                        echo '<a href="'.$popup_video.'" class="ninetheme-product-video-button mfp-iframe" data-fancybox><i class="fa fa-play"></i></a>';
                    }
                }
            }
            ninetheme_single_product_labels();
            do_action( 'woocommerce_product_thumbnails' );
            echo '<div class="ninetheme-gallery-grid-item ninetheme-gallery-grid-item-first" data-src="'.esc_url( $url ).'" data-fancybox="gallery"><span class="ninetheme-product-popup"><i class="fas fa-expand"></i></span>'.$img.'</div>';
            if ( !empty( $images ) ) {
                echo '<div class="row row-cols-1 row-cols-sm-'.esc_attr( $column ).'">';
                foreach ( $images as $image ) {
                    $gimg = wp_get_attachment_image( $image, $tsize );
                    $gurl = wp_get_attachment_image_url( $image, $size );
                    echo '<div class="col ninetheme-gallery-grid-item mt-30" data-src="'.esc_url( $gurl ).'" data-fancybox="gallery"><span class="ninetheme-product-popup"><i class="fas fa-expand"></i></span>'.$gimg.'</div>';
                }
                echo '</div>';
            }
            ?>
        </div>
        <?php
    }
}


if ( ! function_exists( 'ninetheme_single_product_nav_two' ) ) {
    function ninetheme_single_product_nav_two() {

        if ( '0' == ninetheme_settings('single_shop_nav_visibility', '1') || 'bottom' == ninetheme_settings('single_shop_nav_position', 'both') ) {
            return;
        }
        $prev    = get_previous_post();
        $prevID  = $prev ? $prev->ID : '';
        $next    = get_next_post();
        $nextID  = $next ? $next->ID : '';
        $imgSize = array(40,40,true);
        ?>
        <div class="ninetheme-product-nav ninetheme-flex ninetheme-align-center">
            <?php if ( $prevID ) : ?>
                <a class="product-nav-link ninetheme-nav-prev" href="<?php echo esc_url( get_permalink( $prevID ) ); ?>">
                    <span class="ninetheme-nav-arrow ninetheme-nav-prev-arrow"></span>
                    <span class="product-nav-content">
                        <?php echo apply_filters( 'ninetheme_products_nav_image', get_the_post_thumbnail( $prevID, $imgSize ) ); ?>
                        <span class="product-nav-title"><?php echo get_the_title( $prevID ); ?></span>
                    </span>
                </a>
            <?php else : ?>
                <a class="product-nav-link ninetheme-nav-prev disabled" href="#0">
                    <span class="ninetheme-nav-arrow ninetheme-nav-prev-arrow"></span>
                </a>
            <?php endif ?>

            <a href="<?php echo apply_filters( 'ninetheme_single_product_back_btn_url', get_permalink( wc_get_page_id( 'shop' ) ) ); ?>" class="product-nav-link ninetheme-nav-shop">
                <span class="ninetheme-shop-link-inner">
                    <span class="ninetheme-shop-link-icon"></span>
                    <span class="ninetheme-shop-link-icon"></span>
                </span>
            </a>

            <?php if ( $nextID ) : ?>
                <a class="product-nav-link ninetheme-nav-next" href="<?php echo esc_url( get_permalink( $nextID ) ); ?>">
                    <span class="ninetheme-nav-arrow ninetheme-nav-next-arrow"></span>
                    <span class="product-nav-content">
                        <?php echo apply_filters( 'ninetheme_products_nav_image', get_the_post_thumbnail( $nextID, $imgSize ) ); ?>
                        <span class="product-nav-title"><?php echo get_the_title( $nextID ); ?></span>
                    </span>
                </a>
            <?php else : ?>
                <a class="product-nav-link ninetheme-nav-next disabled" href="#0">
                    <span class="ninetheme-nav-arrow ninetheme-nav-next-arrow"></span>
                </a>
            <?php endif ?>
        </div>
        <?php
    }
}

if ( ! function_exists( 'ninetheme_single_product_nav_three' ) ) {
    add_action( 'ninetheme_after_wc_single', 'ninetheme_single_product_nav_three' );
    function ninetheme_single_product_nav_three() {

        if ( '0' == ninetheme_settings('single_shop_nav_visibility', '1') || 'top' == ninetheme_settings('single_shop_nav_position', 'both') ) {
            return;
        }
        $prev    = get_previous_post();
        $prevID  = $prev ? $prev->ID : '';
        $next    = get_next_post();
        $nextID  = $next ? $next->ID : '';
        $imgSize = 'thumbnail';
        ?>
        <div class="ninetheme-product-nav-bg">
            <div class="container-xl ninetheme-container-xl">
                <div class="row">
                    <?php if ( $prevID ) : ?>
                        <a class="product-nav-link ninetheme-nav-prev col-12 col-md-6" href="<?php echo esc_url( get_permalink( $prevID ) ); ?>">
                            <h5 class="product-nav-title"><?php echo get_the_title( $prevID ); ?></h5>
                        </a>
                    <?php endif ?>

                    <?php if ( $nextID ) : ?>
                        <a class="product-nav-link ninetheme-nav-next col-12 col-md-6" href="<?php echo esc_url( get_permalink( $nextID ) ); ?>">
                            <h5 class="product-nav-title"><?php echo get_the_title( $nextID ); ?></h5>
                        </a>
                    <?php endif ?>
                </div>
            </div>
        </div>
        <?php
    }
}


/**
* Add stock progressbar
*/
if ( ! function_exists( 'ninetheme_product_stock_progress_bar' ) ) {
    function ninetheme_product_stock_progress_bar() {
        global $post,$product;
        $product_id   = $post->ID;
        $progressbar  = ninetheme_settings( 'single_shop_progressbar_visibility', '0' );
        $manage_stock = get_post_meta( $product_id, '_manage_stock', true );

        if ( $manage_stock != 'yes' || '0' == $progressbar ) {
            return;
        }

        $current_stock = get_post_meta( $product_id, '_stock', true );
        $total_sold    = $product->get_total_sales();
        $percentage    = $total_sold > 0 && $current_stock > 0 ? round( $total_sold / $current_stock * 100 ) : 0;

        if ( $current_stock > 0 ) {
            ?>
            <div class="ninetheme-summary-item ninetheme-single-product-stock">
                <div class="stock-details">
                    <div class="stock-sold"><?php esc_html_e( 'Ordered:', 'crisop' ); ?><span> <?php echo esc_html( $total_sold ); ?></span></div>
                    <div class="current-stock"><?php esc_html_e( 'Items available:', 'crisop' ); ?><span> <?php echo esc_html( $current_stock ); ?></span></div>
                </div>
                <div class="ninetheme-product-stock-progress">
                    <div class="ninetheme-product-stock-progressbar" data-stock-percent="<?php echo esc_attr( $percentage ); ?>%"></div>
                </div>
            </div>
            <?php
        }
    }
}

/**
* Add size guide popup
*/
if ( ! function_exists( 'ninetheme_product_popup_details' ) ) {
    add_action( 'woocommerce_single_product_summary', 'ninetheme_product_popup_details', 35 );
    function ninetheme_product_popup_details()
    {
        $product_id = get_the_ID();
        $guide      = get_post_meta( $product_id, 'ninetheme_product_size_guide', true );
        $question   = ninetheme_settings( 'single_shop_question_form_template', null );
        $delivery   = ninetheme_settings( 'single_shop_delivery_template', null );
        if ( $guide || $question || $delivery && '0' != ninetheme_settings( 'product_popups_section_visibility', '1' ) ) {
            ?>
            <div class="ninetheme-summary-item ninetheme-product-popup-details">
                <?php
                ninetheme_product_size_guide();
                ninetheme_product_delivery_return();
                ninetheme_product_question_form();
                ninetheme_product_estimated_delivery();
                ninetheme_product_views();
                ?>
            </div>
            <?php
        }
    }
}
/**
* Add size guide popup
*/
if ( ! function_exists( 'ninetheme_product_size_guide' ) ) {
    function ninetheme_product_size_guide()
    {
        global $product;
        $id          = $product->get_id();

        $guide_id    = get_post_meta( $id, 'ninetheme_product_size_guide', true );
        $template_id = $guide_id ? $guide_id : ninetheme_settings( 'product_size_guide_template', null );

        if ( null == $template_id || '' == $template_id || '0' == ninetheme_settings( 'product_size_guide_visibility', '0' ) ) {
            return;
        }

        $cats          = wc_get_product_term_ids( $id, 'product_cat' );
        $tags          = wc_get_product_term_ids( $id, 'product_tag' );
        $total_terms   = !empty( $cats ) && !empty( $tags ) ? array_merge( $cats, $tags ) : $cats;
        $total_terms[] = $id;
        $cat_exclude   = ninetheme_settings( 'product_size_guide_category_exclude', null );
        $cat_exclude   = $cat_exclude ? $cat_exclude : array();
        $tag_exclude   = ninetheme_settings( 'product_size_guide_tag_exclude', null );
        $tag_exclude   = $tag_exclude ? $tag_exclude : array();
        $total_exclude = array_merge( $cat_exclude, $tag_exclude );
        $text          = ninetheme_settings( 'size_guide_text' ) ? ninetheme_settings( 'size_guide_text' ) : esc_html__( 'Size Guide', 'crisop' );
        $icon          = ninetheme_settings( 'size_guide_icon' ) ? ninetheme_settings( 'size_guide_icon' ) : ninetheme_svg_lists('ruler', 'ninetheme-svg-icon').'&nbsp';

        if ( array_intersect( $total_exclude, $total_terms ) ) {
            return;
        }

        ?>
        <div class="ninetheme-size-guide-btn has-svg-icon ninetheme-flex ninetheme-align-center">
            <?php printf('%s', $icon); ?>
            <a href="#ninetheme_size_guide_<?php echo esc_attr( $template_id ); ?>" data-fancybox><?php echo esc_html( $text ); ?></a>
        </div>
        <div class="ninetheme-single-product-size-guide ninetheme-hide" id="ninetheme_size_guide_<?php echo esc_attr( $template_id ); ?>">
            <?php
            if ( $guide_id ) {
                echo do_shortcode('[ninetheme-template id="'.$guide_id.'" css="yes"]');
            } else {
                echo ninetheme_print_elementor_templates( 'product_size_guide_template', '' );
            }
            ?>
        </div>
        <?php
    }
}


/**
* Add question form popup
*/
if ( ! function_exists( 'ninetheme_product_question_form' ) ) {
    function ninetheme_product_question_form()
    {
        global $product;
        $template_id = ninetheme_settings( 'single_shop_question_form_template', null );

        if ( null == $template_id || '' == $template_id ) {
            return;
        }
        ?>
        <div class="ninetheme-product-question-btn has-svg-icon ninetheme-flex ninetheme-align-center">
            <?php echo ninetheme_svg_lists('question', 'ninetheme-svg-icon'); ?>&nbsp;
            <a href="#ninetheme_product_question_<?php echo esc_attr( $template_id ); ?>" data-fancybox><?php esc_html_e( 'Size Guide', 'crisop' ); ?></a>
        </div>
        <div class="ninetheme-single-product-question ninetheme-hide" id="ninetheme_product_question_<?php echo esc_attr( $template_id ); ?>">
            <?php echo ninetheme_print_elementor_templates( 'single_shop_question_form_template', '' ); ?>
        </div>
        <?php
    }
}


/**
* Add delivery and return popup
*/
if ( ! function_exists( 'ninetheme_product_delivery_return' ) ) {
    function ninetheme_product_delivery_return()
    {
        global $product;

        $template_id = ninetheme_settings( 'single_shop_delivery_template', null );

        if ( null == $template_id || '' == $template_id || '0' == ninetheme_settings( 'product_delivery_visibility', '1' ) ) {
            return;
        }

        $id            = $product->get_id();
        $cats          = wc_get_product_term_ids( $id, 'product_cat' );
        $tags          = wc_get_product_term_ids( $id, 'product_tag' );
        $total_terms   = !empty( $cats ) && !empty( $tags ) ? array_merge( $cats, $tags ) : $cats;
        $total_terms[] = $id;
        $cat_exclude   = ninetheme_settings( 'single_shop_delivery_template_category_exclude', null );
        $cat_exclude   = $cat_exclude ? $cat_exclude : array();
        $tag_exclude   = ninetheme_settings( 'single_shop_delivery_template_tag_exclude', null );
        $tag_exclude   = $tag_exclude ? $tag_exclude : array();
        $text          = ninetheme_settings( 'product_delivery_text' ) ? ninetheme_settings( 'product_delivery_text' ) : esc_html__( 'Delivery & Return', 'crisop' );
        $icon          = ninetheme_settings( 'product_delivery_icon' ) ? ninetheme_settings( 'product_delivery_icon' ) : ninetheme_svg_lists('delivery-return', 'ninetheme-svg-icon').'&nbsp';

        $total_exclude    = array_merge( $cat_exclude, $tag_exclude );

        if ( array_intersect( $total_exclude, $total_terms ) ) {
            return;
        }
        ?>
        <div class="ninetheme-product-delivery-btn has-svg-icon ninetheme-flex ninetheme-align-center">
            <?php printf('%s', $icon); ?>
            <a href="#ninetheme_product_delivery_<?php echo esc_attr( $template_id ); ?>" data-fancybox><?php echo esc_html( $text ); ?></a>
        </div>
        <div class="ninetheme-single-product-delivery ninetheme-hide" id="ninetheme_product_delivery_<?php echo esc_attr( $template_id ); ?>">
            <?php echo ninetheme_print_elementor_templates( 'single_shop_delivery_template', '' ); ?>
        </div>
        <?php
    }
}

if ( ! function_exists( 'ninetheme_product_views' ) ) {
    function ninetheme_product_views()
    {
        if ( '0' == ninetheme_settings('single_shop_visit_count_visibility', '0' ) ) {
            return;
        }
        wp_enqueue_script( 'jquery-cookie');
        global $product;

        $data[] = ninetheme_settings( 'visit_count_min' ) ? '"min":' . ninetheme_settings( 'visit_count_min' ) : '"min":10';
        $data[] = ninetheme_settings( 'visit_count_max' ) ? '"max":' . ninetheme_settings( 'visit_count_max' ) : '"max":50';
        $data[] = ninetheme_settings( 'visit_count_delay' ) ? '"delay":' . ninetheme_settings( 'visit_count_delay' ) : '"delay":30000';
        $data[] = ninetheme_settings( 'visit_count_change' ) ? '"change":' . ninetheme_settings( 'visit_count_change' ) : '"change":5';
        $data[] = '"id":' . $product->get_id();
        $text1  = ninetheme_settings( 'visitor_count_text' ) ? ninetheme_settings( 'visitor_count_text' ) : esc_html__( 'people', 'crisop' );
        $text2  = ninetheme_settings( 'visitor_count_text2' ) ? ninetheme_settings( 'visitor_count_text2' ) : esc_html__( 'are viewing this right now', 'crisop' );
        $icon   = ninetheme_settings( 'visitor_count_icon' ) ? ninetheme_settings( 'visitor_count_icon' ) : ninetheme_svg_lists('smile', 'ninetheme-svg-icon').'&nbsp';
        ?>
        <div class="ninetheme-product-view" data-product-view='{<?php echo implode(',', $data ); ?>}'>
            <?php printf('%s', $icon); ?>
            <span><span class="ninetheme-view-count">&nbsp;</span> <?php echo esc_html( $text1 ); ?></span>&nbsp;
            <?php echo esc_html( $text2 ); ?>
        </div>
        <?php
    }
}

if ( ! function_exists( 'ninetheme_product_estimated_delivery' ) ) {
    function ninetheme_product_estimated_delivery() {

        if ( '0' == ninetheme_settings('single_shop_estimated_delivery_visibility', '0' ) ) {
            return;
        }

        $min_ed = ninetheme_settings('single_shop_min_estimated_delivery');
        $max_ed = ninetheme_settings('single_shop_max_estimated_delivery');
        $text   = ninetheme_settings( 'estimated_delivery_text' );
        $icon   = ninetheme_settings( 'estimated_delivery_icon' );

        $min   = $min_ed ? $min_ed : 3;
        $from  = '+' . $min;
        $from .= ' ' . ( $min = 1 ? 'day' : 'days' );

        $max = $max_ed ? (int) $max_ed : 7;
        $to  = '+' . $max;
        $to .= ' ' . ( $max = 1 ? 'day' : 'days' );

        $now = get_date_from_gmt( date('Y-m-d H:i:s'), 'Y-m-d' );
        $est_days = array();

        $format = esc_html__( 'M d', 'crisop' );
        $est_days[] = date_i18n( $format, strtotime( $now . $from ), true );
        $est_days[] = date_i18n( $format, strtotime( $now . $to ), true );

        if ( !empty( $est_days ) ) {

            $text = $text ? $text : esc_html__( 'Estimated Delivery:', 'crisop' );
            $icon = $icon ? $icon : ninetheme_svg_lists('shipping', 'ninetheme-svg-icon').'&nbsp';
            ?>
            <div class="ninetheme-estimated-delivery">
                <?php printf('%s', $icon); ?>
                <span class="estimated-text"><?php echo esc_html( $text ).'&nbsp'; ?></span>
                <span class="estimated-date"><?php echo implode( ' ', $est_days ); ?></span>
            </div>
            <?php
        }
    }
}


/**
* Add product excerpt
*/
if ( ! function_exists( 'ninetheme_product_excerpt' ) ) {
    function ninetheme_product_excerpt()
    {
        global $product;
        if ( $product->get_short_description() ) {
            printf('<p class="ninetheme-product-excerpt">%s</p>', $product->get_short_description() );
        }
    }
}

/**
* Add product rating
*/
if ( ! function_exists( 'ninetheme_product_rating' ) ) {
    function ninetheme_product_rating()
    {
        global $product;
        $rating_count = $product->get_rating_count();
        $review_count = $product->get_review_count();
        $average      = $product->get_average_rating();
        if ( $product->get_average_rating() ) {
            ?>
            <div class="ninetheme-rating star-rating">
                <span data-width="<?php echo esc_attr( ( $average / 5 ) * 100  ); ?>"></span>
                <?php if ( comments_open() ) { ?>
                    <a href="#reviews" class="ninetheme-review-link ninetheme-small-title" rel="nofollow"><?php printf( _n( '%s review', '%s reviews', $review_count, 'crisop' ), '<span class="count">' . esc_html( $review_count ) . '</span>' ); ?></a>
                <?php } ?>
            </div>
            <?php
        }
    }
}

/**
* Add product rating
*/
if ( ! function_exists( 'ninetheme_product_meta' ) ) {
    function ninetheme_product_meta()
    {
        global $product;
        ?>
        <div class="ninetheme-summary-item ninetheme-product-meta">
            <?php do_action( 'woocommerce_product_meta_start' ); ?>
            <?php echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="ninetheme-small-title posted_in"><span class="label">' . _n( 'Category:', 'Categories:', count( $product->get_category_ids() ), 'crisop' ) . ' ', '</span></span>' ); ?>
            <?php echo wc_get_product_tag_list( $product->get_id(), ', ', '<span class="ninetheme-small-title tagged_as">' . _n( 'Tag:', 'Tags:', count( $product->get_tag_ids() ), 'crisop' ) . ' ', '</span>' ); ?>
            <?php do_action( 'woocommerce_product_meta_end' ); ?>
        </div>
        <?php
    }
}


/**
* Get product sku
*/
if ( ! function_exists( 'ninetheme_product_sku' ) ) {
    function ninetheme_product_sku()
    {
        global $product;
        if ( $product->get_sku() ) {
        echo '<div class="ninetheme-product-sku"><span class="label">'.esc_html__('SKU:', 'crisop') .' </span><span class="value">'.esc_html( $product->get_sku() ).'</span></div>';
        }
    }
}


if ( ! function_exists( 'ninetheme_product_badge' ) ) {
    function ninetheme_product_badge($echo=true)
    {
        global $product;
        $custom_badge = get_post_meta( $product->get_id(), 'ninetheme_use_custom_badge', true );
        if ( 'yes' == $custom_badge ) {
            $groups = get_post_meta( $product->get_id(), 'ninetheme_badge_group', array() );
            foreach ( $groups as $group ) {
                foreach ( $group as $badge ) {
                    if ( !empty( $badge ) && !empty( $badge['BadgeTitle'] ) ) {
                        $title = $badge['BadgeTitle'];
                        $color_select = !empty( $badge['BadgeColorSelect'] ) ? $badge['BadgeColorSelect'] : 'default';
                        $color = $color_select == 'custom' && !empty( $badge['BadgeColor'] ) ? ' data-label-color="'.$badge['BadgeColor'].'"' : '';
                        echo '<span class="ninetheme-label ninetheme-badge ninetheme-bg-'.esc_attr( $color_select ).'"'.$color.'>'.esc_html( $title ).'</span> ';
                    }
                }
            }
        } else {
            if ( $product->is_on_sale() ) {
                echo '<span class="ninetheme-label ninetheme-badge ninetheme-bg-default">'.esc_html__( 'Sale!', 'crisop' ).'</span>';
            }
        }
    }
}


if ( ! function_exists( 'ninetheme_featured_product_icon' ) ) {
    function ninetheme_featured_product_icon()
    {
        global $product;

        $output = '';

        if ( $product->is_featured() ) {
            $output .= '<a href="'.esc_url( add_query_arg('featured','yes', wc_get_page_permalink( 'shop' ) ) ).'" class="featured-link">';
            $output .= '<img src="'.get_template_directory_uri().'/images/star.png" alt="star">';
            $output .= '</a>';
        }

        return $output;
    }
}


if ( ! function_exists( 'ninetheme_only_left_in_stock' ) ) {
    function ninetheme_only_left_in_stock()
    {
        global $product;

        $output = '';

        $managestock    = $product->managing_stock();
        $stock_quantity = $product->get_stock_quantity();
        $stock_format   = esc_html__('Only %s left in stock','crisop');

        if ( $managestock && $stock_quantity < 10 ) {
            $output .= '<div class="product-message color-danger">'.sprintf( $stock_format, $stock_quantity ).'</div>';
        }
        return $output;
    }
}


if ( ! function_exists( 'ninetheme_shipping_class_name' ) ) {
    function ninetheme_shipping_class_name( $type = 'name' )
    {
        global $product;
        $class_id = $product->get_shipping_class_id();

        if ( !$class_id ) {
            return;
        }
        $type = $type == 'desc' ? 'description' : 'name';

        $term = get_term_by( 'id', $class_id, 'product_shipping_class' );

        return $term && ! is_wp_error( $term ) ? '<span class="ninetheme-product-shipping-message">'.$term->$type.'</span>' : '';
    }
}


/**
* Single product labels
*/
if ( ! function_exists( 'ninetheme_single_product_labels' ) ) {
    function ninetheme_single_product_labels()
    {
        if ( '0' == ninetheme_settings('single_shop_top_labels_visibility', '1' ) ) {
            return;
        }
        echo '<div class="ninetheme-product-labels">';
            ninetheme_product_badge();
            ninetheme_product_discount();
        echo '</div>';
    }
}


if ( ! function_exists( 'ninetheme_loop_category_title' ) ) {

    /**
    * Show the subcategory title in the product loop.
    *
    * @param object $category Category object.
    */
    function ninetheme_loop_category_title( $category ) {
        ?>
        <h4 class="cat-name">
            <?php
            echo esc_html( $category->name );

            if ( $category->count > 0 ) {
                echo '<span class="cat-count">' . esc_html( $category->count ) . '</span>';
            }
            ?>
        </h4>
        <?php
    }
}


/**
* product brand
*/
if ( ! function_exists( 'ninetheme_product_brands' ) ) {
    function ninetheme_product_brands()
    {
        global $product;
        $brands = '';
        $metaid = defined( 'YITH_WCBR' ) ? 'yith_product_brand' : 'ninetheme_product_brands';
        $terms = get_the_terms( $product->get_id(), $metaid );
        if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) {
            $brands = array();
            foreach ( $terms as $term ) {
                if ( $term->parent == 0 ) {
                    $brands[] = sprintf( '<a class="ninetheme-brands" href="%s" itemprop="brand" title="%s">%s</a>',
                        get_term_link( $term ),
                        $term->slug,
                        $term->name
                    );
                }
            }
        }
        echo !empty( $brands ) ? '<span class="ninetheme-brands"><span class="label">'.esc_html__('Brands: ', 'crisop' ) .'</span><span class="links">' .implode( ', ', $brands ) .'</span></span>' : '';
    }
}


/**
*  add custom color field to for product badge
*/
if ( ! function_exists( 'ninetheme_wc_product_meta_color' ) ) {

    function ninetheme_wc_product_meta_color( $field )
    {
        global $thepostid, $post;

        $thepostid      = empty( $thepostid ) ? $post->ID : $thepostid;
        $field['class'] = isset( $field['class'] ) ? $field['class'] : 'ninetheme-color-field';
        $field['value'] = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );

        echo '<p class="form-field ' . esc_attr( $field['id'] ) . '_field"><label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>
        <input type="text" class="ninetheme-color-field" name="' . esc_attr( $field['id'] ) . '" id="' . esc_attr( $field['id'] ) . '" value="' . esc_attr( $field['value'] ) . '" /></p>';
    }
}

function ninetheme_wc_repeatable_meta_display() {
    global $thepostid, $post;
    $thepostid   = empty( $thepostid ) ? $post->ID : $thepostid;
    $badge_group = get_post_meta( $thepostid, 'ninetheme_badge_group', true);
    wp_nonce_field( 'ninetheme_repeatable_meta_box_nonce', 'ninetheme_repeatable_meta_box_nonce' );
    ?>
    <script type="text/javascript">
    jQuery(document).ready(function( $ ){
        $( '#add-row' ).on('click', function() {
            var row = $( '.empty-row.screen-reader-text' ).clone(true);
            row.removeClass( 'empty-row screen-reader-text' );
            row.find('.ninetheme-color-field-added').addClass( 'ninetheme-color-field' ).removeClass( 'ninetheme-color-field-added' );
            row.find('.ninetheme_product_badge_color_select_added').addClass( 'ninetheme_product_badge_color_select' ).removeClass( 'ninetheme_product_badge_color_select_added' );
            row.insertBefore( '#repeatable-fieldset-one p:last' );
            $(".ninetheme-color-field-wrapper-added .ninetheme-color-field").wpColorPicker();
            $(".ninetheme-color-field-wrapper-added .wp-picker-container").addClass( 'hidden' );
            $('body').trigger('domiChanged');
        });

        function domiChanged(){
            $(".ninetheme-color-field-wrapper-added").each(function(){
                var $this = $(this).find('.ninetheme_product_badge_color_select');
                $this.on('change', function(){
                    if ( $this.val() == 'custom' ) {
                        $this.next().removeClass('hidden');
                    } else {
                        $this.next().addClass('hidden');
                    }
                });
            });
        }
        $('body').on('domiChanged', function(){
            domiChanged();
        });

        $( '.remove-row' ).on('click', function() {
            $(this).parents('p').remove();
        });
    });
</script>
<div id="repeatable-fieldset-one" class="ninetheme_badge_group_field">
    <label for="custombadge_group"><?php echo esc_attr_e( 'Badge Title / Color', 'crisop' ); ?></label>
    <?php
    if ( $badge_group ) {
        foreach ( $badge_group as $field ) {
            ?>
            <p class="form-field ninetheme-color-field-wrapper">
                <input type="text" class="ninetheme-badge-title-field" placeholder="<?php echo esc_attr_e( 'Badge Title', 'crisop' ); ?>" name="BadgeTitle[]" value="<?php if ( $field['BadgeTitle'] != '' ) echo esc_attr( $field['BadgeTitle'] ); ?>" />
                <select name="BadgeColorSelect[]" class="select ninetheme_product_badge_color_select">
                    <option value=""<?php if ( $field['BadgeColorSelect'] == '' ) echo ' selected="selected"'; ?>><?php echo esc_attr_e( 'Select a color', 'crisop' ); ?></option>
                    <option value="red-soft" style="background-color:#DD2623"<?php if ( $field['BadgeColorSelect'] == 'red-soft' ) echo ' selected="selected"'; ?>><?php echo esc_attr_e( 'Red', 'crisop' ); ?></option>
                    <option value="green-soft" style="background-color:#C0F0DC"<?php if ( $field['BadgeColorSelect'] == 'green-soft' ) echo ' selected="selected"'; ?>><?php echo esc_attr_e( 'crisop', 'crisop' ); ?></option>
                    <option value="purple-soft" style="background-color:#D8D2FF"<?php if ( $field['BadgeColorSelect'] == 'purple-soft' ) echo ' selected="selected"'; ?>><?php echo esc_attr_e( 'Purple', 'crisop' ); ?></option>
                    <option value="yellow-soft" style="background-color:#FFFDA5"<?php if ( $field['BadgeColorSelect'] == 'yellow-soft' ) echo ' selected="selected"'; ?>><?php echo esc_attr_e( 'Yellow', 'crisop' ); ?></option>
                    <option value="blue-soft" style="background-color:#B5C7FF"<?php if ( $field['BadgeColorSelect'] == 'blue-soft' ) echo ' selected="selected"'; ?>><?php echo esc_attr_e( 'Blue', 'crisop' ); ?></option>
                    <option value="custom"<?php if ( $field['BadgeColorSelect'] == 'custom' ) echo ' selected="selected"'; ?>><?php echo esc_attr_e( 'Custom Color', 'crisop' ); ?></option>
                </select>
                <input type="text" class="ninetheme-color-field hidden" name="BadgeColor[]" value="<?php if ( $field['BadgeColor'] != '' ) echo esc_attr( $field['BadgeColor'] ); ?>" />
                <span class="button remove-row"><?php echo esc_attr_e( 'Remove', 'crisop' ); ?></span>
            </p>
            <?php
        }
    } else {
        // show a blank one
        ?>
        <p class="form-field ninetheme-color-field-wrapper">
            <input type="text" class="ninetheme-badge-title-field" placeholder="<?php echo esc_attr_e( 'Badge Title', 'crisop' ); ?>" name="BadgeTitle[]" />
            <select name="BadgeColorSelect[]" class="select ninetheme_product_badge_color_select">
                <option value="" selected="selected"><?php echo esc_attr_e( 'Select a color', 'crisop' ); ?></option>
                <option value="red-soft" style="background-color:#DD2623"><?php echo esc_attr_e( 'Red', 'crisop' ); ?></option>
                <option value="green-soft" style="background-color:#C0F0DC"><?php echo esc_attr_e( 'crisop', 'crisop' ); ?></option>
                <option value="purple-soft" style="background-color:#D8D2FF"><?php echo esc_attr_e( 'Purple', 'crisop' ); ?></option>
                <option value="yellow-soft" style="background-color:#FFFDA5"><?php echo esc_attr_e( 'Yellow', 'crisop' ); ?></option>
                <option value="blue-soft" style="background-color:#B5C7FF"><?php echo esc_attr_e( 'Blue', 'crisop' ); ?></option>
                <option value="custom"><?php echo esc_attr_e( 'Custom Color', 'crisop' ); ?></option>
            </select>
            <input type="text" class="ninetheme-color-field hidden" name="BadgeColor[]" />
            <span class="button ninetheme-remove-row-button button-disabled"><?php echo esc_attr_e( 'Remove', 'crisop' ); ?></span>
        </p>
    <?php } ?>

    <!-- empty hidden one for jQuery -->
    <p class="form-field empty-row screen-reader-text ninetheme-color-field-wrapper ninetheme-color-field-wrapper-added">
        <input type="text" class="ninetheme-badge-title-field" placeholder="<?php echo esc_attr_e( 'Badge Title', 'crisop' ); ?>" name="BadgeTitle[]" />
        <select name="BadgeColorSelect[]" class="select ninetheme_product_badge_color_select_added">
            <option value="" selected="selected"><?php echo esc_attr_e( 'Select a color', 'crisop' ); ?></option>
            <option value="red-soft" style="background-color:#DD2623"><?php echo esc_attr_e( 'Red', 'crisop' ); ?></option>
            <option value="green-soft" style="background-color:#C0F0DC"><?php echo esc_attr_e( 'crisop', 'crisop' ); ?></option>
            <option value="purple-soft" style="background-color:#D8D2FF"><?php echo esc_attr_e( 'Purple', 'crisop' ); ?></option>
            <option value="yellow-soft" style="background-color:#FFFDA5"><?php echo esc_attr_e( 'Yellow', 'crisop' ); ?></option>
            <option value="blue-soft" style="background-color:#B5C7FF"><?php echo esc_attr_e( 'Blue', 'crisop' ); ?></option>
            <option value="custom"><?php echo esc_attr_e( 'Custom Color', 'crisop' ); ?></option>
        </select>
        <input type="text" class="ninetheme-color-field-added hidden" name="BadgeColor[]" />
        <span class="button remove-row"><?php echo esc_attr_e( 'Remove', 'crisop' ); ?></span>
    </p>
</div>
<p class="form-field custombadge_group_add_row_field"><span id="add-row" class="button"><?php echo esc_attr_e( 'Add New', 'crisop' ); ?></span></p>
<?php
}
add_action('woocommerce_process_product_meta', 'ninetheme_wc_repeatable_meta_box_save');
function ninetheme_wc_repeatable_meta_box_save( $post_id ) {
    if ( ! isset( $_POST['ninetheme_repeatable_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['ninetheme_repeatable_meta_box_nonce'], 'ninetheme_repeatable_meta_box_nonce' ) ) {
        return;
    }

    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }

    if ( !current_user_can('edit_post', $post_id ) ) {
        return;
    }

    $old   = get_post_meta( $post_id, 'ninetheme_badge_group', true );
    $new   = array();
    $title = $_POST['BadgeTitle'];
    $color_select = $_POST['BadgeColorSelect'];
    $color = $_POST['BadgeColor'];
    $count = count( $title );
    for ( $i = 0; $i < $count; $i++ ) {
        if ( $title[$i] != '' ) {
            $new[$i]['BadgeTitle'] = stripslashes( strip_tags( $title[$i] ) );
            $new[$i]['BadgeColorSelect'] = stripslashes( strip_tags( $color_select[$i] ) );
            $new[$i]['BadgeColor'] = stripslashes( $color[$i] ); // and however you want to sanitize
        }
    }
    if ( !empty( $new ) && $new != $old ) {
        update_post_meta( $post_id, 'ninetheme_badge_group', $new );
    }
    elseif ( empty($new) && $old ) {
        delete_post_meta( $post_id, 'ninetheme_badge_group', $old );
    }
}


/**
*  custom extra tabs for product page
*/
if ( ! function_exists( 'ninetheme_product_extra_fetaures' ) ) {
    add_action( 'woocommerce_single_product_summary', 'ninetheme_product_extra_fetaures', 21 );
    function ninetheme_product_extra_fetaures()
    {
        global $product;
        $fatures = get_post_meta( $product->get_id(), 'ninetheme_product_extra_fatures', true );
        $lists   = '' != $fatures ? preg_split("/\\r\\n|\\r|\\n/", $fatures ) : '';
        $class   = is_product() ? 'ninetheme-summary-item ninetheme-product-extra-features' : 'ninetheme-product-extra-features';

        if ( !empty( $lists ) ) {
            echo '<ul class="'.$class.'">';
                foreach( $lists as $list ) {
                    if ( !empty( $list ) ) {
                        echo '<li><span class="checked">&#x2713</span> '.$list.'</li>';
                    }
                }
            echo '</ul>';
        }
    }
}

/**
*  custom extra tabs for product page
*/
if ( ! function_exists( 'ninetheme_wc_extra_tabs_array' ) ) {
    function ninetheme_wc_extra_tabs_array()
    {
        global $product;
        $tabs        = array();
        $tab_title   = get_post_meta( $product->get_id(), 'ninetheme_tabs_title', true);
        $tab_content = get_post_meta( $product->get_id(), 'ninetheme_tabs_content', true);
        $tabtitle    = preg_split("/\\r\\n|\\r|\\n/", $tab_title );
        $tabcontent  = preg_split("/\\r\\n|\\r|\\n/", $tab_content );

        $count    = 30;
        foreach( ninetheme_combine_arr($tabtitle, $tabcontent) as $title => $details ) {
            if ( !empty( $title ) && !empty( $details ) ) {
                $replaced_title = preg_replace('/\s+/', '_', strtolower(trim($title)));
                $tabs[$replaced_title] = array(
                    'title' => $title,
                    'priority' => $count,
                    'content' => $details
                );
            }
            $count = $count + 10;
        }
        return $tabs;
    }
}


/*
* Tab
*/
if ( ! function_exists( 'ninetheme_product_settings_tabs' ) ) {
    add_filter('woocommerce_product_data_tabs', 'ninetheme_product_settings_tabs' );
    function ninetheme_product_settings_tabs( $tabs ){
        $tabs['ninetheme_general'] = array(
            'label'    => esc_html__('Crisop General', 'crisop'),
            'target'   => 'ninetheme_product_general_data',
            'priority' => 100,
        );
        $tabs['ninetheme_product_page'] = array(
            'label'    => esc_html__('Crisop Product Page', 'crisop'),
            'target'   => 'ninetheme_product_page_data',
            'priority' => 101,
        );
        return $tabs;
    }
}
/*
* Tab content
*/
if ( ! function_exists( 'ninetheme_product_panels' ) ) {
    /*************************************************
    ## Quantity Data Fields
    *************************************************/
    add_action( 'woocommerce_product_data_panels', 'ninetheme_product_panels' );
    function ninetheme_product_panels(){

        echo '<div id="ninetheme_product_general_data" class="panel woocommerce_options_panel hidden">';
            echo '<h3 class="ninetheme-panel-heading">'.esc_html__('Crisop Product General Settings', 'crisop').'</h3>';
            woocommerce_wp_checkbox(
                array(
                    'id' => 'ninetheme_product_discount',
                    'label' => esc_html__( 'Hide Product Discount?', 'crisop' ),
                    'wrapper_class' => 'hide_if_variable',
                    'desc_tip' => false,
                )
            );
            woocommerce_wp_checkbox(
                array(
                    'id' => 'ninetheme_product_hide_stock',
                    'label' => esc_html__( 'Hide Product Stock Label?', 'crisop' ),
                    'wrapper_class' => 'hide_if_variable',
                    'desc_tip' => false,
                )
            );

            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Extra Features Settings', 'crisop').'</h4>';
            woocommerce_wp_textarea_input(
                array(
                    'id' => 'ninetheme_product_extra_fatures',
                    'label' => esc_html__( 'Extra Features', 'crisop' ),
                    'desc_tip' => true,
                    'description' => esc_html__( '!Important note: One feature per line.', 'crisop' ),
                    'rows' => 3
                )
            );
            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Badge Settings', 'crisop').'</h4>';
            woocommerce_wp_checkbox(
                array(
                    'id' => 'ninetheme_use_custom_badge',
                    'label' => esc_html__( 'Use Custom Badge?', 'crisop' ),
                    'desc_tip' => false
                )
            );
            ninetheme_wc_repeatable_meta_display();

            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Countdown Settings', 'crisop').'</h4>';
            woocommerce_wp_checkbox(
                array(
                    'id' => 'ninetheme_product_hide_countdown',
                    'label' => esc_html__( 'Hide Product Countdown?', 'crisop' ),
                    'wrapper_class' => 'hide_if_variable',
                    'desc_tip' => false,
                )
            );
            woocommerce_wp_text_input(
                array(
                    'id' => 'ninetheme_product_countdown_text',
                    'label' => esc_html__( 'Countdown Text', 'crisop' ),
                    'desc_tip' => true,
                    'description' => esc_html__( 'Add your custom text here', 'crisop' ),
                )
            );
        echo '</div>';

        echo '<div id="ninetheme_product_page_data" class="panel woocommerce_options_panel hidden">';
            echo '<h3 class="ninetheme-panel-heading">'.esc_html__('Crisop Product Page Settings', 'crisop').'</h3>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Product Header Type Settings', 'crisop').'</h4>';
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_product_header_type',
                    'label' => esc_html__( 'Header Type?', 'crisop' ),
                    'options' => array(
                        '' => 'Select a type',
                        'default' => esc_html__( 'Theme options settings', 'crisop' ),
                        'dark' => esc_html__( 'Dark', 'crisop' ),
                        'trans-light' => esc_html__( 'Transparent Light', 'crisop' ),
                        'trans-dark' => esc_html__( 'Transparent Dark', 'crisop' ),
                        'custom' => esc_html__( 'Custom Color', 'crisop' ),
                    ),
                    'desc_tip' => true,
                    'description' => esc_html__( 'You can use this option to use a different header for this product', 'crisop' )
                )
            );
            echo '<h4 class="ninetheme-panel-subheading menu-customize">'.esc_html__('Header Custom Color Settings', 'crisop').'</h4>';
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_header_bgcolor',
                    'label' => esc_html__( 'Header Background Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_header_menuitem_color',
                    'label' => esc_html__( 'Menu Item Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_header_menuitem_hvrcolor',
                    'label' => esc_html__( 'Menu Item Hover/Active Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_header_svgicon_color',
                    'label' => esc_html__( 'Header SVG Buttons Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_header_counter_bgcolor',
                    'label' => esc_html__( 'Header SVG Buttons Counter Background Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_header_counter_color',
                    'label' => esc_html__( 'Header SVG Buttons Counter Color', 'crisop' )
                )
            );
            echo '<h4 class="ninetheme-panel-subheading menu-customize">'.esc_html__('Sticky Header Custom Color Settings', 'crisop').'</h4>';
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_sticky_header_bgcolor',
                    'label' => esc_html__( 'Sticky Header Background Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_sticky_header_menuitem_color',
                    'label' => esc_html__( 'Menu Item Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_sticky_header_menuitem_hvrcolor',
                    'label' => esc_html__( 'Menu Item Hover/Active Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_sticky_header_svgicon_color',
                    'label' => esc_html__( 'Header SVG Buttons Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_sticky_header_counter_bgcolor',
                    'label' => esc_html__( 'Header SVG Buttons Counter Background Color', 'crisop' )
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_product_sticky_header_counter_color',
                    'label' => esc_html__( 'Header SVG Buttons Counter Color', 'crisop' )
                )
            );
            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Product Showcase Type Settings', 'crisop').'</h4>';
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_showcase_type',
                    'label' => esc_html__( 'Showcase Type?', 'crisop' ),
                    'options' => array(
                        '' => 'Select a type',
                        'full' => esc_html__( 'Full', 'crisop' ),
                        'carousel' => esc_html__( 'Carousel', 'crisop' ),
                    ),
                    'desc_tip' => false,
                )
            );
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_showcase_bg_type',
                    'label' => esc_html__( 'Background Color Type?', 'crisop' ),
                    'options' => array(
                        '' => 'Select a type',
                        'dark' => esc_html__( 'Dark', 'crisop' ),
                        'light' => esc_html__( 'Light', 'crisop' ),
                        'custom' => esc_html__( 'Custom Color', 'crisop' ),
                    ),
                    'desc_tip' => false,
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_showcase_custom_bgcolor',
                    'label' => esc_html__( 'Custom Background Color', 'crisop' ),
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_showcase_custom_textcolor',
                    'label' => esc_html__( 'Custom Text Color', 'crisop' ),
                )
            );
            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Product Showcase Type Settings', 'crisop').'</h4>';
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_showcase_type',
                    'label' => esc_html__( 'Showcase Type?', 'crisop' ),
                    'options' => array(
                        '' => 'Select a type',
                        'full' => esc_html__( 'Full', 'crisop' ),
                        'carousel' => esc_html__( 'Carousel', 'crisop' ),
                    ),
                    'desc_tip' => false,
                )
            );
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_showcase_bg_type',
                    'label' => esc_html__( 'Background Color Type?', 'crisop' ),
                    'options' => array(
                        '' => 'Select a type',
                        'dark' => esc_html__( 'Dark', 'crisop' ),
                        'light' => esc_html__( 'Light', 'crisop' ),
                        'custom' => esc_html__( 'Custom Color', 'crisop' ),
                    ),
                    'desc_tip' => false,
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_showcase_custom_bgcolor',
                    'label' => esc_html__( 'Custom Background Color', 'crisop' ),
                )
            );
            ninetheme_wc_product_meta_color(
                array(
                    'id' => 'ninetheme_showcase_custom_textcolor',
                    'label' => esc_html__( 'Custom Text Color', 'crisop' ),
                )
            );
            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Product Summary Settings', 'crisop').'</h4>';
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_product_size_guide',
                    'label' => esc_html__( 'Size Guide of product', 'crisop' ),
                    'options' => ninetheme_get_elementorCategories(),
                    'desc_tip' => true,
                    'description' => sprintf('%s <a href="'.esc_url(admin_url('edit.php?post_type=elementor_library')).'"><b>%s</b></a> %s <a href="'.esc_url(admin_url('edit-tags.php?taxonomy=elementor_library_category&post_type=elementor_library')).'"><b>%s</b></a> %s',
                        esc_html__( 'Please create your size guide with', 'crisop' ),
                        esc_html__( 'elementor template', 'crisop' ),
                        esc_html__( 'and assign it to a', 'crisop' ),
                        esc_html__( 'category', 'crisop' ),
                        esc_html__( 'the categories you create will be listed here.', 'crisop' )
                    )
                )
            );
            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Product Video Settings', 'crisop').'</h4>';
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_product_video_type',
                    'label' => esc_html__( 'Product Video Type?', 'crisop' ),
                    'options' => array(
                        '' => 'Select a type',
                        'popup' => esc_html__( 'Popup', 'crisop' ),
                        'gallery' => esc_html__( 'Gallery Item', 'crisop' ),
                    ),
                    'desc_tip' => false
                )
            );
            woocommerce_wp_text_input(
                array(
                    'id' => 'ninetheme_product_popup_video',
                    'label' => esc_html__( 'Popup Video URL', 'crisop' ),
                    'desc_tip' => true,
                    'description' => esc_html__( 'Add your youtube,vimeo,hosted video URL here', 'crisop' )
                )
            );
            woocommerce_wp_text_input(
                array(
                    'id' => 'ninetheme_product_iframe_video',
                    'label' => esc_html__( 'Youtube video ID', 'crisop' ),
                    'desc_tip' => true,
                    'description' => esc_html__( 'Add your youtube video ID here for background autoplay video.', 'crisop' ),
                    'rows' => 4
                )
            );
            woocommerce_wp_select(
                array(
                    'id' => 'ninetheme_product_video_on_shop',
                    'label' => esc_html__( 'Show this iframe video on shop archive?', 'crisop' ),
                    'options' => array(
                        '' => 'Select an option',
                        'no' => esc_html__( 'No', 'crisop' ),
                        'yes' => esc_html__( 'Yes', 'crisop' ),
                    ),
                    'desc_tip' => false
                )
            );
            echo '<div class="ninetheme-panel-divider"></div>';
            echo '<h4 class="ninetheme-panel-subheading">'.esc_html__('Extra Tabs Settings', 'crisop').'</h4>';
            woocommerce_wp_textarea_input(
                array(
                    'id' => 'ninetheme_tabs_title',
                    'label' => esc_html__( 'Extra Tabs Title', 'crisop' ),
                    'desc_tip' => true,
                    'description' => esc_html__( '!Important note: One title per line.', 'crisop' ),
                    'rows' => 3
                )
            );
            woocommerce_wp_textarea_input(
                array(
                    'id' => 'ninetheme_tabs_content',
                    'label' => esc_html__( 'Extra Tabs Content', 'crisop' ),
                    'desc_tip' => true,
                    'description' => esc_html__( '!Important note: One content per line.Iframe,shortcode,HTML content allowed.', 'crisop' ),
                    'rows' => 4
                )
            );
        echo '</div>';
    }
}

/**
*  Save Custom Field
*/
if ( ! function_exists( 'ninetheme_save_product_custom_field' ) ) {
    add_action( 'woocommerce_process_product_meta', 'ninetheme_save_product_custom_field' );
    function ninetheme_save_product_custom_field( $_post_id )
    {
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
            return;
        }
        $options = array(
            'ninetheme_showcase_type',
            'ninetheme_showcase_bg_type',
            'ninetheme_showcase_custom_bgcolor',
            'ninetheme_showcase_custom_textcolor',
            'ninetheme_use_custom_badge',
            'ninetheme_product_discount',
            'ninetheme_product_size_guide',
            'ninetheme_product_hide_stock',
            'ninetheme_product_extra_fatures',
            'ninetheme_product_hide_countdown',
            'ninetheme_product_countdown_text',
            'ninetheme_product_video_type',
            'ninetheme_product_popup_video',
            'ninetheme_product_iframe_video',
            'ninetheme_product_video_on_shop',
            'ninetheme_tabs_title',
            'ninetheme_tabs_content',
            'ninetheme_product_header_type',
            'ninetheme_product_header_bgcolor',
            'ninetheme_product_header_menuitem_color',
            'ninetheme_product_header_menuitem_hvrcolor',
            'ninetheme_product_header_svgicon_color',
            'ninetheme_product_header_counter_bgcolor',
            'ninetheme_product_header_counter_color',
            'ninetheme_product_sticky_header_bgcolor',
            'ninetheme_product_sticky_header_menuitem_color',
            'ninetheme_product_sticky_header_menuitem_hvrcolor',
            'ninetheme_product_sticky_header_svgicon_color',
            'ninetheme_product_sticky_header_counter_bgcolor',
            'ninetheme_product_sticky_header_counter_color',
            'ninetheme_quantity_check',
            'ninetheme_min_quantity',
            'ninetheme_max_quantity',
            'ninetheme_step_quantity'
        );
        foreach ( $options as $option ) {
            if ( isset( $_POST[$option] ) ) {
                update_post_meta( $_post_id, $option, $_POST[$option] );
            } else {
                delete_post_meta( $_post_id, $option );
            }
        }
    }
}


/**
* Remove Reviews tab from tabs
*/
if ( ! function_exists( 'ninetheme_wc_remove_product_tabs' ) ) {
    add_filter( 'woocommerce_product_tabs', 'ninetheme_wc_remove_product_tabs', 98 );
    function ninetheme_wc_remove_product_tabs( $tabs )
    {
        $tabs_type = apply_filters( 'ninetheme_product_tabs_type', ninetheme_settings( 'product_tabs_type', 'tabs' ) );
        if ( 'accordion' == $tabs_type ) {
            unset($tabs['reviews']);
        }
        if ( '0' == ninetheme_settings('product_hide_reviews_tab', '1' ) ) {
            unset($tabs['reviews']);
        }

        $tabs['description']['callback'] = 'ninetheme_wc_custom_description_tab_content'; // Custom description callback

        if ( '0' == ninetheme_settings('product_hide_description_tab', '1' ) ) {
            unset($tabs['description']);
        }
        if ( '0' == ninetheme_settings('product_hide_additional_tab', '1' ) ) {
            unset($tabs['additional_information']);
        }
        if ( '0' == ninetheme_settings('product_hide_crqna_tab', '1' ) ) {
            unset($tabs['cr_qna']);
        }

        $tabs_custom_order = ninetheme_settings( 'product_tabs_custom_order', '0' );
        $tabs_order        = ninetheme_settings( 'product_tabs_order', null );
        if ( $tabs_custom_order == '1' ) {
            if ( !empty( $tabs_order['show'] ) ) {
                unset( $tabs_order['show']['placebo'] );
                $tabs_count = 1;
                foreach ( $tabs_order['show'] as $key => $value ) {
                    $tabs[ $key ][ 'priority' ] = $tabs_count;
                    $tabs_count++;
                }
            }
        }

        return $tabs;
    }
}


/**
 * Customize product data tabs
 */
if ( ! function_exists( 'ninetheme_wc_custom_description_tab_content' ) ) {
    function ninetheme_wc_custom_description_tab_content()
    {
        $desc_tab_title = ninetheme_settings( 'product_description_tab_title', '' );
        $desc_tab_title = '' != $desc_tab_title ? $desc_tab_title : esc_html__( 'Product Details', 'crisop' );
        ?>
        <div class="product-desc-content">
            <?php if ( '1' == ninetheme_settings( 'product_description_tab_title_visibility', '0' ) ) { ?>
                <h4 class="title"><?php echo apply_filters( 'ninetheme_description_tab_title', $desc_tab_title ); ?></h4>
            <?php } ?>
            <?php the_content(); ?>
        </div>
        <?php
    }
}


/**
 * Move Reviews tab after product related
 */
if ( ! function_exists( 'ninetheme_wc_move_product_reviews' ) ) {
    function ninetheme_wc_move_product_reviews()
    {
        comments_template();
    }
}


/**
 * woocommerce_layered_nav_term_html WIDGET
 */
if ( !function_exists( 'ninetheme_add_span_wc_layered_nav_term_html' ) ) {
    function ninetheme_add_span_wc_layered_nav_term_html( $links )
    {
        $links = str_replace( '</a> (', '</a> <span class="widget-list-span">', $links );
        $links = str_replace( '</a> <span class="count">(', '</a> <span class="widget-list-span">', $links );
        $links = str_replace( ')', '', $links );

        return $links;
    }
    add_filter( 'woocommerce_layered_nav_term_html', 'ninetheme_add_span_wc_layered_nav_term_html' );
}


/**
* Add to cart handler.
*/
if ( !function_exists( 'ninetheme_ajax_add_to_cart_handler' ) ) {
    function ninetheme_ajax_add_to_cart_handler()
    {
        ninetheme_cart_fragments();
    }
    add_action( 'wc_ajax_ninetheme_ajax_add_to_cart', 'ninetheme_ajax_add_to_cart_handler' );
    add_action( 'wc_ajax_nopriv_ninetheme_ajax_add_to_cart', 'ninetheme_ajax_add_to_cart_handler' );
}

if ( !function_exists( 'ninetheme_remove_from_cart_handler' ) ) {
    function ninetheme_remove_from_cart_handler()
    {
        $key = wc_clean( isset( $_POST['cart_item_key'] ) ? wp_unslash( $_POST['cart_item_key'] ) : '' );

        if ( $key && false !== WC()->cart->remove_cart_item( $key ) ) {
            ninetheme_cart_fragments('remove');
        } else {
            wp_send_json_error();
        }
    }
    add_action( 'wc_ajax_ninetheme_remove_from_cart', 'ninetheme_remove_from_cart_handler' );
    add_action( 'wc_ajax_nopriv_ninetheme_remove_from_cart', 'ninetheme_remove_from_cart_handler' );
}

if ( !function_exists( 'ninetheme_clear_cart_handler' ) ) {
    function ninetheme_clear_cart_handler()
    {
        global $woocommerce;

        $fragments = array(
            'status' => 'error',
            'msg'    => esc_html__('Your order could not be emptied','crisop')
        );

        WC()->cart->empty_cart();

        if ( WC()->cart->get_cart_contents_count() == 0 ) {
            $fragments = array(
                'status' => 'success',
                'msg'    => esc_html__('Your order has been reset!','crisop')
            );
        }

        ninetheme_cart_fragments('clear',$fragments);
    }
    add_action('wc_ajax_ninetheme_clear_cart', 'ninetheme_clear_cart_handler');
    add_action('wc_ajax_nopriv_ninetheme_clear_cart', 'ninetheme_clear_cart_handler');
}

if ( !function_exists( 'ninetheme_quantity_button' ) ) {
    function ninetheme_quantity_button() {
        if ( ( isset( $_GET['id'] ) && $_GET['id'] ) && ( isset( $_GET['qty'] ) ) ) {

            if ( $_GET['qty'] ) {
                WC()->cart->set_quantity( $_GET['id'], $_GET['qty'] );
            } else {
                WC()->cart->remove_cart_item( $_GET['id'] );
            }

            if ( esc_html( WC()->cart->get_cart_contents_count() ) == 0 ) {
                $fragments = array(
                    'msg' => esc_html__('Your order has been reset!','crisop')
                );
            } else {
                $fragments = array(
                    'msg' => $_GET['qty']
                );
            }

            if ( $_GET['is_cart'] == 'yes' ) {
                ob_start();
                get_template_part('woocommerce/cart/cart');
                $cart = ob_get_clean();
                $fragments['cart'] = $cart;
                ninetheme_cart_fragments('update',$fragments);
            } else {
                ninetheme_cart_fragments('update',$fragments);
            }
        }
    }
    add_action( 'wp_ajax_ninetheme_quantity_button', 'ninetheme_quantity_button' );
    add_action( 'wp_ajax_nopriv_ninetheme_quantity_button', 'ninetheme_quantity_button' );
}

if ( !function_exists( 'ninetheme_cart_fragments' ) ) {
    function ninetheme_cart_fragments( $name = '',$fragments = null )
    {
        global $woocommerce;
        $has_quantity = ninetheme_settings('cart_quantity_visibility', '0');
        ob_start();
        get_template_part('woocommerce/minicart/minicart');
        $minicart = ob_get_clean();

        $notices = wc_print_notices(true);

        ob_start();
        $total  = WC()->cart->get_cart_subtotal();
        $total .= ob_get_clean();

        ob_start();
        $count  = esc_html( WC()->cart->get_cart_contents_count() );
        $count .= ob_get_clean();

        $data = array(
            'fragments' => array(
                'notices'  => $notices,
                'minicart' => $minicart,
                'total'    => $total,
                'count'    => $count,
                'shipping' => ninetheme_free_shipping_goal_content(),
            ),
            'cart_hash' => WC()->cart->get_cart_hash()
        );

        if ( $name == 'clear' && !empty( $fragments ) ) {
            $data['fragments']['clear'] = $fragments;
        }

        if ( $name == 'update' && !empty( $fragments ) ) {
            $data['fragments']['update'] = $fragments;
        }
        if ( $name == 'remove' && !empty( $fragments ) ) {
            $data['fragments']['remove'] = $fragments;
        }

        wp_send_json( $data );
    }
}


if ( ! function_exists( 'ninetheme_free_shipping_goal_content' ) ) {
    function ninetheme_free_shipping_goal_content()
    {
        $amount = round( ninetheme_settings( 'free_shipping_progressbar_amount', 500 ), wc_get_price_decimals() );

        if ( !( $amount > 0 ) || '1' != ninetheme_settings( 'free_shipping_progressbar_visibility', 1 ) ) {
            return;
        }

        $message_initial = ninetheme_settings( 'free_shipping_progressbar_message_initial' );
        $message_success = ninetheme_settings( 'free_shipping_progressbar_message_success' );

        $total     = WC()->cart->get_displayed_subtotal();
        $remainder = ( $amount - $total );
        $value     = $total <= $amount ? ( $total / $amount ) * 100 : 100;

        if ( $total == 0 ) {
            $value = 0;
        }

        if ( $total >= $amount ) {
            if ( $message_success ) {
                $message = sprintf('%s', $message_success );
            } else {
                $message = sprintf('%s <strong>%s</strong>',
                esc_html__('Congrats! You are eligible for', 'crisop'),
                esc_html__('more to enjoy FREE Shipping', 'crisop'));
            }
        } else {
            if ( $message_initial ) {
                $message = sprintf('%s', str_replace( '[remainder]', wc_price( $remainder ), $message_initial ) );
            } else {
                $message = sprintf('%s %s <strong>%s</strong>',
                esc_html__('Buy', 'crisop'),
                wc_price( $remainder ),
                esc_html__('more to enjoy FREE Shipping', 'crisop'));
            }
        }

        $shipping = array(
            'value'   => $value,
            'message' => $message
        );

        return $shipping;
    }
}


/**
* ajax quick shop handler.
*/
if ( !function_exists( 'ninetheme_ajax_quick_shop' ) ) {

    add_action( 'wp_ajax_ninetheme_ajax_quick_shop', 'ninetheme_ajax_quick_shop' );
    add_action( 'wp_ajax_nopriv_ninetheme_ajax_quick_shop', 'ninetheme_ajax_quick_shop' );

    function ninetheme_ajax_quick_shop()
    {
        global $post, $product;
        $product_id = absint( $_GET['product_id'] );
        $product    = wc_get_product( $product_id );

        if ( !$product ) {
            return;
        }

        $post = get_post( $product_id );
        setup_postdata( $post );
        ?>
        <div id="product-<?php echo esc_attr( $product_id ); ?>" <?php wc_product_class( 'ninetheme-quickshop-wrapper single-content zoom-anim-dialog', $product ); ?>>
            <div class="ninetheme-quickshop-inner">
                <?php if ( ninetheme_settings('header_cart_before_buttons', '' ) ) { ?>
                    <div class="minicart-extra-text">
                        <?php echo ninetheme_settings('header_cart_before_buttons', '' ); ?>
                    </div>
                <?php } ?>

                <div class="ninetheme-quickshop-form-wrapper">
                    <h5 class="ninetheme-product-title"><?php the_title();?></h5>
                    <?php woocommerce_template_single_add_to_cart( $product ); ?>
                    <div class="ninetheme-quickshop-notices"></div>
                </div>

                <div class="ninetheme-quickshop-buttons-wrapper">
                    <div class="ninetheme-flex">
                        <a class="ninetheme-btn-text" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><?php echo esc_html_e( 'View Cart', 'crisop' ); ?></a>
                        <a class="ninetheme-btn-text" href="<?php echo esc_url( wc_get_checkout_url() ); ?>"><?php echo esc_html_e( 'Checkout', 'crisop' ); ?></a>
                    </div>
                </div>

            </div>
        </div>

        <?php
        wp_reset_postdata();
        die();
    }
}


/**
* Add category banner if shortcode exists
*/
if ( !function_exists( 'ninetheme_print_category_banner' ) ) {
    add_action( 'ninetheme_shop_before_loop', 'ninetheme_print_category_banner', 10 );
    function ninetheme_print_category_banner()
    {
        $cat_template = ninetheme_settings('shop_category_pages_before_loop_templates', null );
        $tag_template = ninetheme_settings('shop_tag_pages_before_loop_templates', null );
        $banner       = get_term_meta( get_queried_object_id(), 'ninetheme_wc_cat_banner', true );
        $t_id         = is_tax('ninetheme_product_campaigns') ? get_queried_object_id() : '';
        $campaign     = get_option( "taxonomy_$t_id" );
        $layouts      = isset( $_GET['shop_layouts'] ) && ( 'left-sidebar' == $_GET['shop_layouts'] || 'right-sidebar' == $_GET['shop_layouts'] ) ? true : false;

        if ( ( $cat_template || $tag_template || $banner ) && ( is_product_category() || is_product_tag() ) ) {

            if ( $banner && is_product_category() ) {
                printf( '<div class="shop-cat-banner ninetheme-before-loop-template">%s</div>', do_shortcode( $banner ) );
            } elseif ( $cat_template && is_product_category() ) {
                echo ninetheme_print_elementor_templates( 'shop_category_pages_before_loop_templates', 'shop-cat-banner ninetheme-before-loop-template', true );
            } elseif ( $tag_template && is_product_tag() ) {
                echo ninetheme_print_elementor_templates( 'shop_tag_pages_before_loop_templates', 'shop-tag-banner ninetheme-before-loop-template', true );
            } else {
                printf( '<div class="shop-cat-banner ninetheme-before-loop-template">%s</div>', do_shortcode( $banner ) );
            }

        } elseif ( $campaign && is_tax('ninetheme_product_campaigns') ) {

            printf( '<div class="shop-cat-banner ninetheme-before-loop-template">%s</div>', do_shortcode( $campaign ) );

        } else {

            if ( 'left-sidebar' == ninetheme_settings('shop_layout') || 'right-sidebar' == ninetheme_settings('shop_layout') || $layouts ) {
                $template_id = ninetheme_settings('shop_before_loop_templates', null);
                if ( $template_id ) {
                    echo '<div class="ninetheme-before-loop-template template-loading"><span class="loading-template"><span class="ajax-loader"></span></span>'.do_shortcode( '[ninetheme-template id="'.$template_id.'"]' ).'</div>';
                }
            }
        }
    }
}


add_action('product_cat_add_form_fields', 'ninetheme_wc_taxonomy_add_new_meta_field', 15, 1);
//Product Cat Create page
function ninetheme_wc_taxonomy_add_new_meta_field() {
    ?>

    <p class="form-field ninetheme_wc_cat_banner_field">
    <label for="ninetheme_wc_cat_banner"><?php esc_html_e( 'Crisop Category Banner ', 'crisop' ); ?></label>
    <textarea name="ninetheme_wc_cat_banner" id="ninetheme_wc_cat_banner" rows="4"></textarea>
    <span class="description"><?php esc_html_e( 'If you want to show a different banner on the archive category page for this category, use this field.Iframe,shortcode,HTML content allowed.', 'crisop' ); ?></span>
    </p>

	<div class="form-field ninetheme_term-hero-bgimage-wrap">
		<label><?php esc_html_e( 'Crisop Shop Category Page Hero Background Image', 'crisop' ); ?></label>
		<div id="ninetheme_product_cat_hero_bgimage" style="float: left; margin-right: 10px;"><img src="<?php echo esc_url( wc_placeholder_img_src() ); ?>" width="60px" height="60px" /></div>
		<div style="line-height: 60px;">
			<input type="hidden" id="ninetheme_product_cat_hero_bgimage_id" name="ninetheme_product_cat_hero_bgimage_id" />
			<button type="button" class="ninetheme_upload_image_button button"><?php esc_html_e( 'Upload/Add image', 'crisop' ); ?></button>
			<button type="button" class="ninetheme_remove_image_button button"><?php esc_html_e( 'Remove image', 'crisop' ); ?></button>
		</div>
		<div class="clear"></div>
		<span class="description"><?php esc_html_e( 'If you want to show a different background image on the shop archive category page for this category, upload your image from here.', 'crisop'); ?></span>
		<script type="text/javascript">

			// Only show the "remove image" button when needed
			if ( ! jQuery( '#ninetheme_product_cat_hero_bgimage_id' ).val() ) {
				jQuery( '.ninetheme_term-hero-bgimage-wrap .ninetheme_remove_image_button' ).hide();
			}

			// Uploading files
			var ninetheme_cat_hero_file_frame;

			jQuery( document ).on( 'click', '.ninetheme_term-hero-bgimage-wrap .ninetheme_upload_image_button', function( event ) {

				event.preventDefault();

				// If the media frame already exists, reopen it.
				if ( ninetheme_cat_hero_file_frame ) {
					ninetheme_cat_hero_file_frame.open();
					return;
				}

				// Create the media frame.
				ninetheme_cat_hero_file_frame = wp.media.frames.downloadable_file = wp.media({
					title: '<?php esc_html_e( 'Choose an image', 'crisop' ); ?>',
					button: {
						text: '<?php esc_html_e( 'Use image', 'crisop' ); ?>'
					},
					multiple: false
				});

				// When an image is selected, run a callback.
				ninetheme_cat_hero_file_frame.on( 'select', function() {
					var attachment           = ninetheme_cat_hero_file_frame.state().get( 'selection' ).first().toJSON();
					var attachment_thumbnail = attachment.sizes.thumbnail || attachment.sizes.full;

					jQuery( '#ninetheme_product_cat_hero_bgimage_id' ).val( attachment.id );
					jQuery( '#ninetheme_product_cat_hero_bgimage' ).find( 'img' ).attr( 'src', attachment_thumbnail.url );
					jQuery( '.ninetheme_term-hero-bgimage-wrap .ninetheme_remove_image_button' ).show();
				});

				// Finally, open the modal.
				ninetheme_cat_hero_file_frame.open();
			});

			jQuery( document ).on( 'click', '.ninetheme_term-hero-bgimage-wrap .ninetheme_remove_image_button', function() {
				jQuery( '#ninetheme_product_cat_hero_bgimage' ).find( 'img' ).attr( 'src', '<?php echo esc_js( wc_placeholder_img_src() ); ?>' );
				jQuery( '#ninetheme_product_cat_hero_bgimage_id' ).val( '' );
				jQuery( '.ninetheme_term-hero-bgimage-wrap .ninetheme_remove_image_button' ).hide();
				return false;
			});

			jQuery( document ).ajaxComplete( function( event, request, options ) {
				if ( request && 4 === request.readyState && 200 === request.status
					&& options.data && 0 <= options.data.indexOf( 'action=add-tag' ) ) {

					var res = wpAjax.parseAjaxResponse( request.responseXML, 'ajax-response' );
					if ( ! res || res.errors ) {
						return;
					}
					// Clear Thumbnail fields on submit
					jQuery( '#ninetheme_product_cat_hero_bgimage' ).find( 'img' ).attr( 'src', '<?php echo esc_js( wc_placeholder_img_src() ); ?>' );
					jQuery( '#ninetheme_product_cat_hero_bgimage_id' ).val( '' );
					jQuery( '.ninetheme_term-hero-bgimage-wrap .ninetheme_remove_image_button' ).hide();
					return;
				}
			} );

		</script>
	</div>
	<div class="clear"></div>
	<?php
}


add_action('product_cat_edit_form_fields', 'ninetheme_wc_taxonomy_edit_meta_field', 15, 1);
//Product Cat Edit page
function ninetheme_wc_taxonomy_edit_meta_field($term) {

    //getting term ID
    $term_id = $term->term_id;

    // retrieve the existing value(s) for this meta field.
    $ninetheme_wc_cat_banner = get_term_meta($term_id, 'ninetheme_wc_cat_banner', true);
	$thumbnail_id = absint( get_term_meta( $term_id, 'ninetheme_product_cat_hero_bgimage_id', true ) );

	if ( $thumbnail_id ) {
		$image = wp_get_attachment_thumb_url( $thumbnail_id );
	} else {
		$image = wc_placeholder_img_src();
	}
    ?>
    <tr class="form-field term-ninetheme-banner-wrap">
        <th scope="row" valign="top"><label for="ninetheme_wc_cat_banner"><?php esc_html_e('Crisop Banner', 'crisop'); ?></label></th>
        <td>
            <textarea name="ninetheme_wc_cat_banner" id="ninetheme_wc_cat_banner" rows="5" cols="50" class="large-text"><?php echo esc_html($ninetheme_wc_cat_banner) ? $ninetheme_wc_cat_banner : ''; ?></textarea>
            <p class="description"><?php esc_html_e('If you want to show a different banner on the archive category page for this category, use this field.Iframe,shortcode,HTML content allowed.', 'crisop'); ?></p>
        </td>
    </tr>

	<tr class="form-field ninetheme_term-hero_bgimage-wrap">
		<th scope="row" valign="top"><label><?php esc_html_e( 'Crisop Shop Category Page Hero Background Image', 'crisop' ); ?></label></th>
		<td>
			<div id="ninetheme_product_cat_hero_bgimage" style="float: left; margin-right: 10px;"><img src="<?php echo esc_url( $image ); ?>" width="60px" height="60px" /></div>
			<div style="line-height: 60px;">
				<input type="hidden" id="ninetheme_product_cat_hero_bgimage_id" name="ninetheme_product_cat_hero_bgimage_id" value="<?php echo esc_attr( $thumbnail_id ); ?>" />
				<button type="button" class="ninetheme_upload_image_button button"><?php esc_html_e( 'Upload/Add image', 'crisop' ); ?></button>
				<button type="button" class="ninetheme_remove_image_button button"><?php esc_html_e( 'Remove image', 'crisop' ); ?></button>
			</div>
			<div class="clear"></div>
			<span class="description"><?php esc_html_e( 'If you want to show a different background image on the shop archive category page for this category, upload your image from here.', 'crisop'); ?></span>
			<script type="text/javascript">

				// Only show the "remove image" button when needed
				if ( '0' === jQuery( '#ninetheme_product_cat_hero_bgimage_id' ).val() ) {
					jQuery( '.ninetheme_term-hero_bgimage-wrap .ninetheme_remove_image_button' ).hide();
				}

				// Uploading files
				var ninetheme_cat_hero_file_frame;

				jQuery( document ).on( 'click', '.ninetheme_term-hero_bgimage-wrap .ninetheme_upload_image_button', function( event ) {

					event.preventDefault();

					// If the media frame already exists, reopen it.
					if ( ninetheme_cat_hero_file_frame ) {
						ninetheme_cat_hero_file_frame.open();
						return;
					}

					// Create the media frame.
					ninetheme_cat_hero_file_frame = wp.media.frames.downloadable_file = wp.media({
						title: '<?php esc_html_e( 'Choose an image', 'crisop' ); ?>',
						button: {
							text: '<?php esc_html_e( 'Use image', 'crisop' ); ?>'
						},
						multiple: false
					});

					// When an image is selected, run a callback.
					ninetheme_cat_hero_file_frame.on( 'select', function() {
						var attachment           = ninetheme_cat_hero_file_frame.state().get( 'selection' ).first().toJSON();
						var attachment_thumbnail = attachment.sizes.thumbnail || attachment.sizes.full;

						jQuery( '#ninetheme_product_cat_hero_bgimage_id' ).val( attachment.id );
						jQuery( '#ninetheme_product_cat_hero_bgimage' ).find( 'img' ).attr( 'src', attachment_thumbnail.url );
						jQuery( '.ninetheme_term-hero_bgimage-wrap .ninetheme_remove_image_button' ).show();
					});

					// Finally, open the modal.
					ninetheme_cat_hero_file_frame.open();
				});

				jQuery( document ).on( 'click', '.ninetheme_term-hero_bgimage-wrap .ninetheme_remove_image_button', function() {
					jQuery( '#ninetheme_product_cat_hero_bgimage' ).find( 'img' ).attr( 'src', '<?php echo esc_js( wc_placeholder_img_src() ); ?>' );
					jQuery( '#ninetheme_product_cat_hero_bgimage_id' ).val( '' );
					jQuery( '.ninetheme_term-hero_bgimage-wrap .ninetheme_remove_image_button' ).hide();
					return false;
				});

			</script>
			<div class="clear"></div>
		</td>
	</tr>
    <?php
}


add_action('edited_product_cat', 'ninetheme_wc_save_taxonomy_custom_meta', 15, 1);
add_action('create_product_cat', 'ninetheme_wc_save_taxonomy_custom_meta', 15, 1);
// Save extra taxonomy fields callback function.
function ninetheme_wc_save_taxonomy_custom_meta( $term_id ) {

    $ninetheme_wc_cat_banner = filter_input(INPUT_POST, 'ninetheme_wc_cat_banner');
    $ninetheme_product_cat_hero_bgimage_id = filter_input(INPUT_POST, 'ninetheme_product_cat_hero_bgimage_id');
    update_term_meta($term_id, 'ninetheme_wc_cat_banner', $ninetheme_wc_cat_banner);
    update_term_meta($term_id, 'ninetheme_product_cat_hero_bgimage_id', $ninetheme_product_cat_hero_bgimage_id);
}


//Displaying Additional Columns
add_filter( 'manage_edit-product_cat_columns', 'ninetheme_wc_customFieldsListTitle' ); //Register Function
function ninetheme_wc_customFieldsListTitle( $columns ) {
    $columns['ninetheme_cat_banner'] = esc_html__( 'Banner', 'crisop' );
    return $columns;
}


add_action( 'manage_product_cat_custom_column', 'ninetheme_wc_customFieldsListDisplay' , 10, 3); //Populating the Columns
function ninetheme_wc_customFieldsListDisplay( $columns, $column, $id ) {
    if ( 'ninetheme_cat_banner' == $column ) {
        $columns = get_term_meta($id, 'ninetheme_wc_cat_banner', true);
        $columns = $columns ? '<span class="wc-banner"></span>' : '';
    }
    return $columns;
}


if ( ! function_exists( 'ninetheme_wc_per_page_select' ) ) {
    function ninetheme_wc_per_page_select()
    {
        if ( ! wc_get_loop_prop( 'is_paginated' ) ) {
            return;
        }

        $numbers = ninetheme_settings( 'per_page_select_options' );
        $per_page_opt = ( ! empty( $numbers ) ) ? explode( ',', $numbers ) : array( 9, 12, 24, 36 );

        ?>
        <div class="ninetheme-filter-per-page ninetheme-shop-filter-item">
            <ul class="ninetheme-filter-action">
                <li class="ninetheme-per-page-title"><?php esc_html_e( 'Show', 'crisop' ); ?></li>
                <?php foreach ( $per_page_opt as $key => $value ) {

                    $link = add_query_arg( 'per_page', $value );

                    $classes = isset( $_GET['per_page'] ) && $_GET['per_page'] === $value ? ' active' : '';
                    $val = $value == -1 ? esc_html__( 'All', 'crisop' ) : $value;
                    ?>
                    <li class="ninetheme-per-page-item<?php echo esc_attr( $classes ); ?>">
                        <a rel="nofollow noopener" href="<?php echo esc_url( $link ); ?>"><?php esc_html( printf( '%s', $val ) ); ?></a>
                    </li>
                <?php } ?>
            </ul>
        </div>
        <?php
    }
}

if ( ! function_exists( 'ninetheme_wc_column_select' ) ) {
    function ninetheme_wc_column_select()
    {
        if ( ! wc_get_loop_prop( 'is_paginated' ) ) {
            return;
        }
        if ( !ninetheme_get_shop_column() && 'list' == ninetheme_settings( 'shop_product_type', '4' ) ) {
            $col = 1;
        } elseif ( intval(ninetheme_get_shop_column()) > 1 ) {
            $col = intval(ninetheme_get_shop_column());
        } else {
            $col = isset( $_GET['column'] ) && $_GET['column'] ? intval( $_GET['column'] ) : intval( ninetheme_settings( 'shop_colxl' ) );
        }

        $active = $hide = '';
        $cols = array( 1, 2, 3, 4, 5 );

        ?>
        <div class="ninetheme-filter-column-select ninetheme-shop-filter-item">
            <ul class="ninetheme-filter-action ninetheme-filter-columns ninetheme-mini-icon">
                <?php
                foreach ( $cols as $key => $value ) {

                    if ( ( $col < 6 ) && ( $col === $value ) ) {
                        $active = ' active';
                    }
                    if ( $value === 3 ) {
                        $hide = ' d-none d-sm-flex';
                    }
                    if ( $value === 4 ) {
                        $hide = ' d-none d-lg-flex';
                    }
                    if ( $value === 5 ) {
                        $hide = ' d-none d-xl-flex';
                    }
                    ?>
                    <li class="<?php echo esc_attr( 'val-'.$value.$active.$hide ); ?>">
                        <a rel="nofollow noopener" href="<?php echo esc_url( add_query_arg( 'column', $value ) ); ?>"><?php echo ninetheme_svg_lists('column-'.$value, 'ninetheme-svg-icon');?></a>
                    </li>
                    <?php
                    $active = '';
                }
                ?>
            </ul>
        </div>
        <?php
    }
}


if ( !function_exists( 'ninetheme_wc_category_search_form' ) ) {
    function ninetheme_wc_category_search_form() {

        $terms = get_terms( array( 'taxonomy' => 'product_cat', 'hide_empty' => false, 'parent' => 0 ) );
        ?>
        <div class="header-search-wrap">
            <form role="search" method="get" action="<?php echo esc_url( home_url( '/'  ) ) ?>">
                <input  type="text" name="s"
                value="<?php get_search_query() ?>"
                placeholder="<?php echo esc_attr_e( 'Search for your item\'s type.....', 'crisop' ) ?>">
                <input type="hidden" name="post_type" value="product" />
                <select class="custom-select" name="product_cat">
                    <option value="" selected><?php echo esc_html_e( 'All Category', 'crisop' ) ?></option>
                    <?php
                    foreach ( $terms as $term ) {
                        if ( $term->count >= 1 ) {
                            ?>
                            <option value="<?php echo esc_attr( $term->slug ) ?>"><?php echo esc_html( $term->name ) ?></option>
                            <?php
                        }
                    }
                    ?>
                </select>
                <button class="btn-submit" type="submit"><?php echo ninetheme_svg_lists( 'search' ); ?></button>
                <?php do_action( 'wpml_add_language_form_field' ); ?>
            </form>
        </div>
        <?php
    }
}


if ( !function_exists( 'ninetheme_wc_format_sale_price' ) ) {
    /**
     * Format a sale price for display.
     *
     * @since  3.0.0
     * @param  string $regular_price Regular price.
     * @param  string $sale_price    Sale price.
     * @return string
     */
    add_filter( 'woocommerce_format_sale_price', 'ninetheme_wc_format_sale_price', 10, 3 );
    function ninetheme_wc_format_sale_price( $price, $regular_price, $sale_price ) {
        $price = '<span class="ninetheme-primary-color del"><span>' . ( is_numeric( $regular_price ) ? wc_price( $regular_price ) : $regular_price ) . '</span> – </span> <span class="ninetheme-primary-color ins">' . ( is_numeric( $sale_price ) ? wc_price( $sale_price ) : $sale_price ) . '</span>';
        return $price;
    }
}


if ( !function_exists( 'ninetheme_shop_main_loop' ) ) {
    add_action('ninetheme_shop_main_loop','ninetheme_shop_main_loop', 10 );
    function ninetheme_shop_main_loop()
    {
        $class = ninetheme_wc_product_column();
        $loop  = woocommerce_product_loop();

        $style  = apply_filters('ninetheme_shop_layout_style', ninetheme_settings( 'shop_layout_style', 'bordered' ) );
        $class .= 'bordered' == $style || ( isset( $_GET['shop_layout_style'] ) && $_GET['shop_layout_style'] == 'bordered' ) ? ' style-2' : ' style-1';

        if ( !ninetheme_is_pjax() ) {
            echo '<div class="ninetheme-products-wrapper">';
        }
            do_action( 'ninetheme_shop_choosen_filters' );

            echo '<div class="shop-data-filters" data-shop-filters=\''.ninetheme_wc_filters_for_ajax().'\'></div>';

            if ( $loop ) {
                echo '<div class="ninetheme-products products row '.$class.'">';

                    if ( wc_get_loop_prop( 'total' ) ) {
                        while ( have_posts() ) {
                            the_post();

                            /**
                            * Hook: woocommerce_shop_loop.
                            */
                            do_action( 'woocommerce_shop_loop' );

                            wc_get_template_part( 'content', 'product' );
                        }
                    }
                echo '</div>';

                /**
                * Hook: ninetheme_shop_pagination.
                *
                * @hooked ninetheme_shop_pagination
                */
                do_action( 'ninetheme_shop_pagination' );
            } else {
                /**
                * Hook: woocommerce_no_products_found.
                *
                * @hooked wc_no_products_found - 10
                */
                do_action( 'woocommerce_no_products_found' );
            }
        if ( !ninetheme_is_pjax() ) {
            echo '</div>';
        }
    }
}



if ( !function_exists( 'ninetheme_shop_sidebar' ) ) {
    add_action('ninetheme_shop_sidebar','ninetheme_shop_sidebar', 10 );
    function ninetheme_shop_sidebar()
    {
        $layout = apply_filters('ninetheme_shop_layout', ninetheme_settings( 'shop_layout', 'left-sidebar' ) );
        $class  = wp_is_mobile() ? 'ninetheme-shop-fixed-sidebar' : 'default-sidebar col-lg-3';
        if ( ( 'left-sidebar' == $layout || 'right-sidebar' == $layout ) && is_active_sidebar( 'shop-page-sidebar' ) ) {
            ?>
            <div class="nt-sidebar ninetheme-shop-sidebar <?php echo esc_attr( $class ); ?>" data-column="default-sidebar col-lg-3">
                <div class="ninetheme-panel-close-button ninetheme-close-sidebar"></div>
                <div class="nt-sidebar-inner-wrapper">
                    <div class="nt-sidebar-inner"><?php dynamic_sidebar( 'shop-page-sidebar' ); ?></div>
                </div>
            </div>
            <?php
        }
    }
}

if ( !function_exists( 'ninetheme_shop_top_sidebar' ) ) {
    add_action('ninetheme_shop_before_loop','ninetheme_shop_top_sidebar', 20 );
    function ninetheme_shop_top_sidebar()
    {
        $layout = apply_filters('ninetheme_shop_layout', ninetheme_settings( 'shop_layout', 'left-sidebar' ) );
        $type   = apply_filters('ninetheme_shop_top_sidebar_type', ninetheme_settings( 'shop_top_sidebar_type', 'dropdown' ) );
        $class  = 'dropdown' == $type ? 'ninetheme-shop-dropdown-sidebar' : 'ninetheme-shop-hidden-top-sidebar d-none';
        $class .= ninetheme_is_pjax() ? ' nt-sidebar-ajax-content' : '';
        $column = ninetheme_settings( 'shop_top_sidebar_column', '3' );

        if ( 'top-sidebar' == $layout && is_active_sidebar( 'shop-page-top-sidebar' ) ) {
            ?>
            <div class="nt-sidebar ninetheme-shop-sidebar shop-top-sidebar <?php echo esc_attr( $class ); ?>">
                <div class="nt-sidebar-inner-wrapper">
                    <div class="nt-sidebar-inner row row-cols-<?php echo esc_attr( $column ); ?>">
                        <?php dynamic_sidebar( 'shop-page-top-sidebar' ); ?>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}

if ( !function_exists( 'ninetheme_shop_sidebar_fixed' ) ) {
    add_action('ninetheme_after_shop_page','ninetheme_shop_sidebar_fixed', 20 );
    function ninetheme_shop_sidebar_fixed()
    {
        $layout  = apply_filters('ninetheme_shop_layout', ninetheme_settings( 'shop_layout', 'left-sidebar' ) );
        $sidebar = 'top-sidebar' == $layout ? 'shop-page-top-sidebar' : 'shop-page-sidebar';
        $class   = 'top-sidebar' == $layout ? ' shop-top-sidebar-content' : '';
        $class  .= ninetheme_is_pjax() ? ' nt-sidebar-ajax-content' : '';

        if ( is_active_sidebar( $sidebar ) && $layout == 'fixed-sidebar' ) {
            ?>
            <div class="nt-sidebar ninetheme-shop-sidebar ninetheme-shop-fixed-sidebar<?php echo esc_attr( $class ); ?>">
                <div class="ninetheme-panel-close-button ninetheme-close-sidebar"></div>
                <div class="nt-sidebar-inner-wrapper">
                    <?php do_action( 'ninetheme_choosen_filters' );?>
                    <div class="nt-sidebar-inner ninetheme-scrollbar">
                        <?php dynamic_sidebar( $sidebar ); ?>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}


if ( !function_exists( 'ninetheme_shop_loop_notices' ) ) {
    add_action('ninetheme_before_wp_footer','ninetheme_shop_loop_notices', 15 );
    function ninetheme_shop_loop_notices()
    {
        if ( is_checkout() || '0' == ninetheme_settings( 'shop_cart_popup_notices_visibility', '1' ) ) {
            return;
        }
        ?>
        <div class="ninetheme-shop-popup-notices postion-<?php echo ninetheme_settings( 'shop_cart_popup_notices_position', 'bottom-right' );?>"></div>
        <?php
    }
}


if ( !function_exists( 'shop_product_summary_layouts_manager' ) ) {
    function shop_product_summary_layouts_manager()
    {
        if ( 'default' == ninetheme_settings( 'single_shop_summary_layout_type', 'default' ) ) {
            return;
        }
        $defaults = [
            'show'=> [
                'bread' => '',
                'title' => '',
                'rating' => '',
                'price' => '',
                'excerpt' => '',
                'cart' => '',
                'meta' => ''
            ]
        ];

        $layouts = ninetheme_settings( 'single_shop_summary_layouts', $defaults );

        if ( $layouts ) {

            unset( $layouts['show']['placebo'] );

            foreach ( $layouts['show'] as $key => $value ) {
                switch ( $key ) {
                    case 'bread':
                        echo ninetheme_breadcrumbs();
                    break;
                    case 'title':
                        woocommerce_template_single_title();
                    break;
                    case 'rating':
                        woocommerce_template_single_rating();
                    break;
                    case 'price':
                        woocommerce_template_single_price();
                    break;
                    case 'cart':
                        woocommerce_template_single_add_to_cart();
                    break;
                    case 'excerpt':
                         woocommerce_template_single_excerpt();
                    break;
                    case 'meta':
                         woocommerce_template_single_meta();
                    break;
                }
            }
        }
    }
}


if ( !function_exists( 'shop_loop_filters_layouts' ) ) {
    add_action('ninetheme_shop_before_loop','shop_loop_filters_layouts', 15 );
    function shop_loop_filters_layouts()
    {
        $defaults = [
            'left'=> [
                'result-count' => ''
            ],
            'right'=> [
                'sidebar-filter' => '',
                'per-page' => '',
                'ordering' => '',
                'column-select' => ''
            ]
        ];
        $layouts      = apply_filters( 'ninetheme_get_filters_layouts', ninetheme_settings( 'shop_loop_filters_layouts', $defaults ) );
        $page_layout  = apply_filters('ninetheme_shop_layout', ninetheme_settings( 'shop_layout', 'left-sidebar' ) );
        $sidebar_type = apply_filters('ninetheme_shop_top_sidebar_type', ninetheme_settings( 'shop_top_sidebar_type', 'dropdown' ) );
        $sidebar      = 'top-sidebar' == $page_layout ? 'shop-page-top-sidebar' : 'shop-page-sidebar';
        if ( $layouts ) {

            unset( $layouts['left']['placebo'] );
            unset( $layouts['right']['placebo'] );

            echo '<div class="ninetheme-inline-two-block ninetheme-before-loop ninetheme-shop-filter-top-area ninetheme-bg-gray">';

                if ( !empty( $layouts['left'] ) ) {
                    echo '<div class="ninetheme-block-left">';
                        if ( array_key_exists('sidebar-filter', $layouts['right']) && $page_layout != 'no-sidebar' && is_active_sidebar( $sidebar ) ) {
                            echo '<div class="ninetheme-open-fixed-sidebar ninetheme-open-fixed-sidebar-mobile"><span>'.esc_html__( 'Filter', 'crisop' ).'</span> '.ninetheme_svg_lists( 'filter', 'ninetheme-svg-icon' ).'</div>';
                        }
                        foreach ( $layouts['left'] as $key => $value ) {
                            switch ( $key ) {
                                case 'sidebar-filter':
                                if ( $page_layout == 'top-sidebar' && 'hidden' == $sidebar_type && is_active_sidebar( $sidebar ) ) {
                                    echo '<div class="ninetheme-toggle-hidden-sidebar"><span>'.esc_html__( 'Filter', 'crisop' ).'</span> '.ninetheme_svg_lists( 'filter', 'ninetheme-svg-icon' ).'<div class="ninetheme-filter-close"></div></div>';
                                }
                                if ( $page_layout == 'fixed-sidebar' && is_active_sidebar( $sidebar ) ) {
                                    echo '<div class="ninetheme-open-fixed-sidebar"><span>'.esc_html__( 'Filter', 'crisop' ).'</span> '.ninetheme_svg_lists( 'filter', 'ninetheme-svg-icon' ).'</div>';
                                }
                                break;

                                case 'search':
                                echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                break;

                                case 'result-count':
                                echo '<div class="ninetheme-woo-result-count">';woocommerce_result_count();echo '</div>';
                                break;

                                case 'breadcrumbs':
                                echo '<div class="ninetheme-woo-breadcrumb">'.ninetheme_breadcrumbs().'</div>';
                                break;

                                case 'per-page':
                                echo '<div class="ninetheme-shop-filter-area ninetheme-filter-per-page-area">';
                                    ninetheme_wc_per_page_select();
                                echo '</div>';
                                break;

                                case 'column-select':
                                echo '<div class="ninetheme-shop-filter-area ninetheme-filter-column-select-area">';
                                    ninetheme_wc_column_select();
                                echo '</div>';
                                break;

                                case 'ordering':
                                if ( woocommerce_product_loop() ) {
                                    echo '<div class="ninetheme-shop-filter-area ninetheme-filter-ordering-area">';
                                        woocommerce_catalog_ordering();
                                    echo '</div>';
                                }
                                break;
                            }
                        }
                    echo '</div>';
                }

                if ( !empty( $layouts['right'] ) ) {
                    echo '<div class="ninetheme-block-right">';
                        foreach ( $layouts['right'] as $key => $value ) {
                            switch ( $key ) {

                                case 'sidebar-filter':
                                if ( $page_layout == 'top-sidebar' && 'hidden' == $sidebar_type && is_active_sidebar( $sidebar ) ) {
                                    echo '<div class="ninetheme-toggle-hidden-sidebar"><span>'.esc_html__( 'Filter', 'crisop' ).'</span> '.ninetheme_svg_lists( 'filter', 'ninetheme-svg-icon' ).'<div class="ninetheme-filter-close"></div></div>';
                                }
                                if ( $page_layout == 'fixed-sidebar' && is_active_sidebar( $sidebar ) ) {
                                    echo '<div class="ninetheme-open-fixed-sidebar"><span>'.esc_html__( 'Filter', 'crisop' ).'</span> '.ninetheme_svg_lists( 'filter', 'ninetheme-svg-icon' ).'</div>';
                                }
                                break;

                                case 'search':
                                echo '<div class="top-action-btn" data-name="search-popup">'.ninetheme_svg_lists( 'search', 'ninetheme-svg-icon' ).'</div>';
                                break;

                                case 'result-count':
                                echo '<div class="ninetheme-woo-result-count">';woocommerce_result_count();echo '</div>';
                                break;

                                case 'breadcrumbs':
                                echo '<div class="ninetheme-woo-breadcrumb">'.ninetheme_breadcrumbs().'</div>';
                                break;

                                case 'per-page':
                                echo '<div class="ninetheme-shop-filter-area ninetheme-filter-per-page-area">';
                                    ninetheme_wc_per_page_select();
                                echo '</div>';
                                break;

                                case 'column-select':
                                echo '<div class="ninetheme-shop-filter-area ninetheme-filter-column-select-area">';
                                    ninetheme_wc_column_select();
                                echo '</div>';
                                break;

                                case 'ordering':
                                if ( woocommerce_product_loop() ) {
                                    echo '<div class="ninetheme-shop-filter-area ninetheme-filter-ordering-area">';
                                        woocommerce_catalog_ordering();
                                    echo '</div>';
                                }
                                break;
                            }
                        }
                    echo '</div>';
                }
            echo '</div>';
        }
    }
}

if ( !function_exists( 'ninetheme_loop_product_buttons_layouts' ) ) {
    function ninetheme_loop_product_buttons_layouts()
    {
        $layouts = ninetheme_settings( 'shop_loop_product_buttons_layouts' );
        $layouts = apply_filters( 'ninetheme_loop_product_buttons_layouts', $layouts );

        if ( $layouts ) {
            unset( $layouts['show']['placebo'] );
            foreach ( $layouts['show'] as $key => $value ) {

                switch ( $key ) {

                    case 'cart':
                    echo ninetheme_add_to_cart('icon');
                    break;

                    case 'quickview':
                    echo ninetheme_quickview_button();
                    break;

                    case 'compare':
                    echo ninetheme_compare_button();
                    break;

                    case 'wishlist':
                    echo ninetheme_wishlist_button();
                    break;
                }
            }
        }
    }
}


if ( !function_exists( 'ninetheme_loop_product_type1' ) ) {
    function ninetheme_loop_product_type1()
    {
        global $product;
        $id      = $product->get_id();
        $link    = get_permalink();
        $layout  = ninetheme_settings( 'shop_layout_style', 'default' );
        $weight  = $product->get_weight();
        $w_unit  = get_option('woocommerce_weight_unit');
        $excerpt = $product->get_short_description();
        $sku     = $product->get_sku();
        ?>
        <div class="woocommerce ninetheme-loop-product ninetheme-loop-product-type-1 hint-left" data-id="<?php echo esc_attr( $id ) ?>">
            <div class="ninetheme-loop-thumb-wrapper">
                <?php ninetheme_loop_product_thumb(); ?>

                <div class="ninetheme-loop-product-actions-hover">
                    <?php
                    echo ninetheme_quickview_button();
                    echo ninetheme_compare_button();
                    echo ninetheme_wishlist_button();

                    do_action( 'ninetheme_shop_loop_after_buttons' );
                    ?>
                </div>
            </div>

            <?php echo ninetheme_featured_product_icon(); ?>

            <div class="ninetheme-loop-product-details">
                <?php do_action( 'ninetheme_shop_loop_before_content' ); ?>

                <?php ninetheme_loop_product_stock_status(); ?>
                <?php woocommerce_template_loop_rating(); ?>

                <?php if ( $weight ) { ?>
                    <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                <?php } ?>

                <?php woocommerce_template_loop_price(); ?>
                <h6 class="ninetheme-loop-product-name"><a href="<?php echo esc_url( $link ) ?>"><?php echo get_the_title() ?></a></h6>
                <?php ninetheme_product_extra_fetaures(); ?>
                <div class="ninetheme-loop-product-labels">
                    <?php ninetheme_product_badge(); ?>
                    <?php ninetheme_product_discount(); ?>
                </div>

                <?php
                ninetheme_product_sku();
                ninetheme_cart_with_quantity('button');
                do_action( 'ninetheme_shop_loop_after_content' );
                ?>
            </div>

            <?php if ( '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details ninetheme-scrollbar">
                    <?php if ( $weight ) { ?>
                        <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                    <?php } ?>
                    <?php if ( $product->has_dimensions() ) { ?>
                        <span class="ninetheme-loop-product-shipping-dimensions"><?php echo esc_html( wc_format_dimensions( $product->get_dimensions(false) ) ); ?></span>
                    <?php } ?>
                    <?php
                        echo ninetheme_shipping_class_name();
                        echo ninetheme_only_left_in_stock();
                        ninetheme_product_sku();

                        if ( $product->get_short_description() ) {
                            echo '<div class="ninetheme-product-excerpt">'.$excerpt.'</div>';
                        }
                    ?>
                </div>
            <?php } ?>

            <?php if ( 'bordered' == $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details-trigger">
                    <span></span><span></span><span></span>
                </div>
            <?php } ?>

        </div>
        <?php if ( 'bordered' != $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
            <div class="ninetheme-loop-product-more-details-trigger">
                <span></span><span></span><span></span>
            </div>
            <?php
        }
    }
}

if ( !function_exists( 'ninetheme_loop_product_type2' ) ) {
    function ninetheme_loop_product_type2()
    {
        global $product;
        $id      = $product->get_id();
        $link    = get_permalink();
        $layout  = ninetheme_settings( 'shop_layout_style', 'default' );
        $weight  = $product->get_weight();
        $w_unit  = get_option('woocommerce_weight_unit');
        $excerpt = $product->get_short_description();
        $sku     = $product->get_sku();
        ?>
        <div class="woocommerce ninetheme-loop-product ninetheme-loop-product-type-2" data-id="<?php echo esc_attr( $id ) ?>">
            <div class="ninetheme-loop-thumb-wrapper">
                <?php ninetheme_loop_product_thumb(); ?>

                <div class="ninetheme-loop-product-actions-hover hint-top">
                    <?php
                    echo ninetheme_quickview_button();
                    echo ninetheme_compare_button();
                    echo ninetheme_wishlist_button();

                    do_action( 'ninetheme_shop_loop_after_buttons' );
                    ?>
                </div>
            </div>

            <?php echo ninetheme_featured_product_icon(); ?>

            <div class="ninetheme-loop-product-details hint-left">
                <?php do_action( 'ninetheme_shop_loop_before_content' ); ?>

                <?php ninetheme_loop_product_stock_status(); ?>
                <?php woocommerce_template_loop_rating(); ?>

                <?php if ( $weight ) { ?>
                    <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                <?php } ?>

                <?php woocommerce_template_loop_price(); ?>
                <h6 class="ninetheme-loop-product-name"><a href="<?php echo esc_url( $link ) ?>"><?php echo get_the_title() ?></a></h6>
                <?php ninetheme_product_extra_fetaures(); ?>
                <div class="ninetheme-loop-product-labels">
                    <?php ninetheme_product_badge(); ?>
                    <?php ninetheme_product_discount(); ?>
                </div>

                <?php
                ninetheme_product_sku();
                ninetheme_cart_with_quantity('icon');
                do_action( 'ninetheme_shop_loop_after_content' );
                ?>
            </div>

            <?php if ( '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details ninetheme-scrollbar">
                    <?php if ( $weight ) { ?>
                        <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                    <?php } ?>
                    <?php if ( $product->has_dimensions() ) { ?>
                        <span class="ninetheme-loop-product-shipping-dimensions"><?php echo esc_html( wc_format_dimensions( $product->get_dimensions(false) ) ); ?></span>
                    <?php } ?>
                    <?php
                        echo ninetheme_shipping_class_name();
                        echo ninetheme_only_left_in_stock();
                        ninetheme_product_sku();

                        if ( $product->get_short_description() ) {
                            echo '<div class="ninetheme-product-excerpt">'.$excerpt.'</div>';
                        }
                    ?>
                </div>
            <?php } ?>

            <?php if ( 'bordered' == $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details-trigger">
                    <span></span><span></span><span></span>
                </div>
            <?php } ?>

        </div>
        <?php if ( 'bordered' != $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
            <div class="ninetheme-loop-product-more-details-trigger">
                <span></span><span></span><span></span>
            </div>
            <?php
        }
    }
}

if ( !function_exists( 'ninetheme_loop_product_type3' ) ) {
    function ninetheme_loop_product_type3()
    {
        global $product;
        $id       = $product->get_id();
        $link     = get_permalink();
        $layout   = ninetheme_settings( 'shop_layout_style', 'default' );
        $weight   = $product->get_weight();
        $w_unit   = get_option('woocommerce_weight_unit');
        $excerpt  = $product->get_short_description();
        $sku      = $product->get_sku();
        $campains = get_the_terms( $id, 'ninetheme_product_campaigns' );
        ?>
        <div class="woocommerce ninetheme-loop-product ninetheme-loop-product-type-3" data-id="<?php echo esc_attr( $id ) ?>">
            <div class="ninetheme-loop-thumb-wrapper">
                <?php ninetheme_loop_product_thumb(); ?>

                <div class="ninetheme-loop-product-actions-hover hint-top">
                    <?php
                    echo ninetheme_quickview_button();
                    echo ninetheme_compare_button();
                    echo ninetheme_wishlist_button();

                    do_action( 'ninetheme_shop_loop_after_buttons' );
                    ?>
                </div>
            </div>

            <?php echo ninetheme_featured_product_icon(); ?>

            <div class="ninetheme-loop-product-details">
                <?php do_action( 'ninetheme_shop_loop_before_content' ); ?>

                <?php ninetheme_loop_product_stock_status(); ?>
                <?php woocommerce_template_loop_rating(); ?>

                <?php if ( $weight ) { ?>
                    <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                <?php } ?>

                <?php woocommerce_template_loop_price(); ?>
                <h6 class="ninetheme-loop-product-name"><a href="<?php echo esc_url( $link ) ?>"><?php echo get_the_title() ?></a></h6>
                <?php ninetheme_product_extra_fetaures(); ?>
                <div class="ninetheme-loop-product-labels">
                    <?php ninetheme_product_badge(); ?>
                    <?php ninetheme_product_discount(); ?>
                </div>

                <?php
                ninetheme_product_sku();
                ninetheme_cart_with_quantity('button');
                do_action( 'ninetheme_shop_loop_after_content' );
                ?>
            </div>

            <?php if ( '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details ninetheme-scrollbar">
                    <?php if ( $weight ) { ?>
                        <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                    <?php } ?>
                    <?php if ( $product->has_dimensions() ) { ?>
                        <span class="ninetheme-loop-product-shipping-dimensions"><?php echo esc_html( wc_format_dimensions( $product->get_dimensions(false) ) ); ?></span>
                    <?php } ?>
                    <?php
                        echo ninetheme_shipping_class_name();
                        echo ninetheme_only_left_in_stock();
                        ninetheme_product_sku();

                        if ( $product->get_short_description() ) {
                            echo '<div class="ninetheme-product-excerpt">'.$excerpt.'</div>';
                        }
                    ?>
                </div>
            <?php } ?>

            <?php if ( 'bordered' == $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details-trigger">
                    <span></span><span></span><span></span>
                </div>
            <?php } ?>

        </div>
        <?php if ( 'bordered' != $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
            <div class="ninetheme-loop-product-more-details-trigger">
                <span></span><span></span><span></span>
            </div>
            <?php
        }
    }
}

if ( !function_exists( 'ninetheme_loop_product_type4' ) ) {
    function ninetheme_loop_product_type4()
    {
        global $product;
        $id      = $product->get_id();
        $link    = get_permalink();
        $layout  = ninetheme_settings( 'shop_layout_style', 'default' );
        $weight  = $product->get_weight();
        $w_unit  = get_option('woocommerce_weight_unit');
        $excerpt = $product->get_short_description();
        $sku     = $product->get_sku();
        ?>
        <div class="woocommerce ninetheme-loop-product ninetheme-loop-product-type-4 hint-left" data-id="<?php echo esc_attr( $id ) ?>">

            <?php ninetheme_cart_with_quantity('icon'); ?>

            <div class="ninetheme-loop-thumb-wrapper">

                <?php ninetheme_loop_product_thumb(); ?>

                <div class="ninetheme-loop-product-actions-hover">
                    <?php
                    echo ninetheme_quickview_button();
                    echo ninetheme_compare_button();
                    echo ninetheme_wishlist_button();

                    do_action( 'ninetheme_shop_loop_after_buttons' );
                    ?>
                </div>
            </div>

            <?php echo ninetheme_featured_product_icon(); ?>

            <div class="ninetheme-loop-product-details">
                <?php do_action( 'ninetheme_shop_loop_before_content' ); ?>

                <?php ninetheme_loop_product_stock_status(); ?>
                <?php woocommerce_template_loop_rating(); ?>

                <?php if ( $weight ) { ?>
                    <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                <?php } ?>

                <?php woocommerce_template_loop_price(); ?>

                <h6 class="ninetheme-loop-product-name"><a href="<?php echo esc_url( $link ) ?>"><?php echo get_the_title() ?></a></h6>
                <?php ninetheme_product_extra_fetaures(); ?>
                <div class="ninetheme-loop-product-labels">
                    <?php ninetheme_product_badge(); ?>
                    <?php ninetheme_product_discount(); ?>
                </div>

                <?php ninetheme_product_sku(); ?>

                <?php do_action( 'ninetheme_shop_loop_after_content' ); ?>
            </div>

            <?php if ( '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details ninetheme-scrollbar">
                    <?php if ( $weight ) { ?>
                        <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                    <?php } ?>
                    <?php if ( $product->has_dimensions() ) { ?>
                        <span class="ninetheme-loop-product-shipping-dimensions"><?php echo esc_html( wc_format_dimensions( $product->get_dimensions(false) ) ); ?></span>
                    <?php } ?>
                    <?php
                        echo ninetheme_shipping_class_name();
                        echo ninetheme_only_left_in_stock();
                        ninetheme_product_sku();
                        if ( $product->get_short_description() ) {
                            echo '<div class="ninetheme-product-excerpt">'.$excerpt.'</div>';
                        }
                    ?>
                </div>
            <?php } ?>

            <?php if ( 'bordered' == $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details-trigger">
                    <span></span><span></span><span></span>
                </div>
            <?php } ?>

        </div>
        <?php if ( 'bordered' != $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
            <div class="ninetheme-loop-product-more-details-trigger">
                <span></span><span></span><span></span>
            </div>
            <?php
        }
    }
}


if ( !function_exists( 'ninetheme_loop_product_type_list' ) ) {
    function ninetheme_loop_product_type_list()
    {
        global $product;
        $id      = $product->get_id();
        $link    = get_permalink();
        $layout  = ninetheme_settings( 'shop_layout_style', 'default' );
        $weight  = $product->get_weight();
        $w_unit  = get_option('woocommerce_weight_unit');
        $excerpt = $product->get_short_description();
        $sku     = $product->get_sku();
        ?>
        <div class="woocommerce ninetheme-loop-product ninetheme-loop-product-type-list" data-id="<?php echo esc_attr( $id ) ?>">
            <div class="ninetheme-loop-thumb-wrapper">
                <?php ninetheme_loop_product_thumb(); ?>
                <div class="ninetheme-loop-product-actions-hover hint-left">
                    <?php
                    echo ninetheme_quickview_button();
                    echo ninetheme_compare_button();
                    echo ninetheme_wishlist_button();

                    do_action( 'ninetheme_shop_loop_after_buttons' );
                    ?>
                </div>
            </div>

            <?php echo ninetheme_featured_product_icon(); ?>

            <div class="ninetheme-loop-product-details">
                <?php do_action( 'ninetheme_shop_loop_before_content' ); ?>

                <?php ninetheme_loop_product_stock_status(); ?>

                <?php if ( $weight ) { ?>
                    <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                <?php } ?>

                <?php woocommerce_template_loop_price(); ?>
                <h6 class="ninetheme-loop-product-name"><a href="<?php echo esc_url( $link ) ?>"><?php echo get_the_title(); ?></a></h6>
                <?php ninetheme_product_extra_fetaures(); ?>
                <div class="ninetheme-loop-product-labels">
                    <?php ninetheme_product_badge(); ?>
                    <?php ninetheme_product_discount(); ?>
                </div>
                <?php
                ninetheme_product_sku();
                ninetheme_cart_with_quantity('button');
                do_action( 'ninetheme_shop_loop_after_content' );
                ?>
            </div>

            <?php if ( '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details ninetheme-scrollbar">
                    <?php if ( $weight ) { ?>
                        <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                    <?php } ?>
                    <?php if ( $product->has_dimensions() ) { ?>
                        <span class="ninetheme-loop-product-shipping-dimensions"><?php echo esc_html( wc_format_dimensions( $product->get_dimensions(false) ) ); ?></span>
                    <?php } ?>
                    <?php
                        echo ninetheme_shipping_class_name();
                        echo ninetheme_only_left_in_stock();
                        ninetheme_product_sku();

                        if ( $product->get_short_description() ) {
                            echo '<div class="ninetheme-product-excerpt">'.$excerpt.'</div>';
                        }
                    ?>
                </div>
            <?php } ?>

            <?php if ( 'bordered' == $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
                <div class="ninetheme-loop-product-more-details-trigger">
                    <span></span><span></span><span></span>
                </div>
            <?php } ?>

        </div>
        <?php if ( 'bordered' != $layout && '1' == ninetheme_settings( 'shop_product_box_details_visibility', '0' ) ) { ?>
            <div class="ninetheme-loop-product-more-details-trigger">
                <span></span><span></span><span></span>
            </div>
            <?php
        }
    }
}

if ( !function_exists( 'ninetheme_loop_product_widget_content' ) ) {
    function ninetheme_loop_product_widget_content($box_style='style-1')
    {
        global $product;
        $id       = $product->get_id();
        $link     = get_permalink();
        $type     = ninetheme_settings( 'shop_product_type', '4' );
        $type     = 'list' == $type ? 4 : $type;
        $hint     = 'list' == $type ? ' hint-top' : ' hint-left';
        $layout   = ninetheme_settings( 'shop_layout_style', 'default' );
        $css_class  = 'ninetheme-type-product ninetheme-product-type-'.$type;

        $class    = 'ninetheme-loop-product ninetheme-loop-product-type-1 ninetheme-loop-product-type-'.$type.$hint;
        $btn_type = '3' == $type ? 'button' : 'icon';
        $weight   = $product->get_weight();
        $w_unit   = get_option('woocommerce_weight_unit');
        $excerpt  = $product->get_short_description();
        $sku      = $product->get_sku();
        $campains = get_the_terms( $id, 'ninetheme_product_campaigns' );

        ?>
        <div <?php wc_product_class( $css_class, $product ); ?>>
            <div class="woocommerce <?php echo esc_attr( $class ) ?>" data-id="<?php echo esc_attr( $id ) ?>">
                <?php
                if ( $type == 4 ) {
                    ninetheme_cart_with_quantity('icon');
                }
                ?>
                <div class="ninetheme-loop-thumb-wrapper">
                    <?php ninetheme_loop_product_thumb(); ?>

                    <div class="ninetheme-loop-product-actions-hover">
                        <?php
                        echo ninetheme_quickview_button();
                        echo ninetheme_compare_button();
                        echo ninetheme_wishlist_button();
                        ?>
                        <?php do_action( 'ninetheme_shop_loop_after_buttons' ); ?>
                    </div>

                </div>

                <?php echo ninetheme_featured_product_icon(); ?>

                <div class="ninetheme-loop-product-details">
                    <?php do_action( 'ninetheme_shop_loop_before_content' ); ?>

                    <?php ninetheme_loop_product_stock_status(); ?>
                     <?php woocommerce_template_loop_rating(); ?>

                    <?php if ( $weight ) { ?>
                        <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                    <?php } ?>

                    <?php woocommerce_template_loop_price(); ?>
                    <h6 class="ninetheme-loop-product-name"><a href="<?php echo esc_url( $link ) ?>"><?php echo get_the_title() ?></a></h6>
                    <?php ninetheme_product_extra_fetaures(); ?>
                    <div class="ninetheme-loop-product-labels">
                        <?php ninetheme_product_badge(); ?>
                        <?php ninetheme_product_discount(); ?>
                    </div>
                    <?php ninetheme_product_sku(); ?>
                    <?php
                    if ( $type != 4 ) {
                        ninetheme_cart_with_quantity($btn_type);
                    }
                    ?>
                    <?php do_action( 'ninetheme_shop_loop_after_content' ); ?>
                </div>
                <div class="ninetheme-loop-product-more-details ninetheme-scrollbar">
                    <?php if ( $weight ) { ?>
                        <span class="ninetheme-loop-product-shipping-weight"><?php echo esc_html( $weight.' '.$w_unit ); ?></span>
                    <?php } ?>
                    <?php if ( $product->has_dimensions() ) { ?>
                        <span class="ninetheme-loop-product-shipping-dimensions"><?php echo esc_html( wc_format_dimensions( $product->get_dimensions(false) ) ); ?></span>
                    <?php } ?>
                    <?php
                        echo ninetheme_shipping_class_name();
                        echo ninetheme_only_left_in_stock();
                        ninetheme_product_sku();

                        if ( $product->get_short_description() ) {
                            echo '<div class="ninetheme-product-excerpt">'.$excerpt.'</div>';
                        }
                    ?>
                </div>
                <?php if ( 'style-2' == $box_style ) { ?>
                    <div class="ninetheme-loop-product-more-details-trigger">
                        <span></span><span></span><span></span>
                    </div>
                <?php } ?>
            </div>
            <?php if ( 'style-1' == $box_style ) { ?>
                <div class="ninetheme-loop-product-more-details-trigger">
                    <span></span><span></span><span></span>
                </div>
                <?php
            }
        echo '</div>';
    }
}


if ( !function_exists( 'ninetheme_loop_product_custom_layout_manager' ) ) {
    function ninetheme_loop_product_custom_layout_manager()
    {
        global $product;
        $layouts = ninetheme_settings( 'shop_loop_product_layouts' );
        if ( $layouts ) {
            unset( $layouts['show']['placebo'] );

            echo '<div class="woocommerce ninetheme-loop-product ninetheme-loop-product-type-custom hint-top" data-id="'.$product->get_id().'">';

                foreach ( $layouts['show'] as $key => $value ) {

                    switch ( $key ) {

                        case 'thumb':
                        echo '<div class="ninetheme-loop-thumb-wrapper">';
                            ninetheme_loop_product_thumb();
                            echo '<span class="loading-wrapper"><span class="ajax-loading"></span></span>';
                        echo '</div>';
                        break;

                        case 'title':
                        echo '<h6 class="ninetheme-loop-product-name"><a href="'.esc_url( get_permalink() ).'">'.get_the_title().'</a></h6>';
                        break;

                        case 'price':
                            woocommerce_template_loop_price();
                        break;

                        case 'rating':
                            woocommerce_template_loop_rating();
                        break;

                        case 'buttons':
                        echo '<div class="ninetheme-loop-product-buttons-static">';
                            ninetheme_loop_product_buttons_layouts();
                        echo '</div>';
                        break;

                        case 'cart':
                            echo ninetheme_add_to_cart('button');
                        break;

                        case 'stock':
                            ninetheme_loop_product_stock_status();
                        break;

                        case 'sale':
                            echo '<div class="ninetheme-loop-product-labels">';
                                ninetheme_product_badge();
                                ninetheme_product_discount();
                            echo '</div>';
                        break;

                        case 'desc':
                            ninetheme_product_excerpt();
                        break;
                    }
                }

            echo '</div>';
        }
    }
}


/**
* Single Bottom Popup Product Add To Cart
*/
if ( ! function_exists( 'ninetheme_product_bottom_popup_cart' ) ) {
    add_action( 'ninetheme_before_wp_footer', 'ninetheme_product_bottom_popup_cart', 10 );
    function ninetheme_product_bottom_popup_cart()
    {
        global $product;

        if ( !is_product() || $product->is_type('external') || '0' == ninetheme_settings( 'ninetheme_product_bottom_popup_cart', '0' ) ) {
            return;
        }
        ?>
        <div id="product-bottom-<?php the_ID(); ?>" <?php wc_product_class( 'ninetheme-product-bottom-popup-cart', $product ); ?>>
            <div class="container-xl ninetheme-container-xl">
                <div class="row">
                    <div class="col-12 col-md-6 d-none d-md-flex">
                        <div class="ninetheme-product-bottom-details">
                            <?php echo get_the_post_thumbnail( $product->get_id(), 'thumbnail' ); ?>
                            <div class="ninetheme-product-bottom-title">
                                <?php echo get_the_title( $product->get_id() ); ?>
                                <?php woocommerce_template_loop_price(); ?>
                            </div>
                        </div>
                    </div>
                    <div class="col-12 col-md-6 d-md-flex col-button">
                        <div class="ninetheme-product-bottom-title mobile-title">
                            <?php echo get_the_title( $product->get_id() ); ?>
                        </div>
                        <?php echo ninetheme_add_to_cart(); ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}

if ( ! function_exists( 'ninetheme_get_swatches_colors' ) ) {
    function ninetheme_get_swatches_colors()
    {
        $colors = array();
        $terms  = get_terms("pa_color");
        if ( empty( $terms ) ) {
            return;
        }
        foreach ( $terms as $term ) {
            if ( !empty( $term->term_id ) ) {
                $val = get_term_meta( $term->term_id, 'ninetheme_swatches_color', true );
                $colors[$term->name] = $val;
            }
        }
        return !empty( $colors ) ? $colors : false;
    }
}

/*************************************************
## Get vendor name
*************************************************/
if ( ! function_exists( 'ninetheme_vendor_name' ) ) {
    function ninetheme_vendor_name()
    {
        if ( function_exists( 'get_wcmp_vendor_settings' ) ) {
            global $post;
            $vendor = get_wcmp_product_vendors( $post->ID );
            if ( isset( $vendor->page_title ) ) {
                $store_name = $vendor->page_title;
                return '<a href="'.esc_url( $vendor->permalink ).'">'.esc_html( $store_name ).'</a>';
            }
        } elseif ( class_exists( 'WeDevs_Dokan' ) ) {
            // Get the author ID (the vendor ID)
            $vendor_id  = get_post_field( 'post_author', get_the_id() );
            $store_info = dokan_get_store_info( $vendor_id ); // Get the store data
            $store_name = $store_info['store_name'];          // Get the store name
            $store_url  = dokan_get_store_url( $vendor_id );  // Get the store URL

            if ( isset( $store_name ) ) {
                return '<a href="'.esc_url( $store_url ).'">'.esc_html( $store_name ).'</a>';
            }
        }
    }
}

/*************************************************
## Whatsapp Button For Single Product
*************************************************/
if ( ! function_exists( 'ninetheme_product_whatsapp_button' ) ) {
    function ninetheme_product_whatsapp_button()
    {
        if ( '0' == ninetheme_settings( 'product_whatsapp_button_visibility', '1' ) ) {
            return;
        }
        $page_link     = get_the_permalink();
        $link          = ninetheme_settings( 'product_whatsapp_link' );
        $mobile_link   = ninetheme_settings( 'product_whatsapp_mobile_link' );
        $whatsapp_link = wp_is_mobile() ? $mobile_link : $link;
        $target        = ninetheme_settings( 'product_whatsapp_target' );
        $btn_title     = ninetheme_settings( 'whatsapp_btn_title', '' ) ? ninetheme_settings( 'whatsapp_btn_title' ) : esc_html__( 'Whatsapp', 'crisop' );
        $default_link  = wp_is_mobile() ? 'whatsapp://send?text=' . urlencode( $page_link ) : 'https://api.whatsapp.com/send?text=' . urlencode( $page_link );
        ?>
        <a
        rel="noopener noreferrer nofollow"
        href="<?php echo '' != $whatsapp_link ? $whatsapp_link : $default_link; ?>"
        target="<?php echo esc_attr( $target ); ?>"
        class="ninetheme-btn ninetheme-btn-medium social-whatsapp"
        data-title="whatsapp">
            <i class="fab fa-whatsapp"></i>
            <span class="whatsapp-text"><?php echo esc_html( $btn_title ); ?></span>
        </a>
        <?php
    }
}

/*************************************************
## Custom Action Button For Single Product
*************************************************/
if ( ! function_exists( 'ninetheme_product_page_custom_btn' ) ) {
    add_action( 'woocommerce_after_add_to_cart_form', 'ninetheme_product_page_custom_btn', 10 );
    function ninetheme_product_page_custom_btn()
    {
        if ( '0' == ninetheme_settings( 'product_custom_btn_visibility', '1' ) ) {
            return;
        }
        $page_link = get_the_permalink();
        $page_id   = get_the_ID();
        $action    = ninetheme_settings( 'product_custom_btn_action', '' );
        $title     = ninetheme_settings( 'product_custom_btn_title', '' );
        $link      = ninetheme_settings( 'product_custom_btn_link', '' );
        $target    = ninetheme_settings( 'product_custom_btn_target' );
        $shortcode = ninetheme_settings( 'product_custom_btn_form_shortcode', '' );
        $wlink     = ninetheme_settings( 'product_custom_btn_whatsapp_link' );
        $wlink     = $wlink ? $wlink : 'https://api.whatsapp.com/send?text=' . urlencode( $page_link );
        $wm_link   = ninetheme_settings( 'product_custom_btn_whatsapp_mobile_link' );
        $wm_link   = $wm_link ? $wm_link : 'whatsapp://send?text=' . urlencode( $page_link );
        $w_link    = wp_is_mobile() ? $wm_link : $wlink;

        if ( 'link' == $action ) {

            echo '<a class="ninetheme-btn ninetheme-btn-medium ninetheme-btn-primary ninetheme-btn-reverse ninetheme-btn-action" href="'.$link.'" target="'.$target.'">'.$title.'</a>';

        } elseif ( 'form' == $action ) {

            wp_enqueue_style( 'fancybox' );
            wp_enqueue_script( 'fancybox' );

            echo '<a class="ninetheme-btn ninetheme-btn-medium ninetheme-btn-primary ninetheme-btn-reverse ninetheme-btn-action" data-fancybox="dialog" data-src="#dialog-content-'.$page_id.'" href="#dialog-content-'.$page_id.'">'.$title.'</a>';
            echo '<div id="dialog-content-'.$page_id.'" style="display:none;max-width:500px;">'.do_shortcode( $shortcode ).'</div>';

        } elseif ( 'whatsapp' == $action ) {

            echo '<a rel="noopener noreferrer nofollow" href="'.$w_link.'" target="'.esc_html( $target ).'" class="ninetheme-btn ninetheme-btn-medium social-whatsapp ninetheme-btn-action"><i class="fab fa-whatsapp"></i><span class="whatsapp-text">'.$title.'</span></a>';
        }
    }
}

/*************************************************
## Buy Now Button For Single Product
*************************************************/
if ( ! function_exists( 'ninetheme_add_buy_now_button_single' ) ) {
    function ninetheme_add_buy_now_button_single()
    {
        if ( '0' == ninetheme_settings( 'buy_now_visibility', '0' ) ) {
            return false;
        }
        global $product;
        $param = apply_filters( 'ninetheme_buy_now_param', ninetheme_settings( 'buy_now_param', 'ninetheme-buy-now' ) );
        $btn_title = ninetheme_settings( 'buy_now_btn_title', '' ) ? ninetheme_settings( 'buy_now_btn_title' ) : esc_html__( 'Buy Now', 'crisop' );
        if ($product->is_type( 'simple' ) || $product->is_type( 'variable' ) ) {
            printf( '<button id="buynow" type="submit" name="'.$param.'" value="%d" class="ninetheme-btn-buynow ninetheme-btn ninetheme-btn-medium ninetheme-btn-primary ninetheme-btn-reverse">%s</button>', $product->get_ID(), $btn_title );
        }
    }
}


/*************************************************
## Handle for click on buy now
*************************************************/
if ( ! function_exists( 'ninetheme_handle_buy_now' ) ) {
    function ninetheme_handle_buy_now()
    {
        $param = apply_filters( 'ninetheme_buy_now_param', ninetheme_settings( 'buy_now_param', 'ninetheme-buy-now' ) );

        if ( ! isset( $_REQUEST[ $param ] ) || '0' == ninetheme_settings( 'buy_now_visibility', '0' ) ) {
            return false;
        }

        $quantity     = floatval( isset( $_REQUEST['quantity'] ) ? $_REQUEST['quantity'] : 1 );
        $product_id   = absint( isset( $_REQUEST[ $param ] ) ? $_REQUEST[$param] : 0 );
        $variation_id = absint( isset( $_REQUEST[ 'variation_id' ] ) ? $_REQUEST['variation_id'] : 0 );
        $variation    = [];

        foreach ( $_REQUEST as $name => $value ) {
            if ( substr( $name, 0, 10 ) === 'attribute_' ) {
                $variation[ $name ] = $value;
            }
        }

        if ( $product_id ) {
            if ( '1' == ninetheme_settings( 'buy_now_reset_cart', '0' ) ) {
                WC()->cart->empty_cart();
            }

            if ( $variation_id ) {
                foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                    if ( $cart_item['product_id'] == $product_id && $cart_item['variation_id'] == $variation_id ) {
                        WC()->cart->remove_cart_item( $cart_item_key );
                    }
                }
                WC()->cart->add_to_cart( $product_id, $quantity, $variation_id, $variation );
            } else {
                WC()->cart->add_to_cart( $product_id, $quantity );
            }

            switch ( apply_filters( 'ninetheme_buy_now_redirect', ninetheme_settings( 'buy_now_redirect', 'checkout' ) ) ) {
                case 'checkout':
                $redirect = wc_get_checkout_url();
                break;
                case 'cart':
                $redirect = wc_get_cart_url();
                break;
                default:
                $redirect = ninetheme_settings( 'buy_now_redirect_custom', '/' );
            }

            $redirect = esc_url( apply_filters( 'buy_now_redirect_url', $redirect ) );

            if ( empty( $redirect ) ) {
                $redirect = '/';
            }

            wp_safe_redirect( $redirect );

            exit;
        }

    }
    add_action( 'template_redirect', 'ninetheme_handle_buy_now' );
}


/**
*  countdown for product
*/
if ( ! function_exists( 'ninetheme_product_countdown' ) ) {
    function ninetheme_product_countdown()
    {
        if ( '1' == ninetheme_settings('product_countdown_visibility','1') ) {
            global $product;

            $id      = $product->get_id();
            $update  = ninetheme_settings('product_countdown_update');
            $hide    = get_post_meta( $id, 'ninetheme_product_hide_countdown', true);
            $text    = get_post_meta( $id, 'ninetheme_product_countdown_text', true);
            $ot_time = ninetheme_settings('product_countdown_date');
            $date    = get_post_meta( $id, '_sale_price_dates_to', true);
            $mb_time = $date ? date_i18n( 'Y/m/d', $date ) : '';
            $time    = $mb_time ? $mb_time : $ot_time;
            $icon    = ninetheme_settings('product_countdown_icon','');
            $ot_text = ninetheme_settings('product_countdown_text','');
            $expired = ninetheme_settings('product_countdown_expired','');
            $icon    = $icon ? $icon : ninetheme_svg_lists( 'flash', 'ninetheme-svg-icon' );
            $text    = $text ? $text : $ot_text;
            $text2   = ninetheme_settings('product_countdown_after_text');
            $class   = $text2 ? ' has-after-text' : '';
            $expired = $expired ? $expired : esc_html__('Expired','crisop');

            if ( 'yes' != $hide && $time ) {
                $current_time = date( 'Y/m/d' );

                if ( ( $current_time == $time || $time < $current_time ) && '1' == $update ) {
                    $next_time = ninetheme_settings('product_countdown_update_next', 7 );
                    $time      = date('Y/m/d', strtotime($current_time. ' + '.$next_time.' days'));
                }

                echo '<div class="ninetheme-summary-item ninetheme-viewed-offer-time'.$class.'">';
                    if ( trim($icon) && '1' == ninetheme_settings('product_countdown_icon_visibilty', '0')  ) {
                        echo '<div class="offer-time-icon">'.$icon.'</div>';
                    }
                    echo '<div class="offer-time-inner">';
                        if ( $text ) {
                            echo '<p class="offer-time-text">'.$text.'</p>';
                        }
                        echo '<div class="ninetheme-coming-time" data-countdown=\'{"date":"'.$time.'","expired":"'.$expired.'"}\'>
                        <div class="time-count days"></div>
                        <span class="separator">:</span>
                        <div class="time-count hours"></div>
                        <span class="separator">:</span>
                        <div class="time-count minutes"></div>
                        <span class="separator">:</span>
                        <div class="time-count second"></div>
                        </div>';
                        if ( $text2 ) {
                            echo '<p class="offer-time-text-after">'.$text2.'</p>';
                        }
                    echo '</div>';
                echo '</div>';
            }
        }
    }
}


if ( ! function_exists( 'ninetheme_cart_goal_progressbar' ) ) {
    add_action( 'ninetheme_before_cart_table', 'ninetheme_cart_goal_progressbar', 10 );
    add_action( 'ninetheme_side_panel_after_header', 'ninetheme_cart_goal_progressbar', 10 );
    function ninetheme_cart_goal_progressbar()
    {
        $amount = round( ninetheme_settings( 'free_shipping_progressbar_amount', 500 ), wc_get_price_decimals() );
        if ( !( $amount > 0 ) || '1' != ninetheme_settings( 'free_shipping_progressbar_visibility', 1 ) ) {
            return;
        }

        $message_initial = ninetheme_settings( 'free_shipping_progressbar_message_initial' );
        $message_success = ninetheme_settings( 'free_shipping_progressbar_message_success' );

        $total     = WC()->cart->get_displayed_subtotal();
        $remainder = ( $amount - $total );
        $success   = $total >= $amount ? ' free-shipping-success' : '';
        $value     = $total <= $amount ? ( $total / $amount ) * 100 : 100;
        if ( is_cart() ) {
            $success .= ' cart-page-goal';
        } elseif ( is_checkout() ) {
            $success .= ' checkout-page-goal';
        }
        if ( $total == 0 ) {
            $value = 0;
        }
        wp_enqueue_style( 'ninetheme-wc-free-shipping-progressbar');
        ?>
        <div class="ninetheme-cart-goal-wrapper<?php echo esc_attr( $success ); ?>">
            <div class="ninetheme-cart-goal-text">
                <?php
                if ( $total >= $amount ) {
                    if ( $message_success ) {
                        echo sprintf('%s', $message_success );
                    } else {
                        echo sprintf('%s <strong>%s</strong>',
                        esc_html__('Congrats! You are eligible for', 'crisop'),
                        esc_html__('more to enjoy FREE Shipping', 'crisop'));
                    }
                } else {
                    if ( $message_initial ) {
                        echo sprintf('%s', str_replace( '[remainder]', wc_price( $remainder ), $message_initial ) );
                    } else {
                        echo sprintf('%s %s <strong>%s</strong>',
                        esc_html__('Buy', 'crisop'),
                        wc_price( $remainder ),
                        esc_html__('more to enjoy FREE Shipping', 'crisop'));
                    }
                }
                ?>
                <input type="hidden" name="ninetheme-cart-goal-percent" value="<?php echo esc_attr( $value ); ?>" class="ninetheme-cart-goal-percent">
            </div>
            <div class="ninetheme-free-shipping-progress">
                <div class="ninetheme-progress-bar-wrap">
                    <div class="ninetheme-progress-bar" style="width:<?php echo esc_attr( $value ); ?>%;">
                        <div class="ninetheme-progress-value">
                            <?php echo ninetheme_svg_lists( 'delivery-return', 'ninetheme-svg-icon' ); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php
    }
}


/*************************************************
## Recently Viewed Products Always
*************************************************/
if ( ! function_exists( 'ninetheme_track_product_view' ) ) {

    remove_action( 'template_redirect', 'wc_track_product_view', 20 );
    add_action( 'template_redirect', 'ninetheme_track_product_view', 20 );
    function ninetheme_track_product_view() {
        if ( ! is_singular( 'product' ) && '1' != ninetheme_settings( 'shop_recently_visibility', 1 ) ) {
            return;
        }

        global $post;

        if ( empty( $_COOKIE['woocommerce_recently_viewed'] ) ) { // @codingStandardsIgnoreLine.
            $viewed_products = array();
        } else {
            $viewed_products = wp_parse_id_list( (array) explode( '|', wp_unslash( $_COOKIE['woocommerce_recently_viewed'] ) ) ); // @codingStandardsIgnoreLine.
        }

        // Unset if already in viewed products list.
        $keys = array_flip( $viewed_products );

        if ( !empty($viewed_products) && isset( $keys[ $post->ID ] ) ) {
            unset( $viewed_products[ $keys[ $post->ID ] ] );
        }

        $viewed_products[] = $post->ID;

        if ( count( $viewed_products ) > 15 ) {
            array_shift( $viewed_products );
        }

        // Store for session only.
        wc_setcookie( 'woocommerce_recently_viewed', implode( '|', $viewed_products ) );
    }
}

/*************************************************
## Recently Viewed Products Loop
*************************************************/
if ( ! function_exists( 'ninetheme_recently_viewed_product_loop' ) ) {

    add_action('ninetheme_after_main_content','ninetheme_recently_viewed_product_loop');
    function ninetheme_recently_viewed_product_loop()
    {
        if ( '1' != ninetheme_settings( 'shop_recently_visibility', 1 ) ) {
            return;
        }
        $viewed_products = ! empty( $_COOKIE['woocommerce_recently_viewed'] ) ? (array) explode( '|', wp_unslash( $_COOKIE['woocommerce_recently_viewed'] ) ) : array(); // @codingStandardsIgnoreLine
        $viewed_products = array_reverse( array_filter( array_map( 'absint', $viewed_products ) ) );

        if ( empty( $viewed_products) || !is_woocommerce()) {
            return;
        }

        $heading = ninetheme_settings('shop_recently_title', '');
        $heading = $heading ? esc_html( $heading ) : esc_html__( 'Recently Viewed Products', 'crisop' );

        $slider_options = json_encode(array(
            "loop"          => '1' == ninetheme_settings( 'shop_recently_loop', '0' ) ? true : false,
            "speed"         => intval(ninetheme_settings( 'shop_recently_speed', 800 )),
            "spaceBetween"  => intval(ninetheme_settings( 'shop_recently_gap', 20 )),
            "slidesPerView" => 1,
            "grabCursor"    => true,
            "autoHeight"    => true,
            "watchSlidesProgress" => true,
            "autoplay"      => '1' == ninetheme_settings( 'shop_recently_autoplay', 1 ) ? ["pauseOnMouseEnter" => true,"disableOnInteraction" => false] : false,
            "navigation"    => [
                "nextEl" => ".recently-slider-nav .ninetheme-slide-next",
                "prevEl" => ".recently-slider-nav .ninetheme-slide-prev"
            ],
            "breakpoints"   => [
                "0" => [
                    "slidesPerView" => intval(ninetheme_settings( 'shop_recently_smperview', 2 ))
                ],
                "768" => [
                    "slidesPerView" => intval(ninetheme_settings( 'shop_recently_mdperview', 3 ))
                ],
                "1024" => [
                    "slidesPerView" => intval(ninetheme_settings( 'shop_recently_perview', 6 ))
                ]
            ]
        ));

        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => 8,
            'post__in'       => $viewed_products,
            'orderby'        => 'post__in',
            'post_status'    => 'publish'
        );
        $hideoutstock = get_option('woocommerce_hide_out_of_stock_items');
        if ($hideoutstock == 'yes' ) {
            $args['meta_query'][] = array(
                'key'       => '_stock_status',
                'compare'   => '=',
                'value'     => 'instock'
            );
        }
        $loop = new WP_Query( $args );

        if ( $loop ) {
            wp_enqueue_script( 'swiper' );
            ?>
            <div class="ninetheme-product-recently ninetheme-recently-product-wrapper">
                <div class="container-xl ninetheme-container-xl">
                    <div class="row">
                        <div class="col-12">
                            <div class="section-title-wrapper">
                                <?php if ( $heading ) : ?>
                                    <h6 class="section-title"><?php echo esc_html( $heading ); ?></h6>
                                <?php endif; ?>
                                <div class="recently-slider-nav slider-nav-top">
                                    <div class="ninetheme-slide-prev swiper-button-prev"></div>
                                    <div class="ninetheme-slide-next swiper-button-next"></div>
                                </div>
                            </div>
                        </div>
                        <div class="col-12">
                            <div class="ninetheme-wc-swipper-wrapper woocommerce style-1">
                                <div class="ninetheme-recently-slider swiper-container" data-swiper-options="<?php echo esc_attr( $slider_options ); ?>">
                                    <div class="swiper-wrapper">
                                        <?php
                                            if ( $loop->have_posts() ) {
                                                while ( $loop->have_posts() ) {
                                                    $loop->the_post();
                                                    global $product;
                                                    if ( !empty( $product ) && $product->is_visible() ) {
                                                        echo '<div class="swiper-slide">';
                                                            wc_get_template_part( 'content', 'product' );
                                                        echo '</div>';
                                                    }
                                                }
                                            }
                                            wp_reset_postdata();
                                        ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}

/*************************************************
## Product Pairs
*************************************************/
if ( ! function_exists( 'ninetheme_product_pairs_selection' ) ) {
    add_action( 'woocommerce_product_options_related', 'ninetheme_product_pairs_selection' );
    function ninetheme_product_pairs_selection()
    {
        global $post;
        $postId       = $post->ID;
        $product_idss = get_post_meta( $postId, 'pairs_ids' );
        $productIds   = is_array($product_idss) && !empty( $product_idss ) ? $product_idss[0] : array();
        if ( !empty( $productIds ) ) {
            ?>
            <div class="options_group">
                <p class="form-field">
                    <label for="pairs_ids"><?php esc_html_e( 'Pairs', 'crisop' ); ?></label>
                    <select class="wc-product-search"
                    multiple="multiple"
                    style="width: 50%;"
                    id="pairs_ids"
                    name="pairs_ids[]"
                    data-placeholder="<?php esc_attr_e( 'Search for a product&hellip;', 'crisop' ); ?>"
                    data-action="woocommerce_json_search_products_and_variations"
                    data-exclude="<?php echo intval( $postId ); ?>">
                    <?php
                    foreach ( $productIds as $product_id => $id ) {
                        $product = wc_get_product( $id );
                        if ( is_object( $product ) ) {
                            echo '<option value="' . esc_attr( $id ) . '"' . selected( true, true, false ) . '>' . esc_html( wp_strip_all_tags( $product->get_formatted_name() ) ) . '</option>';
                        }
                    }
                    ?>
                </select> <?php echo wc_help_tip( __( 'Pairs are products which you recommend instead of the currently viewed product, for example, products that are more profitable or better quality or more expensive.', 'crisop' ) ); // WPCS: XSS ok. ?>
                </p>
                <?php
                woocommerce_wp_select(
                    array(
                        'id' => 'pairs_layout_type',
                        'label' => esc_html__( 'Pair Product Images Layout?', 'crisop' ),
                        'options' => array(
                            '' => 'Select a type',
                            'grid' => esc_html__( 'Grid', 'crisop' ),
                            'slider' => esc_html__( 'Carousel Slider', 'crisop' ),
                        ),
                        'desc_tip' => false
                    )
                );
                ?>
            </div>
            <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_pairs_save_product_custom_field' ) ) {
    add_action( 'woocommerce_process_product_meta', 'ninetheme_pairs_save_product_custom_field' );
    function ninetheme_pairs_save_product_custom_field( $_post_id )
    {
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
            return;
        }

        if ( isset( $_POST['pairs_ids'] ) ) {
            $option = array_map( 'intval', (array) wp_unslash( $_POST['pairs_ids'] ) );
            update_post_meta( $_post_id, 'pairs_ids', $option );
        } else {
            delete_post_meta( $_post_id, 'pairs_ids' );
        }

        if ( isset( $_POST['pairs_layout_type'] ) ) {
            update_post_meta( $_post_id, 'pairs_layout_type', $_POST['pairs_layout_type'] );
        } else {
            delete_post_meta( $_post_id, 'pairs_layout_type' );
        }
    }
}

if ( ! function_exists( 'ninetheme_product_summary_pairs' ) ) {
    add_action( 'woocommerce_single_product_summary', 'ninetheme_product_summary_pairs', 34 );
    function ninetheme_product_summary_pairs()
    {
        global $product;

        if ( !is_product() || $product->is_type( 'grouped' ) ) {
            return;
        }

        $pairs_ids   = get_post_meta( $product->get_id(), 'pairs_ids' );
        $pair_layout = get_post_meta( $product->get_id(), 'pairs_layout_type', true );
        $pairs       = is_array($pairs_ids) && !empty( $pairs_ids ) ? $pairs_ids[0] : array();
        $tag         = ninetheme_settings('product_pairs_heading_tag');
        $tag         = $tag ? $tag : 'h6';
        $heading     = ninetheme_settings('product_pairs_heading');
        $heading     = $heading ? $heading : esc_html__( 'People Who Bought This Product Also Bought These', 'crisop' );
        if ( !empty( $pairs ) ) {
            ?>
            <div id="products-pairs-<?php the_ID(); ?>" class="ninetheme-products-pairs">

                <<?php echo esc_attr( $tag ); ?> class="pairs-main-title"><?php echo esc_html( $heading ); ?></<?php echo esc_attr( $tag ); ?>>

                <?php
                foreach ( $pairs as $pair => $id ) {
                    $pair_product = wc_get_product( $id );
                    if ( !empty( $pair_product ) ) {
                        $pairId  = $pair_product->get_id();
                        $gallery = $pair_product->get_gallery_image_ids();
                        ?>
                        <div class="ninetheme-widget-product-list-type">
                            <div class="ninetheme-product-list-type-inner woocommerce hint-top">
                                <div class="ninetheme-product-list-type-image-wrapper">
                                    <?php if ( !empty( $gallery ) && $pair_layout == 'slider' ) { ?>
                                        <div class="swiper-container pair-images-slider">
                                            <div class="swiper-wrapper">
                                                <div class="pair-slider-item swiper-slide">
                                                    <div class="pairs-image"><a href="<?php echo esc_url( get_permalink( $pairId ) ); ?>"><?php echo get_the_post_thumbnail( $pairId, 'medium' ); ?></a></div>
                                                </div>
                                                <?php foreach ( $gallery as $img ) { ?>
                                                    <div class="pair-slider-item swiper-slide">
                                                        <div class="pairs-image"><a href="<?php echo esc_url( get_permalink( $pairId ) ); ?>"><?php echo wp_get_attachment_image( $img, 'medium' ); ?></a></div>
                                                    </div>
                                                <?php } ?>
                                            </div>
                                        </div>
                                    <?php } else { ?>
                                        <div class="pairs-image">
                                            <a href="<?php echo esc_url( get_permalink($pairId) ); ?>"><?php echo get_the_post_thumbnail( $pairId, 'medium' ); ?></a>
                                        </div>
                                    <?php } ?>
                                </div>
                                <div class="ninetheme-product-list-type-details-wrapper">
                                    <div class="ninetheme-product-list-type-product-top">
                                        <?php
                                            ninetheme_loop_product_stock_status_by_id( $pairId );
                                            $rating = $pair_product->get_average_rating();
                                            $count  = $pair_product->get_rating_count();
                                            if ( $pair_product->get_average_rating() ) {
                                                wc_get_rating_html( $rating, $count );
                                            }
                                        ?>
                                    </div>
                                    <span class="ninetheme-product-list-type-product-title"><?php echo get_the_title( $pairId ); ?></span>
                                    <?php echo '<span class="ninetheme-price price">'.$pair_product->get_price_html().'</span>'; ?>
                                </div>
                                <div class="ninetheme-product-list-type-product-actions hint-top">
                                <?php
                                    echo ninetheme_add_to_cart_by_id($pairId,'icon');
                                    echo ninetheme_quickview_button_by_id($pairId);
                                    ninetheme_compare_button_by_id($pairId);
                                    ninetheme_wishlist_button_by_id($pairId);
                                ?>
                                </div>
                            </div>
                        </div>
                    <?php } ?>
                <?php } ?>
            </div>
            <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_product_reviews_slider' ) ) {
    add_action( 'woocommerce_after_single_product_summary', 'ninetheme_product_reviews_slider', 12 );
    function ninetheme_product_reviews_slider()
    {
        $template_id = ninetheme_settings('product_custom_reviews_template', null);

        if ( is_product() && ! empty( $template_id ) ) {
            wp_enqueue_style( 'ninetheme-wc-custom-reviews-slider' );
            wp_enqueue_script( 'slick' );

            echo do_shortcode( '[ninetheme-template id="'.$template_id.'"]' );
        }
    }
}

if ( !function_exists( 'ninetheme_remove_some_fields_checkout' ) ) {
    add_filter( 'woocommerce_checkout_fields' , 'ninetheme_remove_some_fields_checkout' );
    function ninetheme_remove_some_fields_checkout($fields)
    {
        if ( 'no' == ninetheme_settings( 'checkout_form_customize', 'no' ) ) {
            return $fields;
        }

        $layouts  = ninetheme_settings( 'checkout_form_layouts' );

        // billing fields
        if ( '0' == $layouts['billing_first_name'] ) {
            unset( $fields['billing']['billing_first_name'] );
        }
        if ( '0' == $layouts['billing_last_name'] ) {
            unset( $fields['billing']['billing_last_name'] );
        }
        if ( '0' == $layouts['billing_company'] ) {
            unset( $fields['billing']['billing_company'] );
        }
        if ( '0' == $layouts['billing_address_1'] ) {
            unset( $fields['billing']['billing_address_1'] );
        }
        if ( '0' == $layouts['billing_address_2'] ) {
            unset( $fields['billing']['billing_address_2'] );
        }
        if ( '0' == $layouts['billing_city'] ) {
            unset( $fields['billing']['billing_city'] );
        }
        if ( '0' == $layouts['billing_postcode'] ) {
            unset( $fields['billing']['billing_postcode'] );
        }
        if ( '0' == $layouts['billing_country'] ) {
            unset( $fields['billing']['billing_country'] );
        }
        if ( '0' == $layouts['billing_state'] ) {
            unset( $fields['billing']['billing_state'] );
        }
        if ( '0' == $layouts['billing_phone'] ) {
            unset( $fields['billing']['billing_phone'] );
        }
        if ( '0' == $layouts['billing_email'] ) {
            unset( $fields['billing']['billing_email'] );
        }
        // order field
        if ( '0' == $layouts['order_comments'] ) {
            unset( $fields['order']['order_comments'] );
        }
        // account fields
        if ( '0' == $layouts['account_username'] ) {
            unset( $fields['account']['account_username'] );
        }
        if ( '0' == $layouts['account_password'] ) {
            unset( $fields['account']['account_password'] );
        }
        if ( '0' == $layouts['account_password-2'] ) {
            unset( $fields['account']['account_password-2'] );
        }
        // shipping fields
        if ( '0' == $layouts['shipping_first_name'] ) {
            unset( $fields['shipping']['shipping_first_name'] );
        }
        if ( '0' == $layouts['shipping_last_name'] ) {
            unset( $fields['shipping']['shipping_last_name'] );
        }
        if ( '0' == $layouts['shipping_company'] ) {
            unset( $fields['shipping']['shipping_company'] );
        }
        if ( '0' == $layouts['shipping_address_1'] ) {
            unset( $fields['shipping']['shipping_address_1'] );
        }
        if ( '0' == $layouts['shipping_address_2'] ) {
            unset( $fields['shipping']['shipping_address_2'] );
        }
        if ( '0' == $layouts['shipping_city'] ) {
            unset( $fields['shipping']['shipping_city'] );
        }
        if ( '0' == $layouts['shipping_postcode'] ) {
            unset( $fields['shipping']['shipping_postcode'] );
        }
        if ( '0' == $layouts['shipping_country'] ) {
            unset( $fields['shipping']['shipping_country'] );
        }
        if ( '0' == $layouts['shipping_state'] ) {
            unset( $fields['shipping']['shipping_state'] );
        }

        return $fields;
    }
}

if ( !function_exists( 'ninetheme_remove_requirement_from_fields_checkout' ) ) {
    add_filter( 'woocommerce_billing_fields', 'ninetheme_remove_requirement_from_fields_checkout', 10, 1 );
    function ninetheme_remove_requirement_from_fields_checkout($fields)
    {
        if ( 'no' == ninetheme_settings( 'checkout_form_customize', 'no' ) ) {
            return $fields;
        }

        $required = ninetheme_settings( 'checkout_form_required_fields_layouts' );

        // billing fields
        if ( '0' == $required['billing_first_name'] && isset( $fields['billing_first_name'] ) ) {
            $fields['billing_first_name']['required'] = false;
        }
        if ( '0' == $required['billing_last_name'] && isset( $fields['billing_last_name'] ) ) {
            $fields['billing_last_name']['required'] = false;
        }
        if ( '1' == $required['billing_company'] && isset( $fields['billing_company'] ) ) {
            $fields['billing_company']['required'] = true;
        }
        if ( '0' == $required['billing_address_1'] && isset( $fields['billing_address_1'] ) ) {
            $fields['billing_address_1']['required'] = false;
        }
        if ( '1' == $required['billing_address_2'] && isset( $fields['billing_address_2'] ) ) {
            $fields['billing_address_2']['required'] = true;
        }
        if ( '0' == $required['billing_city'] && isset( $fields['billing_city'] ) ) {
            $fields['billing_city']['required'] = false;
        }
        if ( '0' == $required['billing_postcode'] && isset( $fields['billing_postcode'] ) ) {
            $fields['billing_postcode']['required'] = false;
        }
        if ( '0' == $required['billing_country'] && isset( $fields['billing_country'] ) ) {
            $fields['billing_country']['required'] = false;
        }
        if ( '0' == $required['billing_state'] && isset( $fields['billing_state'] ) ) {
            $fields['billing_state']['required'] = false;
        }
        if ( '0' == $required['billing_phone'] && isset( $fields['billing_phone'] ) ) {
            $fields['billing_phone']['required'] = false;
        }
        if ( '0' == $required['billing_email'] && isset( $fields['billing_email'] ) ) {
            $fields['billing_email']['required'] = false;
        }

        return $fields;
    }
}

if ( !function_exists( 'ninetheme_remove_requirement_shipping_from_fields_checkout' ) ) {
    add_filter( 'woocommerce_shipping_fields', 'ninetheme_remove_requirement_shipping_from_fields_checkout', 10, 1 );
    function ninetheme_remove_requirement_shipping_from_fields_checkout($fields)
    {
        if ( 'no' == ninetheme_settings( 'checkout_form_customize', 'no' ) ) {
            return $fields;
        }

        $required = ninetheme_settings( 'checkout_form_required_fields_layouts' );

        // shipping fields
        if ( '0' == $required['shipping_first_name'] && isset( $fields['shipping_first_name'] ) ) {
            $fields['shipping_first_name']['required'] = false;
        }
        if ( '0' == $required['shipping_last_name'] && isset( $fields['shipping_last_name'] ) ) {
            $fields['shipping_last_name']['required'] = false;
        }
        if ( '1' == $required['shipping_company'] && isset( $fields['shipping_company'] ) ) {
            $fields['shipping_company']['required'] = true;
        }
        if ( '0' == $required['shipping_address_1'] && isset( $fields['shipping_address_1'] ) ) {
            $fields['shipping_address_1']['required'] = false;
        }
        if ( '1' == $required['shipping_address_2'] && isset( $fields['shipping_address_2'] ) ) {
            $fields['shipping_company']['required'] = true;
        }
        if ( '0' == $required['shipping_city'] && isset( $fields['shipping_city'] ) ) {
            $fields['shipping_city']['required'] = false;
        }
        if ( '0' == $required['shipping_postcode'] && isset( $fields['shipping_postcode'] ) ) {
            $fields['shipping_postcode']['required'] = false;
        }
        if ( '0' == $required['shipping_country'] && isset( $fields['shipping_country'] ) ) {
            $fields['shipping_country']['required'] = false;
        }
        if ( '0' == $required['shipping_state'] && isset( $fields['shipping_state'] ) ) {
            $fields['shipping_state']['required'] = false;
        }

        return $fields;
    }
}

/**
* Shop page custom query
*/
if ( ! function_exists( 'ninetheme_shop_custom_query' ) ) {

    add_action( 'woocommerce_product_query', 'ninetheme_shop_custom_query' );
    function ninetheme_shop_custom_query( $q )
    {
        if ( '1' == ninetheme_settings( 'shop_fast_filter_visibility', '0' ) ) {
            if ( isset( $_GET['featured'] ) && $_GET['featured'] == 'yes' ) {
                $q->set( 'tax_query', array (
                    array(
                        'taxonomy' => 'product_visibility',
                        'field'    => 'name',
                        'terms'    => array( 'featured' ),
                        'operator' => 'IN'
                    )
                ));
            }

            if ( isset( $_GET['best_seller'] ) && $_GET['best_seller'] == 'yes' ) {
                $q->set ( 'meta_key', 'total_sales' );
                $q->set ( 'orderby', 'meta_value_num' );
            }
        }

        if ( is_shop() && '1' == ninetheme_settings( 'shop_custom_query_visibility', '0' ) ) {

            $tax_query     = $q->get( 'tax_query' );
            $meta_query    = $q->get( 'meta_query' );
            $scenario      = ninetheme_settings( 'shop_custom_query_scenario' );
            $cats          = ninetheme_settings( 'shop_custom_query_cats', null );
            $tags          = ninetheme_settings( 'shop_custom_query_tags', null );
            $attrs         = ninetheme_settings( 'shop_custom_query_attr', null );
            $order         = ninetheme_settings( 'shop_custom_query_order' );
            $orderby       = ninetheme_settings( 'shop_custom_query_orderby' );
            $cats_operator = 'include' == ninetheme_settings( 'shop_custom_query_cats_operator' ) ? 'IN' : 'NOT IN';
            $tags_operator = 'include' == ninetheme_settings( 'shop_custom_query_tags_operator' ) ? 'IN' : 'NOT IN';
            $mobperpage    = ninetheme_settings( 'shop_custom_query_mobile_perpage' );
            $perpage       = wp_is_mobile() && $mobperpage ? $mobperpage : ninetheme_settings( 'shop_custom_query_perpage' );
            $per_page      = isset( $_GET['per_page'] ) && $_GET['per_page'] ? esc_html( $_GET['per_page'] ) : $perpage;

            $q->set( 'order', $order );
            $q->set( 'posts_per_page', $per_page );

            $args['tax_query'] = array(
                'relation' => 'AND'
            );

            if ( 'featured' == $scenario ) {

                $tax_query[] = array(
                    'taxonomy' => 'product_visibility',
                    'field'    => 'name',
                    'terms'    => 'featured',
                    'operator' => 'IN'
                );

            } elseif ( 'on-sale' == $scenario ) {

                $meta_query[] = array(
                    'relation' => 'OR',
                    array( // Simple products type
                        'key'     => '_sale_price',
                        'value'   => 0,
                        'compare' => '>',
                        'type'    => 'numeric'
                    ),
                    array( // Variable products type
                        'key'     => '_min_variation_sale_price',
                        'value'   => 0,
                        'compare' => '>',
                        'type'    => 'numeric'
                    )
                );

            } elseif ( 'best' == $scenario ) {

                $q->set( 'orderby', 'meta_value_num' );
                $q->set( 'meta_key', 'total_sales' );

            } elseif ( 'rated' == $scenario ) {

                $q->set( 'meta_key', '_wc_average_rating' );
                $q->set( 'order', 'DESC' );
                $q->set( 'orderby', 'meta_value_num' );

            } elseif ( 'popularity' == $scenario ) {

                $q->set( 'meta_key', 'total_sales' );
                $q->set( 'order', 'DESC' );
                $q->set( 'orderby', 'meta_value_num' );

            } else {

                $q->set( 'orderby', $orderby );

            }

            if ( !empty( $cats ) ) {
                $tax_query[] = array(
                    'taxonomy' => 'product_cat',
                    'field'    => 'term_id',
                    'terms'    => $cats,
                    'operator' => $cats_operator
                );
            }

            if ( !empty( $tags ) ) {
                $tax_query[] = array(
                    'taxonomy' => 'product_tag',
                    'field'    => 'term_id',
                    'terms'    => $tags,
                    'operator' => $tags_operator
                );
            }

            if ( !empty( $attrs ) ) {
                foreach ( $attrs as $key ) {

                    $attr_terms      = ninetheme_settings( 'shop_custom_query_attr_terms_'.$key );
                    $terms_operator  = 'include' == ninetheme_settings( 'shop_custom_query_attr_terms_operator_'.$key ) ? 'IN' : 'NOT IN';
                    $attr_id         = wc_attribute_taxonomy_id_by_name( $key );
                    $attr_info       = wc_get_attribute( $attr_id );

                    if ( !empty( $attr_terms ) ) {
                        $tax_query[] = array(
                            'taxonomy' => $attr_info->slug,
                            'field'    => 'term_id',
                            'terms'    => $attr_terms,
                            'operator' => $terms_operator
                        );
                    }
                }
            }

            $q->set( 'meta_query', $meta_query );
            $q->set( 'tax_query', $tax_query );
        }
    }
}


Crisop_Min_Max_Quantities_For_WooCommerce_Admin::get_instance();
class Crisop_Min_Max_Quantities_For_WooCommerce_Admin {
    private static $instance = null;
    public static function get_instance() {
        if ( is_null( self::$instance ) ) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    function __construct() {

        // Variations
        if (defined('WC_VERSION') && version_compare(WC_VERSION, '2.3.0', '>=')) {
            add_action('woocommerce_save_product_variation', array($this, 'save_variation_settings'), 10, 2);
        }

        add_action('woocommerce_variation_options', array(&$this, 'variation_options'), 10, 3);
        add_action('woocommerce_product_after_variable_attributes', array(&$this, 'variation_panel'), 10, 3);

        // Meta
        add_action('woocommerce_product_options_general_product_data', array(&$this, 'write_panel'));

        add_action('woocommerce_process_product_meta', array(&$this, 'write_panel_save'));

        // Category level
        add_action('created_term', array($this, 'category_fields_save'), 10, 3);
        add_action('edit_term', array($this, 'category_fields_save'), 10, 3);
        add_action('product_cat_edit_form_fields', array($this, 'edit_category_fields'), 10, 2);
        add_action('product_cat_add_form_fields', array($this, 'add_category_fields'));
        add_filter('manage_edit-product_cat_columns', array($this, 'product_cat_columns'));
        add_filter('manage_product_cat_custom_column', array($this, 'product_cat_column'), 10, 3);
    }

    /**
     * write_panel function.
     *
     * @access public
     * @return void
     */
    function write_panel() {
        global $woocommerce;

        echo '<div class="options_group">';

    	woocommerce_wp_text_input( array( 'id' => 'minimum_allowed_quantity', 'label' => __( 'Minimum quantity', 'crisop' ), 'description' => __( 'Enter a quantity to prevent the user buying this product if they have fewer than the allowed quantity in their cart', 'crisop' ), 'desc_tip' => true ) );

    	woocommerce_wp_text_input( array( 'id' => 'maximum_allowed_quantity', 'label' => __( 'Maximum quantity', 'crisop' ), 'description' => __( 'Enter a quantity to prevent the user buying this product if they have more than the allowed quantity in their cart', 'crisop' ), 'desc_tip' => true ) );

    	woocommerce_wp_text_input( array( 'id' => 'group_of_quantity', 'label' => __( 'Group of...', 'crisop' ), 'description' => __( 'Enter a quantity to only allow this product to be purchased in groups of X', 'crisop' ), 'desc_tip' => true ) );

    	woocommerce_wp_checkbox( array( 'id' => 'minmax_do_not_count', 'label' => __( 'Order rules: Do not count', 'crisop' ), 'description' => __( 'Don\'t count this product against your minimum order quantity/value rules.', 'crisop' ) ) );

    	woocommerce_wp_checkbox( array( 'id' => 'minmax_cart_exclude', 'label' => __( 'Order rules: Exclude', 'crisop' ), 'description' => __( 'Exclude this product from minimum order quantity/value rules. If this is the only item in the cart, rules will not apply.', 'crisop' ) ) );

    	woocommerce_wp_checkbox( array( 'id' => 'minmax_category_group_of_exclude', 'label' => __( 'Category rules: Exclude', 'crisop' ), 'description' => __( 'Exclude this product from category group-of-quantity rules. This product will not be counted towards category groups.', 'crisop' ) ) );

        echo '</div>';
    }

    /**
     * write_panel_save variations.
     *
     * @access public
     * @param mixed $post_id
     * @return void
     */
    public function save_variation_settings($variation_id, $i) {
        $min_max_rules = isset($_POST['min_max_rules']) ? array_map('sanitize_text_field', $_POST['min_max_rules']) : null;

        $minimum_allowed_quantity = isset($_POST['variation_minimum_allowed_quantity']) ? array_map('sanitize_text_field', $_POST['variation_minimum_allowed_quantity']) : '';

        $maximum_allowed_quantity = isset($_POST['variation_maximum_allowed_quantity']) ? array_map('sanitize_text_field', $_POST['variation_maximum_allowed_quantity']) : '';

        $group_of_quantity = isset($_POST['variation_group_of_quantity']) ? array_map('sanitize_text_field', $_POST['variation_group_of_quantity']) : '';

        $minmax_do_not_count = isset($_POST['variation_minmax_do_not_count']) ? array_map('sanitize_text_field', $_POST['variation_minmax_do_not_count']) : null;

        $minmax_cart_exclude = isset($_POST['variation_minmax_cart_exclude']) ? array_map('sanitize_text_field', $_POST['variation_minmax_cart_exclude']) : null;

        $minmax_category_group_of_exclude = isset($_POST['variation_minmax_category_group_of_exclude']) ? array_map('sanitize_text_field', $_POST['variation_minmax_category_group_of_exclude']) : null;

        if (isset($min_max_rules[$i])) {
            update_post_meta($variation_id, 'min_max_rules', 'yes');
        } else {
            update_post_meta($variation_id, 'min_max_rules', 'no');
        }

        update_post_meta($variation_id, 'variation_minimum_allowed_quantity', $minimum_allowed_quantity[$i]);
        update_post_meta($variation_id, 'variation_maximum_allowed_quantity', $maximum_allowed_quantity[$i]);
        update_post_meta($variation_id, 'variation_group_of_quantity', $group_of_quantity[$i]);

        if (isset($minmax_do_not_count[$i])) {
            update_post_meta($variation_id, 'variation_minmax_do_not_count', 'yes');
        } else {
            update_post_meta($variation_id, 'variation_minmax_do_not_count', 'no');
        }

        if (isset($minmax_cart_exclude[$i])) {
            update_post_meta($variation_id, 'variation_minmax_cart_exclude', 'yes');
        } else {
            update_post_meta($variation_id, 'variation_minmax_cart_exclude', 'no');
        }

        if (isset($minmax_category_group_of_exclude[$i])) {
            update_post_meta($variation_id, 'variation_minmax_category_group_of_exclude', 'yes');
        } else {
            update_post_meta($variation_id, 'variation_minmax_category_group_of_exclude', 'no');
        }
    }

    /**
     * write_panel_save function.
     *
     * @access public
     * @param mixed $post_id
     * @return void
     */
    function write_panel_save($post_id) {

        // simple product save 2.1+ - 2.3
        if (isset($_POST['minimum_allowed_quantity'])) {
            update_post_meta($post_id, 'minimum_allowed_quantity', esc_attr($_POST['minimum_allowed_quantity']));
        }

        if (isset($_POST['maximum_allowed_quantity'])) {
            update_post_meta($post_id, 'maximum_allowed_quantity', esc_attr($_POST['maximum_allowed_quantity']));
        }

        if (isset($_POST['group_of_quantity'])) {
            update_post_meta($post_id, 'group_of_quantity', esc_attr($_POST['group_of_quantity']));
        }

        update_post_meta($post_id, 'minmax_do_not_count', empty($_POST['minmax_do_not_count']) ? 'no' : 'yes' );

        update_post_meta($post_id, 'minmax_cart_exclude', empty($_POST['minmax_cart_exclude']) ? 'no' : 'yes' );

        update_post_meta($post_id, 'minmax_category_group_of_exclude', empty($_POST['minmax_category_group_of_exclude']) ? 'no' : 'yes' );

        // variable product save 2.1 - 2.2
        if (isset($_POST['variable_post_id']) && defined('WC_VERSION') && version_compare(WC_VERSION, '2.3.0', '<')) {

            $variable_post_id = $_POST['variable_post_id'];

            $min_max_rules = isset($_POST['min_max_rules']) ? array_map('sanitize_text_field', $_POST['min_max_rules']) : null;

            $minimum_allowed_quantity = isset($_POST['variation_minimum_allowed_quantity']) ? array_map('sanitize_text_field', $_POST['variation_minimum_allowed_quantity']) : '';

            $maximum_allowed_quantity = isset($_POST['variation_maximum_allowed_quantity']) ? array_map('sanitize_text_field', $_POST['variation_maximum_allowed_quantity']) : '';

            $group_of_quantity = isset($_POST['variation_group_of_quantity']) ? array_map('sanitize_text_field', $_POST['variation_group_of_quantity']) : '';

            $minmax_do_not_count = isset($_POST['variation_minmax_do_not_count']) ? array_map('sanitize_text_field', $_POST['variation_minmax_do_not_count']) : null;

            $minmax_cart_exclude = isset($_POST['variation_minmax_cart_exclude']) ? array_map('sanitize_text_field', $_POST['variation_minmax_cart_exclude']) : null;

            $minmax_category_group_of_exclude = isset($_POST['variation_minmax_category_group_of_exclude']) ? array_map('sanitize_text_field', $_POST['variation_minmax_category_group_of_exclude']) : null;

            $max_loop = max(array_keys($_POST['variable_post_id']));

            for ($i = 0; $i <= $max_loop; $i++) {

                if (!isset($variable_post_id[$i]))
                    continue;

                $variation_id = absint($variable_post_id[$i]);

                if (isset($min_max_rules[$i])) {
                    update_post_meta($variation_id, 'min_max_rules', 'yes');
                    update_post_meta($variation_id, 'minimum_allowed_quantity', $minimum_allowed_quantity[$i]);
                    update_post_meta($variation_id, 'maximum_allowed_quantity', $maximum_allowed_quantity[$i]);
                    update_post_meta($variation_id, 'group_of_quantity', $group_of_quantity[$i]);

                    if (isset($minmax_do_not_count[$i])) {
                        update_post_meta($variation_id, 'minmax_do_not_count', 'yes');
                    } else {
                        update_post_meta($variation_id, 'minmax_do_not_count', 'no');
                    }

                    if (isset($minmax_cart_exclude[$i])) {
                        update_post_meta($variation_id, 'minmax_cart_exclude', 'yes');
                    } else {
                        update_post_meta($variation_id, 'minmax_cart_exclude', 'no');
                    }

                    if (isset($minmax_category_group_of_exclude[$i])) {
                        update_post_meta($variation_id, 'minmax_category_group_of_exclude', 'yes');
                    } else {
                        update_post_meta($variation_id, 'minmax_category_group_of_exclude', 'no');
                    }
                } else {
                    update_post_meta($variation_id, 'min_max_rules', 'no');
                }
            }
        }
    }

    /**
     * variation_options function.
     *
     * @access public
     * @return void
     */
    function variation_options($loop, $variation_data, $variation) {

        $min_max_rules = get_post_meta($variation->ID, 'min_max_rules', true);
        ?>
        <label>
            <input type="checkbox" class="checkbox min_max_rules" name="min_max_rules[<?php echo $loop; ?>]" <?php if ( $min_max_rules ) checked( $min_max_rules, 'yes' ); ?> />
            <?php _e( 'Min/Max Rules', 'crisop' ); ?>
            <a class="tips" data-tip="<?php _e( 'Enable this option to override min/max settings at variation level', 'crisop' ); ?>" href="#">[?]</a>
        </label>
        <?php
    }

    /**
     * variation_panel function.
     *
     * @access public
     * @param mixed $loop
     * @param mixed $variation_data
     * @return void
     */
    function variation_panel($loop, $variation_data, $variation) {

        $rules        = get_post_meta($variation->ID, 'min_max_rules', true);
        $visible      = isset($rules) && 'no' === $rules ? 'style="display:none"' : '';
        $min_qty      = get_post_meta($variation->ID, 'variation_minimum_allowed_quantity', true);
        $max_qty      = get_post_meta($variation->ID, 'variation_maximum_allowed_quantity', true);
        $group_of     = get_post_meta($variation->ID, 'variation_group_of_quantity', true);
        $not_count    = get_post_meta($variation->ID, 'variation_minmax_do_not_count', true);
        $cart_exclude = get_post_meta($variation->ID, 'variation_minmax_cart_exclude', true);
        $cat_exclude  = get_post_meta($variation->ID, 'variation_minmax_category_group_of_exclude', true);

        ?>
        <div class="min_max_rules_options" <?php echo $visible; ?>>
            <p class="form-row form-row-first">
                <label>
                    <?php _e( 'Minimum quantity', 'crisop' ); ?>
                    <input type="number" size="5" name="variation_minimum_allowed_quantity[<?php echo $loop; ?>]" value="<?php if ($min_qty) echo esc_attr($min_qty); ?>" />
                </label>
            </p>

            <p class="form-row form-row-last">
                <label>
                    <?php _e( 'Maximum quantity', 'crisop' ); ?>
                    <input type="number" size="5" name="variation_maximum_allowed_quantity[<?php echo $loop; ?>]" value="<?php if ($max_qty) echo esc_attr($max_qty); ?>" />
                </label>
            </p>

            <p class="form-row form-row-first">
                <label>
                    <?php _e( 'Group of...', 'crisop' ); ?>
                    <input type="number" size="5" name="variation_group_of_quantity[<?php echo $loop; ?>]" value="<?php if ($group_of) echo esc_attr($group_of); ?>" />
                </label>
            </p>

            <p class="form-row form-row-last">
                <label>
                    <input type="checkbox" class="checkbox" name="variation_minmax_do_not_count[<?php echo $loop; ?>]" <?php if ( $not_count ) checked( $not_count, 'yes' ) ?> />
                    <?php _e( 'Order rules: Do not count', 'crisop' ); ?>
                    <a class="tips" data-tip="<?php _e( 'Don\'t count this product against your minimum order quantity/value rules.', 'crisop' ); ?>" href="#">[?]</a>
                </label>

                <label>
                    <input type="checkbox" class="checkbox" name="variation_minmax_cart_exclude[<?php echo $loop; ?>]" <?php if ( $cart_exclude ) checked( $cart_exclude, 'yes' ) ?> />
                    <?php _e( 'Order rules: Exclude', 'crisop' ); ?>
                    <a class="tips" data-tip="<?php _e( 'Exclude this product from minimum order quantity/value rules. If this is the only item in the cart, rules will not apply.', 'crisop' ); ?>" href="#">[?]</a>
                </label>

                <label>
                    <input type="checkbox" class="checkbox" name="variation_minmax_category_group_of_exclude[<?php echo $loop; ?>]" <?php if ( $cat_exclude ) checked( $cat_exclude, 'yes' ) ?> />
                    <?php _e( 'Category group-of rules: Exclude', 'crisop' ); ?>
                    <a class="tips" data-tip="<?php _e( 'Exclude this product from category group-of-quantity rules. This product will not be counted towards category groups.', 'crisop' ); ?>" href="#">[?]</a>
                </label>
            </p>
        </div>
        <?php
    }

    /**
     * Category thumbnail fields.
     *
     * @access public
     * @return void
     */
    function add_category_fields() {
        global $woocommerce;
        ?>
        <div class="form-field">
            <label><?php _e( 'Group of...', 'crisop' ); ?></label>
            <input type="number" size="5" name="group_of_quantity" />
            <p class="description"><?php _e( 'Enter a quantity to only allow products in this category to be purchased in groups of X', 'crisop' ); ?></p>
        </div>
        <?php
    }

    /**
     * Edit category thumbnail field.
     *
     * @access public
     * @param mixed $term Term (category) being edited
     * @param mixed $taxonomy Taxonomy of the term being edited
     * @return void
     */
    function edit_category_fields($term, $taxonomy) {
        global $woocommerce;

        $display_type = get_term_meta($term->term_id, 'group_of_quantity', true);
        ?>
        <tr class="form-field">
            <th scope="row" valign="top"><label><?php _e( 'Group of...', 'crisop' ); ?></label></th>
            <td>
                <input type="number" size="5" name="group_of_quantity" value="<?php echo $display_type; ?>" />
                <p class="description"><?php _e( 'Enter a quantity to only allow products in this category to be purchased in groups of X', 'crisop' ); ?></p>
            </td>
        </tr>
        <?php
    }

    /**
     * woocommerce_category_fields_save function.
     *
     * @access public
     * @param mixed $term_id Term ID being saved
     * @param mixed $tt_id
     * @param mixed $taxonomy Taxonomy of the term being saved
     * @return void
     */
    function category_fields_save($term_id, $tt_id, $taxonomy) {
        if (isset($_POST['group_of_quantity'])) {
            update_woocommerce_term_meta($term_id, 'group_of_quantity', esc_attr($_POST['group_of_quantity']));
        }
    }

    /**
     * product_cat_columns function.
     *
     * @access public
     * @param mixed $columns
     * @return void
     */
    function product_cat_columns($columns) {
        $columns['groupof'] = __( 'Purchasable in...', 'crisop' );

        return $columns;
    }

    /**
     * product_cat_column function.
     *
     * @access public
     * @param mixed $columns
     * @param mixed $column
     * @param mixed $id
     * @return void
     */
    function product_cat_column($columns, $column, $id) {
        global $woocommerce;

        if ($column == 'groupof') {
            if ($groupof = get_term_meta($id, 'group_of_quantity', true)) {
                $columns .= __( 'Groups of', 'crisop' ) . ' ' . absint( $groupof );
            } else {
                $columns .= '&ndash;';
            }
        }

        return $columns;
    }
}

Crisop_Min_Max_Quantities_For_WooCommerce::get_instance();
class Crisop_Min_Max_Quantities_For_WooCommerce {

    var $minimum_order_quantity;
    var $maximum_order_quantity;
    var $minimum_order_value;
    var $maximum_order_value;
    var $excludes = array();
    private static $instance = null;

    public static function get_instance()
    {
        if ( is_null( self::$instance ) ) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    public function __construct()
    {
        $this->minimum_order_quantity = absint(ninetheme_settings('minimum_quantity'));
        $this->maximum_order_quantity = absint(ninetheme_settings('maximum_quantity'));
        $this->minimum_order_value    = absint(ninetheme_settings('minimum_order'));
        $this->maximum_order_value    = absint(ninetheme_settings('maximum_order'));

        // Check items
        add_action('woocommerce_check_cart_items', array($this, 'check_cart_items'));

        // quantity selelectors (2.0+)
        add_filter('woocommerce_quantity_input_args', array($this, 'update_quantity_args'), 10, 2);
        add_filter('woocommerce_available_variation', array($this, 'available_variation'), 10, 3);

        // Prevent add to cart
        add_filter('woocommerce_add_to_cart_validation', array($this, 'add_to_cart'), 10, 4);

        // Min add to cart ajax
        add_filter('ninetheme_minmax_quantity', array($this, 'add_to_cart_quantity'), 10, 2);

        add_action('wp_enqueue_scripts', array($this, 'load_scripts'));
    }

    public function load_scripts()
    {
        // only load on single product page and cart page
        if ( is_product() || is_cart() ) {
            wc_enqueue_js("
                jQuery( 'body' ).on( 'show_variation', function( event, variation ) {
                    jQuery( 'form.variations_form' ).find( 'input[name=quantity]' ).prop( 'step', variation.step ).val( variation.input_value );
                });
            ");
        }
    }

    /**
     * Add an error
     * @todo remove deprecated add error in future wc versions
     */
    public function add_error($error)
    {
        wc_add_notice($error, 'error');
    }

    /**
     * Add quantity property to add to cart button on shop loop for simple products.
     *
     * @access public
     * @return void
     */
    public function add_to_cart_quantity()
    {
        global $product;

        $type     = $product->get_type();
        $qty_attr = 1;

        if ( 'variable' !== $type ) {
            $pid = $product->get_id();
            $minimum_quantity  = absint(get_post_meta($pid, 'minimum_allowed_quantity', true));
            $group_of_quantity = absint(get_post_meta($pid, 'group_of_quantity', true));

            if ( $minimum_quantity || $group_of_quantity ) {

                $qty_attr = $minimum_quantity;

                if ( $group_of_quantity > 0 && $minimum_quantity < $group_of_quantity ) {
                    $qty_attr = $group_of_quantity;
                }
            }
        }

        return $qty_attr;
    }

    /**
     * Validate cart items against set rules
     *
     * @todo remove deprecated woocommerce global and use WC() in future wc versions
     * @access public
     * @return void
     */
    public function check_cart_items()
    {
        $checked_ids = $product_quantities = $category_quantities = array();
        $total_quantity = $total_cost = 0;
        $apply_cart_rules = false;

        // Count items + variations first
        foreach ( WC()->cart->get_cart() as $cart_item_key => $values ) {

            if (!isset($product_quantities[$values['product_id']])) {

                $product_quantities[$values['product_id']] = 0;
            }

            if ($values['variation_id']) {

                if (!isset($product_quantities[$values['variation_id']])) {

                    $product_quantities[$values['variation_id']] = 0;
                }

                $min_max_rules = get_post_meta($values['variation_id'], 'min_max_rules', true);

                if ('yes' === $min_max_rules) {

                    $product_quantities[$values['variation_id']] += $values['quantity'];
                } else {

                    $product_quantities[$values['product_id']] += $values['quantity'];
                }
            } else {

                $product_quantities[$values['product_id']] += $values['quantity'];
            }
        }

        // Check cart items
        foreach ( WC()->cart->get_cart() as $cart_item_key => $values ) {

            if ($values['variation_id']) {

                $min_max_rules = get_post_meta($values['variation_id'], 'min_max_rules', true);

                if ('yes' === $min_max_rules) {

                    $checking_id = $values['variation_id'];
                } else {

                    $checking_id = $values['product_id'];
                }

            } else {

                $checking_id = $values['product_id'];
            }

            // Get categories and counts
            $terms = get_the_terms($values['product_id'], 'product_cat');
            $found_term_ids = array();

            if ($terms) {

                foreach ($terms as $term) {

                    if ('yes' === get_post_meta($checking_id, 'minmax_category_group_of_exclude', true)) {
                        continue;
                    }

                    if (in_array($term->term_id, $found_term_ids)) {
                        continue;
                    }

                    $found_term_ids[] = $term->term_id;
                    $category_quantities[$term->term_id] = isset($category_quantities[$term->term_id]) ? $category_quantities[$term->term_id] + $values['quantity'] : $values['quantity'];

                    // Record count in parents of this category too
                    $parents = get_ancestors($term->term_id, 'product_cat');

                    foreach ($parents as $parent) {
                        if (in_array($parent, $found_term_ids)) {
                            continue;
                        }

                        $found_term_ids[] = $parent;
                        $category_quantities[$parent] = isset($category_quantities[$parent]) ? $category_quantities[$parent] + $values['quantity'] : $values['quantity'];
                    }
                }
            }

            // Check item rules once per product ID
            if (in_array($checking_id, $checked_ids)) {
                continue;
            }

            // parent product level
            $do_not_count = get_post_meta($values['product_id'], 'minmax_do_not_count', true);
            $cart_exclude = get_post_meta($values['product_id'], 'minmax_cart_exclude', true);

            // variation level override
            $do_not_count = 'yes' === get_post_meta($checking_id, 'variation_minmax_do_not_count', true) ? 'yes' : $do_not_count;
            $cart_exclude = 'yes' === get_post_meta($checking_id, 'variation_minmax_cart_exclude', true) ? 'yes' : $cart_exclude;

            $product = $values['data'];

            // Cart rules
            $minmax_do_not_count = apply_filters('wc_min_max_quantity_minmax_do_not_count', $do_not_count, $checking_id, $cart_item_key, $values);
            $minmax_cart_exclude = apply_filters('wc_min_max_quantity_minmax_cart_exclude', $cart_exclude, $checking_id, $cart_item_key, $values);

            if ('yes' === $minmax_do_not_count || 'yes' === $minmax_cart_exclude) {
                // Do not count
                $this->excludes[] = $product->get_title();

            } else {

                $total_quantity += $product_quantities[$checking_id];
                $total_cost += $product->get_price() * $product_quantities[$checking_id];
            }

            if ('yes' !== $minmax_cart_exclude) {
                $apply_cart_rules = true;
            }

            $checked_ids[] = $checking_id;

            if ($values['variation_id']) {

                $minimum_quantity = absint(apply_filters('wc_min_max_quantity_minimum_allowed_quantity', get_post_meta($checking_id, 'variation_minimum_allowed_quantity', true), $checking_id, $cart_item_key, $values));

                $maximum_quantity = absint(apply_filters('wc_min_max_quantity_maximum_allowed_quantity', get_post_meta($checking_id, 'variation_maximum_allowed_quantity', true), $checking_id, $cart_item_key, $values));

                $group_of_quantity = absint(apply_filters('wc_min_max_quantity_group_of_quantity', get_post_meta($checking_id, 'variation_group_of_quantity', true), $checking_id, $cart_item_key, $values));

            } else {

                $minimum_quantity = absint(apply_filters('wc_min_max_quantity_minimum_allowed_quantity', get_post_meta($checking_id, 'minimum_allowed_quantity', true), $checking_id, $cart_item_key, $values));

                $maximum_quantity = absint(apply_filters('wc_min_max_quantity_maximum_allowed_quantity', get_post_meta($checking_id, 'maximum_allowed_quantity', true), $checking_id, $cart_item_key, $values));

                $group_of_quantity = absint(apply_filters('wc_min_max_quantity_group_of_quantity', get_post_meta($checking_id, 'group_of_quantity', true), $checking_id, $cart_item_key, $values));
            }

            $this->check_rules($product, $product_quantities[$checking_id], $minimum_quantity, $maximum_quantity, $group_of_quantity);
        }

        // Cart rules
        if ($apply_cart_rules) {

            $excludes = '';

            if (sizeof($this->excludes) > 0) {
                $excludes = ' (' . __('excludes ', 'crisop') . implode(', ', $this->excludes) . ')';
            }

            // Check cart quantity
            $quantity = $this->minimum_order_quantity;

            if ($quantity > 0 && $total_quantity < $quantity) {

                $this->add_error(sprintf(__('The minimum allowed order quantity is %s - please add more items to your cart', 'crisop'), $quantity) . $excludes);

                return;
            }

            $quantity = $this->maximum_order_quantity;

            if ($quantity > 0 && $total_quantity > $quantity) {

                $this->add_error(sprintf(__('The maximum allowed order quantity is %s - please remove some items from your cart.', 'crisop'), $quantity));

                return;
            }

            // Check cart value
            if ($this->minimum_order_value && $total_cost && $total_cost < $this->minimum_order_value) {

                $this->add_error(sprintf(__('The minimum allowed order value is %s - please add more items to your cart', 'crisop'), woocommerce_price($this->minimum_order_value)) . $excludes);

                return;
            }

            if ($this->maximum_order_value && $total_cost && $total_cost > $this->maximum_order_value) {

                $this->add_error(sprintf(__('The maximum allowed order value is %s - please remove some items from your cart.', 'crisop'), woocommerce_price($this->maximum_order_value)));

                return;
            }
        }

        // Check category rules
        foreach ( $category_quantities as $category => $quantity ) {
            $group_of_quantity = get_term_meta($category, 'group_of_quantity', true);

            if ($group_of_quantity > 0 && ( $quantity % $group_of_quantity ) > 0) {

                $term = get_term_by('id', $category, 'product_cat');
                $product_names = array();

                foreach ( WC()->cart->get_cart() as $cart_item_key => $values ) {

                    if ('yes' === get_post_meta($values['product_id'], 'minmax_category_group_of_exclude', true) || 'yes' === get_post_meta($values['variation_id'], 'minmax_category_group_of_exclude', true)) {
                        continue;
                    }

                    if (has_term($category, 'product_cat', $values['product_id'])) {
                        $product_names[] = $values['data']->get_title();
                    }
                }

                $this->add_error(sprintf(__('Items in the <strong>%s</strong> category (<em>%s</em>) must be bought in groups of %d. Please add another %d to continue.', 'crisop'), $term->name, implode(', ', $product_names), $group_of_quantity, $group_of_quantity - ( $quantity % $group_of_quantity )));

                return;
            }
        }
    }

    /**
     * Add respective error message dpeending on rules checked
     *
     * @todo remove deprecated woocommerce global and use WC() in future wc versions
     * @access public
     * @return void
     */
    public function check_rules($product, $quantity, $minimum_quantity, $maximum_quantity, $group_of_quantity)
    {
        if ( $minimum_quantity > 0 && $quantity < $minimum_quantity ) {

            $this->add_error(sprintf(__('The minimum allowed quantity for %s is %s - please increase the quantity in your cart.', 'crisop'), $product->get_title(), $minimum_quantity));

        } elseif ( $maximum_quantity > 0 && $quantity > $maximum_quantity ) {

            $this->add_error(sprintf(__('The maximum allowed quantity for %s is %s - please decrease the quantity in your cart.', 'crisop'), $product->get_title(), $maximum_quantity));

        }

        if ( $group_of_quantity > 0 && ( $quantity % $group_of_quantity ) ) {

            $this->add_error(sprintf(__('%s must be bought in groups of %d. Please add or decrease another %d to continue.', 'crisop'), $product->get_title(), $group_of_quantity, $group_of_quantity - ( $quantity % $group_of_quantity )));
        }
    }

    /**
     * Add to cart validation
     *
     * @todo remove deprecated woocommerce global and use WC() in future wc versions
     * @access public
     * @param mixed $pass
     * @param mixed $product_id
     * @param mixed $quantity
     * @return void
     */
    public function add_to_cart($pass, $product_id, $quantity, $variation_id = 0)
    {
        $rule_for_variaton = false;

        if ($variation_id) {

            $min_max_rules = get_post_meta($variation_id, 'min_max_rules', true);

            if ('yes' === $min_max_rules) {

                $maximum_quantity = absint(get_post_meta($variation_id, 'variation_maximum_allowed_quantity', true));
                $minimum_quantity = absint(get_post_meta($variation_id, 'variation_minimum_allowed_quantity', true));
                $rule_for_variaton = true;

            } else {

                $maximum_quantity = absint(get_post_meta($product_id, 'maximum_allowed_quantity', true));
                $minimum_quantity = absint(get_post_meta($product_id, 'minimum_allowed_quantity', true));
            }

        } else {

            $maximum_quantity = absint(get_post_meta($product_id, 'maximum_allowed_quantity', true));
            $minimum_quantity = absint(get_post_meta($product_id, 'minimum_allowed_quantity', true));
        }

        $total_quantity = $quantity;

        // Count items
        foreach (WC()->cart->get_cart() as $cart_item_key => $values) {

            if ($rule_for_variaton) {
                if ($values['variation_id'] == $variation_id) {
                    $total_quantity += $values['quantity'];
                }
            } else {
                if ($values['product_id'] == $product_id) {
                    $total_quantity += $values['quantity'];
                }
            }
        }

        if (isset($maximum_quantity) && $maximum_quantity > 0) {
            if ($total_quantity > 0 && $total_quantity > $maximum_quantity) {

                $_product = function_exists('get_product') ? get_product($product_id) : new WC_Product($product_id);

                $this->add_error(sprintf(__('The maximum allowed quantity for %s is %d (you currently have %s in your cart).', 'crisop'), $_product->get_title(), $maximum_quantity, $total_quantity - $quantity));

                $pass = false;
            }
        }

        if (isset($minimum_quantity) && $minimum_quantity > 0) {
            if ($total_quantity < $minimum_quantity) {

                $_product = function_exists('get_product') ? get_product($product_id) : new WC_Product($product_id);

                $this->add_error(sprintf(__('The minimum allowed quantity for %s is %d (you currently have %s in your cart).', 'crisop'), $_product->get_title(), $minimum_quantity, $total_quantity - $quantity));

                $pass = false;
            }
        }

        return $pass;
    }

    /**
     * Updates the quantity arguments
     *
	 * @return array
     */
    function update_quantity_args($data, $product)
    {
        $product_id        = $product->get_id();
        $group_of_quantity = get_post_meta($product_id, 'group_of_quantity', true);
        $minimum_quantity  = get_post_meta($product_id, 'minimum_allowed_quantity', true);
        $maximum_quantity  = get_post_meta($product_id, 'maximum_allowed_quantity', true);

        // if variable product, only apply in cart
        if (is_cart() && isset($product->variation_id)) {

            $min_max_rules = get_post_meta($product->variation_id, 'min_max_rules', true);
            $min_max_rules = 'no' === $min_max_rules || empty($min_max_rules) ? false : true;

            $variation_minimum_quantity  = get_post_meta($product->variation_id, 'variation_minimum_allowed_quantity', true);
            $variation_maximum_quantity  = get_post_meta($product->variation_id, 'variation_maximum_allowed_quantity', true);
            $variation_group_of_quantity = get_post_meta($product->variation_id, 'variation_group_of_quantity', true);

            // override product level
            if ($min_max_rules && $variation_minimum_quantity) {
                $minimum_quantity = $variation_minimum_quantity;
            }

            // override product level
            if ($min_max_rules && $variation_maximum_quantity) {
                $maximum_quantity = $variation_maximum_quantity;
            }

            // override product level
            if ($min_max_rules && $variation_group_of_quantity) {
                $group_of_quantity = $variation_group_of_quantity;
            }
        }

        if ($minimum_quantity) {
            if ($product->managing_stock() && $product->backorders_allowed() && absint($minimum_quantity) > $product->get_stock_quantity()) {
                $data['min_value'] = $product->get_stock_quantity();
            } else {
                $data['min_value'] = $minimum_quantity;
            }
        }

        if ($maximum_quantity) {
            if ($product->managing_stock() && $product->backorders_allowed()) {
                $data['max_value'] = $maximum_quantity;
            } elseif ($product->managing_stock() && absint($maximum_quantity) > $product->get_stock_quantity()) {
                $data['max_value'] = $product->get_stock_quantity();
            } else {
                $data['max_value'] = $maximum_quantity;
            }
        }

        if ($group_of_quantity) {
            $data['step'] = 1;

            // if both minimum and maximum quantity are set, make sure both are equally divisble by qroup of quantity
            if ($maximum_quantity && $minimum_quantity) {
                if (absint($maximum_quantity) % absint($group_of_quantity) === 0 && absint($minimum_quantity) % absint($group_of_quantity) === 0) {
                    $data['step'] = $group_of_quantity;
                }
            } elseif (!$maximum_quantity || absint($maximum_quantity) % absint($group_of_quantity) === 0) {
                $data['step'] = $group_of_quantity;
            }

            // set a new minimum if group of is set but not minimum
            if (!$minimum_quantity) {
                $data['min_value'] = $group_of_quantity;
            }
        }

        // don't apply for cart as cart has qty already pre-filled
        if (!is_cart()) {
            $data['input_value'] = !empty($minimum_quantity) ? $minimum_quantity : $data['input_value'];
        }

        return $data;
    }

    /**
     * Adds variation min max settings to the localized variation parameters to be used by JS
     *
     * @access public
     * @param array $data
     * @param obhect $product
     * @param object $variation
     * @return array $data
     */
    function available_variation($data, $product, $variation)
    {
        $product_id        = $product->get_id();
        $variation_id      = $variation->get_id();
        $min_max_rules     = get_post_meta($variation_id, 'min_max_rules', true);
        $min_max_rules     = 'no' === $min_max_rules || empty($min_max_rules) ? false : true;
        $minimum_quantity  = get_post_meta($product_id, 'minimum_allowed_quantity', true);
        $maximum_quantity  = get_post_meta($product_id, 'maximum_allowed_quantity', true);
        $group_of_quantity = get_post_meta($product_id, 'group_of_quantity', true);

        $variation_minimum_quantity  = get_post_meta($variation_id, 'variation_minimum_allowed_quantity', true);
        $variation_maximum_quantity  = get_post_meta($variation_id, 'variation_maximum_allowed_quantity', true);
        $variation_group_of_quantity = get_post_meta($variation_id, 'variation_group_of_quantity', true);

        // override product level
        if ($variation->managing_stock()) {
            $product = $variation;
        }

        // override product level
        if ($min_max_rules && $variation_minimum_quantity) {
            $minimum_quantity = $variation_minimum_quantity;
        }

        // override product level
        if ($min_max_rules && $variation_maximum_quantity) {
            $maximum_quantity = $variation_maximum_quantity;
        }

        // override product level
        if ($min_max_rules && $variation_group_of_quantity) {
            $group_of_quantity = $variation_group_of_quantity;
        }

        if ($minimum_quantity) {
            if ($product->managing_stock() && $product->backorders_allowed() && absint($minimum_quantity) > $product->get_stock_quantity()) {
                $data['min_qty'] = $product->get_stock_quantity();
            } else {
                $data['min_qty'] = $minimum_quantity;
            }
        }

        if ($maximum_quantity) {
            if ($product->managing_stock() && $product->backorders_allowed()) {
                $data['max_qty'] = $maximum_quantity;
            } elseif ($product->managing_stock() && absint($maximum_quantity) > $product->get_stock_quantity()) {
                $data['max_qty'] = $product->get_stock_quantity();
            } else {
                $data['max_qty'] = $maximum_quantity;
            }
        }

        if ($group_of_quantity) {
            $data['step'] = 1;

            // if both minimum and maximum quantity are set, make sure both are equally divisble by qroup of quantity
            if ($maximum_quantity && $minimum_quantity) {
                if (absint($maximum_quantity) % absint($group_of_quantity) === 0 && absint($minimum_quantity) % absint($group_of_quantity) === 0) {
                    $data['step'] = $group_of_quantity;
                }
            } elseif (!$maximum_quantity || absint($maximum_quantity) % absint($group_of_quantity) === 0) {
                $data['step'] = $group_of_quantity;
            }
        }

        // don't apply for cart as cart has qty already pre-filled
        if (!is_cart()) {
            $data['input_value'] = !empty($minimum_quantity) ? $minimum_quantity : 1;
        }

        return $data;
    }
}

if ( !function_exists( 'crisop_custom_stock_status_filter' ) ) {
    add_action( 'woocommerce_product_query', 'crisop_custom_stock_status_filter', 10, 2 );
    function crisop_custom_stock_status_filter($query)
    {
        if ( isset( $_GET['stock_status'] ) && $_GET['stock_status'] === 'instock' ) {
            $query->set('meta_query', array(
                array(
                    'key'     => '_stock_status',
                    'value'   => 'instock',
                    'compare' => '='
                )
            ));
        }

        if ( isset( $_GET['on_sale'] ) && $_GET['on_sale'] == 'onsale' ) {
            $query->set ( 'post__in', wc_get_product_ids_on_sale() );
        }
    }
}

if ( !function_exists( 'ninetheme_shop_loop_categories' ) ) {
    add_action('ninetheme_shop_before_loop','ninetheme_shop_loop_categories', 11 );
    function ninetheme_shop_loop_categories()
    {
        $mode = woocommerce_get_loop_display_mode();
        if ( $mode == 'subcategories' || $mode == 'both' ) {
            $column = ninetheme_wc_product_column();
            $column = apply_filters( 'ninetheme_products_column', $column );
            echo '<div class="ninetheme-shop-categories row '.$column.'">'.woocommerce_maybe_show_product_subcategories().'</div>';
        }
    }
}
